/* Generated by Cython 0.29.21 */

/* BEGIN: Cython Metadata
{
    "distutils": {
        "name": "MorphologicalAnalysis.FsmParseList",
        "sources": [
            "MorphologicalAnalysis/FsmParseList.pyx"
        ]
    },
    "module_name": "MorphologicalAnalysis.FsmParseList"
}
END: Cython Metadata */

#define PY_SSIZE_T_CLEAN
#include "Python.h"
#ifndef Py_PYTHON_H
    #error Python headers needed to compile C extensions, please install development version of Python.
#elif PY_VERSION_HEX < 0x02060000 || (0x03000000 <= PY_VERSION_HEX && PY_VERSION_HEX < 0x03030000)
    #error Cython requires Python 2.6+ or Python 3.3+.
#else
#define CYTHON_ABI "0_29_21"
#define CYTHON_HEX_VERSION 0x001D15F0
#define CYTHON_FUTURE_DIVISION 1
#include <stddef.h>
#ifndef offsetof
  #define offsetof(type, member) ( (size_t) & ((type*)0) -> member )
#endif
#if !defined(WIN32) && !defined(MS_WINDOWS)
  #ifndef __stdcall
    #define __stdcall
  #endif
  #ifndef __cdecl
    #define __cdecl
  #endif
  #ifndef __fastcall
    #define __fastcall
  #endif
#endif
#ifndef DL_IMPORT
  #define DL_IMPORT(t) t
#endif
#ifndef DL_EXPORT
  #define DL_EXPORT(t) t
#endif
#define __PYX_COMMA ,
#ifndef HAVE_LONG_LONG
  #if PY_VERSION_HEX >= 0x02070000
    #define HAVE_LONG_LONG
  #endif
#endif
#ifndef PY_LONG_LONG
  #define PY_LONG_LONG LONG_LONG
#endif
#ifndef Py_HUGE_VAL
  #define Py_HUGE_VAL HUGE_VAL
#endif
#ifdef PYPY_VERSION
  #define CYTHON_COMPILING_IN_PYPY 1
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #undef CYTHON_USE_TYPE_SLOTS
  #define CYTHON_USE_TYPE_SLOTS 0
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #if PY_VERSION_HEX < 0x03050000
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #undef CYTHON_USE_UNICODE_INTERNALS
  #define CYTHON_USE_UNICODE_INTERNALS 0
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #undef CYTHON_AVOID_BORROWED_REFS
  #define CYTHON_AVOID_BORROWED_REFS 1
  #undef CYTHON_ASSUME_SAFE_MACROS
  #define CYTHON_ASSUME_SAFE_MACROS 0
  #undef CYTHON_UNPACK_METHODS
  #define CYTHON_UNPACK_METHODS 0
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#elif defined(PYSTON_VERSION)
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 1
  #define CYTHON_COMPILING_IN_CPYTHON 0
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #undef CYTHON_USE_PYTYPE_LOOKUP
  #define CYTHON_USE_PYTYPE_LOOKUP 0
  #undef CYTHON_USE_ASYNC_SLOTS
  #define CYTHON_USE_ASYNC_SLOTS 0
  #undef CYTHON_USE_PYLIST_INTERNALS
  #define CYTHON_USE_PYLIST_INTERNALS 0
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #undef CYTHON_USE_UNICODE_WRITER
  #define CYTHON_USE_UNICODE_WRITER 0
  #undef CYTHON_USE_PYLONG_INTERNALS
  #define CYTHON_USE_PYLONG_INTERNALS 0
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #undef CYTHON_FAST_THREAD_STATE
  #define CYTHON_FAST_THREAD_STATE 0
  #undef CYTHON_FAST_PYCALL
  #define CYTHON_FAST_PYCALL 0
  #undef CYTHON_PEP489_MULTI_PHASE_INIT
  #define CYTHON_PEP489_MULTI_PHASE_INIT 0
  #undef CYTHON_USE_TP_FINALIZE
  #define CYTHON_USE_TP_FINALIZE 0
  #undef CYTHON_USE_DICT_VERSIONS
  #define CYTHON_USE_DICT_VERSIONS 0
  #undef CYTHON_USE_EXC_INFO_STACK
  #define CYTHON_USE_EXC_INFO_STACK 0
#else
  #define CYTHON_COMPILING_IN_PYPY 0
  #define CYTHON_COMPILING_IN_PYSTON 0
  #define CYTHON_COMPILING_IN_CPYTHON 1
  #ifndef CYTHON_USE_TYPE_SLOTS
    #define CYTHON_USE_TYPE_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYTYPE_LOOKUP
    #define CYTHON_USE_PYTYPE_LOOKUP 0
  #elif !defined(CYTHON_USE_PYTYPE_LOOKUP)
    #define CYTHON_USE_PYTYPE_LOOKUP 1
  #endif
  #if PY_MAJOR_VERSION < 3
    #undef CYTHON_USE_ASYNC_SLOTS
    #define CYTHON_USE_ASYNC_SLOTS 0
  #elif !defined(CYTHON_USE_ASYNC_SLOTS)
    #define CYTHON_USE_ASYNC_SLOTS 1
  #endif
  #if PY_VERSION_HEX < 0x02070000
    #undef CYTHON_USE_PYLONG_INTERNALS
    #define CYTHON_USE_PYLONG_INTERNALS 0
  #elif !defined(CYTHON_USE_PYLONG_INTERNALS)
    #define CYTHON_USE_PYLONG_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_PYLIST_INTERNALS
    #define CYTHON_USE_PYLIST_INTERNALS 1
  #endif
  #ifndef CYTHON_USE_UNICODE_INTERNALS
    #define CYTHON_USE_UNICODE_INTERNALS 1
  #endif
  #if PY_VERSION_HEX < 0x030300F0
    #undef CYTHON_USE_UNICODE_WRITER
    #define CYTHON_USE_UNICODE_WRITER 0
  #elif !defined(CYTHON_USE_UNICODE_WRITER)
    #define CYTHON_USE_UNICODE_WRITER 1
  #endif
  #ifndef CYTHON_AVOID_BORROWED_REFS
    #define CYTHON_AVOID_BORROWED_REFS 0
  #endif
  #ifndef CYTHON_ASSUME_SAFE_MACROS
    #define CYTHON_ASSUME_SAFE_MACROS 1
  #endif
  #ifndef CYTHON_UNPACK_METHODS
    #define CYTHON_UNPACK_METHODS 1
  #endif
  #ifndef CYTHON_FAST_THREAD_STATE
    #define CYTHON_FAST_THREAD_STATE 1
  #endif
  #ifndef CYTHON_FAST_PYCALL
    #define CYTHON_FAST_PYCALL 1
  #endif
  #ifndef CYTHON_PEP489_MULTI_PHASE_INIT
    #define CYTHON_PEP489_MULTI_PHASE_INIT (PY_VERSION_HEX >= 0x03050000)
  #endif
  #ifndef CYTHON_USE_TP_FINALIZE
    #define CYTHON_USE_TP_FINALIZE (PY_VERSION_HEX >= 0x030400a1)
  #endif
  #ifndef CYTHON_USE_DICT_VERSIONS
    #define CYTHON_USE_DICT_VERSIONS (PY_VERSION_HEX >= 0x030600B1)
  #endif
  #ifndef CYTHON_USE_EXC_INFO_STACK
    #define CYTHON_USE_EXC_INFO_STACK (PY_VERSION_HEX >= 0x030700A3)
  #endif
#endif
#if !defined(CYTHON_FAST_PYCCALL)
#define CYTHON_FAST_PYCCALL  (CYTHON_FAST_PYCALL && PY_VERSION_HEX >= 0x030600B1)
#endif
#if CYTHON_USE_PYLONG_INTERNALS
  #include "longintrepr.h"
  #undef SHIFT
  #undef BASE
  #undef MASK
  #ifdef SIZEOF_VOID_P
    enum { __pyx_check_sizeof_voidp = 1 / (int)(SIZEOF_VOID_P == sizeof(void*)) };
  #endif
#endif
#ifndef __has_attribute
  #define __has_attribute(x) 0
#endif
#ifndef __has_cpp_attribute
  #define __has_cpp_attribute(x) 0
#endif
#ifndef CYTHON_RESTRICT
  #if defined(__GNUC__)
    #define CYTHON_RESTRICT __restrict__
  #elif defined(_MSC_VER) && _MSC_VER >= 1400
    #define CYTHON_RESTRICT __restrict
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_RESTRICT restrict
  #else
    #define CYTHON_RESTRICT
  #endif
#endif
#ifndef CYTHON_UNUSED
# if defined(__GNUC__)
#   if !(defined(__cplusplus)) || (__GNUC__ > 3 || (__GNUC__ == 3 && __GNUC_MINOR__ >= 4))
#     define CYTHON_UNUSED __attribute__ ((__unused__))
#   else
#     define CYTHON_UNUSED
#   endif
# elif defined(__ICC) || (defined(__INTEL_COMPILER) && !defined(_MSC_VER))
#   define CYTHON_UNUSED __attribute__ ((__unused__))
# else
#   define CYTHON_UNUSED
# endif
#endif
#ifndef CYTHON_MAYBE_UNUSED_VAR
#  if defined(__cplusplus)
     template<class T> void CYTHON_MAYBE_UNUSED_VAR( const T& ) { }
#  else
#    define CYTHON_MAYBE_UNUSED_VAR(x) (void)(x)
#  endif
#endif
#ifndef CYTHON_NCP_UNUSED
# if CYTHON_COMPILING_IN_CPYTHON
#  define CYTHON_NCP_UNUSED
# else
#  define CYTHON_NCP_UNUSED CYTHON_UNUSED
# endif
#endif
#define __Pyx_void_to_None(void_result) ((void)(void_result), Py_INCREF(Py_None), Py_None)
#ifdef _MSC_VER
    #ifndef _MSC_STDINT_H_
        #if _MSC_VER < 1300
           typedef unsigned char     uint8_t;
           typedef unsigned int      uint32_t;
        #else
           typedef unsigned __int8   uint8_t;
           typedef unsigned __int32  uint32_t;
        #endif
    #endif
#else
   #include <stdint.h>
#endif
#ifndef CYTHON_FALLTHROUGH
  #if defined(__cplusplus) && __cplusplus >= 201103L
    #if __has_cpp_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH [[fallthrough]]
    #elif __has_cpp_attribute(clang::fallthrough)
      #define CYTHON_FALLTHROUGH [[clang::fallthrough]]
    #elif __has_cpp_attribute(gnu::fallthrough)
      #define CYTHON_FALLTHROUGH [[gnu::fallthrough]]
    #endif
  #endif
  #ifndef CYTHON_FALLTHROUGH
    #if __has_attribute(fallthrough)
      #define CYTHON_FALLTHROUGH __attribute__((fallthrough))
    #else
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
  #if defined(__clang__ ) && defined(__apple_build_version__)
    #if __apple_build_version__ < 7000000
      #undef  CYTHON_FALLTHROUGH
      #define CYTHON_FALLTHROUGH
    #endif
  #endif
#endif

#ifndef CYTHON_INLINE
  #if defined(__clang__)
    #define CYTHON_INLINE __inline__ __attribute__ ((__unused__))
  #elif defined(__GNUC__)
    #define CYTHON_INLINE __inline__
  #elif defined(_MSC_VER)
    #define CYTHON_INLINE __inline
  #elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define CYTHON_INLINE inline
  #else
    #define CYTHON_INLINE
  #endif
#endif

#if CYTHON_COMPILING_IN_PYPY && PY_VERSION_HEX < 0x02070600 && !defined(Py_OptimizeFlag)
  #define Py_OptimizeFlag 0
#endif
#define __PYX_BUILD_PY_SSIZE_T "n"
#define CYTHON_FORMAT_SSIZE_T "z"
#if PY_MAJOR_VERSION < 3
  #define __Pyx_BUILTIN_MODULE_NAME "__builtin__"
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a+k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
  #define __Pyx_DefaultClassType PyClass_Type
#else
  #define __Pyx_BUILTIN_MODULE_NAME "builtins"
#if PY_VERSION_HEX >= 0x030800A4 && PY_VERSION_HEX < 0x030800B2
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, 0, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#else
  #define __Pyx_PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)\
          PyCode_New(a, k, l, s, f, code, c, n, v, fv, cell, fn, name, fline, lnos)
#endif
  #define __Pyx_DefaultClassType PyType_Type
#endif
#ifndef Py_TPFLAGS_CHECKTYPES
  #define Py_TPFLAGS_CHECKTYPES 0
#endif
#ifndef Py_TPFLAGS_HAVE_INDEX
  #define Py_TPFLAGS_HAVE_INDEX 0
#endif
#ifndef Py_TPFLAGS_HAVE_NEWBUFFER
  #define Py_TPFLAGS_HAVE_NEWBUFFER 0
#endif
#ifndef Py_TPFLAGS_HAVE_FINALIZE
  #define Py_TPFLAGS_HAVE_FINALIZE 0
#endif
#ifndef METH_STACKLESS
  #define METH_STACKLESS 0
#endif
#if PY_VERSION_HEX <= 0x030700A3 || !defined(METH_FASTCALL)
  #ifndef METH_FASTCALL
     #define METH_FASTCALL 0x80
  #endif
  typedef PyObject *(*__Pyx_PyCFunctionFast) (PyObject *self, PyObject *const *args, Py_ssize_t nargs);
  typedef PyObject *(*__Pyx_PyCFunctionFastWithKeywords) (PyObject *self, PyObject *const *args,
                                                          Py_ssize_t nargs, PyObject *kwnames);
#else
  #define __Pyx_PyCFunctionFast _PyCFunctionFast
  #define __Pyx_PyCFunctionFastWithKeywords _PyCFunctionFastWithKeywords
#endif
#if CYTHON_FAST_PYCCALL
#define __Pyx_PyFastCFunction_Check(func)\
    ((PyCFunction_Check(func) && (METH_FASTCALL == (PyCFunction_GET_FLAGS(func) & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)))))
#else
#define __Pyx_PyFastCFunction_Check(func) 0
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Malloc)
  #define PyObject_Malloc(s)   PyMem_Malloc(s)
  #define PyObject_Free(p)     PyMem_Free(p)
  #define PyObject_Realloc(p)  PyMem_Realloc(p)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX < 0x030400A1
  #define PyMem_RawMalloc(n)           PyMem_Malloc(n)
  #define PyMem_RawRealloc(p, n)       PyMem_Realloc(p, n)
  #define PyMem_RawFree(p)             PyMem_Free(p)
#endif
#if CYTHON_COMPILING_IN_PYSTON
  #define __Pyx_PyCode_HasFreeVars(co)  PyCode_HasFreeVars(co)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno) PyFrame_SetLineNumber(frame, lineno)
#else
  #define __Pyx_PyCode_HasFreeVars(co)  (PyCode_GetNumFree(co) > 0)
  #define __Pyx_PyFrame_SetLineNumber(frame, lineno)  (frame)->f_lineno = (lineno)
#endif
#if !CYTHON_FAST_THREAD_STATE || PY_VERSION_HEX < 0x02070000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#elif PY_VERSION_HEX >= 0x03060000
  #define __Pyx_PyThreadState_Current _PyThreadState_UncheckedGet()
#elif PY_VERSION_HEX >= 0x03000000
  #define __Pyx_PyThreadState_Current PyThreadState_GET()
#else
  #define __Pyx_PyThreadState_Current _PyThreadState_Current
#endif
#if PY_VERSION_HEX < 0x030700A2 && !defined(PyThread_tss_create) && !defined(Py_tss_NEEDS_INIT)
#include "pythread.h"
#define Py_tss_NEEDS_INIT 0
typedef int Py_tss_t;
static CYTHON_INLINE int PyThread_tss_create(Py_tss_t *key) {
  *key = PyThread_create_key();
  return 0;
}
static CYTHON_INLINE Py_tss_t * PyThread_tss_alloc(void) {
  Py_tss_t *key = (Py_tss_t *)PyObject_Malloc(sizeof(Py_tss_t));
  *key = Py_tss_NEEDS_INIT;
  return key;
}
static CYTHON_INLINE void PyThread_tss_free(Py_tss_t *key) {
  PyObject_Free(key);
}
static CYTHON_INLINE int PyThread_tss_is_created(Py_tss_t *key) {
  return *key != Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE void PyThread_tss_delete(Py_tss_t *key) {
  PyThread_delete_key(*key);
  *key = Py_tss_NEEDS_INIT;
}
static CYTHON_INLINE int PyThread_tss_set(Py_tss_t *key, void *value) {
  return PyThread_set_key_value(*key, value);
}
static CYTHON_INLINE void * PyThread_tss_get(Py_tss_t *key) {
  return PyThread_get_key_value(*key);
}
#endif
#if CYTHON_COMPILING_IN_CPYTHON || defined(_PyDict_NewPresized)
#define __Pyx_PyDict_NewPresized(n)  ((n <= 8) ? PyDict_New() : _PyDict_NewPresized(n))
#else
#define __Pyx_PyDict_NewPresized(n)  PyDict_New()
#endif
#if PY_MAJOR_VERSION >= 3 || CYTHON_FUTURE_DIVISION
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_TrueDivide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceTrueDivide(x,y)
#else
  #define __Pyx_PyNumber_Divide(x,y)         PyNumber_Divide(x,y)
  #define __Pyx_PyNumber_InPlaceDivide(x,y)  PyNumber_InPlaceDivide(x,y)
#endif
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1 && CYTHON_USE_UNICODE_INTERNALS
#define __Pyx_PyDict_GetItemStr(dict, name)  _PyDict_GetItem_KnownHash(dict, name, ((PyASCIIObject *) name)->hash)
#else
#define __Pyx_PyDict_GetItemStr(dict, name)  PyDict_GetItem(dict, name)
#endif
#if PY_VERSION_HEX > 0x03030000 && defined(PyUnicode_KIND)
  #define CYTHON_PEP393_ENABLED 1
  #define __Pyx_PyUnicode_READY(op)       (likely(PyUnicode_IS_READY(op)) ?\
                                              0 : _PyUnicode_Ready((PyObject *)(op)))
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_LENGTH(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) PyUnicode_READ_CHAR(u, i)
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   PyUnicode_MAX_CHAR_VALUE(u)
  #define __Pyx_PyUnicode_KIND(u)         PyUnicode_KIND(u)
  #define __Pyx_PyUnicode_DATA(u)         PyUnicode_DATA(u)
  #define __Pyx_PyUnicode_READ(k, d, i)   PyUnicode_READ(k, d, i)
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  PyUnicode_WRITE(k, d, i, ch)
  #if defined(PyUnicode_IS_READY) && defined(PyUnicode_GET_SIZE)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != (likely(PyUnicode_IS_READY(u)) ? PyUnicode_GET_LENGTH(u) : PyUnicode_GET_SIZE(u)))
  #else
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_LENGTH(u))
  #endif
#else
  #define CYTHON_PEP393_ENABLED 0
  #define PyUnicode_1BYTE_KIND  1
  #define PyUnicode_2BYTE_KIND  2
  #define PyUnicode_4BYTE_KIND  4
  #define __Pyx_PyUnicode_READY(op)       (0)
  #define __Pyx_PyUnicode_GET_LENGTH(u)   PyUnicode_GET_SIZE(u)
  #define __Pyx_PyUnicode_READ_CHAR(u, i) ((Py_UCS4)(PyUnicode_AS_UNICODE(u)[i]))
  #define __Pyx_PyUnicode_MAX_CHAR_VALUE(u)   ((sizeof(Py_UNICODE) == 2) ? 65535 : 1114111)
  #define __Pyx_PyUnicode_KIND(u)         (sizeof(Py_UNICODE))
  #define __Pyx_PyUnicode_DATA(u)         ((void*)PyUnicode_AS_UNICODE(u))
  #define __Pyx_PyUnicode_READ(k, d, i)   ((void)(k), (Py_UCS4)(((Py_UNICODE*)d)[i]))
  #define __Pyx_PyUnicode_WRITE(k, d, i, ch)  (((void)(k)), ((Py_UNICODE*)d)[i] = ch)
  #define __Pyx_PyUnicode_IS_TRUE(u)      (0 != PyUnicode_GET_SIZE(u))
#endif
#if CYTHON_COMPILING_IN_PYPY
  #define __Pyx_PyUnicode_Concat(a, b)      PyNumber_Add(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  PyNumber_Add(a, b)
#else
  #define __Pyx_PyUnicode_Concat(a, b)      PyUnicode_Concat(a, b)
  #define __Pyx_PyUnicode_ConcatSafe(a, b)  ((unlikely((a) == Py_None) || unlikely((b) == Py_None)) ?\
      PyNumber_Add(a, b) : __Pyx_PyUnicode_Concat(a, b))
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyUnicode_Contains)
  #define PyUnicode_Contains(u, s)  PySequence_Contains(u, s)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyByteArray_Check)
  #define PyByteArray_Check(obj)  PyObject_TypeCheck(obj, &PyByteArray_Type)
#endif
#if CYTHON_COMPILING_IN_PYPY && !defined(PyObject_Format)
  #define PyObject_Format(obj, fmt)  PyObject_CallMethod(obj, "__format__", "O", fmt)
#endif
#define __Pyx_PyString_FormatSafe(a, b)   ((unlikely((a) == Py_None || (PyString_Check(b) && !PyString_CheckExact(b)))) ? PyNumber_Remainder(a, b) : __Pyx_PyString_Format(a, b))
#define __Pyx_PyUnicode_FormatSafe(a, b)  ((unlikely((a) == Py_None || (PyUnicode_Check(b) && !PyUnicode_CheckExact(b)))) ? PyNumber_Remainder(a, b) : PyUnicode_Format(a, b))
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyString_Format(a, b)  PyUnicode_Format(a, b)
#else
  #define __Pyx_PyString_Format(a, b)  PyString_Format(a, b)
#endif
#if PY_MAJOR_VERSION < 3 && !defined(PyObject_ASCII)
  #define PyObject_ASCII(o)            PyObject_Repr(o)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBaseString_Type            PyUnicode_Type
  #define PyStringObject               PyUnicodeObject
  #define PyString_Type                PyUnicode_Type
  #define PyString_Check               PyUnicode_Check
  #define PyString_CheckExact          PyUnicode_CheckExact
#ifndef PyObject_Unicode
  #define PyObject_Unicode             PyObject_Str
#endif
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyBaseString_Check(obj) PyUnicode_Check(obj)
  #define __Pyx_PyBaseString_CheckExact(obj) PyUnicode_CheckExact(obj)
#else
  #define __Pyx_PyBaseString_Check(obj) (PyString_Check(obj) || PyUnicode_Check(obj))
  #define __Pyx_PyBaseString_CheckExact(obj) (PyString_CheckExact(obj) || PyUnicode_CheckExact(obj))
#endif
#ifndef PySet_CheckExact
  #define PySet_CheckExact(obj)        (Py_TYPE(obj) == &PySet_Type)
#endif
#if PY_VERSION_HEX >= 0x030900A4
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_SET_REFCNT(obj, refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SET_SIZE(obj, size)
#else
  #define __Pyx_SET_REFCNT(obj, refcnt) Py_REFCNT(obj) = (refcnt)
  #define __Pyx_SET_SIZE(obj, size) Py_SIZE(obj) = (size)
#endif
#if CYTHON_ASSUME_SAFE_MACROS
  #define __Pyx_PySequence_SIZE(seq)  Py_SIZE(seq)
#else
  #define __Pyx_PySequence_SIZE(seq)  PySequence_Size(seq)
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyIntObject                  PyLongObject
  #define PyInt_Type                   PyLong_Type
  #define PyInt_Check(op)              PyLong_Check(op)
  #define PyInt_CheckExact(op)         PyLong_CheckExact(op)
  #define PyInt_FromString             PyLong_FromString
  #define PyInt_FromUnicode            PyLong_FromUnicode
  #define PyInt_FromLong               PyLong_FromLong
  #define PyInt_FromSize_t             PyLong_FromSize_t
  #define PyInt_FromSsize_t            PyLong_FromSsize_t
  #define PyInt_AsLong                 PyLong_AsLong
  #define PyInt_AS_LONG                PyLong_AS_LONG
  #define PyInt_AsSsize_t              PyLong_AsSsize_t
  #define PyInt_AsUnsignedLongMask     PyLong_AsUnsignedLongMask
  #define PyInt_AsUnsignedLongLongMask PyLong_AsUnsignedLongLongMask
  #define PyNumber_Int                 PyNumber_Long
#endif
#if PY_MAJOR_VERSION >= 3
  #define PyBoolObject                 PyLongObject
#endif
#if PY_MAJOR_VERSION >= 3 && CYTHON_COMPILING_IN_PYPY
  #ifndef PyUnicode_InternFromString
    #define PyUnicode_InternFromString(s) PyUnicode_FromString(s)
  #endif
#endif
#if PY_VERSION_HEX < 0x030200A4
  typedef long Py_hash_t;
  #define __Pyx_PyInt_FromHash_t PyInt_FromLong
  #define __Pyx_PyInt_AsHash_t   PyInt_AsLong
#else
  #define __Pyx_PyInt_FromHash_t PyInt_FromSsize_t
  #define __Pyx_PyInt_AsHash_t   PyInt_AsSsize_t
#endif
#if PY_MAJOR_VERSION >= 3
  #define __Pyx_PyMethod_New(func, self, klass) ((self) ? ((void)(klass), PyMethod_New(func, self)) : __Pyx_NewRef(func))
#else
  #define __Pyx_PyMethod_New(func, self, klass) PyMethod_New(func, self, klass)
#endif
#if CYTHON_USE_ASYNC_SLOTS
  #if PY_VERSION_HEX >= 0x030500B1
    #define __Pyx_PyAsyncMethodsStruct PyAsyncMethods
    #define __Pyx_PyType_AsAsync(obj) (Py_TYPE(obj)->tp_as_async)
  #else
    #define __Pyx_PyType_AsAsync(obj) ((__Pyx_PyAsyncMethodsStruct*) (Py_TYPE(obj)->tp_reserved))
  #endif
#else
  #define __Pyx_PyType_AsAsync(obj) NULL
#endif
#ifndef __Pyx_PyAsyncMethodsStruct
    typedef struct {
        unaryfunc am_await;
        unaryfunc am_aiter;
        unaryfunc am_anext;
    } __Pyx_PyAsyncMethodsStruct;
#endif

#if defined(WIN32) || defined(MS_WINDOWS)
  #define _USE_MATH_DEFINES
#endif
#include <math.h>
#ifdef NAN
#define __PYX_NAN() ((float) NAN)
#else
static CYTHON_INLINE float __PYX_NAN() {
  float value;
  memset(&value, 0xFF, sizeof(value));
  return value;
}
#endif
#if defined(__CYGWIN__) && defined(_LDBL_EQ_DBL)
#define __Pyx_truncl trunc
#else
#define __Pyx_truncl truncl
#endif

#define __PYX_MARK_ERR_POS(f_index, lineno) \
    { __pyx_filename = __pyx_f[f_index]; (void)__pyx_filename; __pyx_lineno = lineno; (void)__pyx_lineno; __pyx_clineno = __LINE__; (void)__pyx_clineno; }
#define __PYX_ERR(f_index, lineno, Ln_error) \
    { __PYX_MARK_ERR_POS(f_index, lineno) goto Ln_error; }

#ifndef __PYX_EXTERN_C
  #ifdef __cplusplus
    #define __PYX_EXTERN_C extern "C"
  #else
    #define __PYX_EXTERN_C extern
  #endif
#endif

#define __PYX_HAVE__MorphologicalAnalysis__FsmParseList
#define __PYX_HAVE_API__MorphologicalAnalysis__FsmParseList
/* Early includes */
#ifdef _OPENMP
#include <omp.h>
#endif /* _OPENMP */

#if defined(PYREX_WITHOUT_ASSERTIONS) && !defined(CYTHON_WITHOUT_ASSERTIONS)
#define CYTHON_WITHOUT_ASSERTIONS
#endif

typedef struct {PyObject **p; const char *s; const Py_ssize_t n; const char* encoding;
                const char is_unicode; const char is_str; const char intern; } __Pyx_StringTabEntry;

#define __PYX_DEFAULT_STRING_ENCODING_IS_ASCII 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_UTF8 0
#define __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT (PY_MAJOR_VERSION >= 3 && __PYX_DEFAULT_STRING_ENCODING_IS_UTF8)
#define __PYX_DEFAULT_STRING_ENCODING ""
#define __Pyx_PyObject_FromString __Pyx_PyBytes_FromString
#define __Pyx_PyObject_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#define __Pyx_uchar_cast(c) ((unsigned char)c)
#define __Pyx_long_cast(x) ((long)x)
#define __Pyx_fits_Py_ssize_t(v, type, is_signed)  (\
    (sizeof(type) < sizeof(Py_ssize_t))  ||\
    (sizeof(type) > sizeof(Py_ssize_t) &&\
          likely(v < (type)PY_SSIZE_T_MAX ||\
                 v == (type)PY_SSIZE_T_MAX)  &&\
          (!is_signed || likely(v > (type)PY_SSIZE_T_MIN ||\
                                v == (type)PY_SSIZE_T_MIN)))  ||\
    (sizeof(type) == sizeof(Py_ssize_t) &&\
          (is_signed || likely(v < (type)PY_SSIZE_T_MAX ||\
                               v == (type)PY_SSIZE_T_MAX)))  )
static CYTHON_INLINE int __Pyx_is_valid_index(Py_ssize_t i, Py_ssize_t limit) {
    return (size_t) i < (size_t) limit;
}
#if defined (__cplusplus) && __cplusplus >= 201103L
    #include <cstdlib>
    #define __Pyx_sst_abs(value) std::abs(value)
#elif SIZEOF_INT >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) abs(value)
#elif SIZEOF_LONG >= SIZEOF_SIZE_T
    #define __Pyx_sst_abs(value) labs(value)
#elif defined (_MSC_VER)
    #define __Pyx_sst_abs(value) ((Py_ssize_t)_abs64(value))
#elif defined (__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
    #define __Pyx_sst_abs(value) llabs(value)
#elif defined (__GNUC__)
    #define __Pyx_sst_abs(value) __builtin_llabs(value)
#else
    #define __Pyx_sst_abs(value) ((value<0) ? -value : value)
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject*);
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject*, Py_ssize_t* length);
#define __Pyx_PyByteArray_FromString(s) PyByteArray_FromStringAndSize((const char*)s, strlen((const char*)s))
#define __Pyx_PyByteArray_FromStringAndSize(s, l) PyByteArray_FromStringAndSize((const char*)s, l)
#define __Pyx_PyBytes_FromString        PyBytes_FromString
#define __Pyx_PyBytes_FromStringAndSize PyBytes_FromStringAndSize
static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char*);
#if PY_MAJOR_VERSION < 3
    #define __Pyx_PyStr_FromString        __Pyx_PyBytes_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyBytes_FromStringAndSize
#else
    #define __Pyx_PyStr_FromString        __Pyx_PyUnicode_FromString
    #define __Pyx_PyStr_FromStringAndSize __Pyx_PyUnicode_FromStringAndSize
#endif
#define __Pyx_PyBytes_AsWritableString(s)     ((char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableSString(s)    ((signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsWritableUString(s)    ((unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsString(s)     ((const char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsSString(s)    ((const signed char*) PyBytes_AS_STRING(s))
#define __Pyx_PyBytes_AsUString(s)    ((const unsigned char*) PyBytes_AS_STRING(s))
#define __Pyx_PyObject_AsWritableString(s)    ((char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableSString(s)    ((signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsWritableUString(s)    ((unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsSString(s)    ((const signed char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_AsUString(s)    ((const unsigned char*) __Pyx_PyObject_AsString(s))
#define __Pyx_PyObject_FromCString(s)  __Pyx_PyObject_FromString((const char*)s)
#define __Pyx_PyBytes_FromCString(s)   __Pyx_PyBytes_FromString((const char*)s)
#define __Pyx_PyByteArray_FromCString(s)   __Pyx_PyByteArray_FromString((const char*)s)
#define __Pyx_PyStr_FromCString(s)     __Pyx_PyStr_FromString((const char*)s)
#define __Pyx_PyUnicode_FromCString(s) __Pyx_PyUnicode_FromString((const char*)s)
static CYTHON_INLINE size_t __Pyx_Py_UNICODE_strlen(const Py_UNICODE *u) {
    const Py_UNICODE *u_end = u;
    while (*u_end++) ;
    return (size_t)(u_end - u - 1);
}
#define __Pyx_PyUnicode_FromUnicode(u)       PyUnicode_FromUnicode(u, __Pyx_Py_UNICODE_strlen(u))
#define __Pyx_PyUnicode_FromUnicodeAndLength PyUnicode_FromUnicode
#define __Pyx_PyUnicode_AsUnicode            PyUnicode_AsUnicode
#define __Pyx_NewRef(obj) (Py_INCREF(obj), obj)
#define __Pyx_Owned_Py_None(b) __Pyx_NewRef(Py_None)
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b);
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject*);
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject*);
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x);
#define __Pyx_PySequence_Tuple(obj)\
    (likely(PyTuple_CheckExact(obj)) ? __Pyx_NewRef(obj) : PySequence_Tuple(obj))
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject*);
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t);
#if CYTHON_ASSUME_SAFE_MACROS
#define __pyx_PyFloat_AsDouble(x) (PyFloat_CheckExact(x) ? PyFloat_AS_DOUBLE(x) : PyFloat_AsDouble(x))
#else
#define __pyx_PyFloat_AsDouble(x) PyFloat_AsDouble(x)
#endif
#define __pyx_PyFloat_AsFloat(x) ((float) __pyx_PyFloat_AsDouble(x))
#if PY_MAJOR_VERSION >= 3
#define __Pyx_PyNumber_Int(x) (PyLong_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Long(x))
#else
#define __Pyx_PyNumber_Int(x) (PyInt_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Int(x))
#endif
#define __Pyx_PyNumber_Float(x) (PyFloat_CheckExact(x) ? __Pyx_NewRef(x) : PyNumber_Float(x))
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
static int __Pyx_sys_getdefaultencoding_not_ascii;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    PyObject* ascii_chars_u = NULL;
    PyObject* ascii_chars_b = NULL;
    const char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    if (strcmp(default_encoding_c, "ascii") == 0) {
        __Pyx_sys_getdefaultencoding_not_ascii = 0;
    } else {
        char ascii_chars[128];
        int c;
        for (c = 0; c < 128; c++) {
            ascii_chars[c] = c;
        }
        __Pyx_sys_getdefaultencoding_not_ascii = 1;
        ascii_chars_u = PyUnicode_DecodeASCII(ascii_chars, 128, NULL);
        if (!ascii_chars_u) goto bad;
        ascii_chars_b = PyUnicode_AsEncodedString(ascii_chars_u, default_encoding_c, NULL);
        if (!ascii_chars_b || !PyBytes_Check(ascii_chars_b) || memcmp(ascii_chars, PyBytes_AS_STRING(ascii_chars_b), 128) != 0) {
            PyErr_Format(
                PyExc_ValueError,
                "This module compiled with c_string_encoding=ascii, but default encoding '%.200s' is not a superset of ascii.",
                default_encoding_c);
            goto bad;
        }
        Py_DECREF(ascii_chars_u);
        Py_DECREF(ascii_chars_b);
    }
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    Py_XDECREF(ascii_chars_u);
    Py_XDECREF(ascii_chars_b);
    return -1;
}
#endif
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT && PY_MAJOR_VERSION >= 3
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_DecodeUTF8(c_str, size, NULL)
#else
#define __Pyx_PyUnicode_FromStringAndSize(c_str, size) PyUnicode_Decode(c_str, size, __PYX_DEFAULT_STRING_ENCODING, NULL)
#if __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
static char* __PYX_DEFAULT_STRING_ENCODING;
static int __Pyx_init_sys_getdefaultencoding_params(void) {
    PyObject* sys;
    PyObject* default_encoding = NULL;
    char* default_encoding_c;
    sys = PyImport_ImportModule("sys");
    if (!sys) goto bad;
    default_encoding = PyObject_CallMethod(sys, (char*) (const char*) "getdefaultencoding", NULL);
    Py_DECREF(sys);
    if (!default_encoding) goto bad;
    default_encoding_c = PyBytes_AsString(default_encoding);
    if (!default_encoding_c) goto bad;
    __PYX_DEFAULT_STRING_ENCODING = (char*) malloc(strlen(default_encoding_c) + 1);
    if (!__PYX_DEFAULT_STRING_ENCODING) goto bad;
    strcpy(__PYX_DEFAULT_STRING_ENCODING, default_encoding_c);
    Py_DECREF(default_encoding);
    return 0;
bad:
    Py_XDECREF(default_encoding);
    return -1;
}
#endif
#endif


/* Test for GCC > 2.95 */
#if defined(__GNUC__)     && (__GNUC__ > 2 || (__GNUC__ == 2 && (__GNUC_MINOR__ > 95)))
  #define likely(x)   __builtin_expect(!!(x), 1)
  #define unlikely(x) __builtin_expect(!!(x), 0)
#else /* !__GNUC__ or GCC < 2.95 */
  #define likely(x)   (x)
  #define unlikely(x) (x)
#endif /* __GNUC__ */
static CYTHON_INLINE void __Pyx_pretend_to_initialize(void* ptr) { (void)ptr; }

static PyObject *__pyx_m = NULL;
static PyObject *__pyx_d;
static PyObject *__pyx_b;
static PyObject *__pyx_cython_runtime = NULL;
static PyObject *__pyx_empty_tuple;
static PyObject *__pyx_empty_bytes;
static PyObject *__pyx_empty_unicode;
static int __pyx_lineno;
static int __pyx_clineno = 0;
static const char * __pyx_cfilenm= __FILE__;
static const char *__pyx_filename;


static const char *__pyx_f[] = {
  "MorphologicalAnalysis/FsmParseList.pyx",
  "stringsource",
  "Word.pxd",
  "MorphologicalAnalysis/InflectionalGroup.pxd",
  "MorphologicalAnalysis/MorphologicalParse.pxd",
  "MorphologicalAnalysis/State.pxd",
  "MorphologicalAnalysis/FsmParse.pxd",
};

/*--- Type declarations ---*/
struct __pyx_obj_10Dictionary_4Word_Word;
struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup;
struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;
struct __pyx_obj_21MorphologicalAnalysis_5State_State;
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse;
struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList;

/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */
struct __pyx_obj_10Dictionary_4Word_Word {
  PyObject_HEAD
  struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtab;
  PyObject *name;
};


/* "MorphologicalAnalysis/InflectionalGroup.pxd":1
 * cdef class InflectionalGroup:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __IG
 */
struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_vtab;
  PyObject *__pyx___IG;
};


/* "MorphologicalAnalysis/MorphologicalParse.pxd":6
 * 
 * 
 * cdef class MorphologicalParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list inflectional_groups
 */
struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_vtab;
  PyObject *inflectional_groups;
  struct __pyx_obj_10Dictionary_4Word_Word *root;
};


/* "MorphologicalAnalysis/State.pxd":1
 * cdef class State:             # <<<<<<<<<<<<<<
 * 
 *     cdef bint __start_state, __end_state
 */
struct __pyx_obj_21MorphologicalAnalysis_5State_State {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *__pyx_vtab;
  int __pyx___start_state;
  int __pyx___end_state;
  PyObject *__pyx___name;
  PyObject *__pyx___pos;
};


/* "MorphologicalAnalysis/FsmParse.pxd":5
 * 
 * 
 * cdef class FsmParse(MorphologicalParse):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __suffix_list
 */
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse {
  struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse __pyx_base;
  PyObject *__pyx___suffix_list;
  PyObject *__pyx___form_list;
  PyObject *__pyx___transition_list;
  PyObject *__pyx___with_list;
  PyObject *__pyx___initial_pos;
  PyObject *__pyx___pos;
  PyObject *__pyx___form;
  PyObject *__pyx___verb_agreement;
  PyObject *__pyx___possesive_agreement;
};


/* "MorphologicalAnalysis/FsmParseList.pxd":4
 * from MorphologicalAnalysis.FsmParse cimport FsmParse
 * 
 * cdef class FsmParseList:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __fsm_parses
 */
struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList {
  PyObject_HEAD
  struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_vtab;
  PyObject *__pyx___fsm_parses;
};



/* "Dictionary/Word.pxd":1
 * cdef class Word:             # <<<<<<<<<<<<<<
 * 
 *     cdef str name
 */

struct __pyx_vtabstruct_10Dictionary_4Word_Word {
  int (*charCount)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*getName)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*setName)(struct __pyx_obj_10Dictionary_4Word_Word *, PyObject *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  PyObject *(*toCharacters)(struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_10Dictionary_4Word_Word *__pyx_vtabptr_10Dictionary_4Word_Word;


/* "MorphologicalAnalysis/InflectionalGroup.pxd":1
 * cdef class InflectionalGroup:             # <<<<<<<<<<<<<<
 * 
 *     cdef list __IG
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup {
  PyObject *(*getTag)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  PyObject *(*containsCase)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  int (*containsPlural)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
  int (*containsTag)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, PyObject *, int __pyx_skip_dispatch);
  int (*containsPossessive)(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *__pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup;


/* "MorphologicalAnalysis/MorphologicalParse.pxd":6
 * 
 * 
 * cdef class MorphologicalParse:             # <<<<<<<<<<<<<<
 * 
 *     cdef list inflectional_groups
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse {
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWord)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTransitionList)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getInflectionalGroupString)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*getInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*getLastInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int, int __pyx_skip_dispatch);
  int (*tagSize)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*firstInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup *(*lastInflectionalGroup)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_10Dictionary_4Word_Word *(*getWordWithPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getRootPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*lastIGContainsCase)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*lastIGContainsTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  int (*lastIGContainsPossessive)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isCapitalWord)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isNoun)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isVerb)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isRootVerb)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isAdjective)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isProperNoun)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPunctuation)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isCardinal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isOrdinal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isReal)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isNumber)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isTime)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isDate)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isHashTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isEmail)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPercent)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isFraction)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isRange)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isPlural)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*isAuxiliary)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  int (*containsTag)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getTreePos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPronType)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getNumType)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getReflex)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getNumber)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getCase)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getDefinite)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getDegree)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPolarity)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getPerson)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getVoice)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getAspect)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getTense)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getMood)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getVerbForm)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyFeatures)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getUniversalDependencyPos)(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *__pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse;


/* "MorphologicalAnalysis/State.pxd":1
 * cdef class State:             # <<<<<<<<<<<<<<
 * 
 *     cdef bint __start_state, __end_state
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State {
  PyObject *(*getName)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
  PyObject *(*getPos)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
  int (*isEndState)(struct __pyx_obj_21MorphologicalAnalysis_5State_State *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State *__pyx_vtabptr_21MorphologicalAnalysis_5State_State;


/* "MorphologicalAnalysis/FsmParse.pxd":5
 * 
 * 
 * cdef class FsmParse(MorphologicalParse):             # <<<<<<<<<<<<<<
 * 
 *     cdef list __suffix_list
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse {
  struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse __pyx_base;
  PyObject *(*constructInflectionalGroups)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getVerbAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getPossesiveAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*setAgreement)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLastLemmaWithTag)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getLastLemma)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*addSuffix)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, struct __pyx_obj_21MorphologicalAnalysis_5State_State *, PyObject *, PyObject *, PyObject *, PyObject *, int __pyx_skip_dispatch);
  PyObject *(*getSurfaceForm)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*getStartState)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getFinalPos)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getInitialPos)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*setForm)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, PyObject *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_5State_State *(*getFinalSuffix)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*headerTransition)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*pronounTransition)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*transitionList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*suffixList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*withList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*getWithList)(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse;


/* "MorphologicalAnalysis/FsmParseList.pyx":1
 * cdef class FsmParseList:             # <<<<<<<<<<<<<<
 * 
 *     longest_root_exceptions = [
 */

struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList {
  int (*size)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch);
  PyObject *(*addFsmParse)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *(*getFsmParse)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int, int __pyx_skip_dispatch);
  PyObject *(*rootWords)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch);
  PyObject *(*reduceToParsesWithSameRootAndPos)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch);
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *(*getParseWithLongestRootWord)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch);
  PyObject *(*reduceToParsesWithSameRoot)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, PyObject *, int __pyx_skip_dispatch);
  int (*isLongestRootException)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch);
  PyObject *(*constructParseListForDifferentRootWithPos)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch);
  PyObject *(*parsesWithoutPrefixAndSuffix)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch);
};
static struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_vtabptr_21MorphologicalAnalysis_12FsmParseList_FsmParseList;

/* --- Runtime support code (head) --- */
/* Refnanny.proto */
#ifndef CYTHON_REFNANNY
  #define CYTHON_REFNANNY 0
#endif
#if CYTHON_REFNANNY
  typedef struct {
    void (*INCREF)(void*, PyObject*, int);
    void (*DECREF)(void*, PyObject*, int);
    void (*GOTREF)(void*, PyObject*, int);
    void (*GIVEREF)(void*, PyObject*, int);
    void* (*SetupContext)(const char*, int, const char*);
    void (*FinishContext)(void**);
  } __Pyx_RefNannyAPIStruct;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNanny = NULL;
  static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname);
  #define __Pyx_RefNannyDeclarations void *__pyx_refnanny = NULL;
#ifdef WITH_THREAD
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          if (acquire_gil) {\
              PyGILState_STATE __pyx_gilstate_save = PyGILState_Ensure();\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
              PyGILState_Release(__pyx_gilstate_save);\
          } else {\
              __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__);\
          }
#else
  #define __Pyx_RefNannySetupContext(name, acquire_gil)\
          __pyx_refnanny = __Pyx_RefNanny->SetupContext((name), __LINE__, __FILE__)
#endif
  #define __Pyx_RefNannyFinishContext()\
          __Pyx_RefNanny->FinishContext(&__pyx_refnanny)
  #define __Pyx_INCREF(r)  __Pyx_RefNanny->INCREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_DECREF(r)  __Pyx_RefNanny->DECREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GOTREF(r)  __Pyx_RefNanny->GOTREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_GIVEREF(r) __Pyx_RefNanny->GIVEREF(__pyx_refnanny, (PyObject *)(r), __LINE__)
  #define __Pyx_XINCREF(r)  do { if((r) != NULL) {__Pyx_INCREF(r); }} while(0)
  #define __Pyx_XDECREF(r)  do { if((r) != NULL) {__Pyx_DECREF(r); }} while(0)
  #define __Pyx_XGOTREF(r)  do { if((r) != NULL) {__Pyx_GOTREF(r); }} while(0)
  #define __Pyx_XGIVEREF(r) do { if((r) != NULL) {__Pyx_GIVEREF(r);}} while(0)
#else
  #define __Pyx_RefNannyDeclarations
  #define __Pyx_RefNannySetupContext(name, acquire_gil)
  #define __Pyx_RefNannyFinishContext()
  #define __Pyx_INCREF(r) Py_INCREF(r)
  #define __Pyx_DECREF(r) Py_DECREF(r)
  #define __Pyx_GOTREF(r)
  #define __Pyx_GIVEREF(r)
  #define __Pyx_XINCREF(r) Py_XINCREF(r)
  #define __Pyx_XDECREF(r) Py_XDECREF(r)
  #define __Pyx_XGOTREF(r)
  #define __Pyx_XGIVEREF(r)
#endif
#define __Pyx_XDECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_XDECREF(tmp);\
    } while (0)
#define __Pyx_DECREF_SET(r, v) do {\
        PyObject *tmp = (PyObject *) r;\
        r = v; __Pyx_DECREF(tmp);\
    } while (0)
#define __Pyx_CLEAR(r)    do { PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);} while(0)
#define __Pyx_XCLEAR(r)   do { if((r) != NULL) {PyObject* tmp = ((PyObject*)(r)); r = NULL; __Pyx_DECREF(tmp);}} while(0)

/* PyObjectGetAttrStr.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GetAttrStr(o,n) PyObject_GetAttr(o,n)
#endif

/* GetBuiltinName.proto */
static PyObject *__Pyx_GetBuiltinName(PyObject *name);

/* RaiseDoubleKeywords.proto */
static void __Pyx_RaiseDoubleKeywordsError(const char* func_name, PyObject* kw_name);

/* ParseKeywords.proto */
static int __Pyx_ParseOptionalKeywords(PyObject *kwds, PyObject **argnames[],\
    PyObject *kwds2, PyObject *values[], Py_ssize_t num_pos_args,\
    const char* function_name);

/* RaiseArgTupleInvalid.proto */
static void __Pyx_RaiseArgtupleInvalid(const char* func_name, int exact,
    Py_ssize_t num_min, Py_ssize_t num_max, Py_ssize_t num_found);

/* ArgTypeTest.proto */
#define __Pyx_ArgTypeTest(obj, type, none_allowed, name, exact)\
    ((likely((Py_TYPE(obj) == type) | (none_allowed && (obj == Py_None)))) ? 1 :\
        __Pyx__ArgTypeTest(obj, type, name, exact))
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact);

/* GetItemInt.proto */
#define __Pyx_GetItemInt(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Fast(o, (Py_ssize_t)i, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL) :\
               __Pyx_GetItemInt_Generic(o, to_py_func(i))))
#define __Pyx_GetItemInt_List(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_List_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "list index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
#define __Pyx_GetItemInt_Tuple(o, i, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_GetItemInt_Tuple_Fast(o, (Py_ssize_t)i, wraparound, boundscheck) :\
    (PyErr_SetString(PyExc_IndexError, "tuple index out of range"), (PyObject*)NULL))
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              int wraparound, int boundscheck);
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j);
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i,
                                                     int is_list, int wraparound, int boundscheck);

/* PyFunctionFastCall.proto */
#if CYTHON_FAST_PYCALL
#define __Pyx_PyFunction_FastCall(func, args, nargs)\
    __Pyx_PyFunction_FastCallDict((func), (args), (nargs), NULL)
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs);
#else
#define __Pyx_PyFunction_FastCallDict(func, args, nargs, kwargs) _PyFunction_FastCallDict(func, args, nargs, kwargs)
#endif
#define __Pyx_BUILD_ASSERT_EXPR(cond)\
    (sizeof(char [1 - 2*!(cond)]) - 1)
#ifndef Py_MEMBER_SIZE
#define Py_MEMBER_SIZE(type, member) sizeof(((type *)0)->member)
#endif
  static size_t __pyx_pyframe_localsplus_offset = 0;
  #include "frameobject.h"
  #define __Pxy_PyFrame_Initialize_Offsets()\
    ((void)__Pyx_BUILD_ASSERT_EXPR(sizeof(PyFrameObject) == offsetof(PyFrameObject, f_localsplus) + Py_MEMBER_SIZE(PyFrameObject, f_localsplus)),\
     (void)(__pyx_pyframe_localsplus_offset = ((size_t)PyFrame_Type.tp_basicsize) - Py_MEMBER_SIZE(PyFrameObject, f_localsplus)))
  #define __Pyx_PyFrame_GetLocalsplus(frame)\
    (assert(__pyx_pyframe_localsplus_offset), (PyObject **)(((char *)(frame)) + __pyx_pyframe_localsplus_offset))
#endif

/* PyObjectCall.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw);
#else
#define __Pyx_PyObject_Call(func, arg, kw) PyObject_Call(func, arg, kw)
#endif

/* PyObjectCallMethO.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg);
#endif

/* PyObjectCallNoArg.proto */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func);
#else
#define __Pyx_PyObject_CallNoArg(func) __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL)
#endif

/* PyCFunctionFastCall.proto */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject *__Pyx_PyCFunction_FastCall(PyObject *func, PyObject **args, Py_ssize_t nargs);
#else
#define __Pyx_PyCFunction_FastCall(func, args, nargs)  (assert(0), NULL)
#endif

/* PyObjectCallOneArg.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg);

/* PyObjectCall2Args.proto */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2);

/* PyObjectGetMethod.proto */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method);

/* PyObjectCallMethod1.proto */
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg);

/* pop_index.proto */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix);
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix);
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix);
#define __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    (likely(PyList_CheckExact(L) && __Pyx_fits_Py_ssize_t(ix, type, is_signed))) ?\
        __Pyx__PyList_PopIndex(L, py_ix, ix) : (\
        (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
            __Pyx__PyObject_PopIndex(L, py_ix)))
#define __Pyx_PyList_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    __Pyx_fits_Py_ssize_t(ix, type, is_signed) ?\
        __Pyx__PyList_PopIndex(L, py_ix, ix) : (\
        (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
            __Pyx__PyObject_PopIndex(L, py_ix)))
#else
#define __Pyx_PyList_PopIndex(L, py_ix, ix, is_signed, type, to_py_func)\
    __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func)
#define __Pyx_PyObject_PopIndex(L, py_ix, ix, is_signed, type, to_py_func) (\
    (unlikely((py_ix) == Py_None)) ? __Pyx__PyObject_PopNewIndex(L, to_py_func(ix)) :\
        __Pyx__PyObject_PopIndex(L, py_ix))
#endif

/* PyDictVersioning.proto */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
#define __PYX_DICT_VERSION_INIT  ((PY_UINT64_T) -1)
#define __PYX_GET_DICT_VERSION(dict)  (((PyDictObject*)(dict))->ma_version_tag)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)\
    (version_var) = __PYX_GET_DICT_VERSION(dict);\
    (cache_var) = (value);
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP) {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    if (likely(__PYX_GET_DICT_VERSION(DICT) == __pyx_dict_version)) {\
        (VAR) = __pyx_dict_cached_value;\
    } else {\
        (VAR) = __pyx_dict_cached_value = (LOOKUP);\
        __pyx_dict_version = __PYX_GET_DICT_VERSION(DICT);\
    }\
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj);
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj);
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version);
#else
#define __PYX_GET_DICT_VERSION(dict)  (0)
#define __PYX_UPDATE_DICT_CACHE(dict, value, cache_var, version_var)
#define __PYX_PY_DICT_LOOKUP_IF_MODIFIED(VAR, DICT, LOOKUP)  (VAR) = (LOOKUP);
#endif

/* PyThreadStateGet.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyThreadState_declare  PyThreadState *__pyx_tstate;
#define __Pyx_PyThreadState_assign  __pyx_tstate = __Pyx_PyThreadState_Current;
#define __Pyx_PyErr_Occurred()  __pyx_tstate->curexc_type
#else
#define __Pyx_PyThreadState_declare
#define __Pyx_PyThreadState_assign
#define __Pyx_PyErr_Occurred()  PyErr_Occurred()
#endif

/* PyErrFetchRestore.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_Clear() __Pyx_ErrRestore(NULL, NULL, NULL)
#define __Pyx_ErrRestoreWithState(type, value, tb)  __Pyx_ErrRestoreInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)    __Pyx_ErrFetchInState(PyThreadState_GET(), type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  __Pyx_ErrRestoreInState(__pyx_tstate, type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)    __Pyx_ErrFetchInState(__pyx_tstate, type, value, tb)
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb);
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb);
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_PyErr_SetNone(exc) (Py_INCREF(exc), __Pyx_ErrRestore((exc), NULL, NULL))
#else
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#endif
#else
#define __Pyx_PyErr_Clear() PyErr_Clear()
#define __Pyx_PyErr_SetNone(exc) PyErr_SetNone(exc)
#define __Pyx_ErrRestoreWithState(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchWithState(type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestoreInState(tstate, type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetchInState(tstate, type, value, tb)  PyErr_Fetch(type, value, tb)
#define __Pyx_ErrRestore(type, value, tb)  PyErr_Restore(type, value, tb)
#define __Pyx_ErrFetch(type, value, tb)  PyErr_Fetch(type, value, tb)
#endif

/* WriteUnraisableException.proto */
static void __Pyx_WriteUnraisable(const char *name, int clineno,
                                  int lineno, const char *filename,
                                  int full_traceback, int nogil);

/* ListAppend.proto */
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static CYTHON_INLINE int __Pyx_PyList_Append(PyObject* list, PyObject* x) {
    PyListObject* L = (PyListObject*) list;
    Py_ssize_t len = Py_SIZE(list);
    if (likely(L->allocated > len) & likely(len > (L->allocated >> 1))) {
        Py_INCREF(x);
        PyList_SET_ITEM(list, len, x);
        __Pyx_SET_SIZE(list, len + 1);
        return 0;
    }
    return PyList_Append(list, x);
}
#else
#define __Pyx_PyList_Append(L,x) PyList_Append(L,x)
#endif

/* ExtTypeTest.proto */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type);

/* IncludeStringH.proto */
#include <string.h>

/* BytesEquals.proto */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals);

/* UnicodeEquals.proto */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals);

/* unicode_tailmatch.proto */
static int __Pyx_PyUnicode_Tailmatch(
    PyObject* s, PyObject* substr, Py_ssize_t start, Py_ssize_t end, int direction);

/* PyIntBinop.proto */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, long intval, int inplace, int zerodivision_check);
#else
#define __Pyx_PyInt_AddObjC(op1, op2, intval, inplace, zerodivision_check)\
    (inplace ? PyNumber_InPlaceAdd(op1, op2) : PyNumber_Add(op1, op2))
#endif

/* ObjectGetItem.proto */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key);
#else
#define __Pyx_PyObject_GetItem(obj, key)  PyObject_GetItem(obj, key)
#endif

/* SetItemInt.proto */
#define __Pyx_SetItemInt(o, i, v, type, is_signed, to_py_func, is_list, wraparound, boundscheck)\
    (__Pyx_fits_Py_ssize_t(i, type, is_signed) ?\
    __Pyx_SetItemInt_Fast(o, (Py_ssize_t)i, v, is_list, wraparound, boundscheck) :\
    (is_list ? (PyErr_SetString(PyExc_IndexError, "list assignment index out of range"), -1) :\
               __Pyx_SetItemInt_Generic(o, to_py_func(i), v)))
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v);
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v,
                                               int is_list, int wraparound, int boundscheck);

/* PySequenceContains.proto */
static CYTHON_INLINE int __Pyx_PySequence_ContainsTF(PyObject* item, PyObject* seq, int eq) {
    int result = PySequence_Contains(seq, item);
    return unlikely(result < 0) ? result : (result == (eq == Py_EQ));
}

/* SliceObject.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(
        PyObject* obj, Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** py_start, PyObject** py_stop, PyObject** py_slice,
        int has_cstart, int has_cstop, int wraparound);

/* PyErrExceptionMatches.proto */
#if CYTHON_FAST_THREAD_STATE
#define __Pyx_PyErr_ExceptionMatches(err) __Pyx_PyErr_ExceptionMatchesInState(__pyx_tstate, err)
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err);
#else
#define __Pyx_PyErr_ExceptionMatches(err)  PyErr_ExceptionMatches(err)
#endif

/* GetAttr.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *, PyObject *);

/* GetAttr3.proto */
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *, PyObject *, PyObject *);

/* GetModuleGlobalName.proto */
#if CYTHON_USE_DICT_VERSIONS
#define __Pyx_GetModuleGlobalName(var, name)  {\
    static PY_UINT64_T __pyx_dict_version = 0;\
    static PyObject *__pyx_dict_cached_value = NULL;\
    (var) = (likely(__pyx_dict_version == __PYX_GET_DICT_VERSION(__pyx_d))) ?\
        (likely(__pyx_dict_cached_value) ? __Pyx_NewRef(__pyx_dict_cached_value) : __Pyx_GetBuiltinName(name)) :\
        __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
#define __Pyx_GetModuleGlobalNameUncached(var, name)  {\
    PY_UINT64_T __pyx_dict_version;\
    PyObject *__pyx_dict_cached_value;\
    (var) = __Pyx__GetModuleGlobalName(name, &__pyx_dict_version, &__pyx_dict_cached_value);\
}
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value);
#else
#define __Pyx_GetModuleGlobalName(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
#define __Pyx_GetModuleGlobalNameUncached(var, name)  (var) = __Pyx__GetModuleGlobalName(name)
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name);
#endif

/* Import.proto */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level);

/* ImportFrom.proto */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name);

/* RaiseException.proto */
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause);

/* HasAttr.proto */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *, PyObject *);

/* PyObject_GenericGetAttrNoDict.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttrNoDict PyObject_GenericGetAttr
#endif

/* PyObject_GenericGetAttr.proto */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name);
#else
#define __Pyx_PyObject_GenericGetAttr PyObject_GenericGetAttr
#endif

/* SetVTable.proto */
static int __Pyx_SetVtable(PyObject *dict, void *vtable);

/* PyObjectGetAttrStrNoError.proto */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name);

/* SetupReduce.proto */
static int __Pyx_setup_reduce(PyObject* type_obj);

/* TypeImport.proto */
#ifndef __PYX_HAVE_RT_ImportType_proto
#define __PYX_HAVE_RT_ImportType_proto
enum __Pyx_ImportType_CheckSize {
   __Pyx_ImportType_CheckSize_Error = 0,
   __Pyx_ImportType_CheckSize_Warn = 1,
   __Pyx_ImportType_CheckSize_Ignore = 2
};
static PyTypeObject *__Pyx_ImportType(PyObject* module, const char *module_name, const char *class_name, size_t size, enum __Pyx_ImportType_CheckSize check_size);
#endif

/* GetVTable.proto */
static void* __Pyx_GetVtable(PyObject *dict);

/* CLineInTraceback.proto */
#ifdef CYTHON_CLINE_IN_TRACEBACK
#define __Pyx_CLineForTraceback(tstate, c_line)  (((CYTHON_CLINE_IN_TRACEBACK)) ? c_line : 0)
#else
static int __Pyx_CLineForTraceback(PyThreadState *tstate, int c_line);
#endif

/* CodeObjectCache.proto */
typedef struct {
    PyCodeObject* code_object;
    int code_line;
} __Pyx_CodeObjectCacheEntry;
struct __Pyx_CodeObjectCache {
    int count;
    int max_count;
    __Pyx_CodeObjectCacheEntry* entries;
};
static struct __Pyx_CodeObjectCache __pyx_code_cache = {0,0,NULL};
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line);
static PyCodeObject *__pyx_find_code_object(int code_line);
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object);

/* AddTraceback.proto */
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value);

/* CIntToPy.proto */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value);

/* CIntFromPy.proto */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *);

/* CIntFromPy.proto */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *);

/* FastTypeChecks.proto */
#if CYTHON_COMPILING_IN_CPYTHON
#define __Pyx_TypeCheck(obj, type) __Pyx_IsSubtype(Py_TYPE(obj), (PyTypeObject *)type)
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject *type);
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *type1, PyObject *type2);
#else
#define __Pyx_TypeCheck(obj, type) PyObject_TypeCheck(obj, (PyTypeObject *)type)
#define __Pyx_PyErr_GivenExceptionMatches(err, type) PyErr_GivenExceptionMatches(err, type)
#define __Pyx_PyErr_GivenExceptionMatches2(err, type1, type2) (PyErr_GivenExceptionMatches(err, type1) || PyErr_GivenExceptionMatches(err, type2))
#endif
#define __Pyx_PyException_Check(obj) __Pyx_TypeCheck(obj, PyExc_Exception)

/* CheckBinaryVersion.proto */
static int __Pyx_check_binary_version(void);

/* InitStrings.proto */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t);

static int __pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_size(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_addFsmParse(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_fsmParse, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_getFsmParse(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_v_index, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_rootWords(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_reduceToParsesWithSameRootAndPos(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_10Dictionary_4Word_Word *__pyx_v_currentWithPos, int __pyx_skip_dispatch); /* proto*/
static struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_getParseWithLongestRootWord(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static int __pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_isLongestRootException(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_fsmParse, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_reduceToParsesWithSameRoot(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, PyObject *__pyx_v_currentRoot, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_constructParseListForDifferentRootWithPos(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_parsesWithoutPrefixAndSuffix(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_skip_dispatch); /* proto*/

/* Module declarations from 'Dictionary.Word' */
static PyTypeObject *__pyx_ptype_10Dictionary_4Word_Word = 0;

/* Module declarations from 'MorphologicalAnalysis.InflectionalGroup' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = 0;

/* Module declarations from 'MorphologicalAnalysis.MorphologicalParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = 0;

/* Module declarations from 'MorphologicalAnalysis.State' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_5State_State = 0;

/* Module declarations from 'MorphologicalAnalysis.FsmParse' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse = 0;

/* Module declarations from 'MorphologicalAnalysis.FsmParseList' */
static PyTypeObject *__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList = 0;
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList___pyx_unpickle_FsmParseList__set_state(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, PyObject *); /*proto*/
#define __Pyx_MODULE_NAME "MorphologicalAnalysis.FsmParseList"
extern int __pyx_module_is_main_MorphologicalAnalysis__FsmParseList;
int __pyx_module_is_main_MorphologicalAnalysis__FsmParseList = 0;

/* Implementation of 'MorphologicalAnalysis.FsmParseList' */
static PyObject *__pyx_builtin_range;
static const char __pyx_k_[] = "$";
static const char __pyx_k__2[] = " ";
static const char __pyx_k__3[] = "";
static const char __pyx_k__4[] = "+";
static const char __pyx_k__5[] = "\n";
static const char __pyx_k_new[] = "__new__";
static const char __pyx_k_pop[] = "pop";
static const char __pyx_k_dict[] = "__dict__";
static const char __pyx_k_main[] = "__main__";
static const char __pyx_k_name[] = "__name__";
static const char __pyx_k_size[] = "size";
static const char __pyx_k_test[] = "__test__";
static const char __pyx_k_index[] = "index";
static const char __pyx_k_range[] = "range";
static const char __pyx_k_import[] = "__import__";
static const char __pyx_k_pickle[] = "pickle";
static const char __pyx_k_reduce[] = "__reduce__";
static const char __pyx_k_rindex[] = "rindex";
static const char __pyx_k_update[] = "update";
static const char __pyx_k_getName[] = "getName";
static const char __pyx_k_getWord[] = "getWord";
static const char __pyx_k_getstate[] = "__getstate__";
static const char __pyx_k_pyx_type[] = "__pyx_type";
static const char __pyx_k_setstate[] = "__setstate__";
static const char __pyx_k_fsmParses[] = "fsmParses";
static const char __pyx_k_pyx_state[] = "__pyx_state";
static const char __pyx_k_reduce_ex[] = "__reduce_ex__";
static const char __pyx_k_rootWords[] = "rootWords";
static const char __pyx_k_pyx_result[] = "__pyx_result";
static const char __pyx_k_pyx_vtable[] = "__pyx_vtable__";
static const char __pyx_k_PickleError[] = "PickleError";
static const char __pyx_k_addFsmParse[] = "addFsmParse";
static const char __pyx_k_getFsmParse[] = "getFsmParse";
static const char __pyx_k_FsmParseList[] = "FsmParseList";
static const char __pyx_k_ln_NOUN_VERB[] = "\304\261l\304\261n \304\261 NOUN VERB";
static const char __pyx_k_pyx_checksum[] = "__pyx_checksum";
static const char __pyx_k_stringsource[] = "stringsource";
static const char __pyx_k_in_i_ADJ_NOUN[] = "in i ADJ NOUN";
static const char __pyx_k_lan_NOUN_VERB[] = "\304\261lan \304\261 NOUN VERB";
static const char __pyx_k_nca_NOUN_VERB[] = "\304\261nca \304\261 NOUN VERB";
static const char __pyx_k_reduce_cython[] = "__reduce_cython__";
static const char __pyx_k_getWordWithPos[] = "getWordWithPos";
static const char __pyx_k_ine_i_ADJ_NOUN[] = "ine i ADJ NOUN";
static const char __pyx_k_ini_i_ADJ_NOUN[] = "ini i ADJ NOUN";
static const char __pyx_k_lana_NOUN_VERB[] = "\304\261lana \304\261 NOUN VERB";
static const char __pyx_k_lnca_NOUN_VERB[] = "\304\261l\304\261nca \304\261 NOUN VERB";
static const char __pyx_k_mn_m_NOUN_NOUN[] = "m\304\261n\304\261 m NOUN NOUN";
static const char __pyx_k_mz_m_NOUN_NOUN[] = "m\304\261z m NOUN NOUN";
static const char __pyx_k_na_n_NOUN_NOUN[] = "na n NOUN NOUN";
static const char __pyx_k_ne_n_NOUN_NOUN[] = "ne n NOUN NOUN";
static const char __pyx_k_ne_n_VERB_NOUN[] = "\303\274ne \303\274n VERB NOUN";
static const char __pyx_k_nn_n_NOUN_NOUN[] = "n\304\261n n NOUN NOUN";
static const char __pyx_k_nz_n_NOUN_NOUN[] = "n\304\261z n NOUN NOUN";
static const char __pyx_k_rz_r_NOUN_VERB[] = "r\304\261z r NOUN VERB";
static const char __pyx_k_sa_sa_VERB_ADJ[] = "sa sa VERB ADJ";
static const char __pyx_k_se_se_VERB_ADJ[] = "se se VERB ADJ";
static const char __pyx_k_transitionList[] = "transitionList";
static const char __pyx_k_imiz_i_ADJ_NOUN[] = "imiz i ADJ NOUN";
static const char __pyx_k_inde_i_ADJ_NOUN[] = "inde i ADJ NOUN";
static const char __pyx_k_inin_i_ADJ_NOUN[] = "inin i ADJ NOUN";
static const char __pyx_k_la_la_VERB_NOUN[] = "la la VERB NOUN";
static const char __pyx_k_le_le_VERB_NOUN[] = "le le VERB NOUN";
static const char __pyx_k_msa_m_NOUN_VERB[] = "m\304\261\305\237sa m\304\261\305\237 NOUN VERB";
static const char __pyx_k_nin_n_NOUN_NOUN[] = "nin n NOUN NOUN";
static const char __pyx_k_niz_n_NOUN_NOUN[] = "niz n NOUN NOUN";
static const char __pyx_k_pyx_PickleError[] = "__pyx_PickleError";
static const char __pyx_k_rdm_r_NOUN_VERB[] = "rd\304\261m r NOUN VERB";
static const char __pyx_k_riz_r_NOUN_VERB[] = "riz r NOUN VERB";
static const char __pyx_k_rsa_r_NOUN_VERB[] = "rsa r NOUN VERB";
static const char __pyx_k_rse_r_NOUN_VERB[] = "rse r NOUN VERB";
static const char __pyx_k_setstate_cython[] = "__setstate_cython__";
static const char __pyx_k_un_un_VERB_NOUN[] = "un un VERB NOUN";
static const char __pyx_k_arz_ar_NOUN_VERB[] = "ar\304\261z ar NOUN VERB";
static const char __pyx_k_ilen_i_VERB_VERB[] = "ilen i VERB VERB";
static const char __pyx_k_ilin_i_VERB_VERB[] = "ilin i VERB VERB";
static const char __pyx_k_ince_i_NOUN_VERB[] = "ince i NOUN VERB";
static const char __pyx_k_lar_la_VERB_NOUN[] = "lar la VERB NOUN";
static const char __pyx_k_ler_le_VERB_NOUN[] = "ler le VERB NOUN";
static const char __pyx_k_mal_ma_NOUN_VERB[] = "mal\304\261 ma NOUN VERB";
static const char __pyx_k_mam_ma_NOUN_VERB[] = "mam ma NOUN VERB";
static const char __pyx_k_mas_ma_NOUN_VERB[] = "mas\304\261 ma NOUN VERB";
static const char __pyx_k_mdan_m_NOUN_NOUN[] = "mdan m NOUN NOUN";
static const char __pyx_k_mem_me_NOUN_VERB[] = "mem me NOUN VERB";
static const char __pyx_k_rdim_r_NOUN_VERB[] = "rdim r NOUN VERB";
static const char __pyx_k_rken_r_NOUN_VERB[] = "rken r NOUN VERB";
static const char __pyx_k_rsak_r_NOUN_VERB[] = "rsak r NOUN VERB";
static const char __pyx_k_rsek_r_NOUN_VERB[] = "rsek r NOUN VERB";
static const char __pyx_k_rsnz_r_NOUN_VERB[] = "rs\304\261n\304\261z r NOUN VERB";
static const char __pyx_k_ulan_u_NOUN_VERB[] = "ulan u NOUN VERB";
static const char __pyx_k_unca_u_NOUN_VERB[] = "unca u NOUN VERB";
static const char __pyx_k_ardm_ar_NOUN_VERB[] = "ard\304\261m ar NOUN VERB";
static const char __pyx_k_arsa_ar_NOUN_VERB[] = "arsa ar NOUN VERB";
static const char __pyx_k_eriz_er_NOUN_VERB[] = "eriz er NOUN VERB";
static const char __pyx_k_erse_er_NOUN_VERB[] = "erse er NOUN VERB";
static const char __pyx_k_ilene_i_VERB_VERB[] = "ilene i VERB VERB";
static const char __pyx_k_larm_la_VERB_NOUN[] = "lar\304\261m la VERB NOUN";
static const char __pyx_k_larn_la_VERB_NOUN[] = "lar\304\261n la VERB NOUN";
static const char __pyx_k_leri_le_VERB_NOUN[] = "leri le VERB NOUN";
static const char __pyx_k_mama_ma_NOUN_VERB[] = "mama ma NOUN VERB";
static const char __pyx_k_mamz_ma_NOUN_VERB[] = "mam\304\261z ma NOUN VERB";
static const char __pyx_k_manz_ma_NOUN_VERB[] = "man\304\261z ma NOUN VERB";
static const char __pyx_k_masn_ma_NOUN_VERB[] = "mas\304\261n ma NOUN VERB";
static const char __pyx_k_meli_me_NOUN_VERB[] = "meli me NOUN VERB";
static const char __pyx_k_meme_me_NOUN_VERB[] = "meme me NOUN VERB";
static const char __pyx_k_mesi_me_NOUN_VERB[] = "mesi me NOUN VERB";
static const char __pyx_k_mise_mi_NOUN_VERB[] = "mi\305\237se mi\305\237 NOUN VERB";
static const char __pyx_k_rsanz_r_NOUN_VERB[] = "rsan\304\261z r NOUN VERB";
static const char __pyx_k_unca_un_NOUN_VERB[] = "unca un NOUN VERB";
static const char __pyx_k_unun_un_VERB_NOUN[] = "unun un VERB NOUN";
static const char __pyx_k_aca_acak_NOUN_VERB[] = "aca\304\237\304\261 acak NOUN VERB";
static const char __pyx_k_arken_ar_NOUN_VERB[] = "arken ar NOUN VERB";
static const char __pyx_k_arsak_ar_NOUN_VERB[] = "arsak ar NOUN VERB";
static const char __pyx_k_arsnz_ar_NOUN_VERB[] = "ars\304\261n\304\261z ar NOUN VERB";
static const char __pyx_k_cline_in_traceback[] = "cline_in_traceback";
static const char __pyx_k_erdim_er_NOUN_VERB[] = "erdim er NOUN VERB";
static const char __pyx_k_erken_er_NOUN_VERB[] = "erken er NOUN VERB";
static const char __pyx_k_ersek_er_NOUN_VERB[] = "ersek er NOUN VERB";
static const char __pyx_k_ilen_ile_VERB_VERB[] = "ilen ile VERB VERB";
static const char __pyx_k_ilince_i_VERB_VERB[] = "ilince i VERB VERB";
static const char __pyx_k_lar_la_VERB_NOUN_2[] = "lar\304\261 la VERB NOUN";
static const char __pyx_k_lardr_la_VERB_NOUN[] = "lard\304\261r la VERB NOUN";
static const char __pyx_k_larmz_la_VERB_NOUN[] = "lar\304\261m\304\261z la VERB NOUN";
static const char __pyx_k_larna_la_VERB_NOUN[] = "lar\304\261na la VERB NOUN";
static const char __pyx_k_larnn_la_VERB_NOUN[] = "lar\304\261n\304\261n la VERB NOUN";
static const char __pyx_k_larnz_la_VERB_NOUN[] = "lar\304\261n\304\261z la VERB NOUN";
static const char __pyx_k_lerim_le_VERB_NOUN[] = "lerim le VERB NOUN";
static const char __pyx_k_lerin_le_VERB_NOUN[] = "lerin le VERB NOUN";
static const char __pyx_k_madan_ma_NOUN_VERB[] = "madan ma NOUN VERB";
static const char __pyx_k_maldr_ma_NOUN_VERB[] = "mal\304\261d\304\261r ma NOUN VERB";
static const char __pyx_k_malym_ma_NOUN_VERB[] = "mal\304\261y\304\261m ma NOUN VERB";
static const char __pyx_k_malyz_ma_NOUN_VERB[] = "mal\304\261y\304\261z ma NOUN VERB";
static const char __pyx_k_mamza_ma_NOUN_VERB[] = "mam\304\261za ma NOUN VERB";
static const char __pyx_k_masdr_ma_NOUN_VERB[] = "mas\304\261d\304\261r ma NOUN VERB";
static const char __pyx_k_masna_ma_NOUN_VERB[] = "mas\304\261na ma NOUN VERB";
static const char __pyx_k_meden_me_NOUN_VERB[] = "meden me NOUN VERB";
static const char __pyx_k_memiz_me_NOUN_VERB[] = "memiz me NOUN VERB";
static const char __pyx_k_meniz_me_NOUN_VERB[] = "meniz me NOUN VERB";
static const char __pyx_k_mesin_me_NOUN_VERB[] = "mesin me NOUN VERB";
static const char __pyx_k_rseniz_r_NOUN_VERB[] = "rseniz r NOUN VERB";
static const char __pyx_k_rsiniz_r_NOUN_VERB[] = "rsiniz r NOUN VERB";
static const char __pyx_k_acam_acak_NOUN_VERB[] = "aca\304\237\304\261m acak NOUN VERB";
static const char __pyx_k_acan_acak_NOUN_VERB[] = "aca\304\237\304\261n acak NOUN VERB";
static const char __pyx_k_acaz_acak_NOUN_VERB[] = "aca\304\237\304\261z acak NOUN VERB";
static const char __pyx_k_arsanz_ar_NOUN_VERB[] = "arsan\304\261z ar NOUN VERB";
static const char __pyx_k_ecei_ecek_NOUN_VERB[] = "ece\304\237i ecek NOUN VERB";
static const char __pyx_k_lardan_la_VERB_NOUN[] = "lardan la VERB NOUN";
static const char __pyx_k_larmza_la_VERB_NOUN[] = "lar\304\261m\304\261za la VERB NOUN";
static const char __pyx_k_larmzn_la_VERB_NOUN[] = "lar\304\261m\304\261z\304\261n la VERB NOUN";
static const char __pyx_k_larn_la_VERB_NOUN_2[] = "lar\304\261n\304\261 la VERB NOUN";
static const char __pyx_k_larnda_la_VERB_NOUN[] = "lar\304\261nda la VERB NOUN";
static const char __pyx_k_larnza_la_VERB_NOUN[] = "lar\304\261n\304\261za la VERB NOUN";
static const char __pyx_k_larnzn_la_VERB_NOUN[] = "lar\304\261n\304\261z\304\261n la VERB NOUN";
static const char __pyx_k_laryla_la_VERB_NOUN[] = "lar\304\261yla la VERB NOUN";
static const char __pyx_k_lerden_le_VERB_NOUN[] = "lerden le VERB NOUN";
static const char __pyx_k_lerdir_le_VERB_NOUN[] = "lerdir le VERB NOUN";
static const char __pyx_k_lerine_le_VERB_NOUN[] = "lerine le VERB NOUN";
static const char __pyx_k_lerini_le_VERB_NOUN[] = "lerini le VERB NOUN";
static const char __pyx_k_mallar_ma_NOUN_VERB[] = "mal\304\261lar ma NOUN VERB";
static const char __pyx_k_malsnz_ma_NOUN_VERB[] = "mal\304\261s\304\261n\304\261z ma NOUN VERB";
static const char __pyx_k_mamz_ma_NOUN_VERB_2[] = "mam\304\261z\304\261 ma NOUN VERB";
static const char __pyx_k_manz_ma_NOUN_VERB_2[] = "man\304\261z\304\261 ma NOUN VERB";
static const char __pyx_k_manzda_ma_NOUN_VERB[] = "man\304\261zda ma NOUN VERB";
static const char __pyx_k_manzdr_ma_NOUN_VERB[] = "man\304\261zd\304\261r ma NOUN VERB";
static const char __pyx_k_manzla_ma_NOUN_VERB[] = "man\304\261zla ma NOUN VERB";
static const char __pyx_k_masn_ma_NOUN_VERB_2[] = "mas\304\261n\304\261 ma NOUN VERB";
static const char __pyx_k_masnda_ma_NOUN_VERB[] = "mas\304\261nda ma NOUN VERB";
static const char __pyx_k_masyla_ma_NOUN_VERB[] = "mas\304\261yla ma NOUN VERB";
static const char __pyx_k_memize_me_NOUN_VERB[] = "memize me NOUN VERB";
static const char __pyx_k_memizi_me_NOUN_VERB[] = "memizi me NOUN VERB";
static const char __pyx_k_menizi_me_NOUN_VERB[] = "menizi me NOUN VERB";
static const char __pyx_k_mesine_me_NOUN_VERB[] = "mesine me NOUN VERB";
static const char __pyx_k_mesini_me_NOUN_VERB[] = "mesini me NOUN VERB";
static const char __pyx_k_acamz_acak_NOUN_VERB[] = "aca\304\237\304\261m\304\261z acak NOUN VERB";
static const char __pyx_k_acana_acak_NOUN_VERB[] = "aca\304\237\304\261na acak NOUN VERB";
static const char __pyx_k_acann_acak_NOUN_VERB[] = "aca\304\237\304\261n\304\261n acak NOUN VERB";
static const char __pyx_k_acanz_acak_NOUN_VERB[] = "aca\304\237\304\261n\304\261z acak NOUN VERB";
static const char __pyx_k_eceim_ecek_NOUN_VERB[] = "ece\304\237im ecek NOUN VERB";
static const char __pyx_k_ecein_ecek_NOUN_VERB[] = "ece\304\237in ecek NOUN VERB";
static const char __pyx_k_eceiz_ecek_NOUN_VERB[] = "ece\304\237iz ecek NOUN VERB";
static const char __pyx_k_erseniz_er_NOUN_VERB[] = "erseniz er NOUN VERB";
static const char __pyx_k_ersiniz_er_NOUN_VERB[] = "ersiniz er NOUN VERB";
static const char __pyx_k_lardr_la_VERB_NOUN_2[] = "lar\304\261d\304\261r la VERB NOUN";
static const char __pyx_k_larmdan_la_VERB_NOUN[] = "lar\304\261mdan la VERB NOUN";
static const char __pyx_k_larmz_la_VERB_NOUN_2[] = "lar\304\261m\304\261z\304\261 la VERB NOUN";
static const char __pyx_k_larmzda_la_VERB_NOUN[] = "lar\304\261m\304\261zda la VERB NOUN";
static const char __pyx_k_larmzla_la_VERB_NOUN[] = "lar\304\261m\304\261zla la VERB NOUN";
static const char __pyx_k_larndan_la_VERB_NOUN[] = "lar\304\261ndan la VERB NOUN";
static const char __pyx_k_larnz_la_VERB_NOUN_2[] = "lar\304\261n\304\261z\304\261 la VERB NOUN";
static const char __pyx_k_larnzda_la_VERB_NOUN[] = "lar\304\261n\304\261zda la VERB NOUN";
static const char __pyx_k_larnzla_la_VERB_NOUN[] = "lar\304\261n\304\261zla la VERB NOUN";
static const char __pyx_k_leridir_le_VERB_NOUN[] = "leridir le VERB NOUN";
static const char __pyx_k_lerimiz_le_VERB_NOUN[] = "lerimiz le VERB NOUN";
static const char __pyx_k_lerinde_le_VERB_NOUN[] = "lerinde le VERB NOUN";
static const char __pyx_k_lerinin_le_VERB_NOUN[] = "lerinin le VERB NOUN";
static const char __pyx_k_leriniz_le_VERB_NOUN[] = "leriniz le VERB NOUN";
static const char __pyx_k_leriyle_le_VERB_NOUN[] = "leriyle le VERB NOUN";
static const char __pyx_k_melidir_me_NOUN_VERB[] = "melidir me NOUN VERB";
static const char __pyx_k_meliler_me_NOUN_VERB[] = "meliler me NOUN VERB";
static const char __pyx_k_meliyim_me_NOUN_VERB[] = "meliyim me NOUN VERB";
static const char __pyx_k_meliyiz_me_NOUN_VERB[] = "meliyiz me NOUN VERB";
static const char __pyx_k_menizde_me_NOUN_VERB[] = "menizde me NOUN VERB";
static const char __pyx_k_menizle_me_NOUN_VERB[] = "menizle me NOUN VERB";
static const char __pyx_k_mesidir_me_NOUN_VERB[] = "mesidir me NOUN VERB";
static const char __pyx_k_mesinde_me_NOUN_VERB[] = "mesinde me NOUN VERB";
static const char __pyx_k_mesiyle_me_NOUN_VERB[] = "mesiyle me NOUN VERB";
static const char __pyx_k_acaksa_acak_NOUN_VERB[] = "acaksa acak NOUN VERB";
static const char __pyx_k_acaktr_acak_NOUN_VERB[] = "acakt\304\261r acak NOUN VERB";
static const char __pyx_k_acam_acak_NOUN_VERB_2[] = "aca\304\237\304\261m\304\261 acak NOUN VERB";
static const char __pyx_k_acan_acak_NOUN_VERB_2[] = "aca\304\237\304\261n\304\261 acak NOUN VERB";
static const char __pyx_k_acanza_acak_NOUN_VERB[] = "aca\304\237\304\261n\304\261za acak NOUN VERB";
static const char __pyx_k_acanzn_acak_NOUN_VERB[] = "aca\304\237\304\261n\304\261z\304\261n acak NOUN VERB";
static const char __pyx_k_eceimi_ecek_NOUN_VERB[] = "ece\304\237imi ecek NOUN VERB";
static const char __pyx_k_eceine_ecek_NOUN_VERB[] = "ece\304\237ine ecek NOUN VERB";
static const char __pyx_k_eceini_ecek_NOUN_VERB[] = "ece\304\237ini ecek NOUN VERB";
static const char __pyx_k_ecekse_ecek_NOUN_VERB[] = "ecekse ecek NOUN VERB";
static const char __pyx_k_lardandr_la_VERB_NOUN[] = "lardand\304\261r la VERB NOUN";
static const char __pyx_k_larmzdan_la_VERB_NOUN[] = "lar\304\261m\304\261zdan la VERB NOUN";
static const char __pyx_k_larndaki_la_VERB_NOUN[] = "lar\304\261ndaki la VERB NOUN";
static const char __pyx_k_larnzdan_la_VERB_NOUN[] = "lar\304\261n\304\261zdan la VERB NOUN";
static const char __pyx_k_lerimden_le_VERB_NOUN[] = "lerimden le VERB NOUN";
static const char __pyx_k_lerimize_le_VERB_NOUN[] = "lerimize le VERB NOUN";
static const char __pyx_k_lerimizi_le_VERB_NOUN[] = "lerimizi le VERB NOUN";
static const char __pyx_k_lerinden_le_VERB_NOUN[] = "lerinden le VERB NOUN";
static const char __pyx_k_lerinize_le_VERB_NOUN[] = "lerinize le VERB NOUN";
static const char __pyx_k_lerinizi_le_VERB_NOUN[] = "lerinizi le VERB NOUN";
static const char __pyx_k_maldrlar_ma_NOUN_VERB[] = "mal\304\261d\304\261rlar ma NOUN VERB";
static const char __pyx_k_masndaki_ma_NOUN_VERB[] = "mas\304\261ndaki ma NOUN VERB";
static const char __pyx_k_menizdir_me_NOUN_VERB[] = "menizdir me NOUN VERB";
static const char __pyx_k_acaklar_acak_NOUN_VERB[] = "acaklar\304\261 acak NOUN VERB";
static const char __pyx_k_acanz_acak_NOUN_VERB_2[] = "aca\304\237\304\261n\304\261z\304\261 acak NOUN VERB";
static const char __pyx_k_acanzdr_acak_NOUN_VERB[] = "aca\304\237\304\261n\304\261zd\304\261r acak NOUN VERB";
static const char __pyx_k_eceimiz_ecek_NOUN_VERB[] = "ece\304\237imiz ecek NOUN VERB";
static const char __pyx_k_eceinin_ecek_NOUN_VERB[] = "ece\304\237inin ecek NOUN VERB";
static const char __pyx_k_eceiniz_ecek_NOUN_VERB[] = "ece\304\237iniz ecek NOUN VERB";
static const char __pyx_k_ecektir_ecek_NOUN_VERB[] = "ecektir ecek NOUN VERB";
static const char __pyx_k_isLongestRootException[] = "isLongestRootException";
static const char __pyx_k_larmzdayd_la_VERB_NOUN[] = "lar\304\261m\304\261zdayd\304\261 la VERB NOUN";
static const char __pyx_k_larndandr_la_VERB_NOUN[] = "lar\304\261ndand\304\261r la VERB NOUN";
static const char __pyx_k_larndaysa_la_VERB_NOUN[] = "lar\304\261ndaysa la VERB NOUN";
static const char __pyx_k_larnzdaki_la_VERB_NOUN[] = "lar\304\261n\304\261zdaki la VERB NOUN";
static const char __pyx_k_lerdendir_le_VERB_NOUN[] = "lerdendir le VERB NOUN";
static const char __pyx_k_lerimizde_le_VERB_NOUN[] = "lerimizde le VERB NOUN";
static const char __pyx_k_lerimizin_le_VERB_NOUN[] = "lerimizin le VERB NOUN";
static const char __pyx_k_lerimizle_le_VERB_NOUN[] = "lerimizle le VERB NOUN";
static const char __pyx_k_lerindeki_le_VERB_NOUN[] = "lerindeki le VERB NOUN";
static const char __pyx_k_lerinizde_le_VERB_NOUN[] = "lerinizde le VERB NOUN";
static const char __pyx_k_lerinizin_le_VERB_NOUN[] = "lerinizin le VERB NOUN";
static const char __pyx_k_lerinizle_le_VERB_NOUN[] = "lerinizle le VERB NOUN";
static const char __pyx_k_melisiniz_me_NOUN_VERB[] = "melisiniz me NOUN VERB";
static const char __pyx_k_mesindeki_me_NOUN_VERB[] = "mesindeki me NOUN VERB";
static const char __pyx_k_acaklarn_acak_NOUN_VERB[] = "acaklar\304\261n\304\261 acak NOUN VERB";
static const char __pyx_k_eceinize_ecek_NOUN_VERB[] = "ece\304\237inize ecek NOUN VERB";
static const char __pyx_k_eceinizi_ecek_NOUN_VERB[] = "ece\304\237inizi ecek NOUN VERB";
static const char __pyx_k_ecekleri_ecek_NOUN_VERB[] = "ecekleri ecek NOUN VERB";
static const char __pyx_k_lerimizden_le_VERB_NOUN[] = "lerimizden le VERB NOUN";
static const char __pyx_k_lerindeyse_le_VERB_NOUN[] = "lerindeyse le VERB NOUN";
static const char __pyx_k_lerinizden_le_VERB_NOUN[] = "lerinizden le VERB NOUN";
static const char __pyx_k_longest_root_exceptions[] = "longest_root_exceptions";
static const char __pyx_k_melidirler_me_NOUN_VERB[] = "melidirler me NOUN VERB";
static const char __pyx_k_eceinizin_ecek_NOUN_VERB[] = "ece\304\237inizin ecek NOUN VERB";
static const char __pyx_k_larndakiler_la_VERB_NOUN[] = "lar\304\261ndakiler la VERB NOUN";
static const char __pyx_k_lerindendir_le_VERB_NOUN[] = "lerindendir le VERB NOUN";
static const char __pyx_k_lerinizdeki_le_VERB_NOUN[] = "lerinizdeki le VERB NOUN";
static const char __pyx_k_eceinizdir_ecek_NOUN_VERB[] = "ece\304\237inizdir ecek NOUN VERB";
static const char __pyx_k_eceklerini_ecek_NOUN_VERB[] = "eceklerini ecek NOUN VERB";
static const char __pyx_k_larndakilere_la_VERB_NOUN[] = "lar\304\261ndakilere la VERB NOUN";
static const char __pyx_k_larndakileri_la_VERB_NOUN[] = "lar\304\261ndakileri la VERB NOUN";
static const char __pyx_k_lerimizdeydi_le_VERB_NOUN[] = "lerimizdeydi le VERB NOUN";
static const char __pyx_k_lerindekiler_le_VERB_NOUN[] = "lerindekiler le VERB NOUN";
static const char __pyx_k_pyx_unpickle_FsmParseList[] = "__pyx_unpickle_FsmParseList";
static const char __pyx_k_larndakilerin_la_VERB_NOUN[] = "lar\304\261ndakilerin la VERB NOUN";
static const char __pyx_k_lerindekilere_le_VERB_NOUN[] = "lerindekilere le VERB NOUN";
static const char __pyx_k_lerindekileri_le_VERB_NOUN[] = "lerindekileri le VERB NOUN";
static const char __pyx_k_reduceToParsesWithSameRoot[] = "reduceToParsesWithSameRoot";
static const char __pyx_k_getParseWithLongestRootWord[] = "getParseWithLongestRootWord";
static const char __pyx_k_lerindekilerin_le_VERB_NOUN[] = "lerindekilerin le VERB NOUN";
static const char __pyx_k_parsesWithoutPrefixAndSuffix[] = "parsesWithoutPrefixAndSuffix";
static const char __pyx_k_Incompatible_checksums_s_vs_0xb3[] = "Incompatible checksums (%s vs 0xb37bd0b = (__fsm_parses))";
static const char __pyx_k_MorphologicalAnalysis_FsmParseLi[] = "MorphologicalAnalysis.FsmParseList";
static const char __pyx_k_constructParseListForDifferentRo[] = "constructParseListForDifferentRootWithPos";
static const char __pyx_k_reduceToParsesWithSameRootAndPos[] = "reduceToParsesWithSameRootAndPos";
static PyObject *__pyx_kp_u_;
static PyObject *__pyx_n_s_FsmParseList;
static PyObject *__pyx_kp_s_Incompatible_checksums_s_vs_0xb3;
static PyObject *__pyx_n_s_MorphologicalAnalysis_FsmParseLi;
static PyObject *__pyx_n_s_PickleError;
static PyObject *__pyx_kp_u__2;
static PyObject *__pyx_kp_u__3;
static PyObject *__pyx_kp_u__4;
static PyObject *__pyx_kp_u__5;
static PyObject *__pyx_kp_u_aca_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acaklar_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acaklarn_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acaksa_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acaktr_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acam_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acam_acak_NOUN_VERB_2;
static PyObject *__pyx_kp_u_acamz_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acan_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acan_acak_NOUN_VERB_2;
static PyObject *__pyx_kp_u_acana_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acann_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acanz_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acanz_acak_NOUN_VERB_2;
static PyObject *__pyx_kp_u_acanza_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acanzdr_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acanzn_acak_NOUN_VERB;
static PyObject *__pyx_kp_u_acaz_acak_NOUN_VERB;
static PyObject *__pyx_n_s_addFsmParse;
static PyObject *__pyx_kp_u_ardm_ar_NOUN_VERB;
static PyObject *__pyx_kp_u_arken_ar_NOUN_VERB;
static PyObject *__pyx_kp_u_arsa_ar_NOUN_VERB;
static PyObject *__pyx_kp_u_arsak_ar_NOUN_VERB;
static PyObject *__pyx_kp_u_arsanz_ar_NOUN_VERB;
static PyObject *__pyx_kp_u_arsnz_ar_NOUN_VERB;
static PyObject *__pyx_kp_u_arz_ar_NOUN_VERB;
static PyObject *__pyx_n_s_cline_in_traceback;
static PyObject *__pyx_n_s_constructParseListForDifferentRo;
static PyObject *__pyx_n_s_dict;
static PyObject *__pyx_kp_u_ecei_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceim_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceimi_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceimiz_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_ecein_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceine_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceini_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceinin_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceiniz_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceinizdir_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceinize_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceinizi_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceinizin_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceiz_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_ecekleri_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_eceklerini_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_ecekse_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_ecektir_ecek_NOUN_VERB;
static PyObject *__pyx_kp_u_erdim_er_NOUN_VERB;
static PyObject *__pyx_kp_u_eriz_er_NOUN_VERB;
static PyObject *__pyx_kp_u_erken_er_NOUN_VERB;
static PyObject *__pyx_kp_u_erse_er_NOUN_VERB;
static PyObject *__pyx_kp_u_ersek_er_NOUN_VERB;
static PyObject *__pyx_kp_u_erseniz_er_NOUN_VERB;
static PyObject *__pyx_kp_u_ersiniz_er_NOUN_VERB;
static PyObject *__pyx_n_s_fsmParses;
static PyObject *__pyx_n_s_getFsmParse;
static PyObject *__pyx_n_s_getName;
static PyObject *__pyx_n_s_getParseWithLongestRootWord;
static PyObject *__pyx_n_s_getWord;
static PyObject *__pyx_n_s_getWordWithPos;
static PyObject *__pyx_n_s_getstate;
static PyObject *__pyx_kp_u_ilen_i_VERB_VERB;
static PyObject *__pyx_kp_u_ilen_ile_VERB_VERB;
static PyObject *__pyx_kp_u_ilene_i_VERB_VERB;
static PyObject *__pyx_kp_u_ilin_i_VERB_VERB;
static PyObject *__pyx_kp_u_ilince_i_VERB_VERB;
static PyObject *__pyx_kp_u_imiz_i_ADJ_NOUN;
static PyObject *__pyx_n_s_import;
static PyObject *__pyx_kp_u_in_i_ADJ_NOUN;
static PyObject *__pyx_kp_u_ince_i_NOUN_VERB;
static PyObject *__pyx_kp_u_inde_i_ADJ_NOUN;
static PyObject *__pyx_n_s_index;
static PyObject *__pyx_kp_u_ine_i_ADJ_NOUN;
static PyObject *__pyx_kp_u_ini_i_ADJ_NOUN;
static PyObject *__pyx_kp_u_inin_i_ADJ_NOUN;
static PyObject *__pyx_n_s_isLongestRootException;
static PyObject *__pyx_kp_u_la_la_VERB_NOUN;
static PyObject *__pyx_kp_u_lan_NOUN_VERB;
static PyObject *__pyx_kp_u_lana_NOUN_VERB;
static PyObject *__pyx_kp_u_lar_la_VERB_NOUN;
static PyObject *__pyx_kp_u_lar_la_VERB_NOUN_2;
static PyObject *__pyx_kp_u_lardan_la_VERB_NOUN;
static PyObject *__pyx_kp_u_lardandr_la_VERB_NOUN;
static PyObject *__pyx_kp_u_lardr_la_VERB_NOUN;
static PyObject *__pyx_kp_u_lardr_la_VERB_NOUN_2;
static PyObject *__pyx_kp_u_larm_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larmdan_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larmz_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larmz_la_VERB_NOUN_2;
static PyObject *__pyx_kp_u_larmza_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larmzda_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larmzdan_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larmzdayd_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larmzla_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larmzn_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larn_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larn_la_VERB_NOUN_2;
static PyObject *__pyx_kp_u_larna_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larnda_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larndaki_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larndakiler_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larndakilere_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larndakileri_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larndakilerin_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larndan_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larndandr_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larndaysa_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larnn_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larnz_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larnz_la_VERB_NOUN_2;
static PyObject *__pyx_kp_u_larnza_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larnzda_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larnzdaki_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larnzdan_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larnzla_la_VERB_NOUN;
static PyObject *__pyx_kp_u_larnzn_la_VERB_NOUN;
static PyObject *__pyx_kp_u_laryla_la_VERB_NOUN;
static PyObject *__pyx_kp_u_le_le_VERB_NOUN;
static PyObject *__pyx_kp_u_ler_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerden_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerdendir_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerdir_le_VERB_NOUN;
static PyObject *__pyx_kp_u_leri_le_VERB_NOUN;
static PyObject *__pyx_kp_u_leridir_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerim_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerimden_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerimiz_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerimizde_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerimizden_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerimizdeydi_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerimize_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerimizi_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerimizin_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerimizle_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerin_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerinde_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerindeki_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerindekiler_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerindekilere_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerindekileri_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerindekilerin_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerinden_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerindendir_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerindeyse_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerine_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerini_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerinin_le_VERB_NOUN;
static PyObject *__pyx_kp_u_leriniz_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerinizde_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerinizdeki_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerinizden_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerinize_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerinizi_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerinizin_le_VERB_NOUN;
static PyObject *__pyx_kp_u_lerinizle_le_VERB_NOUN;
static PyObject *__pyx_kp_u_leriyle_le_VERB_NOUN;
static PyObject *__pyx_kp_u_ln_NOUN_VERB;
static PyObject *__pyx_kp_u_lnca_NOUN_VERB;
static PyObject *__pyx_n_s_longest_root_exceptions;
static PyObject *__pyx_kp_u_madan_ma_NOUN_VERB;
static PyObject *__pyx_n_s_main;
static PyObject *__pyx_kp_u_mal_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_maldr_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_maldrlar_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_mallar_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_malsnz_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_malym_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_malyz_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_mam_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_mama_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_mamz_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_mamz_ma_NOUN_VERB_2;
static PyObject *__pyx_kp_u_mamza_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_manz_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_manz_ma_NOUN_VERB_2;
static PyObject *__pyx_kp_u_manzda_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_manzdr_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_manzla_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_mas_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_masdr_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_masn_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_masn_ma_NOUN_VERB_2;
static PyObject *__pyx_kp_u_masna_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_masnda_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_masndaki_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_masyla_ma_NOUN_VERB;
static PyObject *__pyx_kp_u_mdan_m_NOUN_NOUN;
static PyObject *__pyx_kp_u_meden_me_NOUN_VERB;
static PyObject *__pyx_kp_u_meli_me_NOUN_VERB;
static PyObject *__pyx_kp_u_melidir_me_NOUN_VERB;
static PyObject *__pyx_kp_u_melidirler_me_NOUN_VERB;
static PyObject *__pyx_kp_u_meliler_me_NOUN_VERB;
static PyObject *__pyx_kp_u_melisiniz_me_NOUN_VERB;
static PyObject *__pyx_kp_u_meliyim_me_NOUN_VERB;
static PyObject *__pyx_kp_u_meliyiz_me_NOUN_VERB;
static PyObject *__pyx_kp_u_mem_me_NOUN_VERB;
static PyObject *__pyx_kp_u_meme_me_NOUN_VERB;
static PyObject *__pyx_kp_u_memiz_me_NOUN_VERB;
static PyObject *__pyx_kp_u_memize_me_NOUN_VERB;
static PyObject *__pyx_kp_u_memizi_me_NOUN_VERB;
static PyObject *__pyx_kp_u_meniz_me_NOUN_VERB;
static PyObject *__pyx_kp_u_menizde_me_NOUN_VERB;
static PyObject *__pyx_kp_u_menizdir_me_NOUN_VERB;
static PyObject *__pyx_kp_u_menizi_me_NOUN_VERB;
static PyObject *__pyx_kp_u_menizle_me_NOUN_VERB;
static PyObject *__pyx_kp_u_mesi_me_NOUN_VERB;
static PyObject *__pyx_kp_u_mesidir_me_NOUN_VERB;
static PyObject *__pyx_kp_u_mesin_me_NOUN_VERB;
static PyObject *__pyx_kp_u_mesinde_me_NOUN_VERB;
static PyObject *__pyx_kp_u_mesindeki_me_NOUN_VERB;
static PyObject *__pyx_kp_u_mesine_me_NOUN_VERB;
static PyObject *__pyx_kp_u_mesini_me_NOUN_VERB;
static PyObject *__pyx_kp_u_mesiyle_me_NOUN_VERB;
static PyObject *__pyx_kp_u_mise_mi_NOUN_VERB;
static PyObject *__pyx_kp_u_mn_m_NOUN_NOUN;
static PyObject *__pyx_kp_u_msa_m_NOUN_VERB;
static PyObject *__pyx_kp_u_mz_m_NOUN_NOUN;
static PyObject *__pyx_kp_u_na_n_NOUN_NOUN;
static PyObject *__pyx_n_s_name;
static PyObject *__pyx_kp_u_nca_NOUN_VERB;
static PyObject *__pyx_kp_u_ne_n_NOUN_NOUN;
static PyObject *__pyx_kp_u_ne_n_VERB_NOUN;
static PyObject *__pyx_n_s_new;
static PyObject *__pyx_kp_u_nin_n_NOUN_NOUN;
static PyObject *__pyx_kp_u_niz_n_NOUN_NOUN;
static PyObject *__pyx_kp_u_nn_n_NOUN_NOUN;
static PyObject *__pyx_kp_u_nz_n_NOUN_NOUN;
static PyObject *__pyx_n_s_parsesWithoutPrefixAndSuffix;
static PyObject *__pyx_n_s_pickle;
static PyObject *__pyx_n_s_pop;
static PyObject *__pyx_n_s_pyx_PickleError;
static PyObject *__pyx_n_s_pyx_checksum;
static PyObject *__pyx_n_s_pyx_result;
static PyObject *__pyx_n_s_pyx_state;
static PyObject *__pyx_n_s_pyx_type;
static PyObject *__pyx_n_s_pyx_unpickle_FsmParseList;
static PyObject *__pyx_n_s_pyx_vtable;
static PyObject *__pyx_n_s_range;
static PyObject *__pyx_kp_u_rdim_r_NOUN_VERB;
static PyObject *__pyx_kp_u_rdm_r_NOUN_VERB;
static PyObject *__pyx_n_s_reduce;
static PyObject *__pyx_n_s_reduceToParsesWithSameRoot;
static PyObject *__pyx_n_s_reduceToParsesWithSameRootAndPos;
static PyObject *__pyx_n_s_reduce_cython;
static PyObject *__pyx_n_s_reduce_ex;
static PyObject *__pyx_n_s_rindex;
static PyObject *__pyx_kp_u_riz_r_NOUN_VERB;
static PyObject *__pyx_kp_u_rken_r_NOUN_VERB;
static PyObject *__pyx_n_s_rootWords;
static PyObject *__pyx_kp_u_rsa_r_NOUN_VERB;
static PyObject *__pyx_kp_u_rsak_r_NOUN_VERB;
static PyObject *__pyx_kp_u_rsanz_r_NOUN_VERB;
static PyObject *__pyx_kp_u_rse_r_NOUN_VERB;
static PyObject *__pyx_kp_u_rsek_r_NOUN_VERB;
static PyObject *__pyx_kp_u_rseniz_r_NOUN_VERB;
static PyObject *__pyx_kp_u_rsiniz_r_NOUN_VERB;
static PyObject *__pyx_kp_u_rsnz_r_NOUN_VERB;
static PyObject *__pyx_kp_u_rz_r_NOUN_VERB;
static PyObject *__pyx_kp_u_sa_sa_VERB_ADJ;
static PyObject *__pyx_kp_u_se_se_VERB_ADJ;
static PyObject *__pyx_n_s_setstate;
static PyObject *__pyx_n_s_setstate_cython;
static PyObject *__pyx_n_s_size;
static PyObject *__pyx_kp_s_stringsource;
static PyObject *__pyx_n_s_test;
static PyObject *__pyx_n_s_transitionList;
static PyObject *__pyx_kp_u_ulan_u_NOUN_VERB;
static PyObject *__pyx_kp_u_un_un_VERB_NOUN;
static PyObject *__pyx_kp_u_unca_u_NOUN_VERB;
static PyObject *__pyx_kp_u_unca_un_NOUN_VERB;
static PyObject *__pyx_kp_u_unun_un_VERB_NOUN;
static PyObject *__pyx_n_s_update;
static int __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList___init__(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, PyObject *__pyx_v_fsmParses); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_2size(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_4addFsmParse(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_fsmParse); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_6getFsmParse(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_v_index); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_8rootWords(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_10reduceToParsesWithSameRootAndPos(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_10Dictionary_4Word_Word *__pyx_v_currentWithPos); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_12getParseWithLongestRootWord(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_14isLongestRootException(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_fsmParse); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_16reduceToParsesWithSameRoot(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, PyObject *__pyx_v_currentRoot); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_18constructParseListForDifferentRootWithPos(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_20parsesWithoutPrefixAndSuffix(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_22__str__(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_24__reduce_cython__(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_26__setstate_cython__(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList___pyx_unpickle_FsmParseList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state); /* proto */
static PyObject *__pyx_tp_new_21MorphologicalAnalysis_12FsmParseList_FsmParseList(PyTypeObject *t, PyObject *a, PyObject *k); /*proto*/
static PyObject *__pyx_int_1;
static PyObject *__pyx_int_188202251;
static PyObject *__pyx_tuple__6;
static PyObject *__pyx_codeobj__7;
/* Late includes */

/* "MorphologicalAnalysis/FsmParseList.pyx":83
 *         "unca un NOUN VERB", "ilen ile VERB VERB"]
 * 
 *     def __init__(self, fsmParses: list):             # <<<<<<<<<<<<<<
 *         """
 *         A constructor of FsmParseList class which takes a list fsmParses as an input. First it sorts
 */

/* Python wrapper */
static int __pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList___init__[] = "\n        A constructor of FsmParseList class which takes a list fsmParses as an input. First it sorts\n        the items of the list then loops through it, if the current item's transitions equal to the next item's\n        transitions, it removes the latter item. At the end, it assigns this list to the fsmParses variable.\n\n        PARAMETERS\n        ----------\n        fsmParses : list\n            FsmParse list input.\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_21MorphologicalAnalysis_12FsmParseList_12FsmParseList___init__;
#endif
static int __pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_1__init__(PyObject *__pyx_v_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
  PyObject *__pyx_v_fsmParses = 0;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__init__ (wrapper)", 0);
  {
    static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_fsmParses,0};
    PyObject* values[1] = {0};
    if (unlikely(__pyx_kwds)) {
      Py_ssize_t kw_args;
      const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
      switch (pos_args) {
        case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
        CYTHON_FALLTHROUGH;
        case  0: break;
        default: goto __pyx_L5_argtuple_error;
      }
      kw_args = PyDict_Size(__pyx_kwds);
      switch (pos_args) {
        case  0:
        if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_fsmParses)) != 0)) kw_args--;
        else goto __pyx_L5_argtuple_error;
      }
      if (unlikely(kw_args > 0)) {
        if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__init__") < 0)) __PYX_ERR(0, 83, __pyx_L3_error)
      }
    } else if (PyTuple_GET_SIZE(__pyx_args) != 1) {
      goto __pyx_L5_argtuple_error;
    } else {
      values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    }
    __pyx_v_fsmParses = ((PyObject*)values[0]);
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L5_argtuple_error:;
  __Pyx_RaiseArgtupleInvalid("__init__", 1, 1, 1, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(0, 83, __pyx_L3_error)
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return -1;
  __pyx_L4_argument_unpacking_done:;
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_fsmParses), (&PyList_Type), 1, "fsmParses", 1))) __PYX_ERR(0, 83, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList___init__(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self), __pyx_v_fsmParses);

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static int __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList___init__(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, PyObject *__pyx_v_fsmParses) {
  int __pyx_v_i;
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  int __pyx_t_1;
  Py_ssize_t __pyx_t_2;
  int __pyx_t_3;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  PyObject *__pyx_t_6 = NULL;
  long __pyx_t_7;
  PyObject *__pyx_t_8 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__init__", 0);

  /* "MorphologicalAnalysis/FsmParseList.pyx":95
 *         """
 *         cdef int i
 *         fsmParses.sort()             # <<<<<<<<<<<<<<
 *         i = 0
 *         while i < len(fsmParses) - 1:
 */
  if (unlikely(__pyx_v_fsmParses == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "sort");
    __PYX_ERR(0, 95, __pyx_L1_error)
  }
  __pyx_t_1 = PyList_Sort(__pyx_v_fsmParses); if (unlikely(__pyx_t_1 == ((int)-1))) __PYX_ERR(0, 95, __pyx_L1_error)

  /* "MorphologicalAnalysis/FsmParseList.pyx":96
 *         cdef int i
 *         fsmParses.sort()
 *         i = 0             # <<<<<<<<<<<<<<
 *         while i < len(fsmParses) - 1:
 *             if fsmParses[i].transitionList() == fsmParses[i + 1].transitionList():
 */
  __pyx_v_i = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":97
 *         fsmParses.sort()
 *         i = 0
 *         while i < len(fsmParses) - 1:             # <<<<<<<<<<<<<<
 *             if fsmParses[i].transitionList() == fsmParses[i + 1].transitionList():
 *                 fsmParses.pop(i + 1)
 */
  while (1) {
    if (unlikely(__pyx_v_fsmParses == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 97, __pyx_L1_error)
    }
    __pyx_t_2 = PyList_GET_SIZE(__pyx_v_fsmParses); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 97, __pyx_L1_error)
    __pyx_t_3 = ((__pyx_v_i < (__pyx_t_2 - 1)) != 0);
    if (!__pyx_t_3) break;

    /* "MorphologicalAnalysis/FsmParseList.pyx":98
 *         i = 0
 *         while i < len(fsmParses) - 1:
 *             if fsmParses[i].transitionList() == fsmParses[i + 1].transitionList():             # <<<<<<<<<<<<<<
 *                 fsmParses.pop(i + 1)
 *                 i = i - 1
 */
    if (unlikely(__pyx_v_fsmParses == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 98, __pyx_L1_error)
    }
    __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_fsmParses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_6 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_transitionList); if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_6))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_6);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_6);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_6, function);
      }
    }
    __pyx_t_4 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_6, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_6);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    if (unlikely(__pyx_v_fsmParses == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 98, __pyx_L1_error)
    }
    __pyx_t_7 = (__pyx_v_i + 1);
    __pyx_t_5 = __Pyx_GetItemInt_List(__pyx_v_fsmParses, __pyx_t_7, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_5);
    __pyx_t_8 = __Pyx_PyObject_GetAttrStr(__pyx_t_5, __pyx_n_s_transitionList); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_8);
    __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
    __pyx_t_5 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_8))) {
      __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_8);
      if (likely(__pyx_t_5)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_8);
        __Pyx_INCREF(__pyx_t_5);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_8, function);
      }
    }
    __pyx_t_6 = (__pyx_t_5) ? __Pyx_PyObject_CallOneArg(__pyx_t_8, __pyx_t_5) : __Pyx_PyObject_CallNoArg(__pyx_t_8);
    __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
    if (unlikely(!__pyx_t_6)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_6);
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    __pyx_t_8 = PyObject_RichCompare(__pyx_t_4, __pyx_t_6, Py_EQ); __Pyx_XGOTREF(__pyx_t_8); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
    __pyx_t_3 = __Pyx_PyObject_IsTrue(__pyx_t_8); if (unlikely(__pyx_t_3 < 0)) __PYX_ERR(0, 98, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;
    if (__pyx_t_3) {

      /* "MorphologicalAnalysis/FsmParseList.pyx":99
 *         while i < len(fsmParses) - 1:
 *             if fsmParses[i].transitionList() == fsmParses[i + 1].transitionList():
 *                 fsmParses.pop(i + 1)             # <<<<<<<<<<<<<<
 *                 i = i - 1
 *             i = i + 1
 */
      if (unlikely(__pyx_v_fsmParses == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
        __PYX_ERR(0, 99, __pyx_L1_error)
      }
      __pyx_t_8 = __Pyx_PyList_PopIndex(__pyx_v_fsmParses, Py_None, (__pyx_v_i + 1), 1, long, __Pyx_PyInt_From_long); if (unlikely(!__pyx_t_8)) __PYX_ERR(0, 99, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_8);
      __Pyx_DECREF(__pyx_t_8); __pyx_t_8 = 0;

      /* "MorphologicalAnalysis/FsmParseList.pyx":100
 *             if fsmParses[i].transitionList() == fsmParses[i + 1].transitionList():
 *                 fsmParses.pop(i + 1)
 *                 i = i - 1             # <<<<<<<<<<<<<<
 *             i = i + 1
 *         self.__fsm_parses = fsmParses
 */
      __pyx_v_i = (__pyx_v_i - 1);

      /* "MorphologicalAnalysis/FsmParseList.pyx":98
 *         i = 0
 *         while i < len(fsmParses) - 1:
 *             if fsmParses[i].transitionList() == fsmParses[i + 1].transitionList():             # <<<<<<<<<<<<<<
 *                 fsmParses.pop(i + 1)
 *                 i = i - 1
 */
    }

    /* "MorphologicalAnalysis/FsmParseList.pyx":101
 *                 fsmParses.pop(i + 1)
 *                 i = i - 1
 *             i = i + 1             # <<<<<<<<<<<<<<
 *         self.__fsm_parses = fsmParses
 * 
 */
    __pyx_v_i = (__pyx_v_i + 1);
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":102
 *                 i = i - 1
 *             i = i + 1
 *         self.__fsm_parses = fsmParses             # <<<<<<<<<<<<<<
 * 
 *     cpdef int size(self):
 */
  __Pyx_INCREF(__pyx_v_fsmParses);
  __Pyx_GIVEREF(__pyx_v_fsmParses);
  __Pyx_GOTREF(__pyx_v_self->__pyx___fsm_parses);
  __Pyx_DECREF(__pyx_v_self->__pyx___fsm_parses);
  __pyx_v_self->__pyx___fsm_parses = __pyx_v_fsmParses;

  /* "MorphologicalAnalysis/FsmParseList.pyx":83
 *         "unca un NOUN VERB", "ilen ile VERB VERB"]
 * 
 *     def __init__(self, fsmParses: list):             # <<<<<<<<<<<<<<
 *         """
 *         A constructor of FsmParseList class which takes a list fsmParses as an input. First it sorts
 */

  /* function exit code */
  __pyx_r = 0;
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_XDECREF(__pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.__init__", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = -1;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":104
 *         self.__fsm_parses = fsmParses
 * 
 *     cpdef int size(self):             # <<<<<<<<<<<<<<
 *         """
 *         The size method returns the size of fsmParses list.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_3size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_size(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_skip_dispatch) {
  int __pyx_r;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("size", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_size); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 104, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_3size)) {
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 104, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_t_5 = __Pyx_PyInt_As_int(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 104, __pyx_L1_error)
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        __pyx_r = __pyx_t_5;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":113
 *             The size of fsmParses list.
 *         """
 *         return len(self.__fsm_parses)             # <<<<<<<<<<<<<<
 * 
 *     cpdef addFsmParse(self, FsmParse fsmParse):
 */
  __pyx_t_1 = __pyx_v_self->__pyx___fsm_parses;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 113, __pyx_L1_error)
  }
  __pyx_t_6 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_6 == ((Py_ssize_t)-1))) __PYX_ERR(0, 113, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_r = __pyx_t_6;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":104
 *         self.__fsm_parses = fsmParses
 * 
 *     cpdef int size(self):             # <<<<<<<<<<<<<<
 *         """
 *         The size method returns the size of fsmParses list.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_WriteUnraisable("MorphologicalAnalysis.FsmParseList.FsmParseList.size", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_3size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_2size[] = "\n        The size method returns the size of fsmParses list.\n\n        RETURNS\n        -------\n        int\n            The size of fsmParses list.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_3size(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("size (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_2size(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_2size(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("size", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __Pyx_PyInt_From_int(__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_size(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 104, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.size", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":115
 *         return len(self.__fsm_parses)
 * 
 *     cpdef addFsmParse(self, FsmParse fsmParse):             # <<<<<<<<<<<<<<
 *         self.__fsm_parses.append(fsmParse)
 * 
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_5addFsmParse(PyObject *__pyx_v_self, PyObject *__pyx_v_fsmParse); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_addFsmParse(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_fsmParse, int __pyx_skip_dispatch) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  int __pyx_t_5;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("addFsmParse", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_addFsmParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_5addFsmParse)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_fsmParse)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_fsmParse));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 115, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":116
 * 
 *     cpdef addFsmParse(self, FsmParse fsmParse):
 *         self.__fsm_parses.append(fsmParse)             # <<<<<<<<<<<<<<
 * 
 *     cpdef FsmParse getFsmParse(self, int index):
 */
  if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "append");
    __PYX_ERR(0, 116, __pyx_L1_error)
  }
  __pyx_t_5 = __Pyx_PyList_Append(__pyx_v_self->__pyx___fsm_parses, ((PyObject *)__pyx_v_fsmParse)); if (unlikely(__pyx_t_5 == ((int)-1))) __PYX_ERR(0, 116, __pyx_L1_error)

  /* "MorphologicalAnalysis/FsmParseList.pyx":115
 *         return len(self.__fsm_parses)
 * 
 *     cpdef addFsmParse(self, FsmParse fsmParse):             # <<<<<<<<<<<<<<
 *         self.__fsm_parses.append(fsmParse)
 * 
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.addFsmParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_5addFsmParse(PyObject *__pyx_v_self, PyObject *__pyx_v_fsmParse); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_5addFsmParse(PyObject *__pyx_v_self, PyObject *__pyx_v_fsmParse) {
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("addFsmParse (wrapper)", 0);
  if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_fsmParse), __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse, 1, "fsmParse", 0))) __PYX_ERR(0, 115, __pyx_L1_error)
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_4addFsmParse(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self), ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse));

  /* function exit code */
  goto __pyx_L0;
  __pyx_L1_error:;
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_4addFsmParse(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_fsmParse) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("addFsmParse", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_addFsmParse(__pyx_v_self, __pyx_v_fsmParse, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 115, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.addFsmParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":118
 *         self.__fsm_parses.append(fsmParse)
 * 
 *     cpdef FsmParse getFsmParse(self, int index):             # <<<<<<<<<<<<<<
 *         """
 *         The getFsmParse method takes an integer index as an input and returns the item of fsmParses list at given index.
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_7getFsmParse(PyObject *__pyx_v_self, PyObject *__pyx_arg_index); /*proto*/
static struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_getFsmParse(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_v_index, int __pyx_skip_dispatch) {
  struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  PyObject *__pyx_t_5 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFsmParse", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getFsmParse); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 118, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_7getFsmParse)) {
        __Pyx_XDECREF(((PyObject *)__pyx_r));
        __pyx_t_3 = __Pyx_PyInt_From_int(__pyx_v_index); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 118, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_4 = __pyx_t_1; __pyx_t_5 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_4))) {
          __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_4);
          if (likely(__pyx_t_5)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
            __Pyx_INCREF(__pyx_t_5);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_4, function);
          }
        }
        __pyx_t_2 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_5, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3);
        __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 118, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 118, __pyx_L1_error)
        __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":132
 *             The item of fsmParses list at given index.
 *         """
 *         return self.__fsm_parses[index]             # <<<<<<<<<<<<<<
 * 
 *     cpdef str rootWords(self):
 */
  __Pyx_XDECREF(((PyObject *)__pyx_r));
  if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 132, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_index, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 132, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 132, __pyx_L1_error)
  __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1);
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":118
 *         self.__fsm_parses.append(fsmParse)
 * 
 *     cpdef FsmParse getFsmParse(self, int index):             # <<<<<<<<<<<<<<
 *         """
 *         The getFsmParse method takes an integer index as an input and returns the item of fsmParses list at given index.
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.getFsmParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF((PyObject *)__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_7getFsmParse(PyObject *__pyx_v_self, PyObject *__pyx_arg_index); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_6getFsmParse[] = "\n        The getFsmParse method takes an integer index as an input and returns the item of fsmParses list at given index.\n\n        PARAMETERS\n        ----------\n        index : int\n            Integer input.\n\n        RETURNS\n        -------\n        FsmParse\n            The item of fsmParses list at given index.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_7getFsmParse(PyObject *__pyx_v_self, PyObject *__pyx_arg_index) {
  int __pyx_v_index;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("getFsmParse (wrapper)", 0);
  assert(__pyx_arg_index); {
    __pyx_v_index = __Pyx_PyInt_As_int(__pyx_arg_index); if (unlikely((__pyx_v_index == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 118, __pyx_L3_error)
  }
  goto __pyx_L4_argument_unpacking_done;
  __pyx_L3_error:;
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.getFsmParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __Pyx_RefNannyFinishContext();
  return NULL;
  __pyx_L4_argument_unpacking_done:;
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_6getFsmParse(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self), ((int)__pyx_v_index));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_6getFsmParse(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_v_index) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("getFsmParse", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = ((PyObject *)__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_getFsmParse(__pyx_v_self, __pyx_v_index, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 118, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.getFsmParse", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":134
 *         return self.__fsm_parses[index]
 * 
 *     cpdef str rootWords(self):             # <<<<<<<<<<<<<<
 *         """
 *         The rootWords method gets the first item's root of fsmParses list and uses it as currentRoot. Then loops through
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_9rootWords(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_rootWords(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_skip_dispatch) {
  PyObject *__pyx_v_result = 0;
  PyObject *__pyx_v_current_root = 0;
  int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  Py_ssize_t __pyx_t_6;
  int __pyx_t_7;
  int __pyx_t_8;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rootWords", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_rootWords); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 134, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_9rootWords)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 134, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 134, __pyx_L1_error)
        __pyx_r = ((PyObject*)__pyx_t_2);
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":148
 *         cdef str current_root
 *         cdef int i
 *         result = self.__fsm_parses[0].getWord().getName()             # <<<<<<<<<<<<<<
 *         current_root = result
 *         for i in range(1, len(self.__fsm_parses)):
 */
  if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 148, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_getWord); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 148, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 148, __pyx_L1_error)
  __pyx_v_result = ((PyObject*)__pyx_t_1);
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":149
 *         cdef int i
 *         result = self.__fsm_parses[0].getWord().getName()
 *         current_root = result             # <<<<<<<<<<<<<<
 *         for i in range(1, len(self.__fsm_parses)):
 *             if self.__fsm_parses[i].getWord().getName() != current_root:
 */
  __Pyx_INCREF(__pyx_v_result);
  __pyx_v_current_root = __pyx_v_result;

  /* "MorphologicalAnalysis/FsmParseList.pyx":150
 *         result = self.__fsm_parses[0].getWord().getName()
 *         current_root = result
 *         for i in range(1, len(self.__fsm_parses)):             # <<<<<<<<<<<<<<
 *             if self.__fsm_parses[i].getWord().getName() != current_root:
 *                 current_root = self.__fsm_parses[i].getWord().getName()
 */
  __pyx_t_1 = __pyx_v_self->__pyx___fsm_parses;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 150, __pyx_L1_error)
  }
  __pyx_t_5 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 150, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = __pyx_t_5;
  for (__pyx_t_7 = 1; __pyx_t_7 < __pyx_t_6; __pyx_t_7+=1) {
    __pyx_v_i = __pyx_t_7;

    /* "MorphologicalAnalysis/FsmParseList.pyx":151
 *         current_root = result
 *         for i in range(1, len(self.__fsm_parses)):
 *             if self.__fsm_parses[i].getWord().getName() != current_root:             # <<<<<<<<<<<<<<
 *                 current_root = self.__fsm_parses[i].getWord().getName()
 *                 result = result + "$" + current_root
 */
    if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 151, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getWord); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_4 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_getName); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 151, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_v_current_root, Py_NE)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 151, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (__pyx_t_8) {

      /* "MorphologicalAnalysis/FsmParseList.pyx":152
 *         for i in range(1, len(self.__fsm_parses)):
 *             if self.__fsm_parses[i].getWord().getName() != current_root:
 *                 current_root = self.__fsm_parses[i].getWord().getName()             # <<<<<<<<<<<<<<
 *                 result = result + "$" + current_root
 *         return result
 */
      if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 152, __pyx_L1_error)
      }
      __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_getWord); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_getName); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_3)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_3);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_1 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_2);
      __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(0, 152, __pyx_L1_error)
      __Pyx_DECREF_SET(__pyx_v_current_root, ((PyObject*)__pyx_t_1));
      __pyx_t_1 = 0;

      /* "MorphologicalAnalysis/FsmParseList.pyx":153
 *             if self.__fsm_parses[i].getWord().getName() != current_root:
 *                 current_root = self.__fsm_parses[i].getWord().getName()
 *                 result = result + "$" + current_root             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
      __pyx_t_1 = __Pyx_PyUnicode_ConcatSafe(__pyx_v_result, __pyx_kp_u_); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 153, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyUnicode_ConcatSafe(__pyx_t_1, __pyx_v_current_root); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 153, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF_SET(__pyx_v_result, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmParseList.pyx":151
 *         current_root = result
 *         for i in range(1, len(self.__fsm_parses)):
 *             if self.__fsm_parses[i].getWord().getName() != current_root:             # <<<<<<<<<<<<<<
 *                 current_root = self.__fsm_parses[i].getWord().getName()
 *                 result = result + "$" + current_root
 */
    }
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":154
 *                 current_root = self.__fsm_parses[i].getWord().getName()
 *                 result = result + "$" + current_root
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cpdef reduceToParsesWithSameRootAndPos(self, Word currentWithPos):
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_INCREF(__pyx_v_result);
  __pyx_r = __pyx_v_result;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":134
 *         return self.__fsm_parses[index]
 * 
 *     cpdef str rootWords(self):             # <<<<<<<<<<<<<<
 *         """
 *         The rootWords method gets the first item's root of fsmParses list and uses it as currentRoot. Then loops through
 */

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.rootWords", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XDECREF(__pyx_v_result);
  __Pyx_XDECREF(__pyx_v_current_root);
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_9rootWords(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_8rootWords[] = "\n        The rootWords method gets the first item's root of fsmParses list and uses it as currentRoot. Then loops through\n        the fsmParses, if the current item's root does not equal to the currentRoot, it then assigns it as the\n        currentRoot and accumulates root words in a string result.\n\n        RETURNS\n        -------\n        str\n            String result that has root words.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_9rootWords(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
  PyObject *__pyx_r = 0;
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("rootWords (wrapper)", 0);
  __pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_8rootWords(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self));

  /* function exit code */
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_8rootWords(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self) {
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("rootWords", 0);
  __Pyx_XDECREF(__pyx_r);
  __pyx_t_1 = __pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_rootWords(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 134, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_r = __pyx_t_1;
  __pyx_t_1 = 0;
  goto __pyx_L0;

  /* function exit code */
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.rootWords", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = NULL;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":156
 *         return result
 * 
 *     cpdef reduceToParsesWithSameRootAndPos(self, Word currentWithPos):             # <<<<<<<<<<<<<<
 *         """
 *         The reduceToParsesWithSameRootAndPos method takes a Word} currentWithPos as an input and loops i times till
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_11reduceToParsesWithSameRootAndPos(PyObject *__pyx_v_self, PyObject *__pyx_v_currentWithPos); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_reduceToParsesWithSameRootAndPos(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_10Dictionary_4Word_Word *__pyx_v_currentWithPos, int __pyx_skip_dispatch) {
  int __pyx_v_i;
  PyObject *__pyx_r = NULL;
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  PyObject *__pyx_t_2 = NULL;
  PyObject *__pyx_t_3 = NULL;
  PyObject *__pyx_t_4 = NULL;
  Py_ssize_t __pyx_t_5;
  int __pyx_t_6;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("reduceToParsesWithSameRootAndPos", 0);
  /* Check if called by wrapper */
  if (unlikely(__pyx_skip_dispatch)) ;
  /* Check if overridden in Python */
  else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
      PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      #endif
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_reduceToParsesWithSameRootAndPos); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_11reduceToParsesWithSameRootAndPos)) {
        __Pyx_XDECREF(__pyx_r);
        __Pyx_INCREF(__pyx_t_1);
        __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
        if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
          __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
          if (likely(__pyx_t_4)) {
            PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
            __Pyx_INCREF(__pyx_t_4);
            __Pyx_INCREF(function);
            __Pyx_DECREF_SET(__pyx_t_3, function);
          }
        }
        __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_currentWithPos)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_currentWithPos));
        __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
        if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 156, __pyx_L1_error)
        __Pyx_GOTREF(__pyx_t_2);
        __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
        __pyx_r = __pyx_t_2;
        __pyx_t_2 = 0;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        goto __pyx_L0;
      }
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
      __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
      __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
      if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
        __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
      }
      #endif
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    }
    #endif
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":168
 *         """
 *         cdef int i
 *         i = 0             # <<<<<<<<<<<<<<
 *         while i < len(self.__fsm_parses):
 *             if self.__fsm_parses[i].getWordWithPos() != currentWithPos:
 */
  __pyx_v_i = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":169
 *         cdef int i
 *         i = 0
 *         while i < len(self.__fsm_parses):             # <<<<<<<<<<<<<<
 *             if self.__fsm_parses[i].getWordWithPos() != currentWithPos:
 *                 self.__fsm_parses.pop(i)
 */
  while (1) {
    __pyx_t_1 = __pyx_v_self->__pyx___fsm_parses;
    __Pyx_INCREF(__pyx_t_1);
    if (unlikely(__pyx_t_1 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 169, __pyx_L1_error)
    }
    __pyx_t_5 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 169, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = ((__pyx_v_i < __pyx_t_5) != 0);
    if (!__pyx_t_6) break;

    /* "MorphologicalAnalysis/FsmParseList.pyx":170
 *         i = 0
 *         while i < len(self.__fsm_parses):
 *             if self.__fsm_parses[i].getWordWithPos() != currentWithPos:             # <<<<<<<<<<<<<<
 *                 self.__fsm_parses.pop(i)
 *             else:
 */
    if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 170, __pyx_L1_error)
    }
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getWordWithPos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_2)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_2);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 170, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = PyObject_RichCompare(__pyx_t_1, ((PyObject *)__pyx_v_currentWithPos), Py_NE); __Pyx_XGOTREF(__pyx_t_3); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 170, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_3); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 170, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/FsmParseList.pyx":171
 *         while i < len(self.__fsm_parses):
 *             if self.__fsm_parses[i].getWordWithPos() != currentWithPos:
 *                 self.__fsm_parses.pop(i)             # <<<<<<<<<<<<<<
 *             else:
 *                 i = i + 1
 */
      if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
        PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
        __PYX_ERR(0, 171, __pyx_L1_error)
      }
      __pyx_t_3 = __Pyx_PyList_PopIndex(__pyx_v_self->__pyx___fsm_parses, Py_None, __pyx_v_i, 1, int, __Pyx_PyInt_From_int); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 171, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "MorphologicalAnalysis/FsmParseList.pyx":170
 *         i = 0
 *         while i < len(self.__fsm_parses):
 *             if self.__fsm_parses[i].getWordWithPos() != currentWithPos:             # <<<<<<<<<<<<<<
 *                 self.__fsm_parses.pop(i)
 *             else:
 */
      goto __pyx_L5;
    }

    /* "MorphologicalAnalysis/FsmParseList.pyx":173
 *                 self.__fsm_parses.pop(i)
 *             else:
 *                 i = i + 1             # <<<<<<<<<<<<<<
 * 
 *     cpdef FsmParse getParseWithLongestRootWord(self):
 */
    /*else*/ {
      __pyx_v_i = (__pyx_v_i + 1);
    }
    __pyx_L5:;
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":156
 *         return result
 * 
 *     cpdef reduceToParsesWithSameRootAndPos(self, Word currentWithPos):             # <<<<<<<<<<<<<<
 *         """
 *         The reduceToParsesWithSameRootAndPos method takes a Word} currentWithPos as an input and loops i times till
 */

  /* function exit code */
  __pyx_r = Py_None; __Pyx_INCREF(Py_None);
  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_2);
  __Pyx_XDECREF(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_4);
  __Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.reduceToParsesWithSameRootAndPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
  __pyx_r = 0;
  __pyx_L0:;
  __Pyx_XGIVEREF(__pyx_r);
  __Pyx_RefNannyFinishContext();
  return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_11reduceToParsesWithSameRootAndPos(PyObject *__pyx_v_self, PyObject *__pyx_v_currentWithPos); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_10reduceToParsesWithSameRootAndPos[] = "\n        The reduceToParsesWithSameRootAndPos method takes a Word} currentWithPos as an input and loops i times till\n        i equals to the size of the fsmParses list. If the given currentWithPos does not equal to the ith item's\n        root and the MorphologicalTag of the first inflectional of fsmParses, it removes the ith item from the list.\n\n        PARAMETERS\n        ----------\n        currentWithPos : Word\n            Word input.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_11reduceToParsesWithSameRootAndPos(PyObject *__pyx_v_self, PyObject *__pyx_v_currentWithPos) {
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("reduceToParsesWithSameRootAndPos (wrapper)", 0);
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_currentWithPos), __pyx_ptype_10Dictionary_4Word_Word, 1, "currentWithPos", 0))) __PYX_ERR(0, 156, __pyx_L1_error)
__pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_10reduceToParsesWithSameRootAndPos(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self), ((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_v_currentWithPos));

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = NULL;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_10reduceToParsesWithSameRootAndPos(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_10Dictionary_4Word_Word *__pyx_v_currentWithPos) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("reduceToParsesWithSameRootAndPos", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_reduceToParsesWithSameRootAndPos(__pyx_v_self, __pyx_v_currentWithPos, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 156, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.reduceToParsesWithSameRootAndPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":175
 *                 i = i + 1
 * 
 *     cpdef FsmParse getParseWithLongestRootWord(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getParseWithLongestRootWord method returns the parse with the longest root word. If more than one parse has
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_13getParseWithLongestRootWord(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_getParseWithLongestRootWord(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_skip_dispatch) {
int __pyx_v_max_length;
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_best_parse = 0;
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_current_parse = 0;
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
Py_ssize_t __pyx_t_5;
int __pyx_t_6;
Py_ssize_t __pyx_t_7;
int __pyx_t_8;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("getParseWithLongestRootWord", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_getParseWithLongestRootWord); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 175, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_13getParseWithLongestRootWord)) {
      __Pyx_XDECREF(((PyObject *)__pyx_r));
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 175, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 175, __pyx_L1_error)
      __pyx_r = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "MorphologicalAnalysis/FsmParseList.pyx":187
 *         cdef int max_length
 *         cdef FsmParse best_parse, current_parse
 *         max_length = -1             # <<<<<<<<<<<<<<
 *         best_parse = None
 *         if len(self.__fsm_parses) > 0:
 */
__pyx_v_max_length = -1;

/* "MorphologicalAnalysis/FsmParseList.pyx":188
 *         cdef FsmParse best_parse, current_parse
 *         max_length = -1
 *         best_parse = None             # <<<<<<<<<<<<<<
 *         if len(self.__fsm_parses) > 0:
 *             best_parse = self.__fsm_parses[0]
 */
__Pyx_INCREF(Py_None);
__pyx_v_best_parse = ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)Py_None);

/* "MorphologicalAnalysis/FsmParseList.pyx":189
 *         max_length = -1
 *         best_parse = None
 *         if len(self.__fsm_parses) > 0:             # <<<<<<<<<<<<<<
 *             best_parse = self.__fsm_parses[0]
 *         for current_parse in self.__fsm_parses:
 */
__pyx_t_1 = __pyx_v_self->__pyx___fsm_parses;
__Pyx_INCREF(__pyx_t_1);
if (unlikely(__pyx_t_1 == Py_None)) {
  PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
  __PYX_ERR(0, 189, __pyx_L1_error)
}
__pyx_t_5 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 189, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_t_6 = ((__pyx_t_5 > 0) != 0);
if (__pyx_t_6) {

  /* "MorphologicalAnalysis/FsmParseList.pyx":190
 *         best_parse = None
 *         if len(self.__fsm_parses) > 0:
 *             best_parse = self.__fsm_parses[0]             # <<<<<<<<<<<<<<
 *         for current_parse in self.__fsm_parses:
 *             if len(current_parse.getWord().getName()) > max_length and not self.isLongestRootException(current_parse):
 */
  if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 190, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (!(likely(((__pyx_t_1) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_1, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 190, __pyx_L1_error)
  __Pyx_DECREF_SET(__pyx_v_best_parse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_1));
  __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":189
 *         max_length = -1
 *         best_parse = None
 *         if len(self.__fsm_parses) > 0:             # <<<<<<<<<<<<<<
 *             best_parse = self.__fsm_parses[0]
 *         for current_parse in self.__fsm_parses:
 */
}

/* "MorphologicalAnalysis/FsmParseList.pyx":191
 *         if len(self.__fsm_parses) > 0:
 *             best_parse = self.__fsm_parses[0]
 *         for current_parse in self.__fsm_parses:             # <<<<<<<<<<<<<<
 *             if len(current_parse.getWord().getName()) > max_length and not self.isLongestRootException(current_parse):
 *                 max_length = len(current_parse.getWord().getName())
 */
if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
  PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
  __PYX_ERR(0, 191, __pyx_L1_error)
}
__pyx_t_1 = __pyx_v_self->__pyx___fsm_parses; __Pyx_INCREF(__pyx_t_1); __pyx_t_5 = 0;
for (;;) {
  if (__pyx_t_5 >= PyList_GET_SIZE(__pyx_t_1)) break;
  #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
  __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_5); __Pyx_INCREF(__pyx_t_2); __pyx_t_5++; if (unlikely(0 < 0)) __PYX_ERR(0, 191, __pyx_L1_error)
  #else
  __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_5); __pyx_t_5++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  #endif
  if (!(likely(((__pyx_t_2) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_2, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 191, __pyx_L1_error)
  __Pyx_XDECREF_SET(__pyx_v_current_parse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":192
 *             best_parse = self.__fsm_parses[0]
 *         for current_parse in self.__fsm_parses:
 *             if len(current_parse.getWord().getName()) > max_length and not self.isLongestRootException(current_parse):             # <<<<<<<<<<<<<<
 *                 max_length = len(current_parse.getWord().getName())
 *                 best_parse = current_parse
 */
  __pyx_t_2 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_current_parse->__pyx_base.__pyx_vtab)->__pyx_base.getWord(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_current_parse), 0)); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2)->__pyx_vtab)->getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_2), 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 192, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_3); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 192, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_8 = ((__pyx_t_7 > __pyx_v_max_length) != 0);
  if (__pyx_t_8) {
  } else {
    __pyx_t_6 = __pyx_t_8;
    goto __pyx_L7_bool_binop_done;
  }
  __pyx_t_8 = ((!(((struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self->__pyx_vtab)->isLongestRootException(__pyx_v_self, __pyx_v_current_parse, 0) != 0)) != 0);
  __pyx_t_6 = __pyx_t_8;
  __pyx_L7_bool_binop_done:;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/FsmParseList.pyx":193
 *         for current_parse in self.__fsm_parses:
 *             if len(current_parse.getWord().getName()) > max_length and not self.isLongestRootException(current_parse):
 *                 max_length = len(current_parse.getWord().getName())             # <<<<<<<<<<<<<<
 *                 best_parse = current_parse
 *         return best_parse
 */
    __pyx_t_3 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_current_parse->__pyx_base.__pyx_vtab)->__pyx_base.getWord(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_current_parse), 0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_3)->__pyx_vtab)->getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_3), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 193, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__pyx_t_2 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 193, __pyx_L1_error)
    }
    __pyx_t_7 = __Pyx_PyUnicode_GET_LENGTH(__pyx_t_2); if (unlikely(__pyx_t_7 == ((Py_ssize_t)-1))) __PYX_ERR(0, 193, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_v_max_length = __pyx_t_7;

    /* "MorphologicalAnalysis/FsmParseList.pyx":194
 *             if len(current_parse.getWord().getName()) > max_length and not self.isLongestRootException(current_parse):
 *                 max_length = len(current_parse.getWord().getName())
 *                 best_parse = current_parse             # <<<<<<<<<<<<<<
 *         return best_parse
 * 
 */
    __Pyx_INCREF(((PyObject *)__pyx_v_current_parse));
    __Pyx_DECREF_SET(__pyx_v_best_parse, __pyx_v_current_parse);

    /* "MorphologicalAnalysis/FsmParseList.pyx":192
 *             best_parse = self.__fsm_parses[0]
 *         for current_parse in self.__fsm_parses:
 *             if len(current_parse.getWord().getName()) > max_length and not self.isLongestRootException(current_parse):             # <<<<<<<<<<<<<<
 *                 max_length = len(current_parse.getWord().getName())
 *                 best_parse = current_parse
 */
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":191
 *         if len(self.__fsm_parses) > 0:
 *             best_parse = self.__fsm_parses[0]
 *         for current_parse in self.__fsm_parses:             # <<<<<<<<<<<<<<
 *             if len(current_parse.getWord().getName()) > max_length and not self.isLongestRootException(current_parse):
 *                 max_length = len(current_parse.getWord().getName())
 */
}
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "MorphologicalAnalysis/FsmParseList.pyx":195
 *                 max_length = len(current_parse.getWord().getName())
 *                 best_parse = current_parse
 *         return best_parse             # <<<<<<<<<<<<<<
 * 
 *     cpdef bint isLongestRootException(self, FsmParse fsmParse):
 */
__Pyx_XDECREF(((PyObject *)__pyx_r));
__Pyx_INCREF(((PyObject *)__pyx_v_best_parse));
__pyx_r = __pyx_v_best_parse;
goto __pyx_L0;

/* "MorphologicalAnalysis/FsmParseList.pyx":175
 *                 i = i + 1
 * 
 *     cpdef FsmParse getParseWithLongestRootWord(self):             # <<<<<<<<<<<<<<
 *         """
 *         The getParseWithLongestRootWord method returns the parse with the longest root word. If more than one parse has
 */

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.getParseWithLongestRootWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF((PyObject *)__pyx_v_best_parse);
__Pyx_XDECREF((PyObject *)__pyx_v_current_parse);
__Pyx_XGIVEREF((PyObject *)__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_13getParseWithLongestRootWord(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_12getParseWithLongestRootWord[] = "\n        The getParseWithLongestRootWord method returns the parse with the longest root word. If more than one parse has\n        the longest root word, the first parse with that root is returned. If the longest root word belongs to an\n        exceptional case, the parse with the next longest root word that does not, is returned.        \n\n        RETURNS\n        -------\n        Parse with the longest root word.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_13getParseWithLongestRootWord(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("getParseWithLongestRootWord (wrapper)", 0);
__pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_12getParseWithLongestRootWord(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_12getParseWithLongestRootWord(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("getParseWithLongestRootWord", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = ((PyObject *)__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_getParseWithLongestRootWord(__pyx_v_self, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 175, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.getParseWithLongestRootWord", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":197
 *         return best_parse
 * 
 *     cpdef bint isLongestRootException(self, FsmParse fsmParse):             # <<<<<<<<<<<<<<
 *         """
 *         The isLongestRootException method returns true if the longest root word belongs to an exceptional case, false
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_15isLongestRootException(PyObject *__pyx_v_self, PyObject *__pyx_v_fsmParse); /*proto*/
static int __pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_isLongestRootException(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_fsmParse, int __pyx_skip_dispatch) {
PyObject *__pyx_v_surface_form = 0;
PyObject *__pyx_v_root = 0;
PyObject *__pyx_v_longest_root_exception = 0;
PyObject *__pyx_v_exception_items = 0;
PyObject *__pyx_v_surface_form_ending = 0;
PyObject *__pyx_v_longest_root_ending = 0;
PyObject *__pyx_v_longest_root_pos = 0;
PyObject *__pyx_v_possible_root_pos = 0;
PyObject *__pyx_v_possible_root = 0;
struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_current_parse = 0;
int __pyx_r;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
int __pyx_t_5;
Py_ssize_t __pyx_t_6;
PyObject *(*__pyx_t_7)(PyObject *);
int __pyx_t_8;
int __pyx_t_9;
Py_ssize_t __pyx_t_10;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("isLongestRootException", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_isLongestRootException); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 197, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_15isLongestRootException)) {
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, ((PyObject *)__pyx_v_fsmParse)) : __Pyx_PyObject_CallOneArg(__pyx_t_3, ((PyObject *)__pyx_v_fsmParse));
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 197, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_5 = __Pyx_PyObject_IsTrue(__pyx_t_2); if (unlikely((__pyx_t_5 == (int)-1) && PyErr_Occurred())) __PYX_ERR(0, 197, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_r = __pyx_t_5;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "MorphologicalAnalysis/FsmParseList.pyx":214
 *         cdef str surface_form_ending, longest_root_ending, longest_root_pos, possible_root_pos, possible_root
 *         cdef FsmParse current_parse
 *         surface_form = fsmParse.getSurfaceForm()             # <<<<<<<<<<<<<<
 *         root = fsmParse.getWord().getName()
 *         for longest_root_exception in self.longest_root_exceptions:
 */
__pyx_t_1 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->getSurfaceForm(__pyx_v_fsmParse, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 214, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_surface_form = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "MorphologicalAnalysis/FsmParseList.pyx":215
 *         cdef FsmParse current_parse
 *         surface_form = fsmParse.getSurfaceForm()
 *         root = fsmParse.getWord().getName()             # <<<<<<<<<<<<<<
 *         for longest_root_exception in self.longest_root_exceptions:
 *             exception_items = longest_root_exception.split(" ")
 */
__pyx_t_1 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->__pyx_base.getWord(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_fsmParse), 0)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 215, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_t_2 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_1)->__pyx_vtab)->getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_1), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 215, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_v_root = ((PyObject*)__pyx_t_2);
__pyx_t_2 = 0;

/* "MorphologicalAnalysis/FsmParseList.pyx":216
 *         surface_form = fsmParse.getSurfaceForm()
 *         root = fsmParse.getWord().getName()
 *         for longest_root_exception in self.longest_root_exceptions:             # <<<<<<<<<<<<<<
 *             exception_items = longest_root_exception.split(" ")
 *             surface_form_ending = exception_items[0]
 */
__pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_longest_root_exceptions); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 216, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
if (likely(PyList_CheckExact(__pyx_t_2)) || PyTuple_CheckExact(__pyx_t_2)) {
  __pyx_t_1 = __pyx_t_2; __Pyx_INCREF(__pyx_t_1); __pyx_t_6 = 0;
  __pyx_t_7 = NULL;
} else {
  __pyx_t_6 = -1; __pyx_t_1 = PyObject_GetIter(__pyx_t_2); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 216, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_7 = Py_TYPE(__pyx_t_1)->tp_iternext; if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 216, __pyx_L1_error)
}
__Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
for (;;) {
  if (likely(!__pyx_t_7)) {
    if (likely(PyList_CheckExact(__pyx_t_1))) {
      if (__pyx_t_6 >= PyList_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyList_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 216, __pyx_L1_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
    } else {
      if (__pyx_t_6 >= PyTuple_GET_SIZE(__pyx_t_1)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_2 = PyTuple_GET_ITEM(__pyx_t_1, __pyx_t_6); __Pyx_INCREF(__pyx_t_2); __pyx_t_6++; if (unlikely(0 < 0)) __PYX_ERR(0, 216, __pyx_L1_error)
      #else
      __pyx_t_2 = PySequence_ITEM(__pyx_t_1, __pyx_t_6); __pyx_t_6++; if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 216, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      #endif
    }
  } else {
    __pyx_t_2 = __pyx_t_7(__pyx_t_1);
    if (unlikely(!__pyx_t_2)) {
      PyObject* exc_type = PyErr_Occurred();
      if (exc_type) {
        if (likely(__Pyx_PyErr_GivenExceptionMatches(exc_type, PyExc_StopIteration))) PyErr_Clear();
        else __PYX_ERR(0, 216, __pyx_L1_error)
      }
      break;
    }
    __Pyx_GOTREF(__pyx_t_2);
  }
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 216, __pyx_L1_error)
  __Pyx_XDECREF_SET(__pyx_v_longest_root_exception, ((PyObject*)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":217
 *         root = fsmParse.getWord().getName()
 *         for longest_root_exception in self.longest_root_exceptions:
 *             exception_items = longest_root_exception.split(" ")             # <<<<<<<<<<<<<<
 *             surface_form_ending = exception_items[0]
 *             longest_root_ending = exception_items[1]
 */
  if (unlikely(__pyx_v_longest_root_exception == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "split");
    __PYX_ERR(0, 217, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_Split(__pyx_v_longest_root_exception, __pyx_kp_u__2, -1L); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 217, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XDECREF_SET(__pyx_v_exception_items, ((PyObject*)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":218
 *         for longest_root_exception in self.longest_root_exceptions:
 *             exception_items = longest_root_exception.split(" ")
 *             surface_form_ending = exception_items[0]             # <<<<<<<<<<<<<<
 *             longest_root_ending = exception_items[1]
 *             longest_root_pos = exception_items[2]
 */
  if (unlikely(__pyx_v_exception_items == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 218, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_exception_items, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 218, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 218, __pyx_L1_error)
  __Pyx_XDECREF_SET(__pyx_v_surface_form_ending, ((PyObject*)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":219
 *             exception_items = longest_root_exception.split(" ")
 *             surface_form_ending = exception_items[0]
 *             longest_root_ending = exception_items[1]             # <<<<<<<<<<<<<<
 *             longest_root_pos = exception_items[2]
 *             possible_root_pos = exception_items[3]
 */
  if (unlikely(__pyx_v_exception_items == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 219, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_exception_items, 1, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 219, __pyx_L1_error)
  __Pyx_XDECREF_SET(__pyx_v_longest_root_ending, ((PyObject*)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":220
 *             surface_form_ending = exception_items[0]
 *             longest_root_ending = exception_items[1]
 *             longest_root_pos = exception_items[2]             # <<<<<<<<<<<<<<
 *             possible_root_pos = exception_items[3]
 *             possible_root = surface_form.replace(surface_form_ending, "")
 */
  if (unlikely(__pyx_v_exception_items == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 220, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_exception_items, 2, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 220, __pyx_L1_error)
  __Pyx_XDECREF_SET(__pyx_v_longest_root_pos, ((PyObject*)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":221
 *             longest_root_ending = exception_items[1]
 *             longest_root_pos = exception_items[2]
 *             possible_root_pos = exception_items[3]             # <<<<<<<<<<<<<<
 *             possible_root = surface_form.replace(surface_form_ending, "")
 *             if surface_form.endswith(surface_form_ending) and root.endswith(longest_root_ending) \
 */
  if (unlikely(__pyx_v_exception_items == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 221, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_exception_items, 3, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 221, __pyx_L1_error)
  __Pyx_XDECREF_SET(__pyx_v_possible_root_pos, ((PyObject*)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":222
 *             longest_root_pos = exception_items[2]
 *             possible_root_pos = exception_items[3]
 *             possible_root = surface_form.replace(surface_form_ending, "")             # <<<<<<<<<<<<<<
 *             if surface_form.endswith(surface_form_ending) and root.endswith(longest_root_ending) \
 *                     and fsmParse.getRootPos() == longest_root_pos:
 */
  if (unlikely(__pyx_v_surface_form == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "replace");
    __PYX_ERR(0, 222, __pyx_L1_error)
  }
  __pyx_t_2 = PyUnicode_Replace(__pyx_v_surface_form, __pyx_v_surface_form_ending, __pyx_kp_u__3, -1L); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 222, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_XDECREF_SET(__pyx_v_possible_root, ((PyObject*)__pyx_t_2));
  __pyx_t_2 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":223
 *             possible_root_pos = exception_items[3]
 *             possible_root = surface_form.replace(surface_form_ending, "")
 *             if surface_form.endswith(surface_form_ending) and root.endswith(longest_root_ending) \             # <<<<<<<<<<<<<<
 *                     and fsmParse.getRootPos() == longest_root_pos:
 *                 for current_parse in self.__fsm_parses:
 */
  if (unlikely(__pyx_v_surface_form == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
    __PYX_ERR(0, 223, __pyx_L1_error)
  }
  __pyx_t_8 = __Pyx_PyUnicode_Tailmatch(__pyx_v_surface_form, __pyx_v_surface_form_ending, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 223, __pyx_L1_error)
  if ((__pyx_t_8 != 0)) {
  } else {
    __pyx_t_5 = (__pyx_t_8 != 0);
    goto __pyx_L6_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":224
 *             possible_root = surface_form.replace(surface_form_ending, "")
 *             if surface_form.endswith(surface_form_ending) and root.endswith(longest_root_ending) \
 *                     and fsmParse.getRootPos() == longest_root_pos:             # <<<<<<<<<<<<<<
 *                 for current_parse in self.__fsm_parses:
 *                     if current_parse.getWord().getName() == possible_root \
 */
  if (unlikely(__pyx_v_root == Py_None)) {
    PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "endswith");
    __PYX_ERR(0, 223, __pyx_L1_error)
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":223
 *             possible_root_pos = exception_items[3]
 *             possible_root = surface_form.replace(surface_form_ending, "")
 *             if surface_form.endswith(surface_form_ending) and root.endswith(longest_root_ending) \             # <<<<<<<<<<<<<<
 *                     and fsmParse.getRootPos() == longest_root_pos:
 *                 for current_parse in self.__fsm_parses:
 */
  __pyx_t_8 = __Pyx_PyUnicode_Tailmatch(__pyx_v_root, __pyx_v_longest_root_ending, 0, PY_SSIZE_T_MAX, 1); if (unlikely(__pyx_t_8 == ((int)-1))) __PYX_ERR(0, 223, __pyx_L1_error)
  if ((__pyx_t_8 != 0)) {
  } else {
    __pyx_t_5 = (__pyx_t_8 != 0);
    goto __pyx_L6_bool_binop_done;
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":224
 *             possible_root = surface_form.replace(surface_form_ending, "")
 *             if surface_form.endswith(surface_form_ending) and root.endswith(longest_root_ending) \
 *                     and fsmParse.getRootPos() == longest_root_pos:             # <<<<<<<<<<<<<<
 *                 for current_parse in self.__fsm_parses:
 *                     if current_parse.getWord().getName() == possible_root \
 */
  __pyx_t_2 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse->__pyx_base.__pyx_vtab)->__pyx_base.getRootPos(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_fsmParse), 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_2, __pyx_v_longest_root_pos, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 224, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_9 = (__pyx_t_8 != 0);
  __pyx_t_5 = __pyx_t_9;
  __pyx_L6_bool_binop_done:;

  /* "MorphologicalAnalysis/FsmParseList.pyx":223
 *             possible_root_pos = exception_items[3]
 *             possible_root = surface_form.replace(surface_form_ending, "")
 *             if surface_form.endswith(surface_form_ending) and root.endswith(longest_root_ending) \             # <<<<<<<<<<<<<<
 *                     and fsmParse.getRootPos() == longest_root_pos:
 *                 for current_parse in self.__fsm_parses:
 */
  if (__pyx_t_5) {

    /* "MorphologicalAnalysis/FsmParseList.pyx":225
 *             if surface_form.endswith(surface_form_ending) and root.endswith(longest_root_ending) \
 *                     and fsmParse.getRootPos() == longest_root_pos:
 *                 for current_parse in self.__fsm_parses:             # <<<<<<<<<<<<<<
 *                     if current_parse.getWord().getName() == possible_root \
 *                             and current_parse.getRootPos() == possible_root_pos:
 */
    if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not iterable");
      __PYX_ERR(0, 225, __pyx_L1_error)
    }
    __pyx_t_2 = __pyx_v_self->__pyx___fsm_parses; __Pyx_INCREF(__pyx_t_2); __pyx_t_10 = 0;
    for (;;) {
      if (__pyx_t_10 >= PyList_GET_SIZE(__pyx_t_2)) break;
      #if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
      __pyx_t_3 = PyList_GET_ITEM(__pyx_t_2, __pyx_t_10); __Pyx_INCREF(__pyx_t_3); __pyx_t_10++; if (unlikely(0 < 0)) __PYX_ERR(0, 225, __pyx_L1_error)
      #else
      __pyx_t_3 = PySequence_ITEM(__pyx_t_2, __pyx_t_10); __pyx_t_10++; if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 225, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      #endif
      if (!(likely(((__pyx_t_3) == Py_None) || likely(__Pyx_TypeTest(__pyx_t_3, __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse))))) __PYX_ERR(0, 225, __pyx_L1_error)
      __Pyx_XDECREF_SET(__pyx_v_current_parse, ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_t_3));
      __pyx_t_3 = 0;

      /* "MorphologicalAnalysis/FsmParseList.pyx":226
 *                     and fsmParse.getRootPos() == longest_root_pos:
 *                 for current_parse in self.__fsm_parses:
 *                     if current_parse.getWord().getName() == possible_root \             # <<<<<<<<<<<<<<
 *                             and current_parse.getRootPos() == possible_root_pos:
 *                         return True
 */
      __pyx_t_3 = ((PyObject *)((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_current_parse->__pyx_base.__pyx_vtab)->__pyx_base.getWord(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_current_parse), 0)); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 226, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_4 = ((struct __pyx_vtabstruct_10Dictionary_4Word_Word *)((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_3)->__pyx_vtab)->getName(((struct __pyx_obj_10Dictionary_4Word_Word *)__pyx_t_3), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 226, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_9 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_v_possible_root, Py_EQ)); if (unlikely(__pyx_t_9 < 0)) __PYX_ERR(0, 226, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_8 = (__pyx_t_9 != 0);
      if (__pyx_t_8) {
      } else {
        __pyx_t_5 = __pyx_t_8;
        goto __pyx_L12_bool_binop_done;
      }

      /* "MorphologicalAnalysis/FsmParseList.pyx":227
 *                 for current_parse in self.__fsm_parses:
 *                     if current_parse.getWord().getName() == possible_root \
 *                             and current_parse.getRootPos() == possible_root_pos:             # <<<<<<<<<<<<<<
 *                         return True
 *         return False
 */
      __pyx_t_4 = ((struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_current_parse->__pyx_base.__pyx_vtab)->__pyx_base.getRootPos(((struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse *)__pyx_v_current_parse), 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 227, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_8 = (__Pyx_PyUnicode_Equals(__pyx_t_4, __pyx_v_possible_root_pos, Py_EQ)); if (unlikely(__pyx_t_8 < 0)) __PYX_ERR(0, 227, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __pyx_t_9 = (__pyx_t_8 != 0);
      __pyx_t_5 = __pyx_t_9;
      __pyx_L12_bool_binop_done:;

      /* "MorphologicalAnalysis/FsmParseList.pyx":226
 *                     and fsmParse.getRootPos() == longest_root_pos:
 *                 for current_parse in self.__fsm_parses:
 *                     if current_parse.getWord().getName() == possible_root \             # <<<<<<<<<<<<<<
 *                             and current_parse.getRootPos() == possible_root_pos:
 *                         return True
 */
      if (__pyx_t_5) {

        /* "MorphologicalAnalysis/FsmParseList.pyx":228
 *                     if current_parse.getWord().getName() == possible_root \
 *                             and current_parse.getRootPos() == possible_root_pos:
 *                         return True             # <<<<<<<<<<<<<<
 *         return False
 * 
 */
        __pyx_r = 1;
        __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
        __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
        goto __pyx_L0;

        /* "MorphologicalAnalysis/FsmParseList.pyx":226
 *                     and fsmParse.getRootPos() == longest_root_pos:
 *                 for current_parse in self.__fsm_parses:
 *                     if current_parse.getWord().getName() == possible_root \             # <<<<<<<<<<<<<<
 *                             and current_parse.getRootPos() == possible_root_pos:
 *                         return True
 */
      }

      /* "MorphologicalAnalysis/FsmParseList.pyx":225
 *             if surface_form.endswith(surface_form_ending) and root.endswith(longest_root_ending) \
 *                     and fsmParse.getRootPos() == longest_root_pos:
 *                 for current_parse in self.__fsm_parses:             # <<<<<<<<<<<<<<
 *                     if current_parse.getWord().getName() == possible_root \
 *                             and current_parse.getRootPos() == possible_root_pos:
 */
    }
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmParseList.pyx":223
 *             possible_root_pos = exception_items[3]
 *             possible_root = surface_form.replace(surface_form_ending, "")
 *             if surface_form.endswith(surface_form_ending) and root.endswith(longest_root_ending) \             # <<<<<<<<<<<<<<
 *                     and fsmParse.getRootPos() == longest_root_pos:
 *                 for current_parse in self.__fsm_parses:
 */
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":216
 *         surface_form = fsmParse.getSurfaceForm()
 *         root = fsmParse.getWord().getName()
 *         for longest_root_exception in self.longest_root_exceptions:             # <<<<<<<<<<<<<<
 *             exception_items = longest_root_exception.split(" ")
 *             surface_form_ending = exception_items[0]
 */
}
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "MorphologicalAnalysis/FsmParseList.pyx":229
 *                             and current_parse.getRootPos() == possible_root_pos:
 *                         return True
 *         return False             # <<<<<<<<<<<<<<
 * 
 *     cpdef reduceToParsesWithSameRoot(self, str currentRoot):
 */
__pyx_r = 0;
goto __pyx_L0;

/* "MorphologicalAnalysis/FsmParseList.pyx":197
 *         return best_parse
 * 
 *     cpdef bint isLongestRootException(self, FsmParse fsmParse):             # <<<<<<<<<<<<<<
 *         """
 *         The isLongestRootException method returns true if the longest root word belongs to an exceptional case, false
 */

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_WriteUnraisable("MorphologicalAnalysis.FsmParseList.FsmParseList.isLongestRootException", __pyx_clineno, __pyx_lineno, __pyx_filename, 1, 0);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_surface_form);
__Pyx_XDECREF(__pyx_v_root);
__Pyx_XDECREF(__pyx_v_longest_root_exception);
__Pyx_XDECREF(__pyx_v_exception_items);
__Pyx_XDECREF(__pyx_v_surface_form_ending);
__Pyx_XDECREF(__pyx_v_longest_root_ending);
__Pyx_XDECREF(__pyx_v_longest_root_pos);
__Pyx_XDECREF(__pyx_v_possible_root_pos);
__Pyx_XDECREF(__pyx_v_possible_root);
__Pyx_XDECREF((PyObject *)__pyx_v_current_parse);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_15isLongestRootException(PyObject *__pyx_v_self, PyObject *__pyx_v_fsmParse); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_14isLongestRootException[] = "\n        The isLongestRootException method returns true if the longest root word belongs to an exceptional case, false\n        otherwise.\n\n        PARAMETERS\n        ----------\n        fsmParse: FsmParse input\n        \n        RETURNS\n        -------\n        True if the longest root belongs to an exceptional case, false otherwise.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_15isLongestRootException(PyObject *__pyx_v_self, PyObject *__pyx_v_fsmParse) {
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("isLongestRootException (wrapper)", 0);
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_fsmParse), __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse, 1, "fsmParse", 0))) __PYX_ERR(0, 197, __pyx_L1_error)
__pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_14isLongestRootException(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self), ((struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *)__pyx_v_fsmParse));

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = NULL;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_14isLongestRootException(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *__pyx_v_fsmParse) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("isLongestRootException", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __Pyx_PyBool_FromLong(__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_isLongestRootException(__pyx_v_self, __pyx_v_fsmParse, 1)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 197, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.isLongestRootException", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":231
 *         return False
 * 
 *     cpdef reduceToParsesWithSameRoot(self, str currentRoot):             # <<<<<<<<<<<<<<
 *         """
 *         The reduceToParsesWithSameRoot method takes a str currentWithPos as an input and loops i times till
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_17reduceToParsesWithSameRoot(PyObject *__pyx_v_self, PyObject *__pyx_v_currentRoot); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_reduceToParsesWithSameRoot(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, PyObject *__pyx_v_currentRoot, int __pyx_skip_dispatch) {
int __pyx_v_i;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
Py_ssize_t __pyx_t_5;
int __pyx_t_6;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("reduceToParsesWithSameRoot", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_reduceToParsesWithSameRoot); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 231, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_17reduceToParsesWithSameRoot)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_3, __pyx_t_4, __pyx_v_currentRoot) : __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_v_currentRoot);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 231, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_r = __pyx_t_2;
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "MorphologicalAnalysis/FsmParseList.pyx":243
 *         """
 *         cdef int i
 *         i = 0             # <<<<<<<<<<<<<<
 *         while i < len(self.__fsm_parses):
 *             if self.__fsm_parses[i].getWord().getName() != currentRoot:
 */
__pyx_v_i = 0;

/* "MorphologicalAnalysis/FsmParseList.pyx":244
 *         cdef int i
 *         i = 0
 *         while i < len(self.__fsm_parses):             # <<<<<<<<<<<<<<
 *             if self.__fsm_parses[i].getWord().getName() != currentRoot:
 *                 self.__fsm_parses.pop(i)
 */
while (1) {
  __pyx_t_1 = __pyx_v_self->__pyx___fsm_parses;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 244, __pyx_L1_error)
  }
  __pyx_t_5 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 244, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = ((__pyx_v_i < __pyx_t_5) != 0);
  if (!__pyx_t_6) break;

  /* "MorphologicalAnalysis/FsmParseList.pyx":245
 *         i = 0
 *         while i < len(self.__fsm_parses):
 *             if self.__fsm_parses[i].getWord().getName() != currentRoot:             # <<<<<<<<<<<<<<
 *                 self.__fsm_parses.pop(i)
 *             else:
 */
  if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 245, __pyx_L1_error)
  }
  __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_getWord); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_3 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_3)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_3);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_2 = (__pyx_t_3) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_3) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_getName); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_4);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_4, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_6 = (__Pyx_PyUnicode_Equals(__pyx_t_1, __pyx_v_currentRoot, Py_NE)); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 245, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/FsmParseList.pyx":246
 *         while i < len(self.__fsm_parses):
 *             if self.__fsm_parses[i].getWord().getName() != currentRoot:
 *                 self.__fsm_parses.pop(i)             # <<<<<<<<<<<<<<
 *             else:
 *                 i = i + 1
 */
    if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
      PyErr_Format(PyExc_AttributeError, "'NoneType' object has no attribute '%.30s'", "pop");
      __PYX_ERR(0, 246, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_PyList_PopIndex(__pyx_v_self->__pyx___fsm_parses, Py_None, __pyx_v_i, 1, int, __Pyx_PyInt_From_int); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 246, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

    /* "MorphologicalAnalysis/FsmParseList.pyx":245
 *         i = 0
 *         while i < len(self.__fsm_parses):
 *             if self.__fsm_parses[i].getWord().getName() != currentRoot:             # <<<<<<<<<<<<<<
 *                 self.__fsm_parses.pop(i)
 *             else:
 */
    goto __pyx_L5;
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":248
 *                 self.__fsm_parses.pop(i)
 *             else:
 *                 i = i + 1             # <<<<<<<<<<<<<<
 * 
 *     cpdef list constructParseListForDifferentRootWithPos(self):
 */
  /*else*/ {
    __pyx_v_i = (__pyx_v_i + 1);
  }
  __pyx_L5:;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":231
 *         return False
 * 
 *     cpdef reduceToParsesWithSameRoot(self, str currentRoot):             # <<<<<<<<<<<<<<
 *         """
 *         The reduceToParsesWithSameRoot method takes a str currentWithPos as an input and loops i times till
 */

/* function exit code */
__pyx_r = Py_None; __Pyx_INCREF(Py_None);
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.reduceToParsesWithSameRoot", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_17reduceToParsesWithSameRoot(PyObject *__pyx_v_self, PyObject *__pyx_v_currentRoot); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_16reduceToParsesWithSameRoot[] = "\n        The reduceToParsesWithSameRoot method takes a str currentWithPos as an input and loops i times till\n        i equals to the size of the fsmParses list. If the given currentRoot does not equal to the root of ith item of\n        fsmParses, it removes the ith item from the list.\n\n        PARAMETERS\n        ----------\n        currentRoot : str\n            String input.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_17reduceToParsesWithSameRoot(PyObject *__pyx_v_self, PyObject *__pyx_v_currentRoot) {
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("reduceToParsesWithSameRoot (wrapper)", 0);
if (unlikely(!__Pyx_ArgTypeTest(((PyObject *)__pyx_v_currentRoot), (&PyUnicode_Type), 1, "currentRoot", 1))) __PYX_ERR(0, 231, __pyx_L1_error)
__pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_16reduceToParsesWithSameRoot(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self), ((PyObject*)__pyx_v_currentRoot));

/* function exit code */
goto __pyx_L0;
__pyx_L1_error:;
__pyx_r = NULL;
__pyx_L0:;
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_16reduceToParsesWithSameRoot(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, PyObject *__pyx_v_currentRoot) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("reduceToParsesWithSameRoot", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_reduceToParsesWithSameRoot(__pyx_v_self, __pyx_v_currentRoot, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 231, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.reduceToParsesWithSameRoot", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":250
 *                 i = i + 1
 * 
 *     cpdef list constructParseListForDifferentRootWithPos(self):             # <<<<<<<<<<<<<<
 *         """
 *         The constructParseListForDifferentRootWithPos method initially creates a result list then loops through the
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_19constructParseListForDifferentRootWithPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_constructParseListForDifferentRootWithPos(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_skip_dispatch) {
PyObject *__pyx_v_result = 0;
PyObject *__pyx_v_initial = 0;
int __pyx_v_i;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
Py_ssize_t __pyx_t_5;
int __pyx_t_6;
int __pyx_t_7;
long __pyx_t_8;
Py_ssize_t __pyx_t_9;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("constructParseListForDifferentRootWithPos", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_constructParseListForDifferentRo); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 250, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_19constructParseListForDifferentRootWithPos)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 250, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!(likely(PyList_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 250, __pyx_L1_error)
      __pyx_r = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "MorphologicalAnalysis/FsmParseList.pyx":268
 *         cdef list result, initial
 *         cdef int i
 *         result = []             # <<<<<<<<<<<<<<
 *         i = 0
 *         while i < len(self.__fsm_parses):
 */
__pyx_t_1 = PyList_New(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 268, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v_result = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "MorphologicalAnalysis/FsmParseList.pyx":269
 *         cdef int i
 *         result = []
 *         i = 0             # <<<<<<<<<<<<<<
 *         while i < len(self.__fsm_parses):
 *             if i == 0:
 */
__pyx_v_i = 0;

/* "MorphologicalAnalysis/FsmParseList.pyx":270
 *         result = []
 *         i = 0
 *         while i < len(self.__fsm_parses):             # <<<<<<<<<<<<<<
 *             if i == 0:
 *                 initial = [self.__fsm_parses[i]]
 */
while (1) {
  __pyx_t_1 = __pyx_v_self->__pyx___fsm_parses;
  __Pyx_INCREF(__pyx_t_1);
  if (unlikely(__pyx_t_1 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 270, __pyx_L1_error)
  }
  __pyx_t_5 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 270, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_6 = ((__pyx_v_i < __pyx_t_5) != 0);
  if (!__pyx_t_6) break;

  /* "MorphologicalAnalysis/FsmParseList.pyx":271
 *         i = 0
 *         while i < len(self.__fsm_parses):
 *             if i == 0:             # <<<<<<<<<<<<<<
 *                 initial = [self.__fsm_parses[i]]
 *                 result.append(FsmParseList(initial))
 */
  __pyx_t_6 = ((__pyx_v_i == 0) != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/FsmParseList.pyx":272
 *         while i < len(self.__fsm_parses):
 *             if i == 0:
 *                 initial = [self.__fsm_parses[i]]             # <<<<<<<<<<<<<<
 *                 result.append(FsmParseList(initial))
 *             else:
 */
    if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 272, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 272, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_GIVEREF(__pyx_t_1);
    PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_1);
    __pyx_t_1 = 0;
    __Pyx_XDECREF_SET(__pyx_v_initial, ((PyObject*)__pyx_t_2));
    __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmParseList.pyx":273
 *             if i == 0:
 *                 initial = [self.__fsm_parses[i]]
 *                 result.append(FsmParseList(initial))             # <<<<<<<<<<<<<<
 *             else:
 *                 if self.__fsm_parses[i].getWordWithPos() == self.__fsm_parses[i - 1].getWordWithPos():
 */
    __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList), __pyx_v_initial); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_2); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 273, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;

    /* "MorphologicalAnalysis/FsmParseList.pyx":271
 *         i = 0
 *         while i < len(self.__fsm_parses):
 *             if i == 0:             # <<<<<<<<<<<<<<
 *                 initial = [self.__fsm_parses[i]]
 *                 result.append(FsmParseList(initial))
 */
    goto __pyx_L5;
  }

  /* "MorphologicalAnalysis/FsmParseList.pyx":275
 *                 result.append(FsmParseList(initial))
 *             else:
 *                 if self.__fsm_parses[i].getWordWithPos() == self.__fsm_parses[i - 1].getWordWithPos():             # <<<<<<<<<<<<<<
 *                     result[len(result) - 1].addFsmParse(self.__fsm_parses[i])
 *                 else:
 */
  /*else*/ {
    if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 275, __pyx_L1_error)
    }
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_getWordWithPos); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_3);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_3, function);
      }
    }
    __pyx_t_2 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
      __PYX_ERR(0, 275, __pyx_L1_error)
    }
    __pyx_t_8 = (__pyx_v_i - 1);
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_t_8, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_getWordWithPos); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_1)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_1);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_t_1) : __Pyx_PyObject_CallNoArg(__pyx_t_4);
    __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_EQ); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 275, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/FsmParseList.pyx":276
 *             else:
 *                 if self.__fsm_parses[i].getWordWithPos() == self.__fsm_parses[i - 1].getWordWithPos():
 *                     result[len(result) - 1].addFsmParse(self.__fsm_parses[i])             # <<<<<<<<<<<<<<
 *                 else:
 *                     initial = [self.__fsm_parses[i]]
 */
      __pyx_t_5 = PyList_GET_SIZE(__pyx_v_result); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 276, __pyx_L1_error)
      __pyx_t_9 = (__pyx_t_5 - 1);
      __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_result, __pyx_t_9, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_3, __pyx_n_s_addFsmParse); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 276, __pyx_L1_error)
      }
      __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_4 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_1, __pyx_t_3) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_3);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 276, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;

      /* "MorphologicalAnalysis/FsmParseList.pyx":275
 *                 result.append(FsmParseList(initial))
 *             else:
 *                 if self.__fsm_parses[i].getWordWithPos() == self.__fsm_parses[i - 1].getWordWithPos():             # <<<<<<<<<<<<<<
 *                     result[len(result) - 1].addFsmParse(self.__fsm_parses[i])
 *                 else:
 */
      goto __pyx_L6;
    }

    /* "MorphologicalAnalysis/FsmParseList.pyx":278
 *                     result[len(result) - 1].addFsmParse(self.__fsm_parses[i])
 *                 else:
 *                     initial = [self.__fsm_parses[i]]             # <<<<<<<<<<<<<<
 *                     result.append(FsmParseList(initial))
 *             i = i + 1
 */
    /*else*/ {
      if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
        PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
        __PYX_ERR(0, 278, __pyx_L1_error)
      }
      __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 278, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_GIVEREF(__pyx_t_4);
      PyList_SET_ITEM(__pyx_t_2, 0, __pyx_t_4);
      __pyx_t_4 = 0;
      __Pyx_XDECREF_SET(__pyx_v_initial, ((PyObject*)__pyx_t_2));
      __pyx_t_2 = 0;

      /* "MorphologicalAnalysis/FsmParseList.pyx":279
 *                 else:
 *                     initial = [self.__fsm_parses[i]]
 *                     result.append(FsmParseList(initial))             # <<<<<<<<<<<<<<
 *             i = i + 1
 *         return result
 */
      __pyx_t_2 = __Pyx_PyObject_CallOneArg(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList), __pyx_v_initial); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 279, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_7 = __Pyx_PyList_Append(__pyx_v_result, __pyx_t_2); if (unlikely(__pyx_t_7 == ((int)-1))) __PYX_ERR(0, 279, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    }
    __pyx_L6:;
  }
  __pyx_L5:;

  /* "MorphologicalAnalysis/FsmParseList.pyx":280
 *                     initial = [self.__fsm_parses[i]]
 *                     result.append(FsmParseList(initial))
 *             i = i + 1             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_v_i = (__pyx_v_i + 1);
}

/* "MorphologicalAnalysis/FsmParseList.pyx":281
 *                     result.append(FsmParseList(initial))
 *             i = i + 1
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     cpdef str parsesWithoutPrefixAndSuffix(self):
 */
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_result);
__pyx_r = __pyx_v_result;
goto __pyx_L0;

/* "MorphologicalAnalysis/FsmParseList.pyx":250
 *                 i = i + 1
 * 
 *     cpdef list constructParseListForDifferentRootWithPos(self):             # <<<<<<<<<<<<<<
 *         """
 *         The constructParseListForDifferentRootWithPos method initially creates a result list then loops through the
 */

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.constructParseListForDifferentRootWithPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_result);
__Pyx_XDECREF(__pyx_v_initial);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_19constructParseListForDifferentRootWithPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_18constructParseListForDifferentRootWithPos[] = "\n        The constructParseListForDifferentRootWithPos method initially creates a result list then loops through the\n        fsmParses list. For the first iteration, it creates new list as initial, then adds the\n        first item od fsmParses to initial and also add this initial list to the result list. For the following\n        iterations,\n        it checks whether the current item's root with the MorphologicalTag of the first inflectional\n        equal to the previous item's  root with the MorphologicalTag of the first inflectional. If so, it adds that item\n        to the result list, if not it creates new list as initial and adds the first item od fsmParses\n        to initial and also add this initial list to the result list.\n\n        RETURNS\n        -------\n        result : list\n            list type of FsmParseList.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_19constructParseListForDifferentRootWithPos(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("constructParseListForDifferentRootWithPos (wrapper)", 0);
__pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_18constructParseListForDifferentRootWithPos(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_18constructParseListForDifferentRootWithPos(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("constructParseListForDifferentRootWithPos", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_constructParseListForDifferentRootWithPos(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 250, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.constructParseListForDifferentRootWithPos", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":283
 *         return result
 * 
 *     cpdef str parsesWithoutPrefixAndSuffix(self):             # <<<<<<<<<<<<<<
 *         """
 *         The parsesWithoutPrefixAndSuffix method first creates a str array named analyses with the size of fsmParses
 */

static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_21parsesWithoutPrefixAndSuffix(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_parsesWithoutPrefixAndSuffix(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, int __pyx_skip_dispatch) {
PyObject *__pyx_v_analyses = 0;
int __pyx_v_remove_prefix;
int __pyx_v_remove_suffix;
int __pyx_v_i;
int __pyx_v_j;
PyObject *__pyx_v_result = NULL;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
Py_ssize_t __pyx_t_5;
int __pyx_t_6;
PyObject *__pyx_t_7 = NULL;
Py_ssize_t __pyx_t_8;
int __pyx_t_9;
int __pyx_t_10;
int __pyx_t_11;
long __pyx_t_12;
Py_ssize_t __pyx_t_13;
Py_ssize_t __pyx_t_14;
int __pyx_t_15;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("parsesWithoutPrefixAndSuffix", 0);
/* Check if called by wrapper */
if (unlikely(__pyx_skip_dispatch)) ;
/* Check if overridden in Python */
else if (unlikely((Py_TYPE(((PyObject *)__pyx_v_self))->tp_dictoffset != 0) || (Py_TYPE(((PyObject *)__pyx_v_self))->tp_flags & (Py_TPFLAGS_IS_ABSTRACT | Py_TPFLAGS_HEAPTYPE)))) {
  #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  static PY_UINT64_T __pyx_tp_dict_version = __PYX_DICT_VERSION_INIT, __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
  if (unlikely(!__Pyx_object_dict_version_matches(((PyObject *)__pyx_v_self), __pyx_tp_dict_version, __pyx_obj_dict_version))) {
    PY_UINT64_T __pyx_type_dict_guard = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    #endif
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v_self), __pyx_n_s_parsesWithoutPrefixAndSuffix); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    if (!PyCFunction_Check(__pyx_t_1) || (PyCFunction_GET_FUNCTION(__pyx_t_1) != (PyCFunction)(void*)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_21parsesWithoutPrefixAndSuffix)) {
      __Pyx_XDECREF(__pyx_r);
      __Pyx_INCREF(__pyx_t_1);
      __pyx_t_3 = __pyx_t_1; __pyx_t_4 = NULL;
      if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_3))) {
        __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_3);
        if (likely(__pyx_t_4)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
          __Pyx_INCREF(__pyx_t_4);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_3, function);
        }
      }
      __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
      __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
      if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 283, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (!(likely(PyUnicode_CheckExact(__pyx_t_2))||((__pyx_t_2) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_2)->tp_name), 0))) __PYX_ERR(0, 283, __pyx_L1_error)
      __pyx_r = ((PyObject*)__pyx_t_2);
      __pyx_t_2 = 0;
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      goto __pyx_L0;
    }
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
    __pyx_tp_dict_version = __Pyx_get_tp_dict_version(((PyObject *)__pyx_v_self));
    __pyx_obj_dict_version = __Pyx_get_object_dict_version(((PyObject *)__pyx_v_self));
    if (unlikely(__pyx_type_dict_guard != __pyx_tp_dict_version)) {
      __pyx_tp_dict_version = __pyx_obj_dict_version = __PYX_DICT_VERSION_INIT;
    }
    #endif
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    #if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_PYTYPE_LOOKUP && CYTHON_USE_TYPE_SLOTS
  }
  #endif
}

/* "MorphologicalAnalysis/FsmParseList.pyx":308
 *         cdef bint remove_prefix, remove_suffix
 *         cdef int i, j
 *         analyses = [""] * len(self.__fsm_parses)             # <<<<<<<<<<<<<<
 *         remove_prefix = True
 *         remove_suffix = True
 */
__pyx_t_1 = __pyx_v_self->__pyx___fsm_parses;
__Pyx_INCREF(__pyx_t_1);
if (unlikely(__pyx_t_1 == Py_None)) {
  PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
  __PYX_ERR(0, 308, __pyx_L1_error)
}
__pyx_t_5 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 308, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_t_1 = PyList_New(1 * ((__pyx_t_5<0) ? 0:__pyx_t_5)); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 308, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
{ Py_ssize_t __pyx_temp;
  for (__pyx_temp=0; __pyx_temp < __pyx_t_5; __pyx_temp++) {
    __Pyx_INCREF(__pyx_kp_u__3);
    __Pyx_GIVEREF(__pyx_kp_u__3);
    PyList_SET_ITEM(__pyx_t_1, __pyx_temp, __pyx_kp_u__3);
  }
}
__pyx_v_analyses = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "MorphologicalAnalysis/FsmParseList.pyx":309
 *         cdef int i, j
 *         analyses = [""] * len(self.__fsm_parses)
 *         remove_prefix = True             # <<<<<<<<<<<<<<
 *         remove_suffix = True
 *         if len(self.__fsm_parses) == 1:
 */
__pyx_v_remove_prefix = 1;

/* "MorphologicalAnalysis/FsmParseList.pyx":310
 *         analyses = [""] * len(self.__fsm_parses)
 *         remove_prefix = True
 *         remove_suffix = True             # <<<<<<<<<<<<<<
 *         if len(self.__fsm_parses) == 1:
 *             return self.__fsm_parses[0].transitionList()[self.__fsm_parses[0].transitionList().index("+") + 1]
 */
__pyx_v_remove_suffix = 1;

/* "MorphologicalAnalysis/FsmParseList.pyx":311
 *         remove_prefix = True
 *         remove_suffix = True
 *         if len(self.__fsm_parses) == 1:             # <<<<<<<<<<<<<<
 *             return self.__fsm_parses[0].transitionList()[self.__fsm_parses[0].transitionList().index("+") + 1]
 *         for i in range(len(self.__fsm_parses)):
 */
__pyx_t_1 = __pyx_v_self->__pyx___fsm_parses;
__Pyx_INCREF(__pyx_t_1);
if (unlikely(__pyx_t_1 == Py_None)) {
  PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
  __PYX_ERR(0, 311, __pyx_L1_error)
}
__pyx_t_5 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 311, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_t_6 = ((__pyx_t_5 == 1) != 0);
if (__pyx_t_6) {

  /* "MorphologicalAnalysis/FsmParseList.pyx":312
 *         remove_suffix = True
 *         if len(self.__fsm_parses) == 1:
 *             return self.__fsm_parses[0].transitionList()[self.__fsm_parses[0].transitionList().index("+") + 1]             # <<<<<<<<<<<<<<
 *         for i in range(len(self.__fsm_parses)):
 *             analyses[i] = self.__fsm_parses[i].transitionList()
 */
  __Pyx_XDECREF(__pyx_r);
  if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 312, __pyx_L1_error)
  }
  __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_3 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_transitionList); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_3))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_3);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_3);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_3, function);
    }
  }
  __pyx_t_1 = (__pyx_t_2) ? __Pyx_PyObject_CallOneArg(__pyx_t_3, __pyx_t_2) : __Pyx_PyObject_CallNoArg(__pyx_t_3);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 312, __pyx_L1_error)
  }
  __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_transitionList); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  __pyx_t_4 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_4)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_4);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_4) : __Pyx_PyObject_CallNoArg(__pyx_t_7);
  __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_index); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_2)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_2);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_2, __pyx_kp_u__4) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u__4);
  __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 312, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (!(likely(PyUnicode_CheckExact(__pyx_t_3))||((__pyx_t_3) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_t_3)->tp_name), 0))) __PYX_ERR(0, 312, __pyx_L1_error)
  __pyx_r = ((PyObject*)__pyx_t_3);
  __pyx_t_3 = 0;
  goto __pyx_L0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":311
 *         remove_prefix = True
 *         remove_suffix = True
 *         if len(self.__fsm_parses) == 1:             # <<<<<<<<<<<<<<
 *             return self.__fsm_parses[0].transitionList()[self.__fsm_parses[0].transitionList().index("+") + 1]
 *         for i in range(len(self.__fsm_parses)):
 */
}

/* "MorphologicalAnalysis/FsmParseList.pyx":313
 *         if len(self.__fsm_parses) == 1:
 *             return self.__fsm_parses[0].transitionList()[self.__fsm_parses[0].transitionList().index("+") + 1]
 *         for i in range(len(self.__fsm_parses)):             # <<<<<<<<<<<<<<
 *             analyses[i] = self.__fsm_parses[i].transitionList()
 *         while remove_prefix:
 */
__pyx_t_3 = __pyx_v_self->__pyx___fsm_parses;
__Pyx_INCREF(__pyx_t_3);
if (unlikely(__pyx_t_3 == Py_None)) {
  PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
  __PYX_ERR(0, 313, __pyx_L1_error)
}
__pyx_t_5 = PyList_GET_SIZE(__pyx_t_3); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 313, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
__pyx_t_8 = __pyx_t_5;
for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
  __pyx_v_i = __pyx_t_9;

  /* "MorphologicalAnalysis/FsmParseList.pyx":314
 *             return self.__fsm_parses[0].transitionList()[self.__fsm_parses[0].transitionList().index("+") + 1]
 *         for i in range(len(self.__fsm_parses)):
 *             analyses[i] = self.__fsm_parses[i].transitionList()             # <<<<<<<<<<<<<<
 *         while remove_prefix:
 *             remove_prefix = True
 */
  if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 314, __pyx_L1_error)
  }
  __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_transitionList); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __pyx_t_7 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
    __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_1);
    if (likely(__pyx_t_7)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
      __Pyx_INCREF(__pyx_t_7);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_1, function);
    }
  }
  __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_t_7) : __Pyx_PyObject_CallNoArg(__pyx_t_1);
  __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  if (unlikely(__Pyx_SetItemInt(__pyx_v_analyses, __pyx_v_i, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 1, 1, 1) < 0)) __PYX_ERR(0, 314, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":315
 *         for i in range(len(self.__fsm_parses)):
 *             analyses[i] = self.__fsm_parses[i].transitionList()
 *         while remove_prefix:             # <<<<<<<<<<<<<<
 *             remove_prefix = True
 *             for i in range(len(self.__fsm_parses) - 1):
 */
while (1) {
  __pyx_t_6 = (__pyx_v_remove_prefix != 0);
  if (!__pyx_t_6) break;

  /* "MorphologicalAnalysis/FsmParseList.pyx":316
 *             analyses[i] = self.__fsm_parses[i].transitionList()
 *         while remove_prefix:
 *             remove_prefix = True             # <<<<<<<<<<<<<<
 *             for i in range(len(self.__fsm_parses) - 1):
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \
 */
  __pyx_v_remove_prefix = 1;

  /* "MorphologicalAnalysis/FsmParseList.pyx":317
 *         while remove_prefix:
 *             remove_prefix = True
 *             for i in range(len(self.__fsm_parses) - 1):             # <<<<<<<<<<<<<<
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \
 *                         analyses[i][:analyses[i].index("+") + 1] != analyses[i + 1][:analyses[i + 1].index("+") + 1]:
 */
  __pyx_t_3 = __pyx_v_self->__pyx___fsm_parses;
  __Pyx_INCREF(__pyx_t_3);
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 317, __pyx_L1_error)
  }
  __pyx_t_5 = PyList_GET_SIZE(__pyx_t_3); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 317, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_8 = (__pyx_t_5 - 1);
  __pyx_t_5 = __pyx_t_8;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_5; __pyx_t_9+=1) {
    __pyx_v_i = __pyx_t_9;

    /* "MorphologicalAnalysis/FsmParseList.pyx":318
 *             remove_prefix = True
 *             for i in range(len(self.__fsm_parses) - 1):
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \             # <<<<<<<<<<<<<<
 *                         analyses[i][:analyses[i].index("+") + 1] != analyses[i + 1][:analyses[i + 1].index("+") + 1]:
 *                     remove_prefix = False
 */
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__4, __pyx_t_3, Py_NE)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 318, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_11 = (__pyx_t_10 != 0);
    if (!__pyx_t_11) {
    } else {
      __pyx_t_6 = __pyx_t_11;
      goto __pyx_L11_bool_binop_done;
    }
    __pyx_t_12 = (__pyx_v_i + 1);
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_t_12, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 318, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_11 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__4, __pyx_t_3, Py_NE)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 318, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_10 = (__pyx_t_11 != 0);
    if (!__pyx_t_10) {
    } else {
      __pyx_t_6 = __pyx_t_10;
      goto __pyx_L11_bool_binop_done;
    }

    /* "MorphologicalAnalysis/FsmParseList.pyx":319
 *             for i in range(len(self.__fsm_parses) - 1):
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \
 *                         analyses[i][:analyses[i].index("+") + 1] != analyses[i + 1][:analyses[i + 1].index("+") + 1]:             # <<<<<<<<<<<<<<
 *                     remove_prefix = False
 *                     break
 */
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_2);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_2, function);
      }
    }
    __pyx_t_1 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_7, __pyx_kp_u__4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_kp_u__4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_t_1, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_3, 0, 0, NULL, &__pyx_t_2, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_12 = (__pyx_v_i + 1);
    __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_t_12, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __pyx_t_12 = (__pyx_v_i + 1);
    __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_t_12, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __pyx_t_4 = __Pyx_PyObject_GetAttrStr(__pyx_t_7, __pyx_n_s_index); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_4))) {
      __pyx_t_7 = PyMethod_GET_SELF(__pyx_t_4);
      if (likely(__pyx_t_7)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_4);
        __Pyx_INCREF(__pyx_t_7);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_4, function);
      }
    }
    __pyx_t_3 = (__pyx_t_7) ? __Pyx_PyObject_Call2Args(__pyx_t_4, __pyx_t_7, __pyx_kp_u__4) : __Pyx_PyObject_CallOneArg(__pyx_t_4, __pyx_kp_u__4);
    __Pyx_XDECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_2, 0, 0, NULL, &__pyx_t_4, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_4); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_4); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 319, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_6 = __pyx_t_10;
    __pyx_L11_bool_binop_done:;

    /* "MorphologicalAnalysis/FsmParseList.pyx":318
 *             remove_prefix = True
 *             for i in range(len(self.__fsm_parses) - 1):
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \             # <<<<<<<<<<<<<<
 *                         analyses[i][:analyses[i].index("+") + 1] != analyses[i + 1][:analyses[i + 1].index("+") + 1]:
 *                     remove_prefix = False
 */
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/FsmParseList.pyx":320
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \
 *                         analyses[i][:analyses[i].index("+") + 1] != analyses[i + 1][:analyses[i + 1].index("+") + 1]:
 *                     remove_prefix = False             # <<<<<<<<<<<<<<
 *                     break
 *             if remove_prefix:
 */
      __pyx_v_remove_prefix = 0;

      /* "MorphologicalAnalysis/FsmParseList.pyx":321
 *                         analyses[i][:analyses[i].index("+") + 1] != analyses[i + 1][:analyses[i + 1].index("+") + 1]:
 *                     remove_prefix = False
 *                     break             # <<<<<<<<<<<<<<
 *             if remove_prefix:
 *                 for i in range(len(self.__fsm_parses)):
 */
      goto __pyx_L9_break;

      /* "MorphologicalAnalysis/FsmParseList.pyx":318
 *             remove_prefix = True
 *             for i in range(len(self.__fsm_parses) - 1):
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \             # <<<<<<<<<<<<<<
 *                         analyses[i][:analyses[i].index("+") + 1] != analyses[i + 1][:analyses[i + 1].index("+") + 1]:
 *                     remove_prefix = False
 */
    }
  }
  __pyx_L9_break:;

  /* "MorphologicalAnalysis/FsmParseList.pyx":322
 *                     remove_prefix = False
 *                     break
 *             if remove_prefix:             # <<<<<<<<<<<<<<
 *                 for i in range(len(self.__fsm_parses)):
 *                     analyses[i] = analyses[i][analyses[i].index("+") + 1:]
 */
  __pyx_t_6 = (__pyx_v_remove_prefix != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/FsmParseList.pyx":323
 *                     break
 *             if remove_prefix:
 *                 for i in range(len(self.__fsm_parses)):             # <<<<<<<<<<<<<<
 *                     analyses[i] = analyses[i][analyses[i].index("+") + 1:]
 *         while remove_suffix:
 */
    __pyx_t_4 = __pyx_v_self->__pyx___fsm_parses;
    __Pyx_INCREF(__pyx_t_4);
    if (unlikely(__pyx_t_4 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 323, __pyx_L1_error)
    }
    __pyx_t_8 = PyList_GET_SIZE(__pyx_t_4); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 323, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_5 = __pyx_t_8;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_5; __pyx_t_9+=1) {
      __pyx_v_i = __pyx_t_9;

      /* "MorphologicalAnalysis/FsmParseList.pyx":324
 *             if remove_prefix:
 *                 for i in range(len(self.__fsm_parses)):
 *                     analyses[i] = analyses[i][analyses[i].index("+") + 1:]             # <<<<<<<<<<<<<<
 *         while remove_suffix:
 *             remove_suffix = True
 */
      __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 324, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_4);
      __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 324, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __pyx_t_2 = __Pyx_PyObject_GetAttrStr(__pyx_t_1, __pyx_n_s_index); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
        __pyx_t_1 = PyMethod_GET_SELF(__pyx_t_2);
        if (likely(__pyx_t_1)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
          __Pyx_INCREF(__pyx_t_1);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_2, function);
        }
      }
      __pyx_t_3 = (__pyx_t_1) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_1, __pyx_kp_u__4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_kp_u__4);
      __Pyx_XDECREF(__pyx_t_1); __pyx_t_1 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 324, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 324, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      __pyx_t_3 = __Pyx_PyObject_GetSlice(__pyx_t_4, 0, 0, &__pyx_t_2, NULL, NULL, 0, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 324, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(__Pyx_SetItemInt(__pyx_v_analyses, __pyx_v_i, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 1, 1, 1) < 0)) __PYX_ERR(0, 324, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    }

    /* "MorphologicalAnalysis/FsmParseList.pyx":322
 *                     remove_prefix = False
 *                     break
 *             if remove_prefix:             # <<<<<<<<<<<<<<
 *                 for i in range(len(self.__fsm_parses)):
 *                     analyses[i] = analyses[i][analyses[i].index("+") + 1:]
 */
  }
}

/* "MorphologicalAnalysis/FsmParseList.pyx":325
 *                 for i in range(len(self.__fsm_parses)):
 *                     analyses[i] = analyses[i][analyses[i].index("+") + 1:]
 *         while remove_suffix:             # <<<<<<<<<<<<<<
 *             remove_suffix = True
 *             for i in range(len(self.__fsm_parses) - 1):
 */
while (1) {
  __pyx_t_6 = (__pyx_v_remove_suffix != 0);
  if (!__pyx_t_6) break;

  /* "MorphologicalAnalysis/FsmParseList.pyx":326
 *                     analyses[i] = analyses[i][analyses[i].index("+") + 1:]
 *         while remove_suffix:
 *             remove_suffix = True             # <<<<<<<<<<<<<<
 *             for i in range(len(self.__fsm_parses) - 1):
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \
 */
  __pyx_v_remove_suffix = 1;

  /* "MorphologicalAnalysis/FsmParseList.pyx":327
 *         while remove_suffix:
 *             remove_suffix = True
 *             for i in range(len(self.__fsm_parses) - 1):             # <<<<<<<<<<<<<<
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \
 *                         analyses[i][analyses[i].rindex("+") + 1] != analyses[i + 1][analyses[i + 1].rindex("+") + 1]:
 */
  __pyx_t_3 = __pyx_v_self->__pyx___fsm_parses;
  __Pyx_INCREF(__pyx_t_3);
  if (unlikely(__pyx_t_3 == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
    __PYX_ERR(0, 327, __pyx_L1_error)
  }
  __pyx_t_8 = PyList_GET_SIZE(__pyx_t_3); if (unlikely(__pyx_t_8 == ((Py_ssize_t)-1))) __PYX_ERR(0, 327, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __pyx_t_5 = (__pyx_t_8 - 1);
  __pyx_t_8 = __pyx_t_5;
  for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
    __pyx_v_i = __pyx_t_9;

    /* "MorphologicalAnalysis/FsmParseList.pyx":328
 *             remove_suffix = True
 *             for i in range(len(self.__fsm_parses) - 1):
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \             # <<<<<<<<<<<<<<
 *                         analyses[i][analyses[i].rindex("+") + 1] != analyses[i + 1][analyses[i + 1].rindex("+") + 1]:
 *                     remove_suffix = False
 */
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_10 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__4, __pyx_t_3, Py_NE)); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_11 = (__pyx_t_10 != 0);
    if (!__pyx_t_11) {
    } else {
      __pyx_t_6 = __pyx_t_11;
      goto __pyx_L22_bool_binop_done;
    }
    __pyx_t_12 = (__pyx_v_i + 1);
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_t_12, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_11 = (__Pyx_PySequence_ContainsTF(__pyx_kp_u__4, __pyx_t_3, Py_NE)); if (unlikely(__pyx_t_11 < 0)) __PYX_ERR(0, 328, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_10 = (__pyx_t_11 != 0);
    if (!__pyx_t_10) {
    } else {
      __pyx_t_6 = __pyx_t_10;
      goto __pyx_L22_bool_binop_done;
    }

    /* "MorphologicalAnalysis/FsmParseList.pyx":329
 *             for i in range(len(self.__fsm_parses) - 1):
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \
 *                         analyses[i][analyses[i].rindex("+") + 1] != analyses[i + 1][analyses[i + 1].rindex("+") + 1]:             # <<<<<<<<<<<<<<
 *                     remove_suffix = False
 *                     break
 */
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_rindex); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_1);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_1, function);
      }
    }
    __pyx_t_2 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_4, __pyx_kp_u__4) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_kp_u__4);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_1 = __Pyx_PyInt_AddObjC(__pyx_t_2, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __pyx_t_2 = __Pyx_PyObject_GetItem(__pyx_t_3, __pyx_t_1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_2);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __pyx_t_12 = (__pyx_v_i + 1);
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_t_12, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_12 = (__pyx_v_i + 1);
    __pyx_t_4 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_t_12, long, 1, __Pyx_PyInt_From_long, 1, 1, 1); if (unlikely(!__pyx_t_4)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_4);
    __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_4, __pyx_n_s_rindex); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
    __pyx_t_4 = NULL;
    if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
      __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_7);
      if (likely(__pyx_t_4)) {
        PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
        __Pyx_INCREF(__pyx_t_4);
        __Pyx_INCREF(function);
        __Pyx_DECREF_SET(__pyx_t_7, function);
      }
    }
    __pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_4, __pyx_kp_u__4) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_kp_u__4);
    __Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
    if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = __Pyx_PyInt_AddObjC(__pyx_t_3, __pyx_int_1, 1, 0, 0); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_7);
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_3 = __Pyx_PyObject_GetItem(__pyx_t_1, __pyx_t_7); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_7 = PyObject_RichCompare(__pyx_t_2, __pyx_t_3, Py_NE); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_10 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_10 < 0)) __PYX_ERR(0, 329, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_6 = __pyx_t_10;
    __pyx_L22_bool_binop_done:;

    /* "MorphologicalAnalysis/FsmParseList.pyx":328
 *             remove_suffix = True
 *             for i in range(len(self.__fsm_parses) - 1):
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \             # <<<<<<<<<<<<<<
 *                         analyses[i][analyses[i].rindex("+") + 1] != analyses[i + 1][analyses[i + 1].rindex("+") + 1]:
 *                     remove_suffix = False
 */
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/FsmParseList.pyx":330
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \
 *                         analyses[i][analyses[i].rindex("+") + 1] != analyses[i + 1][analyses[i + 1].rindex("+") + 1]:
 *                     remove_suffix = False             # <<<<<<<<<<<<<<
 *                     break
 *             if remove_suffix:
 */
      __pyx_v_remove_suffix = 0;

      /* "MorphologicalAnalysis/FsmParseList.pyx":331
 *                         analyses[i][analyses[i].rindex("+") + 1] != analyses[i + 1][analyses[i + 1].rindex("+") + 1]:
 *                     remove_suffix = False
 *                     break             # <<<<<<<<<<<<<<
 *             if remove_suffix:
 *                 for i in range(len(self.__fsm_parses)):
 */
      goto __pyx_L20_break;

      /* "MorphologicalAnalysis/FsmParseList.pyx":328
 *             remove_suffix = True
 *             for i in range(len(self.__fsm_parses) - 1):
 *                 if "+" not in analyses[i] or "+" not in analyses[i + 1] or \             # <<<<<<<<<<<<<<
 *                         analyses[i][analyses[i].rindex("+") + 1] != analyses[i + 1][analyses[i + 1].rindex("+") + 1]:
 *                     remove_suffix = False
 */
    }
  }
  __pyx_L20_break:;

  /* "MorphologicalAnalysis/FsmParseList.pyx":332
 *                     remove_suffix = False
 *                     break
 *             if remove_suffix:             # <<<<<<<<<<<<<<
 *                 for i in range(len(self.__fsm_parses)):
 *                     analyses[i] = analyses[i][:analyses[i].rindex("+")]
 */
  __pyx_t_6 = (__pyx_v_remove_suffix != 0);
  if (__pyx_t_6) {

    /* "MorphologicalAnalysis/FsmParseList.pyx":333
 *                     break
 *             if remove_suffix:
 *                 for i in range(len(self.__fsm_parses)):             # <<<<<<<<<<<<<<
 *                     analyses[i] = analyses[i][:analyses[i].rindex("+")]
 *         for i in range(len(analyses)):
 */
    __pyx_t_7 = __pyx_v_self->__pyx___fsm_parses;
    __Pyx_INCREF(__pyx_t_7);
    if (unlikely(__pyx_t_7 == Py_None)) {
      PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
      __PYX_ERR(0, 333, __pyx_L1_error)
    }
    __pyx_t_5 = PyList_GET_SIZE(__pyx_t_7); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 333, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    __pyx_t_8 = __pyx_t_5;
    for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
      __pyx_v_i = __pyx_t_9;

      /* "MorphologicalAnalysis/FsmParseList.pyx":334
 *             if remove_suffix:
 *                 for i in range(len(self.__fsm_parses)):
 *                     analyses[i] = analyses[i][:analyses[i].rindex("+")]             # <<<<<<<<<<<<<<
 *         for i in range(len(analyses)):
 *             for j in range(i + 1, len(analyses)):
 */
      __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_2 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_2)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_2);
      __pyx_t_1 = __Pyx_PyObject_GetAttrStr(__pyx_t_2, __pyx_n_s_rindex); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
      __pyx_t_2 = NULL;
      if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_1))) {
        __pyx_t_2 = PyMethod_GET_SELF(__pyx_t_1);
        if (likely(__pyx_t_2)) {
          PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_1);
          __Pyx_INCREF(__pyx_t_2);
          __Pyx_INCREF(function);
          __Pyx_DECREF_SET(__pyx_t_1, function);
        }
      }
      __pyx_t_3 = (__pyx_t_2) ? __Pyx_PyObject_Call2Args(__pyx_t_1, __pyx_t_2, __pyx_kp_u__4) : __Pyx_PyObject_CallOneArg(__pyx_t_1, __pyx_kp_u__4);
      __Pyx_XDECREF(__pyx_t_2); __pyx_t_2 = 0;
      if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
      __pyx_t_1 = __Pyx_PyObject_GetSlice(__pyx_t_7, 0, 0, NULL, &__pyx_t_3, NULL, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_1);
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
      if (unlikely(__Pyx_SetItemInt(__pyx_v_analyses, __pyx_v_i, __pyx_t_1, int, 1, __Pyx_PyInt_From_int, 1, 1, 1) < 0)) __PYX_ERR(0, 334, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    }

    /* "MorphologicalAnalysis/FsmParseList.pyx":332
 *                     remove_suffix = False
 *                     break
 *             if remove_suffix:             # <<<<<<<<<<<<<<
 *                 for i in range(len(self.__fsm_parses)):
 *                     analyses[i] = analyses[i][:analyses[i].rindex("+")]
 */
  }
}

/* "MorphologicalAnalysis/FsmParseList.pyx":335
 *                 for i in range(len(self.__fsm_parses)):
 *                     analyses[i] = analyses[i][:analyses[i].rindex("+")]
 *         for i in range(len(analyses)):             # <<<<<<<<<<<<<<
 *             for j in range(i + 1, len(analyses)):
 *                 if analyses[i] > analyses[j]:
 */
__pyx_t_5 = PyList_GET_SIZE(__pyx_v_analyses); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 335, __pyx_L1_error)
__pyx_t_8 = __pyx_t_5;
for (__pyx_t_9 = 0; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
  __pyx_v_i = __pyx_t_9;

  /* "MorphologicalAnalysis/FsmParseList.pyx":336
 *                     analyses[i] = analyses[i][:analyses[i].rindex("+")]
 *         for i in range(len(analyses)):
 *             for j in range(i + 1, len(analyses)):             # <<<<<<<<<<<<<<
 *                 if analyses[i] > analyses[j]:
 *                     analyses[i], analyses[j] = analyses[j], analyses[i]
 */
  __pyx_t_13 = PyList_GET_SIZE(__pyx_v_analyses); if (unlikely(__pyx_t_13 == ((Py_ssize_t)-1))) __PYX_ERR(0, 336, __pyx_L1_error)
  __pyx_t_14 = __pyx_t_13;
  for (__pyx_t_15 = (__pyx_v_i + 1); __pyx_t_15 < __pyx_t_14; __pyx_t_15+=1) {
    __pyx_v_j = __pyx_t_15;

    /* "MorphologicalAnalysis/FsmParseList.pyx":337
 *         for i in range(len(analyses)):
 *             for j in range(i + 1, len(analyses)):
 *                 if analyses[i] > analyses[j]:             # <<<<<<<<<<<<<<
 *                     analyses[i], analyses[j] = analyses[j], analyses[i]
 *         result = analyses[0]
 */
    __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_1);
    __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_j, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_GOTREF(__pyx_t_3);
    __pyx_t_7 = PyObject_RichCompare(__pyx_t_1, __pyx_t_3, Py_GT); __Pyx_XGOTREF(__pyx_t_7); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
    __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
    __pyx_t_6 = __Pyx_PyObject_IsTrue(__pyx_t_7); if (unlikely(__pyx_t_6 < 0)) __PYX_ERR(0, 337, __pyx_L1_error)
    __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
    if (__pyx_t_6) {

      /* "MorphologicalAnalysis/FsmParseList.pyx":338
 *             for j in range(i + 1, len(analyses)):
 *                 if analyses[i] > analyses[j]:
 *                     analyses[i], analyses[j] = analyses[j], analyses[i]             # <<<<<<<<<<<<<<
 *         result = analyses[0]
 *         for i in range(1, len(analyses)):
 */
      __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_j, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_7);
      __pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_GOTREF(__pyx_t_3);
      if (unlikely(__Pyx_SetItemInt(__pyx_v_analyses, __pyx_v_i, __pyx_t_7, int, 1, __Pyx_PyInt_From_int, 1, 1, 1) < 0)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
      if (unlikely(__Pyx_SetItemInt(__pyx_v_analyses, __pyx_v_j, __pyx_t_3, int, 1, __Pyx_PyInt_From_int, 1, 1, 1) < 0)) __PYX_ERR(0, 338, __pyx_L1_error)
      __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

      /* "MorphologicalAnalysis/FsmParseList.pyx":337
 *         for i in range(len(analyses)):
 *             for j in range(i + 1, len(analyses)):
 *                 if analyses[i] > analyses[j]:             # <<<<<<<<<<<<<<
 *                     analyses[i], analyses[j] = analyses[j], analyses[i]
 *         result = analyses[0]
 */
    }
  }
}

/* "MorphologicalAnalysis/FsmParseList.pyx":339
 *                 if analyses[i] > analyses[j]:
 *                     analyses[i], analyses[j] = analyses[j], analyses[i]
 *         result = analyses[0]             # <<<<<<<<<<<<<<
 *         for i in range(1, len(analyses)):
 *             result = result + "$" + analyses[i]
 */
__pyx_t_3 = __Pyx_GetItemInt_List(__pyx_v_analyses, 0, long, 1, __Pyx_PyInt_From_long, 1, 0, 1); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 339, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__pyx_v_result = __pyx_t_3;
__pyx_t_3 = 0;

/* "MorphologicalAnalysis/FsmParseList.pyx":340
 *                     analyses[i], analyses[j] = analyses[j], analyses[i]
 *         result = analyses[0]
 *         for i in range(1, len(analyses)):             # <<<<<<<<<<<<<<
 *             result = result + "$" + analyses[i]
 *         return result
 */
__pyx_t_5 = PyList_GET_SIZE(__pyx_v_analyses); if (unlikely(__pyx_t_5 == ((Py_ssize_t)-1))) __PYX_ERR(0, 340, __pyx_L1_error)
__pyx_t_8 = __pyx_t_5;
for (__pyx_t_9 = 1; __pyx_t_9 < __pyx_t_8; __pyx_t_9+=1) {
  __pyx_v_i = __pyx_t_9;

  /* "MorphologicalAnalysis/FsmParseList.pyx":341
 *         result = analyses[0]
 *         for i in range(1, len(analyses)):
 *             result = result + "$" + analyses[i]             # <<<<<<<<<<<<<<
 *         return result
 * 
 */
  __pyx_t_3 = PyNumber_Add(__pyx_v_result, __pyx_kp_u_); if (unlikely(!__pyx_t_3)) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __pyx_t_7 = __Pyx_GetItemInt_List(__pyx_v_analyses, __pyx_v_i, int, 1, __Pyx_PyInt_From_int, 1, 1, 1); if (unlikely(!__pyx_t_7)) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __pyx_t_1 = PyNumber_Add(__pyx_t_3, __pyx_t_7); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 341, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_1);
  __pyx_t_1 = 0;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":342
 *         for i in range(1, len(analyses)):
 *             result = result + "$" + analyses[i]
 *         return result             # <<<<<<<<<<<<<<
 * 
 *     def __str__(self) -> str:
 */
__Pyx_XDECREF(__pyx_r);
if (!(likely(PyUnicode_CheckExact(__pyx_v_result))||((__pyx_v_result) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "unicode", Py_TYPE(__pyx_v_result)->tp_name), 0))) __PYX_ERR(0, 342, __pyx_L1_error)
__Pyx_INCREF(__pyx_v_result);
__pyx_r = ((PyObject*)__pyx_v_result);
goto __pyx_L0;

/* "MorphologicalAnalysis/FsmParseList.pyx":283
 *         return result
 * 
 *     cpdef str parsesWithoutPrefixAndSuffix(self):             # <<<<<<<<<<<<<<
 *         """
 *         The parsesWithoutPrefixAndSuffix method first creates a str array named analyses with the size of fsmParses
 */

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.parsesWithoutPrefixAndSuffix", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_analyses);
__Pyx_XDECREF(__pyx_v_result);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_21parsesWithoutPrefixAndSuffix(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_20parsesWithoutPrefixAndSuffix[] = "\n        The parsesWithoutPrefixAndSuffix method first creates a str array named analyses with the size of fsmParses\n        list's size.\n\n        If the size is just 1, it then returns the first item's transitionList, if it is greater than 1, loops through\n        the fsmParses and puts the transitionList of each item to the analyses array.\n\n        If the removePrefix condition holds, it loops through the analyses array and takes each item's substring after\n        the first + sign and updates that item of analyses array with that substring.\n\n        If the removeSuffix condition holds, it loops through the analyses array and takes each item's substring till\n        the last + sign and updates that item of analyses array with that substring.\n\n        It then removes the duplicate items of analyses array and returns a result str that has the accumulated items of\n        analyses array.\n\n        RETURNS\n        -------\n        str\n            result str that has the accumulated items of analyses array.\n        ";
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_21parsesWithoutPrefixAndSuffix(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("parsesWithoutPrefixAndSuffix (wrapper)", 0);
__pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_20parsesWithoutPrefixAndSuffix(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_20parsesWithoutPrefixAndSuffix(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("parsesWithoutPrefixAndSuffix", 0);
__Pyx_XDECREF(__pyx_r);
__pyx_t_1 = __pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_parsesWithoutPrefixAndSuffix(__pyx_v_self, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 283, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_r = __pyx_t_1;
__pyx_t_1 = 0;
goto __pyx_L0;

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.parsesWithoutPrefixAndSuffix", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":344
 *         return result
 * 
 *     def __str__(self) -> str:             # <<<<<<<<<<<<<<
 *         """
 *         The overridden toString method loops through the fsmParses list and accumulates the items to a result str.
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_23__str__(PyObject *__pyx_v_self); /*proto*/
static char __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_22__str__[] = "\n        The overridden toString method loops through the fsmParses list and accumulates the items to a result str.\n\n        RETURNS\n        -------\n        str\n            Result str that has the items of fsmParses list.\n        ";
#if CYTHON_COMPILING_IN_CPYTHON
struct wrapperbase __pyx_wrapperbase_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_22__str__;
#endif
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_23__str__(PyObject *__pyx_v_self) {
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__str__ (wrapper)", 0);
__pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_22__str__(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_22__str__(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self) {
PyObject *__pyx_v_result = NULL;
Py_ssize_t __pyx_v_i;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
Py_ssize_t __pyx_t_2;
Py_ssize_t __pyx_t_3;
Py_ssize_t __pyx_t_4;
PyObject *__pyx_t_5 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__str__", 0);

/* "MorphologicalAnalysis/FsmParseList.pyx":353
 *             Result str that has the items of fsmParses list.
 *         """
 *         result = ""             # <<<<<<<<<<<<<<
 *         for i in range(len(self.__fsm_parses)):
 *             result += self.__fsm_parses[i] + "\n"
 */
__Pyx_INCREF(__pyx_kp_u__3);
__pyx_v_result = __pyx_kp_u__3;

/* "MorphologicalAnalysis/FsmParseList.pyx":354
 *         """
 *         result = ""
 *         for i in range(len(self.__fsm_parses)):             # <<<<<<<<<<<<<<
 *             result += self.__fsm_parses[i] + "\n"
 *         return result
 */
__pyx_t_1 = __pyx_v_self->__pyx___fsm_parses;
__Pyx_INCREF(__pyx_t_1);
if (unlikely(__pyx_t_1 == Py_None)) {
  PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
  __PYX_ERR(0, 354, __pyx_L1_error)
}
__pyx_t_2 = PyList_GET_SIZE(__pyx_t_1); if (unlikely(__pyx_t_2 == ((Py_ssize_t)-1))) __PYX_ERR(0, 354, __pyx_L1_error)
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
__pyx_t_3 = __pyx_t_2;
for (__pyx_t_4 = 0; __pyx_t_4 < __pyx_t_3; __pyx_t_4+=1) {
  __pyx_v_i = __pyx_t_4;

  /* "MorphologicalAnalysis/FsmParseList.pyx":355
 *         result = ""
 *         for i in range(len(self.__fsm_parses)):
 *             result += self.__fsm_parses[i] + "\n"             # <<<<<<<<<<<<<<
 *         return result
 */
  if (unlikely(__pyx_v_self->__pyx___fsm_parses == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(0, 355, __pyx_L1_error)
  }
  __pyx_t_1 = __Pyx_GetItemInt_List(__pyx_v_self->__pyx___fsm_parses, __pyx_v_i, Py_ssize_t, 1, PyInt_FromSsize_t, 1, 1, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_t_5 = PyNumber_Add(__pyx_t_1, __pyx_kp_u__5); if (unlikely(!__pyx_t_5)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyNumber_InPlaceAdd(__pyx_v_result, __pyx_t_5); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 355, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF_SET(__pyx_v_result, __pyx_t_1);
  __pyx_t_1 = 0;
}

/* "MorphologicalAnalysis/FsmParseList.pyx":356
 *         for i in range(len(self.__fsm_parses)):
 *             result += self.__fsm_parses[i] + "\n"
 *         return result             # <<<<<<<<<<<<<<
 */
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v_result);
__pyx_r = __pyx_v_result;
goto __pyx_L0;

/* "MorphologicalAnalysis/FsmParseList.pyx":344
 *         return result
 * 
 *     def __str__(self) -> str:             # <<<<<<<<<<<<<<
 *         """
 *         The overridden toString method loops through the fsmParses list and accumulates the items to a result str.
 */

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.__str__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_result);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_25__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_25__reduce_cython__(PyObject *__pyx_v_self, CYTHON_UNUSED PyObject *unused) {
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__reduce_cython__ (wrapper)", 0);
__pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_24__reduce_cython__(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_24__reduce_cython__(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self) {
PyObject *__pyx_v_state = 0;
PyObject *__pyx_v__dict = 0;
int __pyx_v_use_setstate;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
int __pyx_t_3;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__reduce_cython__", 0);

/* "(tree fragment)":5
 *     cdef object _dict
 *     cdef bint use_setstate
 *     state = (self.__fsm_parses,)             # <<<<<<<<<<<<<<
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 */
__pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 5, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_INCREF(__pyx_v_self->__pyx___fsm_parses);
__Pyx_GIVEREF(__pyx_v_self->__pyx___fsm_parses);
PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v_self->__pyx___fsm_parses);
__pyx_v_state = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "(tree fragment)":6
 *     cdef bint use_setstate
 *     state = (self.__fsm_parses,)
 *     _dict = getattr(self, '__dict__', None)             # <<<<<<<<<<<<<<
 *     if _dict is not None:
 *         state += (_dict,)
 */
__pyx_t_1 = __Pyx_GetAttr3(((PyObject *)__pyx_v_self), __pyx_n_s_dict, Py_None); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 6, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__pyx_v__dict = __pyx_t_1;
__pyx_t_1 = 0;

/* "(tree fragment)":7
 *     state = (self.__fsm_parses,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
__pyx_t_2 = (__pyx_v__dict != Py_None);
__pyx_t_3 = (__pyx_t_2 != 0);
if (__pyx_t_3) {

  /* "(tree fragment)":8
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:
 *         state += (_dict,)             # <<<<<<<<<<<<<<
 *         use_setstate = True
 *     else:
 */
  __pyx_t_1 = PyTuple_New(1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_v__dict);
  __Pyx_GIVEREF(__pyx_v__dict);
  PyTuple_SET_ITEM(__pyx_t_1, 0, __pyx_v__dict);
  __pyx_t_4 = PyNumber_InPlaceAdd(__pyx_v_state, __pyx_t_1); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 8, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_DECREF_SET(__pyx_v_state, ((PyObject*)__pyx_t_4));
  __pyx_t_4 = 0;

  /* "(tree fragment)":9
 *     if _dict is not None:
 *         state += (_dict,)
 *         use_setstate = True             # <<<<<<<<<<<<<<
 *     else:
 *         use_setstate = self.__fsm_parses is not None
 */
  __pyx_v_use_setstate = 1;

  /* "(tree fragment)":7
 *     state = (self.__fsm_parses,)
 *     _dict = getattr(self, '__dict__', None)
 *     if _dict is not None:             # <<<<<<<<<<<<<<
 *         state += (_dict,)
 *         use_setstate = True
 */
  goto __pyx_L3;
}

/* "(tree fragment)":11
 *         use_setstate = True
 *     else:
 *         use_setstate = self.__fsm_parses is not None             # <<<<<<<<<<<<<<
 *     if use_setstate:
 *         return __pyx_unpickle_FsmParseList, (type(self), 0xb37bd0b, None), state
 */
/*else*/ {
  __pyx_t_3 = (__pyx_v_self->__pyx___fsm_parses != ((PyObject*)Py_None));
  __pyx_v_use_setstate = __pyx_t_3;
}
__pyx_L3:;

/* "(tree fragment)":12
 *     else:
 *         use_setstate = self.__fsm_parses is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_FsmParseList, (type(self), 0xb37bd0b, None), state
 *     else:
 */
__pyx_t_3 = (__pyx_v_use_setstate != 0);
if (__pyx_t_3) {

  /* "(tree fragment)":13
 *         use_setstate = self.__fsm_parses is not None
 *     if use_setstate:
 *         return __pyx_unpickle_FsmParseList, (type(self), 0xb37bd0b, None), state             # <<<<<<<<<<<<<<
 *     else:
 *         return __pyx_unpickle_FsmParseList, (type(self), 0xb37bd0b, state)
 */
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_4, __pyx_n_s_pyx_unpickle_FsmParseList); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __Pyx_INCREF(__pyx_int_188202251);
  __Pyx_GIVEREF(__pyx_int_188202251);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_188202251);
  __Pyx_INCREF(Py_None);
  __Pyx_GIVEREF(Py_None);
  PyTuple_SET_ITEM(__pyx_t_1, 2, Py_None);
  __pyx_t_5 = PyTuple_New(3); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 13, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_4);
  PyTuple_SET_ITEM(__pyx_t_5, 0, __pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_5, 1, __pyx_t_1);
  __Pyx_INCREF(__pyx_v_state);
  __Pyx_GIVEREF(__pyx_v_state);
  PyTuple_SET_ITEM(__pyx_t_5, 2, __pyx_v_state);
  __pyx_t_4 = 0;
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_5;
  __pyx_t_5 = 0;
  goto __pyx_L0;

  /* "(tree fragment)":12
 *     else:
 *         use_setstate = self.__fsm_parses is not None
 *     if use_setstate:             # <<<<<<<<<<<<<<
 *         return __pyx_unpickle_FsmParseList, (type(self), 0xb37bd0b, None), state
 *     else:
 */
}

/* "(tree fragment)":15
 *         return __pyx_unpickle_FsmParseList, (type(self), 0xb37bd0b, None), state
 *     else:
 *         return __pyx_unpickle_FsmParseList, (type(self), 0xb37bd0b, state)             # <<<<<<<<<<<<<<
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_FsmParseList__set_state(self, __pyx_state)
 */
/*else*/ {
  __Pyx_XDECREF(__pyx_r);
  __Pyx_GetModuleGlobalName(__pyx_t_5, __pyx_n_s_pyx_unpickle_FsmParseList); if (unlikely(!__pyx_t_5)) __PYX_ERR(1, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_5);
  __pyx_t_1 = PyTuple_New(3); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __Pyx_GIVEREF(((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  PyTuple_SET_ITEM(__pyx_t_1, 0, ((PyObject *)Py_TYPE(((PyObject *)__pyx_v_self))));
  __Pyx_INCREF(__pyx_int_188202251);
  __Pyx_GIVEREF(__pyx_int_188202251);
  PyTuple_SET_ITEM(__pyx_t_1, 1, __pyx_int_188202251);
  __Pyx_INCREF(__pyx_v_state);
  __Pyx_GIVEREF(__pyx_v_state);
  PyTuple_SET_ITEM(__pyx_t_1, 2, __pyx_v_state);
  __pyx_t_4 = PyTuple_New(2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 15, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_GIVEREF(__pyx_t_5);
  PyTuple_SET_ITEM(__pyx_t_4, 0, __pyx_t_5);
  __Pyx_GIVEREF(__pyx_t_1);
  PyTuple_SET_ITEM(__pyx_t_4, 1, __pyx_t_1);
  __pyx_t_5 = 0;
  __pyx_t_1 = 0;
  __pyx_r = __pyx_t_4;
  __pyx_t_4 = 0;
  goto __pyx_L0;
}

/* "(tree fragment)":1
 * def __reduce_cython__(self):             # <<<<<<<<<<<<<<
 *     cdef tuple state
 *     cdef object _dict
 */

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.__reduce_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v_state);
__Pyx_XDECREF(__pyx_v__dict);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_FsmParseList, (type(self), 0xb37bd0b, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_FsmParseList__set_state(self, __pyx_state)
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_27__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state); /*proto*/
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_27__setstate_cython__(PyObject *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__setstate_cython__ (wrapper)", 0);
__pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_26__setstate_cython__(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v_self), ((PyObject *)__pyx_v___pyx_state));

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_26__setstate_cython__(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v_self, PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__setstate_cython__", 0);

/* "(tree fragment)":17
 *         return __pyx_unpickle_FsmParseList, (type(self), 0xb37bd0b, state)
 * def __setstate_cython__(self, __pyx_state):
 *     __pyx_unpickle_FsmParseList__set_state(self, __pyx_state)             # <<<<<<<<<<<<<<
 */
if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 17, __pyx_L1_error)
__pyx_t_1 = __pyx_f_21MorphologicalAnalysis_12FsmParseList___pyx_unpickle_FsmParseList__set_state(__pyx_v_self, ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 17, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
__Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

/* "(tree fragment)":16
 *     else:
 *         return __pyx_unpickle_FsmParseList, (type(self), 0xb37bd0b, state)
 * def __setstate_cython__(self, __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_unpickle_FsmParseList__set_state(self, __pyx_state)
 */

/* function exit code */
__pyx_r = Py_None; __Pyx_INCREF(Py_None);
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.FsmParseList.__setstate_cython__", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":1
 * def __pyx_unpickle_FsmParseList(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* Python wrapper */
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_1__pyx_unpickle_FsmParseList(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds); /*proto*/
static PyMethodDef __pyx_mdef_21MorphologicalAnalysis_12FsmParseList_1__pyx_unpickle_FsmParseList = {"__pyx_unpickle_FsmParseList", (PyCFunction)(void*)(PyCFunctionWithKeywords)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_1__pyx_unpickle_FsmParseList, METH_VARARGS|METH_KEYWORDS, 0};
static PyObject *__pyx_pw_21MorphologicalAnalysis_12FsmParseList_1__pyx_unpickle_FsmParseList(PyObject *__pyx_self, PyObject *__pyx_args, PyObject *__pyx_kwds) {
PyObject *__pyx_v___pyx_type = 0;
long __pyx_v___pyx_checksum;
PyObject *__pyx_v___pyx_state = 0;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
PyObject *__pyx_r = 0;
__Pyx_RefNannyDeclarations
__Pyx_RefNannySetupContext("__pyx_unpickle_FsmParseList (wrapper)", 0);
{
  static PyObject **__pyx_pyargnames[] = {&__pyx_n_s_pyx_type,&__pyx_n_s_pyx_checksum,&__pyx_n_s_pyx_state,0};
  PyObject* values[3] = {0,0,0};
  if (unlikely(__pyx_kwds)) {
    Py_ssize_t kw_args;
    const Py_ssize_t pos_args = PyTuple_GET_SIZE(__pyx_args);
    switch (pos_args) {
      case  3: values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
      CYTHON_FALLTHROUGH;
      case  2: values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
      CYTHON_FALLTHROUGH;
      case  1: values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
      CYTHON_FALLTHROUGH;
      case  0: break;
      default: goto __pyx_L5_argtuple_error;
    }
    kw_args = PyDict_Size(__pyx_kwds);
    switch (pos_args) {
      case  0:
      if (likely((values[0] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_type)) != 0)) kw_args--;
      else goto __pyx_L5_argtuple_error;
      CYTHON_FALLTHROUGH;
      case  1:
      if (likely((values[1] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_checksum)) != 0)) kw_args--;
      else {
        __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_FsmParseList", 1, 3, 3, 1); __PYX_ERR(1, 1, __pyx_L3_error)
      }
      CYTHON_FALLTHROUGH;
      case  2:
      if (likely((values[2] = __Pyx_PyDict_GetItemStr(__pyx_kwds, __pyx_n_s_pyx_state)) != 0)) kw_args--;
      else {
        __Pyx_RaiseArgtupleInvalid("__pyx_unpickle_FsmParseList", 1, 3, 3, 2); __PYX_ERR(1, 1, __pyx_L3_error)
      }
    }
    if (unlikely(kw_args > 0)) {
      if (unlikely(__Pyx_ParseOptionalKeywords(__pyx_kwds, __pyx_pyargnames, 0, values, pos_args, "__pyx_unpickle_FsmParseList") < 0)) __PYX_ERR(1, 1, __pyx_L3_error)
    }
  } else if (PyTuple_GET_SIZE(__pyx_args) != 3) {
    goto __pyx_L5_argtuple_error;
  } else {
    values[0] = PyTuple_GET_ITEM(__pyx_args, 0);
    values[1] = PyTuple_GET_ITEM(__pyx_args, 1);
    values[2] = PyTuple_GET_ITEM(__pyx_args, 2);
  }
  __pyx_v___pyx_type = values[0];
  __pyx_v___pyx_checksum = __Pyx_PyInt_As_long(values[1]); if (unlikely((__pyx_v___pyx_checksum == (long)-1) && PyErr_Occurred())) __PYX_ERR(1, 1, __pyx_L3_error)
  __pyx_v___pyx_state = values[2];
}
goto __pyx_L4_argument_unpacking_done;
__pyx_L5_argtuple_error:;
__Pyx_RaiseArgtupleInvalid("__pyx_unpickle_FsmParseList", 1, 3, 3, PyTuple_GET_SIZE(__pyx_args)); __PYX_ERR(1, 1, __pyx_L3_error)
__pyx_L3_error:;
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.__pyx_unpickle_FsmParseList", __pyx_clineno, __pyx_lineno, __pyx_filename);
__Pyx_RefNannyFinishContext();
return NULL;
__pyx_L4_argument_unpacking_done:;
__pyx_r = __pyx_pf_21MorphologicalAnalysis_12FsmParseList___pyx_unpickle_FsmParseList(__pyx_self, __pyx_v___pyx_type, __pyx_v___pyx_checksum, __pyx_v___pyx_state);

/* function exit code */
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

static PyObject *__pyx_pf_21MorphologicalAnalysis_12FsmParseList___pyx_unpickle_FsmParseList(CYTHON_UNUSED PyObject *__pyx_self, PyObject *__pyx_v___pyx_type, long __pyx_v___pyx_checksum, PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_v___pyx_PickleError = 0;
PyObject *__pyx_v___pyx_result = 0;
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
int __pyx_t_1;
PyObject *__pyx_t_2 = NULL;
PyObject *__pyx_t_3 = NULL;
PyObject *__pyx_t_4 = NULL;
PyObject *__pyx_t_5 = NULL;
int __pyx_t_6;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__pyx_unpickle_FsmParseList", 0);

/* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xb37bd0b:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb37bd0b = (__fsm_parses))" % __pyx_checksum)
 */
__pyx_t_1 = ((__pyx_v___pyx_checksum != 0xb37bd0b) != 0);
if (__pyx_t_1) {

  /* "(tree fragment)":5
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xb37bd0b:
 *         from pickle import PickleError as __pyx_PickleError             # <<<<<<<<<<<<<<
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb37bd0b = (__fsm_parses))" % __pyx_checksum)
 *     __pyx_result = FsmParseList.__new__(__pyx_type)
 */
  __pyx_t_2 = PyList_New(1); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_n_s_PickleError);
  __Pyx_GIVEREF(__pyx_n_s_PickleError);
  PyList_SET_ITEM(__pyx_t_2, 0, __pyx_n_s_PickleError);
  __pyx_t_3 = __Pyx_Import(__pyx_n_s_pickle, __pyx_t_2, 0); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __pyx_t_2 = __Pyx_ImportFrom(__pyx_t_3, __pyx_n_s_PickleError); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __Pyx_INCREF(__pyx_t_2);
  __pyx_v___pyx_PickleError = __pyx_t_2;
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":6
 *     if __pyx_checksum != 0xb37bd0b:
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb37bd0b = (__fsm_parses))" % __pyx_checksum)             # <<<<<<<<<<<<<<
 *     __pyx_result = FsmParseList.__new__(__pyx_type)
 *     if __pyx_state is not None:
 */
  __pyx_t_2 = __Pyx_PyInt_From_long(__pyx_v___pyx_checksum); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_2);
  __pyx_t_4 = __Pyx_PyString_Format(__pyx_kp_s_Incompatible_checksums_s_vs_0xb3, __pyx_t_2); if (unlikely(!__pyx_t_4)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_4);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_INCREF(__pyx_v___pyx_PickleError);
  __pyx_t_2 = __pyx_v___pyx_PickleError; __pyx_t_5 = NULL;
  if (CYTHON_UNPACK_METHODS && unlikely(PyMethod_Check(__pyx_t_2))) {
    __pyx_t_5 = PyMethod_GET_SELF(__pyx_t_2);
    if (likely(__pyx_t_5)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
      __Pyx_INCREF(__pyx_t_5);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_2, function);
    }
  }
  __pyx_t_3 = (__pyx_t_5) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_5, __pyx_t_4) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_t_4);
  __Pyx_XDECREF(__pyx_t_5); __pyx_t_5 = 0;
  __Pyx_DECREF(__pyx_t_4); __pyx_t_4 = 0;
  if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
  __Pyx_Raise(__pyx_t_3, 0, 0, 0);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;
  __PYX_ERR(1, 6, __pyx_L1_error)

  /* "(tree fragment)":4
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 *     if __pyx_checksum != 0xb37bd0b:             # <<<<<<<<<<<<<<
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb37bd0b = (__fsm_parses))" % __pyx_checksum)
 */
}

/* "(tree fragment)":7
 *         from pickle import PickleError as __pyx_PickleError
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb37bd0b = (__fsm_parses))" % __pyx_checksum)
 *     __pyx_result = FsmParseList.__new__(__pyx_type)             # <<<<<<<<<<<<<<
 *     if __pyx_state is not None:
 *         __pyx_unpickle_FsmParseList__set_state(<FsmParseList> __pyx_result, __pyx_state)
 */
__pyx_t_2 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList), __pyx_n_s_new); if (unlikely(!__pyx_t_2)) __PYX_ERR(1, 7, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_2);
__pyx_t_4 = NULL;
if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_2))) {
  __pyx_t_4 = PyMethod_GET_SELF(__pyx_t_2);
  if (likely(__pyx_t_4)) {
    PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_2);
    __Pyx_INCREF(__pyx_t_4);
    __Pyx_INCREF(function);
    __Pyx_DECREF_SET(__pyx_t_2, function);
  }
}
__pyx_t_3 = (__pyx_t_4) ? __Pyx_PyObject_Call2Args(__pyx_t_2, __pyx_t_4, __pyx_v___pyx_type) : __Pyx_PyObject_CallOneArg(__pyx_t_2, __pyx_v___pyx_type);
__Pyx_XDECREF(__pyx_t_4); __pyx_t_4 = 0;
if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 7, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_3);
__Pyx_DECREF(__pyx_t_2); __pyx_t_2 = 0;
__pyx_v___pyx_result = __pyx_t_3;
__pyx_t_3 = 0;

/* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb37bd0b = (__fsm_parses))" % __pyx_checksum)
 *     __pyx_result = FsmParseList.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_FsmParseList__set_state(<FsmParseList> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
__pyx_t_1 = (__pyx_v___pyx_state != Py_None);
__pyx_t_6 = (__pyx_t_1 != 0);
if (__pyx_t_6) {

  /* "(tree fragment)":9
 *     __pyx_result = FsmParseList.__new__(__pyx_type)
 *     if __pyx_state is not None:
 *         __pyx_unpickle_FsmParseList__set_state(<FsmParseList> __pyx_result, __pyx_state)             # <<<<<<<<<<<<<<
 *     return __pyx_result
 * cdef __pyx_unpickle_FsmParseList__set_state(FsmParseList __pyx_result, tuple __pyx_state):
 */
  if (!(likely(PyTuple_CheckExact(__pyx_v___pyx_state))||((__pyx_v___pyx_state) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "tuple", Py_TYPE(__pyx_v___pyx_state)->tp_name), 0))) __PYX_ERR(1, 9, __pyx_L1_error)
  __pyx_t_3 = __pyx_f_21MorphologicalAnalysis_12FsmParseList___pyx_unpickle_FsmParseList__set_state(((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)__pyx_v___pyx_result), ((PyObject*)__pyx_v___pyx_state)); if (unlikely(!__pyx_t_3)) __PYX_ERR(1, 9, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_3);
  __Pyx_DECREF(__pyx_t_3); __pyx_t_3 = 0;

  /* "(tree fragment)":8
 *         raise __pyx_PickleError("Incompatible checksums (%s vs 0xb37bd0b = (__fsm_parses))" % __pyx_checksum)
 *     __pyx_result = FsmParseList.__new__(__pyx_type)
 *     if __pyx_state is not None:             # <<<<<<<<<<<<<<
 *         __pyx_unpickle_FsmParseList__set_state(<FsmParseList> __pyx_result, __pyx_state)
 *     return __pyx_result
 */
}

/* "(tree fragment)":10
 *     if __pyx_state is not None:
 *         __pyx_unpickle_FsmParseList__set_state(<FsmParseList> __pyx_result, __pyx_state)
 *     return __pyx_result             # <<<<<<<<<<<<<<
 * cdef __pyx_unpickle_FsmParseList__set_state(FsmParseList __pyx_result, tuple __pyx_state):
 *     __pyx_result.__fsm_parses = __pyx_state[0]
 */
__Pyx_XDECREF(__pyx_r);
__Pyx_INCREF(__pyx_v___pyx_result);
__pyx_r = __pyx_v___pyx_result;
goto __pyx_L0;

/* "(tree fragment)":1
 * def __pyx_unpickle_FsmParseList(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */

/* function exit code */
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_2);
__Pyx_XDECREF(__pyx_t_3);
__Pyx_XDECREF(__pyx_t_4);
__Pyx_XDECREF(__pyx_t_5);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.__pyx_unpickle_FsmParseList", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = NULL;
__pyx_L0:;
__Pyx_XDECREF(__pyx_v___pyx_PickleError);
__Pyx_XDECREF(__pyx_v___pyx_result);
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}

/* "(tree fragment)":11
 *         __pyx_unpickle_FsmParseList__set_state(<FsmParseList> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_FsmParseList__set_state(FsmParseList __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.__fsm_parses = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

static PyObject *__pyx_f_21MorphologicalAnalysis_12FsmParseList___pyx_unpickle_FsmParseList__set_state(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *__pyx_v___pyx_result, PyObject *__pyx_v___pyx_state) {
PyObject *__pyx_r = NULL;
__Pyx_RefNannyDeclarations
PyObject *__pyx_t_1 = NULL;
int __pyx_t_2;
Py_ssize_t __pyx_t_3;
int __pyx_t_4;
int __pyx_t_5;
PyObject *__pyx_t_6 = NULL;
PyObject *__pyx_t_7 = NULL;
PyObject *__pyx_t_8 = NULL;
int __pyx_lineno = 0;
const char *__pyx_filename = NULL;
int __pyx_clineno = 0;
__Pyx_RefNannySetupContext("__pyx_unpickle_FsmParseList__set_state", 0);

/* "(tree fragment)":12
 *     return __pyx_result
 * cdef __pyx_unpickle_FsmParseList__set_state(FsmParseList __pyx_result, tuple __pyx_state):
 *     __pyx_result.__fsm_parses = __pyx_state[0]             # <<<<<<<<<<<<<<
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
if (unlikely(__pyx_v___pyx_state == Py_None)) {
  PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
  __PYX_ERR(1, 12, __pyx_L1_error)
}
__pyx_t_1 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 0, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 12, __pyx_L1_error)
__Pyx_GOTREF(__pyx_t_1);
if (!(likely(PyList_CheckExact(__pyx_t_1))||((__pyx_t_1) == Py_None)||(PyErr_Format(PyExc_TypeError, "Expected %.16s, got %.200s", "list", Py_TYPE(__pyx_t_1)->tp_name), 0))) __PYX_ERR(1, 12, __pyx_L1_error)
__Pyx_GIVEREF(__pyx_t_1);
__Pyx_GOTREF(__pyx_v___pyx_result->__pyx___fsm_parses);
__Pyx_DECREF(__pyx_v___pyx_result->__pyx___fsm_parses);
__pyx_v___pyx_result->__pyx___fsm_parses = ((PyObject*)__pyx_t_1);
__pyx_t_1 = 0;

/* "(tree fragment)":13
 * cdef __pyx_unpickle_FsmParseList__set_state(FsmParseList __pyx_result, tuple __pyx_state):
 *     __pyx_result.__fsm_parses = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
if (unlikely(__pyx_v___pyx_state == Py_None)) {
  PyErr_SetString(PyExc_TypeError, "object of type 'NoneType' has no len()");
  __PYX_ERR(1, 13, __pyx_L1_error)
}
__pyx_t_3 = PyTuple_GET_SIZE(__pyx_v___pyx_state); if (unlikely(__pyx_t_3 == ((Py_ssize_t)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
__pyx_t_4 = ((__pyx_t_3 > 1) != 0);
if (__pyx_t_4) {
} else {
  __pyx_t_2 = __pyx_t_4;
  goto __pyx_L4_bool_binop_done;
}
__pyx_t_4 = __Pyx_HasAttr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(__pyx_t_4 == ((int)-1))) __PYX_ERR(1, 13, __pyx_L1_error)
__pyx_t_5 = (__pyx_t_4 != 0);
__pyx_t_2 = __pyx_t_5;
__pyx_L4_bool_binop_done:;
if (__pyx_t_2) {

  /* "(tree fragment)":14
 *     __pyx_result.__fsm_parses = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 *         __pyx_result.__dict__.update(__pyx_state[1])             # <<<<<<<<<<<<<<
 */
  __pyx_t_6 = __Pyx_PyObject_GetAttrStr(((PyObject *)__pyx_v___pyx_result), __pyx_n_s_dict); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_7 = __Pyx_PyObject_GetAttrStr(__pyx_t_6, __pyx_n_s_update); if (unlikely(!__pyx_t_7)) __PYX_ERR(1, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_7);
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(__pyx_v___pyx_state == Py_None)) {
    PyErr_SetString(PyExc_TypeError, "'NoneType' object is not subscriptable");
    __PYX_ERR(1, 14, __pyx_L1_error)
  }
  __pyx_t_6 = __Pyx_GetItemInt_Tuple(__pyx_v___pyx_state, 1, long, 1, __Pyx_PyInt_From_long, 0, 0, 1); if (unlikely(!__pyx_t_6)) __PYX_ERR(1, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_6);
  __pyx_t_8 = NULL;
  if (CYTHON_UNPACK_METHODS && likely(PyMethod_Check(__pyx_t_7))) {
    __pyx_t_8 = PyMethod_GET_SELF(__pyx_t_7);
    if (likely(__pyx_t_8)) {
      PyObject* function = PyMethod_GET_FUNCTION(__pyx_t_7);
      __Pyx_INCREF(__pyx_t_8);
      __Pyx_INCREF(function);
      __Pyx_DECREF_SET(__pyx_t_7, function);
    }
  }
  __pyx_t_1 = (__pyx_t_8) ? __Pyx_PyObject_Call2Args(__pyx_t_7, __pyx_t_8, __pyx_t_6) : __Pyx_PyObject_CallOneArg(__pyx_t_7, __pyx_t_6);
  __Pyx_XDECREF(__pyx_t_8); __pyx_t_8 = 0;
  __Pyx_DECREF(__pyx_t_6); __pyx_t_6 = 0;
  if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 14, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_DECREF(__pyx_t_7); __pyx_t_7 = 0;
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "(tree fragment)":13
 * cdef __pyx_unpickle_FsmParseList__set_state(FsmParseList __pyx_result, tuple __pyx_state):
 *     __pyx_result.__fsm_parses = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):             # <<<<<<<<<<<<<<
 *         __pyx_result.__dict__.update(__pyx_state[1])
 */
}

/* "(tree fragment)":11
 *         __pyx_unpickle_FsmParseList__set_state(<FsmParseList> __pyx_result, __pyx_state)
 *     return __pyx_result
 * cdef __pyx_unpickle_FsmParseList__set_state(FsmParseList __pyx_result, tuple __pyx_state):             # <<<<<<<<<<<<<<
 *     __pyx_result.__fsm_parses = __pyx_state[0]
 *     if len(__pyx_state) > 1 and hasattr(__pyx_result, '__dict__'):
 */

/* function exit code */
__pyx_r = Py_None; __Pyx_INCREF(Py_None);
goto __pyx_L0;
__pyx_L1_error:;
__Pyx_XDECREF(__pyx_t_1);
__Pyx_XDECREF(__pyx_t_6);
__Pyx_XDECREF(__pyx_t_7);
__Pyx_XDECREF(__pyx_t_8);
__Pyx_AddTraceback("MorphologicalAnalysis.FsmParseList.__pyx_unpickle_FsmParseList__set_state", __pyx_clineno, __pyx_lineno, __pyx_filename);
__pyx_r = 0;
__pyx_L0:;
__Pyx_XGIVEREF(__pyx_r);
__Pyx_RefNannyFinishContext();
return __pyx_r;
}
static struct __pyx_vtabstruct_21MorphologicalAnalysis_12FsmParseList_FsmParseList __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList;

static PyObject *__pyx_tp_new_21MorphologicalAnalysis_12FsmParseList_FsmParseList(PyTypeObject *t, CYTHON_UNUSED PyObject *a, CYTHON_UNUSED PyObject *k) {
struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *p;
PyObject *o;
if (likely((t->tp_flags & Py_TPFLAGS_IS_ABSTRACT) == 0)) {
  o = (*t->tp_alloc)(t, 0);
} else {
  o = (PyObject *) PyBaseObject_Type.tp_new(t, __pyx_empty_tuple, 0);
}
if (unlikely(!o)) return 0;
p = ((struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)o);
p->__pyx_vtab = __pyx_vtabptr_21MorphologicalAnalysis_12FsmParseList_FsmParseList;
p->__pyx___fsm_parses = ((PyObject*)Py_None); Py_INCREF(Py_None);
return o;
}

static void __pyx_tp_dealloc_21MorphologicalAnalysis_12FsmParseList_FsmParseList(PyObject *o) {
struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *p = (struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)o;
#if CYTHON_USE_TP_FINALIZE
if (unlikely(PyType_HasFeature(Py_TYPE(o), Py_TPFLAGS_HAVE_FINALIZE) && Py_TYPE(o)->tp_finalize) && !_PyGC_FINALIZED(o)) {
  if (PyObject_CallFinalizerFromDealloc(o)) return;
}
#endif
PyObject_GC_UnTrack(o);
Py_CLEAR(p->__pyx___fsm_parses);
(*Py_TYPE(o)->tp_free)(o);
}

static int __pyx_tp_traverse_21MorphologicalAnalysis_12FsmParseList_FsmParseList(PyObject *o, visitproc v, void *a) {
int e;
struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *p = (struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)o;
if (p->__pyx___fsm_parses) {
  e = (*v)(p->__pyx___fsm_parses, a); if (e) return e;
}
return 0;
}

static int __pyx_tp_clear_21MorphologicalAnalysis_12FsmParseList_FsmParseList(PyObject *o) {
PyObject* tmp;
struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *p = (struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *)o;
tmp = ((PyObject*)p->__pyx___fsm_parses);
p->__pyx___fsm_parses = ((PyObject*)Py_None); Py_INCREF(Py_None);
Py_XDECREF(tmp);
return 0;
}

static PyMethodDef __pyx_methods_21MorphologicalAnalysis_12FsmParseList_FsmParseList[] = {
{"size", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_3size, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_2size},
{"addFsmParse", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_5addFsmParse, METH_O, 0},
{"getFsmParse", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_7getFsmParse, METH_O, __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_6getFsmParse},
{"rootWords", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_9rootWords, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_8rootWords},
{"reduceToParsesWithSameRootAndPos", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_11reduceToParsesWithSameRootAndPos, METH_O, __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_10reduceToParsesWithSameRootAndPos},
{"getParseWithLongestRootWord", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_13getParseWithLongestRootWord, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_12getParseWithLongestRootWord},
{"isLongestRootException", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_15isLongestRootException, METH_O, __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_14isLongestRootException},
{"reduceToParsesWithSameRoot", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_17reduceToParsesWithSameRoot, METH_O, __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_16reduceToParsesWithSameRoot},
{"constructParseListForDifferentRootWithPos", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_19constructParseListForDifferentRootWithPos, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_18constructParseListForDifferentRootWithPos},
{"parsesWithoutPrefixAndSuffix", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_21parsesWithoutPrefixAndSuffix, METH_NOARGS, __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_20parsesWithoutPrefixAndSuffix},
{"__reduce_cython__", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_25__reduce_cython__, METH_NOARGS, 0},
{"__setstate_cython__", (PyCFunction)__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_27__setstate_cython__, METH_O, 0},
{0, 0, 0, 0}
};

static PyTypeObject __pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList = {
PyVarObject_HEAD_INIT(0, 0)
"MorphologicalAnalysis.FsmParseList.FsmParseList", /*tp_name*/
sizeof(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList), /*tp_basicsize*/
0, /*tp_itemsize*/
__pyx_tp_dealloc_21MorphologicalAnalysis_12FsmParseList_FsmParseList, /*tp_dealloc*/
#if PY_VERSION_HEX < 0x030800b4
0, /*tp_print*/
#endif
#if PY_VERSION_HEX >= 0x030800b4
0, /*tp_vectorcall_offset*/
#endif
0, /*tp_getattr*/
0, /*tp_setattr*/
#if PY_MAJOR_VERSION < 3
0, /*tp_compare*/
#endif
#if PY_MAJOR_VERSION >= 3
0, /*tp_as_async*/
#endif
0, /*tp_repr*/
0, /*tp_as_number*/
0, /*tp_as_sequence*/
0, /*tp_as_mapping*/
0, /*tp_hash*/
0, /*tp_call*/
__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_23__str__, /*tp_str*/
0, /*tp_getattro*/
0, /*tp_setattro*/
0, /*tp_as_buffer*/
Py_TPFLAGS_DEFAULT|Py_TPFLAGS_HAVE_VERSION_TAG|Py_TPFLAGS_CHECKTYPES|Py_TPFLAGS_HAVE_NEWBUFFER|Py_TPFLAGS_BASETYPE|Py_TPFLAGS_HAVE_GC, /*tp_flags*/
0, /*tp_doc*/
__pyx_tp_traverse_21MorphologicalAnalysis_12FsmParseList_FsmParseList, /*tp_traverse*/
__pyx_tp_clear_21MorphologicalAnalysis_12FsmParseList_FsmParseList, /*tp_clear*/
0, /*tp_richcompare*/
0, /*tp_weaklistoffset*/
0, /*tp_iter*/
0, /*tp_iternext*/
__pyx_methods_21MorphologicalAnalysis_12FsmParseList_FsmParseList, /*tp_methods*/
0, /*tp_members*/
0, /*tp_getset*/
0, /*tp_base*/
0, /*tp_dict*/
0, /*tp_descr_get*/
0, /*tp_descr_set*/
0, /*tp_dictoffset*/
__pyx_pw_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_1__init__, /*tp_init*/
0, /*tp_alloc*/
__pyx_tp_new_21MorphologicalAnalysis_12FsmParseList_FsmParseList, /*tp_new*/
0, /*tp_free*/
0, /*tp_is_gc*/
0, /*tp_bases*/
0, /*tp_mro*/
0, /*tp_cache*/
0, /*tp_subclasses*/
0, /*tp_weaklist*/
0, /*tp_del*/
0, /*tp_version_tag*/
#if PY_VERSION_HEX >= 0x030400a1
0, /*tp_finalize*/
#endif
#if PY_VERSION_HEX >= 0x030800b1
0, /*tp_vectorcall*/
#endif
#if PY_VERSION_HEX >= 0x030800b4 && PY_VERSION_HEX < 0x03090000
0, /*tp_print*/
#endif
};

static PyMethodDef __pyx_methods[] = {
{0, 0, 0, 0}
};

#if PY_MAJOR_VERSION >= 3
#if CYTHON_PEP489_MULTI_PHASE_INIT
static PyObject* __pyx_pymod_create(PyObject *spec, PyModuleDef *def); /*proto*/
static int __pyx_pymod_exec_FsmParseList(PyObject* module); /*proto*/
static PyModuleDef_Slot __pyx_moduledef_slots[] = {
{Py_mod_create, (void*)__pyx_pymod_create},
{Py_mod_exec, (void*)__pyx_pymod_exec_FsmParseList},
{0, NULL}
};
#endif

static struct PyModuleDef __pyx_moduledef = {
  PyModuleDef_HEAD_INIT,
  "FsmParseList",
  0, /* m_doc */
#if CYTHON_PEP489_MULTI_PHASE_INIT
  0, /* m_size */
#else
  -1, /* m_size */
#endif
  __pyx_methods /* m_methods */,
#if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_moduledef_slots, /* m_slots */
#else
  NULL, /* m_reload */
#endif
  NULL, /* m_traverse */
  NULL, /* m_clear */
  NULL /* m_free */
};
#endif
#ifndef CYTHON_SMALL_CODE
#if defined(__clang__)
    #define CYTHON_SMALL_CODE
#elif defined(__GNUC__) && (__GNUC__ > 4 || (__GNUC__ == 4 && __GNUC_MINOR__ >= 3))
    #define CYTHON_SMALL_CODE __attribute__((cold))
#else
    #define CYTHON_SMALL_CODE
#endif
#endif

static __Pyx_StringTabEntry __pyx_string_tab[] = {
  {&__pyx_kp_u_, __pyx_k_, sizeof(__pyx_k_), 0, 1, 0, 0},
  {&__pyx_n_s_FsmParseList, __pyx_k_FsmParseList, sizeof(__pyx_k_FsmParseList), 0, 0, 1, 1},
  {&__pyx_kp_s_Incompatible_checksums_s_vs_0xb3, __pyx_k_Incompatible_checksums_s_vs_0xb3, sizeof(__pyx_k_Incompatible_checksums_s_vs_0xb3), 0, 0, 1, 0},
  {&__pyx_n_s_MorphologicalAnalysis_FsmParseLi, __pyx_k_MorphologicalAnalysis_FsmParseLi, sizeof(__pyx_k_MorphologicalAnalysis_FsmParseLi), 0, 0, 1, 1},
  {&__pyx_n_s_PickleError, __pyx_k_PickleError, sizeof(__pyx_k_PickleError), 0, 0, 1, 1},
  {&__pyx_kp_u__2, __pyx_k__2, sizeof(__pyx_k__2), 0, 1, 0, 0},
  {&__pyx_kp_u__3, __pyx_k__3, sizeof(__pyx_k__3), 0, 1, 0, 0},
  {&__pyx_kp_u__4, __pyx_k__4, sizeof(__pyx_k__4), 0, 1, 0, 0},
  {&__pyx_kp_u__5, __pyx_k__5, sizeof(__pyx_k__5), 0, 1, 0, 0},
  {&__pyx_kp_u_aca_acak_NOUN_VERB, __pyx_k_aca_acak_NOUN_VERB, sizeof(__pyx_k_aca_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acaklar_acak_NOUN_VERB, __pyx_k_acaklar_acak_NOUN_VERB, sizeof(__pyx_k_acaklar_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acaklarn_acak_NOUN_VERB, __pyx_k_acaklarn_acak_NOUN_VERB, sizeof(__pyx_k_acaklarn_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acaksa_acak_NOUN_VERB, __pyx_k_acaksa_acak_NOUN_VERB, sizeof(__pyx_k_acaksa_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acaktr_acak_NOUN_VERB, __pyx_k_acaktr_acak_NOUN_VERB, sizeof(__pyx_k_acaktr_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acam_acak_NOUN_VERB, __pyx_k_acam_acak_NOUN_VERB, sizeof(__pyx_k_acam_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acam_acak_NOUN_VERB_2, __pyx_k_acam_acak_NOUN_VERB_2, sizeof(__pyx_k_acam_acak_NOUN_VERB_2), 0, 1, 0, 0},
  {&__pyx_kp_u_acamz_acak_NOUN_VERB, __pyx_k_acamz_acak_NOUN_VERB, sizeof(__pyx_k_acamz_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acan_acak_NOUN_VERB, __pyx_k_acan_acak_NOUN_VERB, sizeof(__pyx_k_acan_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acan_acak_NOUN_VERB_2, __pyx_k_acan_acak_NOUN_VERB_2, sizeof(__pyx_k_acan_acak_NOUN_VERB_2), 0, 1, 0, 0},
  {&__pyx_kp_u_acana_acak_NOUN_VERB, __pyx_k_acana_acak_NOUN_VERB, sizeof(__pyx_k_acana_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acann_acak_NOUN_VERB, __pyx_k_acann_acak_NOUN_VERB, sizeof(__pyx_k_acann_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acanz_acak_NOUN_VERB, __pyx_k_acanz_acak_NOUN_VERB, sizeof(__pyx_k_acanz_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acanz_acak_NOUN_VERB_2, __pyx_k_acanz_acak_NOUN_VERB_2, sizeof(__pyx_k_acanz_acak_NOUN_VERB_2), 0, 1, 0, 0},
  {&__pyx_kp_u_acanza_acak_NOUN_VERB, __pyx_k_acanza_acak_NOUN_VERB, sizeof(__pyx_k_acanza_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acanzdr_acak_NOUN_VERB, __pyx_k_acanzdr_acak_NOUN_VERB, sizeof(__pyx_k_acanzdr_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acanzn_acak_NOUN_VERB, __pyx_k_acanzn_acak_NOUN_VERB, sizeof(__pyx_k_acanzn_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_acaz_acak_NOUN_VERB, __pyx_k_acaz_acak_NOUN_VERB, sizeof(__pyx_k_acaz_acak_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_n_s_addFsmParse, __pyx_k_addFsmParse, sizeof(__pyx_k_addFsmParse), 0, 0, 1, 1},
  {&__pyx_kp_u_ardm_ar_NOUN_VERB, __pyx_k_ardm_ar_NOUN_VERB, sizeof(__pyx_k_ardm_ar_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_arken_ar_NOUN_VERB, __pyx_k_arken_ar_NOUN_VERB, sizeof(__pyx_k_arken_ar_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_arsa_ar_NOUN_VERB, __pyx_k_arsa_ar_NOUN_VERB, sizeof(__pyx_k_arsa_ar_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_arsak_ar_NOUN_VERB, __pyx_k_arsak_ar_NOUN_VERB, sizeof(__pyx_k_arsak_ar_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_arsanz_ar_NOUN_VERB, __pyx_k_arsanz_ar_NOUN_VERB, sizeof(__pyx_k_arsanz_ar_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_arsnz_ar_NOUN_VERB, __pyx_k_arsnz_ar_NOUN_VERB, sizeof(__pyx_k_arsnz_ar_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_arz_ar_NOUN_VERB, __pyx_k_arz_ar_NOUN_VERB, sizeof(__pyx_k_arz_ar_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_n_s_cline_in_traceback, __pyx_k_cline_in_traceback, sizeof(__pyx_k_cline_in_traceback), 0, 0, 1, 1},
  {&__pyx_n_s_constructParseListForDifferentRo, __pyx_k_constructParseListForDifferentRo, sizeof(__pyx_k_constructParseListForDifferentRo), 0, 0, 1, 1},
  {&__pyx_n_s_dict, __pyx_k_dict, sizeof(__pyx_k_dict), 0, 0, 1, 1},
  {&__pyx_kp_u_ecei_ecek_NOUN_VERB, __pyx_k_ecei_ecek_NOUN_VERB, sizeof(__pyx_k_ecei_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceim_ecek_NOUN_VERB, __pyx_k_eceim_ecek_NOUN_VERB, sizeof(__pyx_k_eceim_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceimi_ecek_NOUN_VERB, __pyx_k_eceimi_ecek_NOUN_VERB, sizeof(__pyx_k_eceimi_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceimiz_ecek_NOUN_VERB, __pyx_k_eceimiz_ecek_NOUN_VERB, sizeof(__pyx_k_eceimiz_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ecein_ecek_NOUN_VERB, __pyx_k_ecein_ecek_NOUN_VERB, sizeof(__pyx_k_ecein_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceine_ecek_NOUN_VERB, __pyx_k_eceine_ecek_NOUN_VERB, sizeof(__pyx_k_eceine_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceini_ecek_NOUN_VERB, __pyx_k_eceini_ecek_NOUN_VERB, sizeof(__pyx_k_eceini_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceinin_ecek_NOUN_VERB, __pyx_k_eceinin_ecek_NOUN_VERB, sizeof(__pyx_k_eceinin_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceiniz_ecek_NOUN_VERB, __pyx_k_eceiniz_ecek_NOUN_VERB, sizeof(__pyx_k_eceiniz_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceinizdir_ecek_NOUN_VERB, __pyx_k_eceinizdir_ecek_NOUN_VERB, sizeof(__pyx_k_eceinizdir_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceinize_ecek_NOUN_VERB, __pyx_k_eceinize_ecek_NOUN_VERB, sizeof(__pyx_k_eceinize_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceinizi_ecek_NOUN_VERB, __pyx_k_eceinizi_ecek_NOUN_VERB, sizeof(__pyx_k_eceinizi_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceinizin_ecek_NOUN_VERB, __pyx_k_eceinizin_ecek_NOUN_VERB, sizeof(__pyx_k_eceinizin_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceiz_ecek_NOUN_VERB, __pyx_k_eceiz_ecek_NOUN_VERB, sizeof(__pyx_k_eceiz_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ecekleri_ecek_NOUN_VERB, __pyx_k_ecekleri_ecek_NOUN_VERB, sizeof(__pyx_k_ecekleri_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eceklerini_ecek_NOUN_VERB, __pyx_k_eceklerini_ecek_NOUN_VERB, sizeof(__pyx_k_eceklerini_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ecekse_ecek_NOUN_VERB, __pyx_k_ecekse_ecek_NOUN_VERB, sizeof(__pyx_k_ecekse_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ecektir_ecek_NOUN_VERB, __pyx_k_ecektir_ecek_NOUN_VERB, sizeof(__pyx_k_ecektir_ecek_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_erdim_er_NOUN_VERB, __pyx_k_erdim_er_NOUN_VERB, sizeof(__pyx_k_erdim_er_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_eriz_er_NOUN_VERB, __pyx_k_eriz_er_NOUN_VERB, sizeof(__pyx_k_eriz_er_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_erken_er_NOUN_VERB, __pyx_k_erken_er_NOUN_VERB, sizeof(__pyx_k_erken_er_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_erse_er_NOUN_VERB, __pyx_k_erse_er_NOUN_VERB, sizeof(__pyx_k_erse_er_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ersek_er_NOUN_VERB, __pyx_k_ersek_er_NOUN_VERB, sizeof(__pyx_k_ersek_er_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_erseniz_er_NOUN_VERB, __pyx_k_erseniz_er_NOUN_VERB, sizeof(__pyx_k_erseniz_er_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ersiniz_er_NOUN_VERB, __pyx_k_ersiniz_er_NOUN_VERB, sizeof(__pyx_k_ersiniz_er_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_n_s_fsmParses, __pyx_k_fsmParses, sizeof(__pyx_k_fsmParses), 0, 0, 1, 1},
  {&__pyx_n_s_getFsmParse, __pyx_k_getFsmParse, sizeof(__pyx_k_getFsmParse), 0, 0, 1, 1},
  {&__pyx_n_s_getName, __pyx_k_getName, sizeof(__pyx_k_getName), 0, 0, 1, 1},
  {&__pyx_n_s_getParseWithLongestRootWord, __pyx_k_getParseWithLongestRootWord, sizeof(__pyx_k_getParseWithLongestRootWord), 0, 0, 1, 1},
  {&__pyx_n_s_getWord, __pyx_k_getWord, sizeof(__pyx_k_getWord), 0, 0, 1, 1},
  {&__pyx_n_s_getWordWithPos, __pyx_k_getWordWithPos, sizeof(__pyx_k_getWordWithPos), 0, 0, 1, 1},
  {&__pyx_n_s_getstate, __pyx_k_getstate, sizeof(__pyx_k_getstate), 0, 0, 1, 1},
  {&__pyx_kp_u_ilen_i_VERB_VERB, __pyx_k_ilen_i_VERB_VERB, sizeof(__pyx_k_ilen_i_VERB_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ilen_ile_VERB_VERB, __pyx_k_ilen_ile_VERB_VERB, sizeof(__pyx_k_ilen_ile_VERB_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ilene_i_VERB_VERB, __pyx_k_ilene_i_VERB_VERB, sizeof(__pyx_k_ilene_i_VERB_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ilin_i_VERB_VERB, __pyx_k_ilin_i_VERB_VERB, sizeof(__pyx_k_ilin_i_VERB_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ilince_i_VERB_VERB, __pyx_k_ilince_i_VERB_VERB, sizeof(__pyx_k_ilince_i_VERB_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_imiz_i_ADJ_NOUN, __pyx_k_imiz_i_ADJ_NOUN, sizeof(__pyx_k_imiz_i_ADJ_NOUN), 0, 1, 0, 0},
  {&__pyx_n_s_import, __pyx_k_import, sizeof(__pyx_k_import), 0, 0, 1, 1},
  {&__pyx_kp_u_in_i_ADJ_NOUN, __pyx_k_in_i_ADJ_NOUN, sizeof(__pyx_k_in_i_ADJ_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_ince_i_NOUN_VERB, __pyx_k_ince_i_NOUN_VERB, sizeof(__pyx_k_ince_i_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_inde_i_ADJ_NOUN, __pyx_k_inde_i_ADJ_NOUN, sizeof(__pyx_k_inde_i_ADJ_NOUN), 0, 1, 0, 0},
  {&__pyx_n_s_index, __pyx_k_index, sizeof(__pyx_k_index), 0, 0, 1, 1},
  {&__pyx_kp_u_ine_i_ADJ_NOUN, __pyx_k_ine_i_ADJ_NOUN, sizeof(__pyx_k_ine_i_ADJ_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_ini_i_ADJ_NOUN, __pyx_k_ini_i_ADJ_NOUN, sizeof(__pyx_k_ini_i_ADJ_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_inin_i_ADJ_NOUN, __pyx_k_inin_i_ADJ_NOUN, sizeof(__pyx_k_inin_i_ADJ_NOUN), 0, 1, 0, 0},
  {&__pyx_n_s_isLongestRootException, __pyx_k_isLongestRootException, sizeof(__pyx_k_isLongestRootException), 0, 0, 1, 1},
  {&__pyx_kp_u_la_la_VERB_NOUN, __pyx_k_la_la_VERB_NOUN, sizeof(__pyx_k_la_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lan_NOUN_VERB, __pyx_k_lan_NOUN_VERB, sizeof(__pyx_k_lan_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_lana_NOUN_VERB, __pyx_k_lana_NOUN_VERB, sizeof(__pyx_k_lana_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_lar_la_VERB_NOUN, __pyx_k_lar_la_VERB_NOUN, sizeof(__pyx_k_lar_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lar_la_VERB_NOUN_2, __pyx_k_lar_la_VERB_NOUN_2, sizeof(__pyx_k_lar_la_VERB_NOUN_2), 0, 1, 0, 0},
  {&__pyx_kp_u_lardan_la_VERB_NOUN, __pyx_k_lardan_la_VERB_NOUN, sizeof(__pyx_k_lardan_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lardandr_la_VERB_NOUN, __pyx_k_lardandr_la_VERB_NOUN, sizeof(__pyx_k_lardandr_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lardr_la_VERB_NOUN, __pyx_k_lardr_la_VERB_NOUN, sizeof(__pyx_k_lardr_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lardr_la_VERB_NOUN_2, __pyx_k_lardr_la_VERB_NOUN_2, sizeof(__pyx_k_lardr_la_VERB_NOUN_2), 0, 1, 0, 0},
  {&__pyx_kp_u_larm_la_VERB_NOUN, __pyx_k_larm_la_VERB_NOUN, sizeof(__pyx_k_larm_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larmdan_la_VERB_NOUN, __pyx_k_larmdan_la_VERB_NOUN, sizeof(__pyx_k_larmdan_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larmz_la_VERB_NOUN, __pyx_k_larmz_la_VERB_NOUN, sizeof(__pyx_k_larmz_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larmz_la_VERB_NOUN_2, __pyx_k_larmz_la_VERB_NOUN_2, sizeof(__pyx_k_larmz_la_VERB_NOUN_2), 0, 1, 0, 0},
  {&__pyx_kp_u_larmza_la_VERB_NOUN, __pyx_k_larmza_la_VERB_NOUN, sizeof(__pyx_k_larmza_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larmzda_la_VERB_NOUN, __pyx_k_larmzda_la_VERB_NOUN, sizeof(__pyx_k_larmzda_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larmzdan_la_VERB_NOUN, __pyx_k_larmzdan_la_VERB_NOUN, sizeof(__pyx_k_larmzdan_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larmzdayd_la_VERB_NOUN, __pyx_k_larmzdayd_la_VERB_NOUN, sizeof(__pyx_k_larmzdayd_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larmzla_la_VERB_NOUN, __pyx_k_larmzla_la_VERB_NOUN, sizeof(__pyx_k_larmzla_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larmzn_la_VERB_NOUN, __pyx_k_larmzn_la_VERB_NOUN, sizeof(__pyx_k_larmzn_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larn_la_VERB_NOUN, __pyx_k_larn_la_VERB_NOUN, sizeof(__pyx_k_larn_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larn_la_VERB_NOUN_2, __pyx_k_larn_la_VERB_NOUN_2, sizeof(__pyx_k_larn_la_VERB_NOUN_2), 0, 1, 0, 0},
  {&__pyx_kp_u_larna_la_VERB_NOUN, __pyx_k_larna_la_VERB_NOUN, sizeof(__pyx_k_larna_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larnda_la_VERB_NOUN, __pyx_k_larnda_la_VERB_NOUN, sizeof(__pyx_k_larnda_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larndaki_la_VERB_NOUN, __pyx_k_larndaki_la_VERB_NOUN, sizeof(__pyx_k_larndaki_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larndakiler_la_VERB_NOUN, __pyx_k_larndakiler_la_VERB_NOUN, sizeof(__pyx_k_larndakiler_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larndakilere_la_VERB_NOUN, __pyx_k_larndakilere_la_VERB_NOUN, sizeof(__pyx_k_larndakilere_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larndakileri_la_VERB_NOUN, __pyx_k_larndakileri_la_VERB_NOUN, sizeof(__pyx_k_larndakileri_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larndakilerin_la_VERB_NOUN, __pyx_k_larndakilerin_la_VERB_NOUN, sizeof(__pyx_k_larndakilerin_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larndan_la_VERB_NOUN, __pyx_k_larndan_la_VERB_NOUN, sizeof(__pyx_k_larndan_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larndandr_la_VERB_NOUN, __pyx_k_larndandr_la_VERB_NOUN, sizeof(__pyx_k_larndandr_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larndaysa_la_VERB_NOUN, __pyx_k_larndaysa_la_VERB_NOUN, sizeof(__pyx_k_larndaysa_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larnn_la_VERB_NOUN, __pyx_k_larnn_la_VERB_NOUN, sizeof(__pyx_k_larnn_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larnz_la_VERB_NOUN, __pyx_k_larnz_la_VERB_NOUN, sizeof(__pyx_k_larnz_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larnz_la_VERB_NOUN_2, __pyx_k_larnz_la_VERB_NOUN_2, sizeof(__pyx_k_larnz_la_VERB_NOUN_2), 0, 1, 0, 0},
  {&__pyx_kp_u_larnza_la_VERB_NOUN, __pyx_k_larnza_la_VERB_NOUN, sizeof(__pyx_k_larnza_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larnzda_la_VERB_NOUN, __pyx_k_larnzda_la_VERB_NOUN, sizeof(__pyx_k_larnzda_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larnzdaki_la_VERB_NOUN, __pyx_k_larnzdaki_la_VERB_NOUN, sizeof(__pyx_k_larnzdaki_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larnzdan_la_VERB_NOUN, __pyx_k_larnzdan_la_VERB_NOUN, sizeof(__pyx_k_larnzdan_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larnzla_la_VERB_NOUN, __pyx_k_larnzla_la_VERB_NOUN, sizeof(__pyx_k_larnzla_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_larnzn_la_VERB_NOUN, __pyx_k_larnzn_la_VERB_NOUN, sizeof(__pyx_k_larnzn_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_laryla_la_VERB_NOUN, __pyx_k_laryla_la_VERB_NOUN, sizeof(__pyx_k_laryla_la_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_le_le_VERB_NOUN, __pyx_k_le_le_VERB_NOUN, sizeof(__pyx_k_le_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_ler_le_VERB_NOUN, __pyx_k_ler_le_VERB_NOUN, sizeof(__pyx_k_ler_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerden_le_VERB_NOUN, __pyx_k_lerden_le_VERB_NOUN, sizeof(__pyx_k_lerden_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerdendir_le_VERB_NOUN, __pyx_k_lerdendir_le_VERB_NOUN, sizeof(__pyx_k_lerdendir_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerdir_le_VERB_NOUN, __pyx_k_lerdir_le_VERB_NOUN, sizeof(__pyx_k_lerdir_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_leri_le_VERB_NOUN, __pyx_k_leri_le_VERB_NOUN, sizeof(__pyx_k_leri_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_leridir_le_VERB_NOUN, __pyx_k_leridir_le_VERB_NOUN, sizeof(__pyx_k_leridir_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerim_le_VERB_NOUN, __pyx_k_lerim_le_VERB_NOUN, sizeof(__pyx_k_lerim_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerimden_le_VERB_NOUN, __pyx_k_lerimden_le_VERB_NOUN, sizeof(__pyx_k_lerimden_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerimiz_le_VERB_NOUN, __pyx_k_lerimiz_le_VERB_NOUN, sizeof(__pyx_k_lerimiz_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerimizde_le_VERB_NOUN, __pyx_k_lerimizde_le_VERB_NOUN, sizeof(__pyx_k_lerimizde_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerimizden_le_VERB_NOUN, __pyx_k_lerimizden_le_VERB_NOUN, sizeof(__pyx_k_lerimizden_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerimizdeydi_le_VERB_NOUN, __pyx_k_lerimizdeydi_le_VERB_NOUN, sizeof(__pyx_k_lerimizdeydi_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerimize_le_VERB_NOUN, __pyx_k_lerimize_le_VERB_NOUN, sizeof(__pyx_k_lerimize_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerimizi_le_VERB_NOUN, __pyx_k_lerimizi_le_VERB_NOUN, sizeof(__pyx_k_lerimizi_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerimizin_le_VERB_NOUN, __pyx_k_lerimizin_le_VERB_NOUN, sizeof(__pyx_k_lerimizin_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerimizle_le_VERB_NOUN, __pyx_k_lerimizle_le_VERB_NOUN, sizeof(__pyx_k_lerimizle_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerin_le_VERB_NOUN, __pyx_k_lerin_le_VERB_NOUN, sizeof(__pyx_k_lerin_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerinde_le_VERB_NOUN, __pyx_k_lerinde_le_VERB_NOUN, sizeof(__pyx_k_lerinde_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerindeki_le_VERB_NOUN, __pyx_k_lerindeki_le_VERB_NOUN, sizeof(__pyx_k_lerindeki_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerindekiler_le_VERB_NOUN, __pyx_k_lerindekiler_le_VERB_NOUN, sizeof(__pyx_k_lerindekiler_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerindekilere_le_VERB_NOUN, __pyx_k_lerindekilere_le_VERB_NOUN, sizeof(__pyx_k_lerindekilere_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerindekileri_le_VERB_NOUN, __pyx_k_lerindekileri_le_VERB_NOUN, sizeof(__pyx_k_lerindekileri_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerindekilerin_le_VERB_NOUN, __pyx_k_lerindekilerin_le_VERB_NOUN, sizeof(__pyx_k_lerindekilerin_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerinden_le_VERB_NOUN, __pyx_k_lerinden_le_VERB_NOUN, sizeof(__pyx_k_lerinden_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerindendir_le_VERB_NOUN, __pyx_k_lerindendir_le_VERB_NOUN, sizeof(__pyx_k_lerindendir_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerindeyse_le_VERB_NOUN, __pyx_k_lerindeyse_le_VERB_NOUN, sizeof(__pyx_k_lerindeyse_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerine_le_VERB_NOUN, __pyx_k_lerine_le_VERB_NOUN, sizeof(__pyx_k_lerine_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerini_le_VERB_NOUN, __pyx_k_lerini_le_VERB_NOUN, sizeof(__pyx_k_lerini_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerinin_le_VERB_NOUN, __pyx_k_lerinin_le_VERB_NOUN, sizeof(__pyx_k_lerinin_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_leriniz_le_VERB_NOUN, __pyx_k_leriniz_le_VERB_NOUN, sizeof(__pyx_k_leriniz_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerinizde_le_VERB_NOUN, __pyx_k_lerinizde_le_VERB_NOUN, sizeof(__pyx_k_lerinizde_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerinizdeki_le_VERB_NOUN, __pyx_k_lerinizdeki_le_VERB_NOUN, sizeof(__pyx_k_lerinizdeki_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerinizden_le_VERB_NOUN, __pyx_k_lerinizden_le_VERB_NOUN, sizeof(__pyx_k_lerinizden_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerinize_le_VERB_NOUN, __pyx_k_lerinize_le_VERB_NOUN, sizeof(__pyx_k_lerinize_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerinizi_le_VERB_NOUN, __pyx_k_lerinizi_le_VERB_NOUN, sizeof(__pyx_k_lerinizi_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerinizin_le_VERB_NOUN, __pyx_k_lerinizin_le_VERB_NOUN, sizeof(__pyx_k_lerinizin_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_lerinizle_le_VERB_NOUN, __pyx_k_lerinizle_le_VERB_NOUN, sizeof(__pyx_k_lerinizle_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_leriyle_le_VERB_NOUN, __pyx_k_leriyle_le_VERB_NOUN, sizeof(__pyx_k_leriyle_le_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_ln_NOUN_VERB, __pyx_k_ln_NOUN_VERB, sizeof(__pyx_k_ln_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_lnca_NOUN_VERB, __pyx_k_lnca_NOUN_VERB, sizeof(__pyx_k_lnca_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_n_s_longest_root_exceptions, __pyx_k_longest_root_exceptions, sizeof(__pyx_k_longest_root_exceptions), 0, 0, 1, 1},
  {&__pyx_kp_u_madan_ma_NOUN_VERB, __pyx_k_madan_ma_NOUN_VERB, sizeof(__pyx_k_madan_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_n_s_main, __pyx_k_main, sizeof(__pyx_k_main), 0, 0, 1, 1},
  {&__pyx_kp_u_mal_ma_NOUN_VERB, __pyx_k_mal_ma_NOUN_VERB, sizeof(__pyx_k_mal_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_maldr_ma_NOUN_VERB, __pyx_k_maldr_ma_NOUN_VERB, sizeof(__pyx_k_maldr_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_maldrlar_ma_NOUN_VERB, __pyx_k_maldrlar_ma_NOUN_VERB, sizeof(__pyx_k_maldrlar_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mallar_ma_NOUN_VERB, __pyx_k_mallar_ma_NOUN_VERB, sizeof(__pyx_k_mallar_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_malsnz_ma_NOUN_VERB, __pyx_k_malsnz_ma_NOUN_VERB, sizeof(__pyx_k_malsnz_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_malym_ma_NOUN_VERB, __pyx_k_malym_ma_NOUN_VERB, sizeof(__pyx_k_malym_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_malyz_ma_NOUN_VERB, __pyx_k_malyz_ma_NOUN_VERB, sizeof(__pyx_k_malyz_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mam_ma_NOUN_VERB, __pyx_k_mam_ma_NOUN_VERB, sizeof(__pyx_k_mam_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mama_ma_NOUN_VERB, __pyx_k_mama_ma_NOUN_VERB, sizeof(__pyx_k_mama_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mamz_ma_NOUN_VERB, __pyx_k_mamz_ma_NOUN_VERB, sizeof(__pyx_k_mamz_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mamz_ma_NOUN_VERB_2, __pyx_k_mamz_ma_NOUN_VERB_2, sizeof(__pyx_k_mamz_ma_NOUN_VERB_2), 0, 1, 0, 0},
  {&__pyx_kp_u_mamza_ma_NOUN_VERB, __pyx_k_mamza_ma_NOUN_VERB, sizeof(__pyx_k_mamza_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_manz_ma_NOUN_VERB, __pyx_k_manz_ma_NOUN_VERB, sizeof(__pyx_k_manz_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_manz_ma_NOUN_VERB_2, __pyx_k_manz_ma_NOUN_VERB_2, sizeof(__pyx_k_manz_ma_NOUN_VERB_2), 0, 1, 0, 0},
  {&__pyx_kp_u_manzda_ma_NOUN_VERB, __pyx_k_manzda_ma_NOUN_VERB, sizeof(__pyx_k_manzda_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_manzdr_ma_NOUN_VERB, __pyx_k_manzdr_ma_NOUN_VERB, sizeof(__pyx_k_manzdr_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_manzla_ma_NOUN_VERB, __pyx_k_manzla_ma_NOUN_VERB, sizeof(__pyx_k_manzla_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mas_ma_NOUN_VERB, __pyx_k_mas_ma_NOUN_VERB, sizeof(__pyx_k_mas_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_masdr_ma_NOUN_VERB, __pyx_k_masdr_ma_NOUN_VERB, sizeof(__pyx_k_masdr_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_masn_ma_NOUN_VERB, __pyx_k_masn_ma_NOUN_VERB, sizeof(__pyx_k_masn_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_masn_ma_NOUN_VERB_2, __pyx_k_masn_ma_NOUN_VERB_2, sizeof(__pyx_k_masn_ma_NOUN_VERB_2), 0, 1, 0, 0},
  {&__pyx_kp_u_masna_ma_NOUN_VERB, __pyx_k_masna_ma_NOUN_VERB, sizeof(__pyx_k_masna_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_masnda_ma_NOUN_VERB, __pyx_k_masnda_ma_NOUN_VERB, sizeof(__pyx_k_masnda_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_masndaki_ma_NOUN_VERB, __pyx_k_masndaki_ma_NOUN_VERB, sizeof(__pyx_k_masndaki_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_masyla_ma_NOUN_VERB, __pyx_k_masyla_ma_NOUN_VERB, sizeof(__pyx_k_masyla_ma_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mdan_m_NOUN_NOUN, __pyx_k_mdan_m_NOUN_NOUN, sizeof(__pyx_k_mdan_m_NOUN_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_meden_me_NOUN_VERB, __pyx_k_meden_me_NOUN_VERB, sizeof(__pyx_k_meden_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_meli_me_NOUN_VERB, __pyx_k_meli_me_NOUN_VERB, sizeof(__pyx_k_meli_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_melidir_me_NOUN_VERB, __pyx_k_melidir_me_NOUN_VERB, sizeof(__pyx_k_melidir_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_melidirler_me_NOUN_VERB, __pyx_k_melidirler_me_NOUN_VERB, sizeof(__pyx_k_melidirler_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_meliler_me_NOUN_VERB, __pyx_k_meliler_me_NOUN_VERB, sizeof(__pyx_k_meliler_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_melisiniz_me_NOUN_VERB, __pyx_k_melisiniz_me_NOUN_VERB, sizeof(__pyx_k_melisiniz_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_meliyim_me_NOUN_VERB, __pyx_k_meliyim_me_NOUN_VERB, sizeof(__pyx_k_meliyim_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_meliyiz_me_NOUN_VERB, __pyx_k_meliyiz_me_NOUN_VERB, sizeof(__pyx_k_meliyiz_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mem_me_NOUN_VERB, __pyx_k_mem_me_NOUN_VERB, sizeof(__pyx_k_mem_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_meme_me_NOUN_VERB, __pyx_k_meme_me_NOUN_VERB, sizeof(__pyx_k_meme_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_memiz_me_NOUN_VERB, __pyx_k_memiz_me_NOUN_VERB, sizeof(__pyx_k_memiz_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_memize_me_NOUN_VERB, __pyx_k_memize_me_NOUN_VERB, sizeof(__pyx_k_memize_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_memizi_me_NOUN_VERB, __pyx_k_memizi_me_NOUN_VERB, sizeof(__pyx_k_memizi_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_meniz_me_NOUN_VERB, __pyx_k_meniz_me_NOUN_VERB, sizeof(__pyx_k_meniz_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_menizde_me_NOUN_VERB, __pyx_k_menizde_me_NOUN_VERB, sizeof(__pyx_k_menizde_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_menizdir_me_NOUN_VERB, __pyx_k_menizdir_me_NOUN_VERB, sizeof(__pyx_k_menizdir_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_menizi_me_NOUN_VERB, __pyx_k_menizi_me_NOUN_VERB, sizeof(__pyx_k_menizi_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_menizle_me_NOUN_VERB, __pyx_k_menizle_me_NOUN_VERB, sizeof(__pyx_k_menizle_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mesi_me_NOUN_VERB, __pyx_k_mesi_me_NOUN_VERB, sizeof(__pyx_k_mesi_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mesidir_me_NOUN_VERB, __pyx_k_mesidir_me_NOUN_VERB, sizeof(__pyx_k_mesidir_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mesin_me_NOUN_VERB, __pyx_k_mesin_me_NOUN_VERB, sizeof(__pyx_k_mesin_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mesinde_me_NOUN_VERB, __pyx_k_mesinde_me_NOUN_VERB, sizeof(__pyx_k_mesinde_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mesindeki_me_NOUN_VERB, __pyx_k_mesindeki_me_NOUN_VERB, sizeof(__pyx_k_mesindeki_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mesine_me_NOUN_VERB, __pyx_k_mesine_me_NOUN_VERB, sizeof(__pyx_k_mesine_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mesini_me_NOUN_VERB, __pyx_k_mesini_me_NOUN_VERB, sizeof(__pyx_k_mesini_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mesiyle_me_NOUN_VERB, __pyx_k_mesiyle_me_NOUN_VERB, sizeof(__pyx_k_mesiyle_me_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mise_mi_NOUN_VERB, __pyx_k_mise_mi_NOUN_VERB, sizeof(__pyx_k_mise_mi_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mn_m_NOUN_NOUN, __pyx_k_mn_m_NOUN_NOUN, sizeof(__pyx_k_mn_m_NOUN_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_msa_m_NOUN_VERB, __pyx_k_msa_m_NOUN_VERB, sizeof(__pyx_k_msa_m_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_mz_m_NOUN_NOUN, __pyx_k_mz_m_NOUN_NOUN, sizeof(__pyx_k_mz_m_NOUN_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_na_n_NOUN_NOUN, __pyx_k_na_n_NOUN_NOUN, sizeof(__pyx_k_na_n_NOUN_NOUN), 0, 1, 0, 0},
  {&__pyx_n_s_name, __pyx_k_name, sizeof(__pyx_k_name), 0, 0, 1, 1},
  {&__pyx_kp_u_nca_NOUN_VERB, __pyx_k_nca_NOUN_VERB, sizeof(__pyx_k_nca_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_ne_n_NOUN_NOUN, __pyx_k_ne_n_NOUN_NOUN, sizeof(__pyx_k_ne_n_NOUN_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_ne_n_VERB_NOUN, __pyx_k_ne_n_VERB_NOUN, sizeof(__pyx_k_ne_n_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_n_s_new, __pyx_k_new, sizeof(__pyx_k_new), 0, 0, 1, 1},
  {&__pyx_kp_u_nin_n_NOUN_NOUN, __pyx_k_nin_n_NOUN_NOUN, sizeof(__pyx_k_nin_n_NOUN_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_niz_n_NOUN_NOUN, __pyx_k_niz_n_NOUN_NOUN, sizeof(__pyx_k_niz_n_NOUN_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_nn_n_NOUN_NOUN, __pyx_k_nn_n_NOUN_NOUN, sizeof(__pyx_k_nn_n_NOUN_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_nz_n_NOUN_NOUN, __pyx_k_nz_n_NOUN_NOUN, sizeof(__pyx_k_nz_n_NOUN_NOUN), 0, 1, 0, 0},
  {&__pyx_n_s_parsesWithoutPrefixAndSuffix, __pyx_k_parsesWithoutPrefixAndSuffix, sizeof(__pyx_k_parsesWithoutPrefixAndSuffix), 0, 0, 1, 1},
  {&__pyx_n_s_pickle, __pyx_k_pickle, sizeof(__pyx_k_pickle), 0, 0, 1, 1},
  {&__pyx_n_s_pop, __pyx_k_pop, sizeof(__pyx_k_pop), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_PickleError, __pyx_k_pyx_PickleError, sizeof(__pyx_k_pyx_PickleError), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_checksum, __pyx_k_pyx_checksum, sizeof(__pyx_k_pyx_checksum), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_result, __pyx_k_pyx_result, sizeof(__pyx_k_pyx_result), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_state, __pyx_k_pyx_state, sizeof(__pyx_k_pyx_state), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_type, __pyx_k_pyx_type, sizeof(__pyx_k_pyx_type), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_unpickle_FsmParseList, __pyx_k_pyx_unpickle_FsmParseList, sizeof(__pyx_k_pyx_unpickle_FsmParseList), 0, 0, 1, 1},
  {&__pyx_n_s_pyx_vtable, __pyx_k_pyx_vtable, sizeof(__pyx_k_pyx_vtable), 0, 0, 1, 1},
  {&__pyx_n_s_range, __pyx_k_range, sizeof(__pyx_k_range), 0, 0, 1, 1},
  {&__pyx_kp_u_rdim_r_NOUN_VERB, __pyx_k_rdim_r_NOUN_VERB, sizeof(__pyx_k_rdim_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_rdm_r_NOUN_VERB, __pyx_k_rdm_r_NOUN_VERB, sizeof(__pyx_k_rdm_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_n_s_reduce, __pyx_k_reduce, sizeof(__pyx_k_reduce), 0, 0, 1, 1},
  {&__pyx_n_s_reduceToParsesWithSameRoot, __pyx_k_reduceToParsesWithSameRoot, sizeof(__pyx_k_reduceToParsesWithSameRoot), 0, 0, 1, 1},
  {&__pyx_n_s_reduceToParsesWithSameRootAndPos, __pyx_k_reduceToParsesWithSameRootAndPos, sizeof(__pyx_k_reduceToParsesWithSameRootAndPos), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_cython, __pyx_k_reduce_cython, sizeof(__pyx_k_reduce_cython), 0, 0, 1, 1},
  {&__pyx_n_s_reduce_ex, __pyx_k_reduce_ex, sizeof(__pyx_k_reduce_ex), 0, 0, 1, 1},
  {&__pyx_n_s_rindex, __pyx_k_rindex, sizeof(__pyx_k_rindex), 0, 0, 1, 1},
  {&__pyx_kp_u_riz_r_NOUN_VERB, __pyx_k_riz_r_NOUN_VERB, sizeof(__pyx_k_riz_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_rken_r_NOUN_VERB, __pyx_k_rken_r_NOUN_VERB, sizeof(__pyx_k_rken_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_n_s_rootWords, __pyx_k_rootWords, sizeof(__pyx_k_rootWords), 0, 0, 1, 1},
  {&__pyx_kp_u_rsa_r_NOUN_VERB, __pyx_k_rsa_r_NOUN_VERB, sizeof(__pyx_k_rsa_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_rsak_r_NOUN_VERB, __pyx_k_rsak_r_NOUN_VERB, sizeof(__pyx_k_rsak_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_rsanz_r_NOUN_VERB, __pyx_k_rsanz_r_NOUN_VERB, sizeof(__pyx_k_rsanz_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_rse_r_NOUN_VERB, __pyx_k_rse_r_NOUN_VERB, sizeof(__pyx_k_rse_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_rsek_r_NOUN_VERB, __pyx_k_rsek_r_NOUN_VERB, sizeof(__pyx_k_rsek_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_rseniz_r_NOUN_VERB, __pyx_k_rseniz_r_NOUN_VERB, sizeof(__pyx_k_rseniz_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_rsiniz_r_NOUN_VERB, __pyx_k_rsiniz_r_NOUN_VERB, sizeof(__pyx_k_rsiniz_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_rsnz_r_NOUN_VERB, __pyx_k_rsnz_r_NOUN_VERB, sizeof(__pyx_k_rsnz_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_rz_r_NOUN_VERB, __pyx_k_rz_r_NOUN_VERB, sizeof(__pyx_k_rz_r_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_sa_sa_VERB_ADJ, __pyx_k_sa_sa_VERB_ADJ, sizeof(__pyx_k_sa_sa_VERB_ADJ), 0, 1, 0, 0},
  {&__pyx_kp_u_se_se_VERB_ADJ, __pyx_k_se_se_VERB_ADJ, sizeof(__pyx_k_se_se_VERB_ADJ), 0, 1, 0, 0},
  {&__pyx_n_s_setstate, __pyx_k_setstate, sizeof(__pyx_k_setstate), 0, 0, 1, 1},
  {&__pyx_n_s_setstate_cython, __pyx_k_setstate_cython, sizeof(__pyx_k_setstate_cython), 0, 0, 1, 1},
  {&__pyx_n_s_size, __pyx_k_size, sizeof(__pyx_k_size), 0, 0, 1, 1},
  {&__pyx_kp_s_stringsource, __pyx_k_stringsource, sizeof(__pyx_k_stringsource), 0, 0, 1, 0},
  {&__pyx_n_s_test, __pyx_k_test, sizeof(__pyx_k_test), 0, 0, 1, 1},
  {&__pyx_n_s_transitionList, __pyx_k_transitionList, sizeof(__pyx_k_transitionList), 0, 0, 1, 1},
  {&__pyx_kp_u_ulan_u_NOUN_VERB, __pyx_k_ulan_u_NOUN_VERB, sizeof(__pyx_k_ulan_u_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_un_un_VERB_NOUN, __pyx_k_un_un_VERB_NOUN, sizeof(__pyx_k_un_un_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_kp_u_unca_u_NOUN_VERB, __pyx_k_unca_u_NOUN_VERB, sizeof(__pyx_k_unca_u_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_unca_un_NOUN_VERB, __pyx_k_unca_un_NOUN_VERB, sizeof(__pyx_k_unca_un_NOUN_VERB), 0, 1, 0, 0},
  {&__pyx_kp_u_unun_un_VERB_NOUN, __pyx_k_unun_un_VERB_NOUN, sizeof(__pyx_k_unun_un_VERB_NOUN), 0, 1, 0, 0},
  {&__pyx_n_s_update, __pyx_k_update, sizeof(__pyx_k_update), 0, 0, 1, 1},
  {0, 0, 0, 0, 0, 0, 0}
};
static CYTHON_SMALL_CODE int __Pyx_InitCachedBuiltins(void) {
  __pyx_builtin_range = __Pyx_GetBuiltinName(__pyx_n_s_range); if (!__pyx_builtin_range) __PYX_ERR(0, 150, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitCachedConstants(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_InitCachedConstants", 0);

  /* "(tree fragment)":1
 * def __pyx_unpickle_FsmParseList(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_tuple__6 = PyTuple_Pack(5, __pyx_n_s_pyx_type, __pyx_n_s_pyx_checksum, __pyx_n_s_pyx_state, __pyx_n_s_pyx_PickleError, __pyx_n_s_pyx_result); if (unlikely(!__pyx_tuple__6)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_tuple__6);
  __Pyx_GIVEREF(__pyx_tuple__6);
  __pyx_codeobj__7 = (PyObject*)__Pyx_PyCode_New(3, 0, 5, 0, CO_OPTIMIZED|CO_NEWLOCALS, __pyx_empty_bytes, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_tuple__6, __pyx_empty_tuple, __pyx_empty_tuple, __pyx_kp_s_stringsource, __pyx_n_s_pyx_unpickle_FsmParseList, 1, __pyx_empty_bytes); if (unlikely(!__pyx_codeobj__7)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_InitGlobals(void) {
  if (__Pyx_InitStrings(__pyx_string_tab) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  __pyx_int_1 = PyInt_FromLong(1); if (unlikely(!__pyx_int_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_int_188202251 = PyInt_FromLong(188202251L); if (unlikely(!__pyx_int_188202251)) __PYX_ERR(0, 1, __pyx_L1_error)
  return 0;
  __pyx_L1_error:;
  return -1;
}

static CYTHON_SMALL_CODE int __Pyx_modinit_global_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_export_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_init_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_type_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_variable_import_code(void); /*proto*/
static CYTHON_SMALL_CODE int __Pyx_modinit_function_import_code(void); /*proto*/

static int __Pyx_modinit_global_init_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_global_init_code", 0);
  /*--- Global init code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_variable_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_export_code", 0);
  /*--- Variable export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_export_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_export_code", 0);
  /*--- Function export code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_type_init_code(void) {
  __Pyx_RefNannyDeclarations
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_init_code", 0);
  /*--- Type init code ---*/
  __pyx_vtabptr_21MorphologicalAnalysis_12FsmParseList_FsmParseList = &__pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList;
  __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList.size = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_size;
  __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList.addFsmParse = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_addFsmParse;
  __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList.getFsmParse = (struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *(*)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_getFsmParse;
  __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList.rootWords = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_rootWords;
  __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList.reduceToParsesWithSameRootAndPos = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, struct __pyx_obj_10Dictionary_4Word_Word *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_reduceToParsesWithSameRootAndPos;
  __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList.getParseWithLongestRootWord = (struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *(*)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_getParseWithLongestRootWord;
  __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList.reduceToParsesWithSameRoot = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, PyObject *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_reduceToParsesWithSameRoot;
  __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList.isLongestRootException = (int (*)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_isLongestRootException;
  __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList.constructParseListForDifferentRootWithPos = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_constructParseListForDifferentRootWithPos;
  __pyx_vtable_21MorphologicalAnalysis_12FsmParseList_FsmParseList.parsesWithoutPrefixAndSuffix = (PyObject *(*)(struct __pyx_obj_21MorphologicalAnalysis_12FsmParseList_FsmParseList *, int __pyx_skip_dispatch))__pyx_f_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_parsesWithoutPrefixAndSuffix;
  if (PyType_Ready(&__pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_VERSION_HEX < 0x030800B1
  __pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList.tp_print = 0;
  #endif
  if ((CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP) && likely(!__pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList.tp_dictoffset && __pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList.tp_getattro == PyObject_GenericGetAttr)) {
    __pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList.tp_getattro = __Pyx_PyObject_GenericGetAttr;
  }
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList, "__init__"); if (unlikely(!wrapper)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_21MorphologicalAnalysis_12FsmParseList_12FsmParseList___init__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_21MorphologicalAnalysis_12FsmParseList_12FsmParseList___init__.doc = __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList___init__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_21MorphologicalAnalysis_12FsmParseList_12FsmParseList___init__;
    }
  }
  #endif
  #if CYTHON_COMPILING_IN_CPYTHON
  {
    PyObject *wrapper = PyObject_GetAttrString((PyObject *)&__pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList, "__str__"); if (unlikely(!wrapper)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (Py_TYPE(wrapper) == &PyWrapperDescr_Type) {
      __pyx_wrapperbase_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_22__str__ = *((PyWrapperDescrObject *)wrapper)->d_base;
      __pyx_wrapperbase_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_22__str__.doc = __pyx_doc_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_22__str__;
      ((PyWrapperDescrObject *)wrapper)->d_base = &__pyx_wrapperbase_21MorphologicalAnalysis_12FsmParseList_12FsmParseList_22__str__;
    }
  }
  #endif
  if (__Pyx_SetVtable(__pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList.tp_dict, __pyx_vtabptr_21MorphologicalAnalysis_12FsmParseList_FsmParseList) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (PyObject_SetAttr(__pyx_m, __pyx_n_s_FsmParseList, (PyObject *)&__pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  if (__Pyx_setup_reduce((PyObject*)&__pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList = &__pyx_type_21MorphologicalAnalysis_12FsmParseList_FsmParseList;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_type_import_code(void) {
  __Pyx_RefNannyDeclarations
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannySetupContext("__Pyx_modinit_type_import_code", 0);
  /*--- Type import code ---*/
  __pyx_t_1 = PyImport_ImportModule("Dictionary.Word"); if (unlikely(!__pyx_t_1)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_10Dictionary_4Word_Word = __Pyx_ImportType(__pyx_t_1, "Dictionary.Word", "Word", sizeof(struct __pyx_obj_10Dictionary_4Word_Word), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_10Dictionary_4Word_Word) __PYX_ERR(2, 1, __pyx_L1_error)
  __pyx_vtabptr_10Dictionary_4Word_Word = (struct __pyx_vtabstruct_10Dictionary_4Word_Word*)__Pyx_GetVtable(__pyx_ptype_10Dictionary_4Word_Word->tp_dict); if (unlikely(!__pyx_vtabptr_10Dictionary_4Word_Word)) __PYX_ERR(2, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.InflectionalGroup"); if (unlikely(!__pyx_t_1)) __PYX_ERR(3, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.InflectionalGroup", "InflectionalGroup", sizeof(struct __pyx_obj_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup) __PYX_ERR(3, 1, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup = (struct __pyx_vtabstruct_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_17InflectionalGroup_InflectionalGroup)) __PYX_ERR(3, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.MorphologicalParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(4, 6, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.MorphologicalParse", "MorphologicalParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse) __PYX_ERR(4, 6, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_18MorphologicalParse_MorphologicalParse)) __PYX_ERR(4, 6, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.State"); if (unlikely(!__pyx_t_1)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_5State_State = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.State", "State", sizeof(struct __pyx_obj_21MorphologicalAnalysis_5State_State), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_5State_State) __PYX_ERR(5, 1, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_5State_State = (struct __pyx_vtabstruct_21MorphologicalAnalysis_5State_State*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_5State_State->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_5State_State)) __PYX_ERR(5, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __pyx_t_1 = PyImport_ImportModule("MorphologicalAnalysis.FsmParse"); if (unlikely(!__pyx_t_1)) __PYX_ERR(6, 5, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse = __Pyx_ImportType(__pyx_t_1, "MorphologicalAnalysis.FsmParse", "FsmParse", sizeof(struct __pyx_obj_21MorphologicalAnalysis_8FsmParse_FsmParse), __Pyx_ImportType_CheckSize_Warn);
   if (!__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse) __PYX_ERR(6, 5, __pyx_L1_error)
  __pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse = (struct __pyx_vtabstruct_21MorphologicalAnalysis_8FsmParse_FsmParse*)__Pyx_GetVtable(__pyx_ptype_21MorphologicalAnalysis_8FsmParse_FsmParse->tp_dict); if (unlikely(!__pyx_vtabptr_21MorphologicalAnalysis_8FsmParse_FsmParse)) __PYX_ERR(6, 5, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  __Pyx_RefNannyFinishContext();
  return 0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  __Pyx_RefNannyFinishContext();
  return -1;
}

static int __Pyx_modinit_variable_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_variable_import_code", 0);
  /*--- Variable import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}

static int __Pyx_modinit_function_import_code(void) {
  __Pyx_RefNannyDeclarations
  __Pyx_RefNannySetupContext("__Pyx_modinit_function_import_code", 0);
  /*--- Function import code ---*/
  __Pyx_RefNannyFinishContext();
  return 0;
}


#ifndef CYTHON_NO_PYINIT_EXPORT
#define __Pyx_PyMODINIT_FUNC PyMODINIT_FUNC
#elif PY_MAJOR_VERSION < 3
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" void
#else
#define __Pyx_PyMODINIT_FUNC void
#endif
#else
#ifdef __cplusplus
#define __Pyx_PyMODINIT_FUNC extern "C" PyObject *
#else
#define __Pyx_PyMODINIT_FUNC PyObject *
#endif
#endif


#if PY_MAJOR_VERSION < 3
__Pyx_PyMODINIT_FUNC initFsmParseList(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC initFsmParseList(void)
#else
__Pyx_PyMODINIT_FUNC PyInit_FsmParseList(void) CYTHON_SMALL_CODE; /*proto*/
__Pyx_PyMODINIT_FUNC PyInit_FsmParseList(void)
#if CYTHON_PEP489_MULTI_PHASE_INIT
{
  return PyModuleDef_Init(&__pyx_moduledef);
}
static CYTHON_SMALL_CODE int __Pyx_check_single_interpreter(void) {
    #if PY_VERSION_HEX >= 0x030700A1
    static PY_INT64_T main_interpreter_id = -1;
    PY_INT64_T current_id = PyInterpreterState_GetID(PyThreadState_Get()->interp);
    if (main_interpreter_id == -1) {
        main_interpreter_id = current_id;
        return (unlikely(current_id == -1)) ? -1 : 0;
    } else if (unlikely(main_interpreter_id != current_id))
    #else
    static PyInterpreterState *main_interpreter = NULL;
    PyInterpreterState *current_interpreter = PyThreadState_Get()->interp;
    if (!main_interpreter) {
        main_interpreter = current_interpreter;
    } else if (unlikely(main_interpreter != current_interpreter))
    #endif
    {
        PyErr_SetString(
            PyExc_ImportError,
            "Interpreter change detected - this module can only be loaded into one interpreter per process.");
        return -1;
    }
    return 0;
}
static CYTHON_SMALL_CODE int __Pyx_copy_spec_to_module(PyObject *spec, PyObject *moddict, const char* from_name, const char* to_name, int allow_none) {
    PyObject *value = PyObject_GetAttrString(spec, from_name);
    int result = 0;
    if (likely(value)) {
        if (allow_none || value != Py_None) {
            result = PyDict_SetItemString(moddict, to_name, value);
        }
        Py_DECREF(value);
    } else if (PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Clear();
    } else {
        result = -1;
    }
    return result;
}
static CYTHON_SMALL_CODE PyObject* __pyx_pymod_create(PyObject *spec, CYTHON_UNUSED PyModuleDef *def) {
    PyObject *module = NULL, *moddict, *modname;
    if (__Pyx_check_single_interpreter())
        return NULL;
    if (__pyx_m)
        return __Pyx_NewRef(__pyx_m);
    modname = PyObject_GetAttrString(spec, "name");
    if (unlikely(!modname)) goto bad;
    module = PyModule_NewObject(modname);
    Py_DECREF(modname);
    if (unlikely(!module)) goto bad;
    moddict = PyModule_GetDict(module);
    if (unlikely(!moddict)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "loader", "__loader__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "origin", "__file__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "parent", "__package__", 1) < 0)) goto bad;
    if (unlikely(__Pyx_copy_spec_to_module(spec, moddict, "submodule_search_locations", "__path__", 0) < 0)) goto bad;
    return module;
bad:
    Py_XDECREF(module);
    return NULL;
}


static CYTHON_SMALL_CODE int __pyx_pymod_exec_FsmParseList(PyObject *__pyx_pyinit_module)
#endif
#endif
{
  PyObject *__pyx_t_1 = NULL;
  int __pyx_lineno = 0;
  const char *__pyx_filename = NULL;
  int __pyx_clineno = 0;
  __Pyx_RefNannyDeclarations
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  if (__pyx_m) {
    if (__pyx_m == __pyx_pyinit_module) return 0;
    PyErr_SetString(PyExc_RuntimeError, "Module 'FsmParseList' has already been imported. Re-initialisation is not supported.");
    return -1;
  }
  #elif PY_MAJOR_VERSION >= 3
  if (__pyx_m) return __Pyx_NewRef(__pyx_m);
  #endif
  #if CYTHON_REFNANNY
__Pyx_RefNanny = __Pyx_RefNannyImportAPI("refnanny");
if (!__Pyx_RefNanny) {
  PyErr_Clear();
  __Pyx_RefNanny = __Pyx_RefNannyImportAPI("Cython.Runtime.refnanny");
  if (!__Pyx_RefNanny)
      Py_FatalError("failed to import 'refnanny' module");
}
#endif
  __Pyx_RefNannySetupContext("__Pyx_PyMODINIT_FUNC PyInit_FsmParseList(void)", 0);
  if (__Pyx_check_binary_version() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pxy_PyFrame_Initialize_Offsets
  __Pxy_PyFrame_Initialize_Offsets();
  #endif
  __pyx_empty_tuple = PyTuple_New(0); if (unlikely(!__pyx_empty_tuple)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_bytes = PyBytes_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_bytes)) __PYX_ERR(0, 1, __pyx_L1_error)
  __pyx_empty_unicode = PyUnicode_FromStringAndSize("", 0); if (unlikely(!__pyx_empty_unicode)) __PYX_ERR(0, 1, __pyx_L1_error)
  #ifdef __Pyx_CyFunction_USED
  if (__pyx_CyFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_FusedFunction_USED
  if (__pyx_FusedFunction_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Coroutine_USED
  if (__pyx_Coroutine_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_Generator_USED
  if (__pyx_Generator_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_AsyncGen_USED
  if (__pyx_AsyncGen_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  #ifdef __Pyx_StopAsyncIteration_USED
  if (__pyx_StopAsyncIteration_init() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  /*--- Library function declarations ---*/
  /*--- Threads initialization code ---*/
  #if defined(__PYX_FORCE_INIT_THREADS) && __PYX_FORCE_INIT_THREADS
  #ifdef WITH_THREAD /* Python build with threading support? */
  PyEval_InitThreads();
  #endif
  #endif
  /*--- Module creation code ---*/
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  __pyx_m = __pyx_pyinit_module;
  Py_INCREF(__pyx_m);
  #else
  #if PY_MAJOR_VERSION < 3
  __pyx_m = Py_InitModule4("FsmParseList", __pyx_methods, 0, 0, PYTHON_API_VERSION); Py_XINCREF(__pyx_m);
  #else
  __pyx_m = PyModule_Create(&__pyx_moduledef);
  #endif
  if (unlikely(!__pyx_m)) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  __pyx_d = PyModule_GetDict(__pyx_m); if (unlikely(!__pyx_d)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_d);
  __pyx_b = PyImport_AddModule(__Pyx_BUILTIN_MODULE_NAME); if (unlikely(!__pyx_b)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_b);
  __pyx_cython_runtime = PyImport_AddModule((char *) "cython_runtime"); if (unlikely(!__pyx_cython_runtime)) __PYX_ERR(0, 1, __pyx_L1_error)
  Py_INCREF(__pyx_cython_runtime);
  if (PyObject_SetAttrString(__pyx_m, "__builtins__", __pyx_b) < 0) __PYX_ERR(0, 1, __pyx_L1_error);
  /*--- Initialize various global constants etc. ---*/
  if (__Pyx_InitGlobals() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #if PY_MAJOR_VERSION < 3 && (__PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT)
  if (__Pyx_init_sys_getdefaultencoding_params() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif
  if (__pyx_module_is_main_MorphologicalAnalysis__FsmParseList) {
    if (PyObject_SetAttr(__pyx_m, __pyx_n_s_name, __pyx_n_s_main) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  }
  #if PY_MAJOR_VERSION >= 3
  {
    PyObject *modules = PyImport_GetModuleDict(); if (unlikely(!modules)) __PYX_ERR(0, 1, __pyx_L1_error)
    if (!PyDict_GetItemString(modules, "MorphologicalAnalysis.FsmParseList")) {
      if (unlikely(PyDict_SetItemString(modules, "MorphologicalAnalysis.FsmParseList", __pyx_m) < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
    }
  }
  #endif
  /*--- Builtin init code ---*/
  if (__Pyx_InitCachedBuiltins() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Constants init code ---*/
  if (__Pyx_InitCachedConstants() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  /*--- Global type/function init code ---*/
  (void)__Pyx_modinit_global_init_code();
  (void)__Pyx_modinit_variable_export_code();
  (void)__Pyx_modinit_function_export_code();
  if (unlikely(__Pyx_modinit_type_init_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  if (unlikely(__Pyx_modinit_type_import_code() < 0)) __PYX_ERR(0, 1, __pyx_L1_error)
  (void)__Pyx_modinit_variable_import_code();
  (void)__Pyx_modinit_function_import_code();
  /*--- Execution code ---*/
  #if defined(__Pyx_Generator_USED) || defined(__Pyx_Coroutine_USED)
  if (__Pyx_patch_abc() < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  #endif

  /* "MorphologicalAnalysis/FsmParseList.pyx":3
 * cdef class FsmParseList:
 * 
 *     longest_root_exceptions = [             # <<<<<<<<<<<<<<
 *         "aca acak NOUN VERB", "acam acak NOUN VERB", "acam acak NOUN VERB", "acamz acak NOUN VERB",
 *         "acan acak NOUN VERB",
 */
  __pyx_t_1 = PyList_New(230); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  __Pyx_INCREF(__pyx_kp_u_aca_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_aca_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 0, __pyx_kp_u_aca_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acam_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acam_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 1, __pyx_kp_u_acam_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acam_acak_NOUN_VERB_2);
  __Pyx_GIVEREF(__pyx_kp_u_acam_acak_NOUN_VERB_2);
  PyList_SET_ITEM(__pyx_t_1, 2, __pyx_kp_u_acam_acak_NOUN_VERB_2);
  __Pyx_INCREF(__pyx_kp_u_acamz_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acamz_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 3, __pyx_kp_u_acamz_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acan_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acan_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 4, __pyx_kp_u_acan_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acana_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acana_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 5, __pyx_kp_u_acana_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acan_acak_NOUN_VERB_2);
  __Pyx_GIVEREF(__pyx_kp_u_acan_acak_NOUN_VERB_2);
  PyList_SET_ITEM(__pyx_t_1, 6, __pyx_kp_u_acan_acak_NOUN_VERB_2);
  __Pyx_INCREF(__pyx_kp_u_acann_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acann_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 7, __pyx_kp_u_acann_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acanz_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acanz_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 8, __pyx_kp_u_acanz_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acanza_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acanza_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 9, __pyx_kp_u_acanza_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acanzdr_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acanzdr_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 10, __pyx_kp_u_acanzdr_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acanz_acak_NOUN_VERB_2);
  __Pyx_GIVEREF(__pyx_kp_u_acanz_acak_NOUN_VERB_2);
  PyList_SET_ITEM(__pyx_t_1, 11, __pyx_kp_u_acanz_acak_NOUN_VERB_2);
  __Pyx_INCREF(__pyx_kp_u_acanzn_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acanzn_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 12, __pyx_kp_u_acanzn_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acaz_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acaz_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 13, __pyx_kp_u_acaz_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acaklar_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acaklar_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 14, __pyx_kp_u_acaklar_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acaklarn_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acaklarn_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 15, __pyx_kp_u_acaklarn_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acaksa_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acaksa_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 16, __pyx_kp_u_acaksa_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_acaktr_acak_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_acaktr_acak_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 17, __pyx_kp_u_acaktr_acak_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ardm_ar_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ardm_ar_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 18, __pyx_kp_u_ardm_ar_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_arz_ar_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_arz_ar_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 19, __pyx_kp_u_arz_ar_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_arken_ar_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_arken_ar_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 20, __pyx_kp_u_arken_ar_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_arsa_ar_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_arsa_ar_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 21, __pyx_kp_u_arsa_ar_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_arsak_ar_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_arsak_ar_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 22, __pyx_kp_u_arsak_ar_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_arsanz_ar_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_arsanz_ar_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 23, __pyx_kp_u_arsanz_ar_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_arsnz_ar_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_arsnz_ar_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 24, __pyx_kp_u_arsnz_ar_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ecei_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ecei_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 25, __pyx_kp_u_ecei_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceim_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceim_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 26, __pyx_kp_u_eceim_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceimi_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceimi_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 27, __pyx_kp_u_eceimi_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceimiz_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceimiz_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 28, __pyx_kp_u_eceimiz_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ecein_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ecein_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 29, __pyx_kp_u_ecein_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceine_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceine_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 30, __pyx_kp_u_eceine_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceini_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceini_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 31, __pyx_kp_u_eceini_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceinin_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceinin_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 32, __pyx_kp_u_eceinin_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceiniz_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceiniz_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 33, __pyx_kp_u_eceiniz_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceinizdir_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceinizdir_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 34, __pyx_kp_u_eceinizdir_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceinize_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceinize_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 35, __pyx_kp_u_eceinize_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceinizi_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceinizi_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 36, __pyx_kp_u_eceinizi_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceinizin_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceinizin_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 37, __pyx_kp_u_eceinizin_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceiz_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceiz_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 38, __pyx_kp_u_eceiz_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ecekleri_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ecekleri_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 39, __pyx_kp_u_ecekleri_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eceklerini_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eceklerini_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 40, __pyx_kp_u_eceklerini_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ecekse_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ecekse_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 41, __pyx_kp_u_ecekse_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ecektir_ecek_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ecektir_ecek_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 42, __pyx_kp_u_ecektir_ecek_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_erdim_er_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_erdim_er_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 43, __pyx_kp_u_erdim_er_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_eriz_er_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_eriz_er_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 44, __pyx_kp_u_eriz_er_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_erken_er_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_erken_er_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 45, __pyx_kp_u_erken_er_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_erse_er_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_erse_er_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 46, __pyx_kp_u_erse_er_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ersek_er_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ersek_er_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 47, __pyx_kp_u_ersek_er_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_erseniz_er_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_erseniz_er_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 48, __pyx_kp_u_erseniz_er_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ersiniz_er_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ersiniz_er_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 49, __pyx_kp_u_ersiniz_er_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ilen_i_VERB_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ilen_i_VERB_VERB);
  PyList_SET_ITEM(__pyx_t_1, 50, __pyx_kp_u_ilen_i_VERB_VERB);
  __Pyx_INCREF(__pyx_kp_u_ilene_i_VERB_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ilene_i_VERB_VERB);
  PyList_SET_ITEM(__pyx_t_1, 51, __pyx_kp_u_ilene_i_VERB_VERB);
  __Pyx_INCREF(__pyx_kp_u_ilin_i_VERB_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ilin_i_VERB_VERB);
  PyList_SET_ITEM(__pyx_t_1, 52, __pyx_kp_u_ilin_i_VERB_VERB);
  __Pyx_INCREF(__pyx_kp_u_ilince_i_VERB_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ilince_i_VERB_VERB);
  PyList_SET_ITEM(__pyx_t_1, 53, __pyx_kp_u_ilince_i_VERB_VERB);
  __Pyx_INCREF(__pyx_kp_u_imiz_i_ADJ_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_imiz_i_ADJ_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 54, __pyx_kp_u_imiz_i_ADJ_NOUN);
  __Pyx_INCREF(__pyx_kp_u_in_i_ADJ_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_in_i_ADJ_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 55, __pyx_kp_u_in_i_ADJ_NOUN);
  __Pyx_INCREF(__pyx_kp_u_inde_i_ADJ_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_inde_i_ADJ_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 56, __pyx_kp_u_inde_i_ADJ_NOUN);
  __Pyx_INCREF(__pyx_kp_u_ine_i_ADJ_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_ine_i_ADJ_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 57, __pyx_kp_u_ine_i_ADJ_NOUN);
  __Pyx_INCREF(__pyx_kp_u_ini_i_ADJ_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_ini_i_ADJ_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 58, __pyx_kp_u_ini_i_ADJ_NOUN);
  __Pyx_INCREF(__pyx_kp_u_inin_i_ADJ_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_inin_i_ADJ_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 59, __pyx_kp_u_inin_i_ADJ_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lan_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_lan_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 60, __pyx_kp_u_lan_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_lana_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_lana_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 61, __pyx_kp_u_lana_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ln_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ln_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 62, __pyx_kp_u_ln_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_lnca_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_lnca_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 63, __pyx_kp_u_lnca_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_la_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_la_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 64, __pyx_kp_u_la_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lar_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lar_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 65, __pyx_kp_u_lar_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lardan_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lardan_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 66, __pyx_kp_u_lardan_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lardandr_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lardandr_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 67, __pyx_kp_u_lardandr_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lardr_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lardr_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 68, __pyx_kp_u_lardr_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lar_la_VERB_NOUN_2);
  __Pyx_GIVEREF(__pyx_kp_u_lar_la_VERB_NOUN_2);
  PyList_SET_ITEM(__pyx_t_1, 69, __pyx_kp_u_lar_la_VERB_NOUN_2);
  __Pyx_INCREF(__pyx_kp_u_lardr_la_VERB_NOUN_2);
  __Pyx_GIVEREF(__pyx_kp_u_lardr_la_VERB_NOUN_2);
  PyList_SET_ITEM(__pyx_t_1, 70, __pyx_kp_u_lardr_la_VERB_NOUN_2);
  __Pyx_INCREF(__pyx_kp_u_larm_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larm_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 71, __pyx_kp_u_larm_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larmdan_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larmdan_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 72, __pyx_kp_u_larmdan_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larmz_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larmz_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 73, __pyx_kp_u_larmz_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larmza_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larmza_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 74, __pyx_kp_u_larmza_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larmzda_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larmzda_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 75, __pyx_kp_u_larmzda_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larmzdan_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larmzdan_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 76, __pyx_kp_u_larmzdan_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larmzdayd_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larmzdayd_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 77, __pyx_kp_u_larmzdayd_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larmz_la_VERB_NOUN_2);
  __Pyx_GIVEREF(__pyx_kp_u_larmz_la_VERB_NOUN_2);
  PyList_SET_ITEM(__pyx_t_1, 78, __pyx_kp_u_larmz_la_VERB_NOUN_2);
  __Pyx_INCREF(__pyx_kp_u_larmzn_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larmzn_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 79, __pyx_kp_u_larmzn_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larmzla_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larmzla_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 80, __pyx_kp_u_larmzla_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larn_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larn_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 81, __pyx_kp_u_larn_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larna_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larna_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 82, __pyx_kp_u_larna_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larnda_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larnda_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 83, __pyx_kp_u_larnda_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larndaki_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larndaki_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 84, __pyx_kp_u_larndaki_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larndakiler_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larndakiler_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 85, __pyx_kp_u_larndakiler_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larndakilere_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larndakilere_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 86, __pyx_kp_u_larndakilere_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larndakileri_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larndakileri_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 87, __pyx_kp_u_larndakileri_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larndakilerin_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larndakilerin_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 88, __pyx_kp_u_larndakilerin_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larndan_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larndan_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 89, __pyx_kp_u_larndan_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larndandr_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larndandr_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 90, __pyx_kp_u_larndandr_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larndaysa_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larndaysa_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 91, __pyx_kp_u_larndaysa_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larn_la_VERB_NOUN_2);
  __Pyx_GIVEREF(__pyx_kp_u_larn_la_VERB_NOUN_2);
  PyList_SET_ITEM(__pyx_t_1, 92, __pyx_kp_u_larn_la_VERB_NOUN_2);
  __Pyx_INCREF(__pyx_kp_u_larnn_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larnn_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 93, __pyx_kp_u_larnn_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larnz_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larnz_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 94, __pyx_kp_u_larnz_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larnza_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larnza_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 95, __pyx_kp_u_larnza_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larnzda_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larnzda_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 96, __pyx_kp_u_larnzda_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larnzdaki_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larnzdaki_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 97, __pyx_kp_u_larnzdaki_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larnzdan_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larnzdan_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 98, __pyx_kp_u_larnzdan_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larnz_la_VERB_NOUN_2);
  __Pyx_GIVEREF(__pyx_kp_u_larnz_la_VERB_NOUN_2);
  PyList_SET_ITEM(__pyx_t_1, 99, __pyx_kp_u_larnz_la_VERB_NOUN_2);
  __Pyx_INCREF(__pyx_kp_u_larnzn_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larnzn_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 100, __pyx_kp_u_larnzn_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_larnzla_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_larnzla_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 101, __pyx_kp_u_larnzla_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_laryla_la_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_laryla_la_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 102, __pyx_kp_u_laryla_la_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_le_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_le_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 103, __pyx_kp_u_le_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_ler_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_ler_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 104, __pyx_kp_u_ler_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerden_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerden_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 105, __pyx_kp_u_lerden_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerdendir_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerdendir_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 106, __pyx_kp_u_lerdendir_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerdir_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerdir_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 107, __pyx_kp_u_lerdir_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_leri_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_leri_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 108, __pyx_kp_u_leri_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_leridir_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_leridir_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 109, __pyx_kp_u_leridir_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerim_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerim_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 110, __pyx_kp_u_lerim_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerimden_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerimden_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 111, __pyx_kp_u_lerimden_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerimiz_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerimiz_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 112, __pyx_kp_u_lerimiz_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerimizde_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerimizde_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 113, __pyx_kp_u_lerimizde_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerimizden_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerimizden_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 114, __pyx_kp_u_lerimizden_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerimizdeydi_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerimizdeydi_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 115, __pyx_kp_u_lerimizdeydi_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerimize_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerimize_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 116, __pyx_kp_u_lerimize_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerimizi_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerimizi_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 117, __pyx_kp_u_lerimizi_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerimizin_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerimizin_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 118, __pyx_kp_u_lerimizin_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerimizle_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerimizle_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 119, __pyx_kp_u_lerimizle_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerin_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerin_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 120, __pyx_kp_u_lerin_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerinde_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerinde_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 121, __pyx_kp_u_lerinde_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerindeki_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerindeki_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 122, __pyx_kp_u_lerindeki_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerindekiler_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerindekiler_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 123, __pyx_kp_u_lerindekiler_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerindekilere_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerindekilere_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 124, __pyx_kp_u_lerindekilere_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerindekileri_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerindekileri_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 125, __pyx_kp_u_lerindekileri_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerindekilerin_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerindekilerin_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 126, __pyx_kp_u_lerindekilerin_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerinden_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerinden_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 127, __pyx_kp_u_lerinden_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerindendir_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerindendir_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 128, __pyx_kp_u_lerindendir_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerindeyse_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerindeyse_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 129, __pyx_kp_u_lerindeyse_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerine_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerine_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 130, __pyx_kp_u_lerine_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerini_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerini_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 131, __pyx_kp_u_lerini_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerinin_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerinin_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 132, __pyx_kp_u_lerinin_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_leriniz_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_leriniz_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 133, __pyx_kp_u_leriniz_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerinizde_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerinizde_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 134, __pyx_kp_u_lerinizde_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerinizdeki_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerinizdeki_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 135, __pyx_kp_u_lerinizdeki_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerinizden_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerinizden_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 136, __pyx_kp_u_lerinizden_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerinize_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerinize_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 137, __pyx_kp_u_lerinize_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerinizi_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerinizi_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 138, __pyx_kp_u_lerinizi_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerinizin_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerinizin_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 139, __pyx_kp_u_lerinizin_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_lerinizle_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_lerinizle_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 140, __pyx_kp_u_lerinizle_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_leriyle_le_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_leriyle_le_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 141, __pyx_kp_u_leriyle_le_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_madan_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_madan_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 142, __pyx_kp_u_madan_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mal_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mal_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 143, __pyx_kp_u_mal_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_maldr_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_maldr_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 144, __pyx_kp_u_maldr_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_maldrlar_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_maldrlar_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 145, __pyx_kp_u_maldrlar_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mallar_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mallar_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 146, __pyx_kp_u_mallar_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_malsnz_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_malsnz_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 147, __pyx_kp_u_malsnz_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_malym_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_malym_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 148, __pyx_kp_u_malym_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_malyz_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_malyz_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 149, __pyx_kp_u_malyz_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mam_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mam_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 150, __pyx_kp_u_mam_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mama_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mama_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 151, __pyx_kp_u_mama_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mamz_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mamz_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 152, __pyx_kp_u_mamz_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mamza_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mamza_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 153, __pyx_kp_u_mamza_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mamz_ma_NOUN_VERB_2);
  __Pyx_GIVEREF(__pyx_kp_u_mamz_ma_NOUN_VERB_2);
  PyList_SET_ITEM(__pyx_t_1, 154, __pyx_kp_u_mamz_ma_NOUN_VERB_2);
  __Pyx_INCREF(__pyx_kp_u_manz_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_manz_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 155, __pyx_kp_u_manz_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_manzda_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_manzda_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 156, __pyx_kp_u_manzda_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_manzdr_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_manzdr_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 157, __pyx_kp_u_manzdr_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_manz_ma_NOUN_VERB_2);
  __Pyx_GIVEREF(__pyx_kp_u_manz_ma_NOUN_VERB_2);
  PyList_SET_ITEM(__pyx_t_1, 158, __pyx_kp_u_manz_ma_NOUN_VERB_2);
  __Pyx_INCREF(__pyx_kp_u_manzla_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_manzla_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 159, __pyx_kp_u_manzla_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mas_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mas_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 160, __pyx_kp_u_mas_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_masdr_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_masdr_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 161, __pyx_kp_u_masdr_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_masn_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_masn_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 162, __pyx_kp_u_masn_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_masna_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_masna_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 163, __pyx_kp_u_masna_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_masnda_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_masnda_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 164, __pyx_kp_u_masnda_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_masndaki_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_masndaki_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 165, __pyx_kp_u_masndaki_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_masn_ma_NOUN_VERB_2);
  __Pyx_GIVEREF(__pyx_kp_u_masn_ma_NOUN_VERB_2);
  PyList_SET_ITEM(__pyx_t_1, 166, __pyx_kp_u_masn_ma_NOUN_VERB_2);
  __Pyx_INCREF(__pyx_kp_u_masyla_ma_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_masyla_ma_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 167, __pyx_kp_u_masyla_ma_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mdan_m_NOUN_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_mdan_m_NOUN_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 168, __pyx_kp_u_mdan_m_NOUN_NOUN);
  __Pyx_INCREF(__pyx_kp_u_meden_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_meden_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 169, __pyx_kp_u_meden_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_meli_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_meli_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 170, __pyx_kp_u_meli_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_melidir_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_melidir_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 171, __pyx_kp_u_melidir_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_melidirler_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_melidirler_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 172, __pyx_kp_u_melidirler_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_meliler_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_meliler_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 173, __pyx_kp_u_meliler_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_melisiniz_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_melisiniz_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 174, __pyx_kp_u_melisiniz_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_meliyim_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_meliyim_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 175, __pyx_kp_u_meliyim_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_meliyiz_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_meliyiz_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 176, __pyx_kp_u_meliyiz_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mem_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mem_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 177, __pyx_kp_u_mem_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_meme_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_meme_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 178, __pyx_kp_u_meme_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_memiz_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_memiz_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 179, __pyx_kp_u_memiz_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_memize_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_memize_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 180, __pyx_kp_u_memize_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_memizi_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_memizi_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 181, __pyx_kp_u_memizi_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_meniz_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_meniz_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 182, __pyx_kp_u_meniz_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_menizde_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_menizde_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 183, __pyx_kp_u_menizde_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_menizdir_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_menizdir_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 184, __pyx_kp_u_menizdir_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_menizi_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_menizi_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 185, __pyx_kp_u_menizi_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_menizle_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_menizle_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 186, __pyx_kp_u_menizle_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mesi_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mesi_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 187, __pyx_kp_u_mesi_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mesidir_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mesidir_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 188, __pyx_kp_u_mesidir_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mesin_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mesin_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 189, __pyx_kp_u_mesin_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mesinde_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mesinde_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 190, __pyx_kp_u_mesinde_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mesindeki_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mesindeki_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 191, __pyx_kp_u_mesindeki_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mesine_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mesine_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 192, __pyx_kp_u_mesine_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mesini_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mesini_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 193, __pyx_kp_u_mesini_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mesiyle_me_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mesiyle_me_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 194, __pyx_kp_u_mesiyle_me_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mise_mi_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_mise_mi_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 195, __pyx_kp_u_mise_mi_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mn_m_NOUN_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_mn_m_NOUN_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 196, __pyx_kp_u_mn_m_NOUN_NOUN);
  __Pyx_INCREF(__pyx_kp_u_msa_m_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_msa_m_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 197, __pyx_kp_u_msa_m_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_mz_m_NOUN_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_mz_m_NOUN_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 198, __pyx_kp_u_mz_m_NOUN_NOUN);
  __Pyx_INCREF(__pyx_kp_u_na_n_NOUN_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_na_n_NOUN_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 199, __pyx_kp_u_na_n_NOUN_NOUN);
  __Pyx_INCREF(__pyx_kp_u_ne_n_NOUN_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_ne_n_NOUN_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 200, __pyx_kp_u_ne_n_NOUN_NOUN);
  __Pyx_INCREF(__pyx_kp_u_nin_n_NOUN_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_nin_n_NOUN_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 201, __pyx_kp_u_nin_n_NOUN_NOUN);
  __Pyx_INCREF(__pyx_kp_u_niz_n_NOUN_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_niz_n_NOUN_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 202, __pyx_kp_u_niz_n_NOUN_NOUN);
  __Pyx_INCREF(__pyx_kp_u_nn_n_NOUN_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_nn_n_NOUN_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 203, __pyx_kp_u_nn_n_NOUN_NOUN);
  __Pyx_INCREF(__pyx_kp_u_nz_n_NOUN_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_nz_n_NOUN_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 204, __pyx_kp_u_nz_n_NOUN_NOUN);
  __Pyx_INCREF(__pyx_kp_u_rdim_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rdim_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 205, __pyx_kp_u_rdim_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rdm_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rdm_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 206, __pyx_kp_u_rdm_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_riz_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_riz_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 207, __pyx_kp_u_riz_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rz_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rz_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 208, __pyx_kp_u_rz_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rken_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rken_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 209, __pyx_kp_u_rken_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rken_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rken_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 210, __pyx_kp_u_rken_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rsa_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rsa_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 211, __pyx_kp_u_rsa_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rsak_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rsak_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 212, __pyx_kp_u_rsak_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rsanz_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rsanz_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 213, __pyx_kp_u_rsanz_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rse_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rse_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 214, __pyx_kp_u_rse_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rsek_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rsek_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 215, __pyx_kp_u_rsek_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rseniz_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rseniz_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 216, __pyx_kp_u_rseniz_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rsiniz_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rsiniz_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 217, __pyx_kp_u_rsiniz_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_rsnz_r_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_rsnz_r_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 218, __pyx_kp_u_rsnz_r_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_sa_sa_VERB_ADJ);
  __Pyx_GIVEREF(__pyx_kp_u_sa_sa_VERB_ADJ);
  PyList_SET_ITEM(__pyx_t_1, 219, __pyx_kp_u_sa_sa_VERB_ADJ);
  __Pyx_INCREF(__pyx_kp_u_se_se_VERB_ADJ);
  __Pyx_GIVEREF(__pyx_kp_u_se_se_VERB_ADJ);
  PyList_SET_ITEM(__pyx_t_1, 220, __pyx_kp_u_se_se_VERB_ADJ);
  __Pyx_INCREF(__pyx_kp_u_ulan_u_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ulan_u_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 221, __pyx_kp_u_ulan_u_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_un_un_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_un_un_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 222, __pyx_kp_u_un_un_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_ne_n_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_ne_n_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 223, __pyx_kp_u_ne_n_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_unun_un_VERB_NOUN);
  __Pyx_GIVEREF(__pyx_kp_u_unun_un_VERB_NOUN);
  PyList_SET_ITEM(__pyx_t_1, 224, __pyx_kp_u_unun_un_VERB_NOUN);
  __Pyx_INCREF(__pyx_kp_u_ince_i_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ince_i_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 225, __pyx_kp_u_ince_i_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_unca_u_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_unca_u_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 226, __pyx_kp_u_unca_u_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_nca_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_nca_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 227, __pyx_kp_u_nca_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_unca_un_NOUN_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_unca_un_NOUN_VERB);
  PyList_SET_ITEM(__pyx_t_1, 228, __pyx_kp_u_unca_un_NOUN_VERB);
  __Pyx_INCREF(__pyx_kp_u_ilen_ile_VERB_VERB);
  __Pyx_GIVEREF(__pyx_kp_u_ilen_ile_VERB_VERB);
  PyList_SET_ITEM(__pyx_t_1, 229, __pyx_kp_u_ilen_ile_VERB_VERB);
  if (PyDict_SetItem((PyObject *)__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList->tp_dict, __pyx_n_s_longest_root_exceptions, __pyx_t_1) < 0) __PYX_ERR(0, 3, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;
  PyType_Modified(__pyx_ptype_21MorphologicalAnalysis_12FsmParseList_FsmParseList);

  /* "(tree fragment)":1
 * def __pyx_unpickle_FsmParseList(__pyx_type, long __pyx_checksum, __pyx_state):             # <<<<<<<<<<<<<<
 *     cdef object __pyx_PickleError
 *     cdef object __pyx_result
 */
  __pyx_t_1 = PyCFunction_NewEx(&__pyx_mdef_21MorphologicalAnalysis_12FsmParseList_1__pyx_unpickle_FsmParseList, NULL, __pyx_n_s_MorphologicalAnalysis_FsmParseLi); if (unlikely(!__pyx_t_1)) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_pyx_unpickle_FsmParseList, __pyx_t_1) < 0) __PYX_ERR(1, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /* "MorphologicalAnalysis/FsmParseList.pyx":1
 * cdef class FsmParseList:             # <<<<<<<<<<<<<<
 * 
 *     longest_root_exceptions = [
 */
  __pyx_t_1 = __Pyx_PyDict_NewPresized(0); if (unlikely(!__pyx_t_1)) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_GOTREF(__pyx_t_1);
  if (PyDict_SetItem(__pyx_d, __pyx_n_s_test, __pyx_t_1) < 0) __PYX_ERR(0, 1, __pyx_L1_error)
  __Pyx_DECREF(__pyx_t_1); __pyx_t_1 = 0;

  /*--- Wrapped vars code ---*/

  goto __pyx_L0;
  __pyx_L1_error:;
  __Pyx_XDECREF(__pyx_t_1);
  if (__pyx_m) {
    if (__pyx_d) {
      __Pyx_AddTraceback("init MorphologicalAnalysis.FsmParseList", __pyx_clineno, __pyx_lineno, __pyx_filename);
    }
    Py_CLEAR(__pyx_m);
  } else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_ImportError, "init MorphologicalAnalysis.FsmParseList");
  }
  __pyx_L0:;
  __Pyx_RefNannyFinishContext();
  #if CYTHON_PEP489_MULTI_PHASE_INIT
  return (__pyx_m != NULL) ? 0 : -1;
  #elif PY_MAJOR_VERSION >= 3
  return __pyx_m;
  #else
  return;
  #endif
}

/* --- Runtime support code --- */
/* Refnanny */
#if CYTHON_REFNANNY
static __Pyx_RefNannyAPIStruct *__Pyx_RefNannyImportAPI(const char *modname) {
    PyObject *m = NULL, *p = NULL;
    void *r = NULL;
    m = PyImport_ImportModule(modname);
    if (!m) goto end;
    p = PyObject_GetAttrString(m, "RefNannyAPI");
    if (!p) goto end;
    r = PyLong_AsVoidPtr(p);
end:
    Py_XDECREF(p);
    Py_XDECREF(m);
    return (__Pyx_RefNannyAPIStruct *)r;
}
#endif

/* PyObjectGetAttrStr */
#if CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStr(PyObject* obj, PyObject* attr_name) {
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro))
        return tp->tp_getattro(obj, attr_name);
#if PY_MAJOR_VERSION < 3
    if (likely(tp->tp_getattr))
        return tp->tp_getattr(obj, PyString_AS_STRING(attr_name));
#endif
    return PyObject_GetAttr(obj, attr_name);
}
#endif

/* GetBuiltinName */
static PyObject *__Pyx_GetBuiltinName(PyObject *name) {
    PyObject* result = __Pyx_PyObject_GetAttrStr(__pyx_b, name);
    if (unlikely(!result)) {
        PyErr_Format(PyExc_NameError,
#if PY_MAJOR_VERSION >= 3
            "name '%U' is not defined", name);
#else
            "name '%.200s' is not defined", PyString_AS_STRING(name));
#endif
    }
    return result;
}

/* RaiseDoubleKeywords */
static void __Pyx_RaiseDoubleKeywordsError(
    const char* func_name,
    PyObject* kw_name)
{
    PyErr_Format(PyExc_TypeError,
        #if PY_MAJOR_VERSION >= 3
        "%s() got multiple values for keyword argument '%U'", func_name, kw_name);
        #else
        "%s() got multiple values for keyword argument '%s'", func_name,
        PyString_AsString(kw_name));
        #endif
}

/* ParseKeywords */
static int __Pyx_ParseOptionalKeywords(
    PyObject *kwds,
    PyObject **argnames[],
    PyObject *kwds2,
    PyObject *values[],
    Py_ssize_t num_pos_args,
    const char* function_name)
{
    PyObject *key = 0, *value = 0;
    Py_ssize_t pos = 0;
    PyObject*** name;
    PyObject*** first_kw_arg = argnames + num_pos_args;
    while (PyDict_Next(kwds, &pos, &key, &value)) {
        name = first_kw_arg;
        while (*name && (**name != key)) name++;
        if (*name) {
            values[name-argnames] = value;
            continue;
        }
        name = first_kw_arg;
        #if PY_MAJOR_VERSION < 3
        if (likely(PyString_Check(key))) {
            while (*name) {
                if ((CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**name) == PyString_GET_SIZE(key))
                        && _PyString_Eq(**name, key)) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    if ((**argname == key) || (
                            (CYTHON_COMPILING_IN_PYPY || PyString_GET_SIZE(**argname) == PyString_GET_SIZE(key))
                             && _PyString_Eq(**argname, key))) {
                        goto arg_passed_twice;
                    }
                    argname++;
                }
            }
        } else
        #endif
        if (likely(PyUnicode_Check(key))) {
            while (*name) {
                int cmp = (**name == key) ? 0 :
                #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                    (__Pyx_PyUnicode_GET_LENGTH(**name) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                #endif
                    PyUnicode_Compare(**name, key);
                if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                if (cmp == 0) {
                    values[name-argnames] = value;
                    break;
                }
                name++;
            }
            if (*name) continue;
            else {
                PyObject*** argname = argnames;
                while (argname != first_kw_arg) {
                    int cmp = (**argname == key) ? 0 :
                    #if !CYTHON_COMPILING_IN_PYPY && PY_MAJOR_VERSION >= 3
                        (__Pyx_PyUnicode_GET_LENGTH(**argname) != __Pyx_PyUnicode_GET_LENGTH(key)) ? 1 :
                    #endif
                        PyUnicode_Compare(**argname, key);
                    if (cmp < 0 && unlikely(PyErr_Occurred())) goto bad;
                    if (cmp == 0) goto arg_passed_twice;
                    argname++;
                }
            }
        } else
            goto invalid_keyword_type;
        if (kwds2) {
            if (unlikely(PyDict_SetItem(kwds2, key, value))) goto bad;
        } else {
            goto invalid_keyword;
        }
    }
    return 0;
arg_passed_twice:
    __Pyx_RaiseDoubleKeywordsError(function_name, key);
    goto bad;
invalid_keyword_type:
    PyErr_Format(PyExc_TypeError,
        "%.200s() keywords must be strings", function_name);
    goto bad;
invalid_keyword:
    PyErr_Format(PyExc_TypeError,
    #if PY_MAJOR_VERSION < 3
        "%.200s() got an unexpected keyword argument '%.200s'",
        function_name, PyString_AsString(key));
    #else
        "%s() got an unexpected keyword argument '%U'",
        function_name, key);
    #endif
bad:
    return -1;
}

/* RaiseArgTupleInvalid */
static void __Pyx_RaiseArgtupleInvalid(
    const char* func_name,
    int exact,
    Py_ssize_t num_min,
    Py_ssize_t num_max,
    Py_ssize_t num_found)
{
    Py_ssize_t num_expected;
    const char *more_or_less;
    if (num_found < num_min) {
        num_expected = num_min;
        more_or_less = "at least";
    } else {
        num_expected = num_max;
        more_or_less = "at most";
    }
    if (exact) {
        more_or_less = "exactly";
    }
    PyErr_Format(PyExc_TypeError,
                 "%.200s() takes %.8s %" CYTHON_FORMAT_SSIZE_T "d positional argument%.1s (%" CYTHON_FORMAT_SSIZE_T "d given)",
                 func_name, more_or_less, num_expected,
                 (num_expected == 1) ? "" : "s", num_found);
}

/* ArgTypeTest */
static int __Pyx__ArgTypeTest(PyObject *obj, PyTypeObject *type, const char *name, int exact)
{
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    else if (exact) {
        #if PY_MAJOR_VERSION == 2
        if ((type == &PyBaseString_Type) && likely(__Pyx_PyBaseString_CheckExact(obj))) return 1;
        #endif
    }
    else {
        if (likely(__Pyx_TypeCheck(obj, type))) return 1;
    }
    PyErr_Format(PyExc_TypeError,
        "Argument '%.200s' has incorrect type (expected %.200s, got %.200s)",
        name, type->tp_name, Py_TYPE(obj)->tp_name);
    return 0;
}

/* GetItemInt */
static PyObject *__Pyx_GetItemInt_Generic(PyObject *o, PyObject* j) {
    PyObject *r;
    if (!j) return NULL;
    r = PyObject_GetItem(o, j);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_List_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyList_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyList_GET_SIZE(o)))) {
        PyObject *r = PyList_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Tuple_Fast(PyObject *o, Py_ssize_t i,
                                                              CYTHON_NCP_UNUSED int wraparound,
                                                              CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
    Py_ssize_t wrapped_i = i;
    if (wraparound & unlikely(i < 0)) {
        wrapped_i += PyTuple_GET_SIZE(o);
    }
    if ((!boundscheck) || likely(__Pyx_is_valid_index(wrapped_i, PyTuple_GET_SIZE(o)))) {
        PyObject *r = PyTuple_GET_ITEM(o, wrapped_i);
        Py_INCREF(r);
        return r;
    }
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
#else
    return PySequence_GetItem(o, i);
#endif
}
static CYTHON_INLINE PyObject *__Pyx_GetItemInt_Fast(PyObject *o, Py_ssize_t i, int is_list,
                                                     CYTHON_NCP_UNUSED int wraparound,
                                                     CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyList_GET_SIZE(o);
        if ((!boundscheck) || (likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o))))) {
            PyObject *r = PyList_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    }
    else if (PyTuple_CheckExact(o)) {
        Py_ssize_t n = ((!wraparound) | likely(i >= 0)) ? i : i + PyTuple_GET_SIZE(o);
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyTuple_GET_SIZE(o)))) {
            PyObject *r = PyTuple_GET_ITEM(o, n);
            Py_INCREF(r);
            return r;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return NULL;
                    PyErr_Clear();
                }
            }
            return m->sq_item(o, i);
        }
    }
#else
    if (is_list || PySequence_Check(o)) {
        return PySequence_GetItem(o, i);
    }
#endif
    return __Pyx_GetItemInt_Generic(o, PyInt_FromSsize_t(i));
}

/* PyFunctionFastCall */
#if CYTHON_FAST_PYCALL
static PyObject* __Pyx_PyFunction_FastCallNoKw(PyCodeObject *co, PyObject **args, Py_ssize_t na,
                                               PyObject *globals) {
    PyFrameObject *f;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    PyObject **fastlocals;
    Py_ssize_t i;
    PyObject *result;
    assert(globals != NULL);
    /* XXX Perhaps we should create a specialized
       PyFrame_New() that doesn't take locals, but does
       take builtins without sanity checking them.
       */
    assert(tstate != NULL);
    f = PyFrame_New(tstate, co, globals, NULL);
    if (f == NULL) {
        return NULL;
    }
    fastlocals = __Pyx_PyFrame_GetLocalsplus(f);
    for (i = 0; i < na; i++) {
        Py_INCREF(*args);
        fastlocals[i] = *args++;
    }
    result = PyEval_EvalFrameEx(f,0);
    ++tstate->recursion_depth;
    Py_DECREF(f);
    --tstate->recursion_depth;
    return result;
}
#if 1 || PY_VERSION_HEX < 0x030600B1
static PyObject *__Pyx_PyFunction_FastCallDict(PyObject *func, PyObject **args, Py_ssize_t nargs, PyObject *kwargs) {
    PyCodeObject *co = (PyCodeObject *)PyFunction_GET_CODE(func);
    PyObject *globals = PyFunction_GET_GLOBALS(func);
    PyObject *argdefs = PyFunction_GET_DEFAULTS(func);
    PyObject *closure;
#if PY_MAJOR_VERSION >= 3
    PyObject *kwdefs;
#endif
    PyObject *kwtuple, **k;
    PyObject **d;
    Py_ssize_t nd;
    Py_ssize_t nk;
    PyObject *result;
    assert(kwargs == NULL || PyDict_Check(kwargs));
    nk = kwargs ? PyDict_Size(kwargs) : 0;
    if (Py_EnterRecursiveCall((char*)" while calling a Python object")) {
        return NULL;
    }
    if (
#if PY_MAJOR_VERSION >= 3
            co->co_kwonlyargcount == 0 &&
#endif
            likely(kwargs == NULL || nk == 0) &&
            co->co_flags == (CO_OPTIMIZED | CO_NEWLOCALS | CO_NOFREE)) {
        if (argdefs == NULL && co->co_argcount == nargs) {
            result = __Pyx_PyFunction_FastCallNoKw(co, args, nargs, globals);
            goto done;
        }
        else if (nargs == 0 && argdefs != NULL
                 && co->co_argcount == Py_SIZE(argdefs)) {
            /* function called with no arguments, but all parameters have
               a default value: use default values as arguments .*/
            args = &PyTuple_GET_ITEM(argdefs, 0);
            result =__Pyx_PyFunction_FastCallNoKw(co, args, Py_SIZE(argdefs), globals);
            goto done;
        }
    }
    if (kwargs != NULL) {
        Py_ssize_t pos, i;
        kwtuple = PyTuple_New(2 * nk);
        if (kwtuple == NULL) {
            result = NULL;
            goto done;
        }
        k = &PyTuple_GET_ITEM(kwtuple, 0);
        pos = i = 0;
        while (PyDict_Next(kwargs, &pos, &k[i], &k[i+1])) {
            Py_INCREF(k[i]);
            Py_INCREF(k[i+1]);
            i += 2;
        }
        nk = i / 2;
    }
    else {
        kwtuple = NULL;
        k = NULL;
    }
    closure = PyFunction_GET_CLOSURE(func);
#if PY_MAJOR_VERSION >= 3
    kwdefs = PyFunction_GET_KW_DEFAULTS(func);
#endif
    if (argdefs != NULL) {
        d = &PyTuple_GET_ITEM(argdefs, 0);
        nd = Py_SIZE(argdefs);
    }
    else {
        d = NULL;
        nd = 0;
    }
#if PY_MAJOR_VERSION >= 3
    result = PyEval_EvalCodeEx((PyObject*)co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, kwdefs, closure);
#else
    result = PyEval_EvalCodeEx(co, globals, (PyObject *)NULL,
                               args, (int)nargs,
                               k, (int)nk,
                               d, (int)nd, closure);
#endif
    Py_XDECREF(kwtuple);
done:
    Py_LeaveRecursiveCall();
    return result;
}
#endif
#endif

/* PyObjectCall */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_Call(PyObject *func, PyObject *arg, PyObject *kw) {
    PyObject *result;
    ternaryfunc call = func->ob_type->tp_call;
    if (unlikely(!call))
        return PyObject_Call(func, arg, kw);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = (*call)(func, arg, kw);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallMethO */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallMethO(PyObject *func, PyObject *arg) {
    PyObject *self, *result;
    PyCFunction cfunc;
    cfunc = PyCFunction_GET_FUNCTION(func);
    self = PyCFunction_GET_SELF(func);
    if (unlikely(Py_EnterRecursiveCall((char*)" while calling a Python object")))
        return NULL;
    result = cfunc(self, arg);
    Py_LeaveRecursiveCall();
    if (unlikely(!result) && unlikely(!PyErr_Occurred())) {
        PyErr_SetString(
            PyExc_SystemError,
            "NULL result without error in PyObject_Call");
    }
    return result;
}
#endif

/* PyObjectCallNoArg */
#if CYTHON_COMPILING_IN_CPYTHON
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallNoArg(PyObject *func) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, NULL, 0);
    }
#endif
#ifdef __Pyx_CyFunction_USED
    if (likely(PyCFunction_Check(func) || __Pyx_CyFunction_Check(func)))
#else
    if (likely(PyCFunction_Check(func)))
#endif
    {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_NOARGS)) {
            return __Pyx_PyObject_CallMethO(func, NULL);
        }
    }
    return __Pyx_PyObject_Call(func, __pyx_empty_tuple, NULL);
}
#endif

/* PyCFunctionFastCall */
#if CYTHON_FAST_PYCCALL
static CYTHON_INLINE PyObject * __Pyx_PyCFunction_FastCall(PyObject *func_obj, PyObject **args, Py_ssize_t nargs) {
    PyCFunctionObject *func = (PyCFunctionObject*)func_obj;
    PyCFunction meth = PyCFunction_GET_FUNCTION(func);
    PyObject *self = PyCFunction_GET_SELF(func);
    int flags = PyCFunction_GET_FLAGS(func);
    assert(PyCFunction_Check(func));
    assert(METH_FASTCALL == (flags & ~(METH_CLASS | METH_STATIC | METH_COEXIST | METH_KEYWORDS | METH_STACKLESS)));
    assert(nargs >= 0);
    assert(nargs == 0 || args != NULL);
    /* _PyCFunction_FastCallDict() must not be called with an exception set,
       because it may clear it (directly or indirectly) and so the
       caller loses its exception */
    assert(!PyErr_Occurred());
    if ((PY_VERSION_HEX < 0x030700A0) || unlikely(flags & METH_KEYWORDS)) {
        return (*((__Pyx_PyCFunctionFastWithKeywords)(void*)meth)) (self, args, nargs, NULL);
    } else {
        return (*((__Pyx_PyCFunctionFast)(void*)meth)) (self, args, nargs);
    }
}
#endif

/* PyObjectCallOneArg */
#if CYTHON_COMPILING_IN_CPYTHON
static PyObject* __Pyx__PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_New(1);
    if (unlikely(!args)) return NULL;
    Py_INCREF(arg);
    PyTuple_SET_ITEM(args, 0, arg);
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
#if CYTHON_FAST_PYCALL
    if (PyFunction_Check(func)) {
        return __Pyx_PyFunction_FastCall(func, &arg, 1);
    }
#endif
    if (likely(PyCFunction_Check(func))) {
        if (likely(PyCFunction_GET_FLAGS(func) & METH_O)) {
            return __Pyx_PyObject_CallMethO(func, arg);
#if CYTHON_FAST_PYCCALL
        } else if (PyCFunction_GET_FLAGS(func) & METH_FASTCALL) {
            return __Pyx_PyCFunction_FastCall(func, &arg, 1);
#endif
        }
    }
    return __Pyx__PyObject_CallOneArg(func, arg);
}
#else
static CYTHON_INLINE PyObject* __Pyx_PyObject_CallOneArg(PyObject *func, PyObject *arg) {
    PyObject *result;
    PyObject *args = PyTuple_Pack(1, arg);
    if (unlikely(!args)) return NULL;
    result = __Pyx_PyObject_Call(func, args, NULL);
    Py_DECREF(args);
    return result;
}
#endif

/* PyObjectCall2Args */
static CYTHON_UNUSED PyObject* __Pyx_PyObject_Call2Args(PyObject* function, PyObject* arg1, PyObject* arg2) {
    PyObject *args, *result = NULL;
    #if CYTHON_FAST_PYCALL
    if (PyFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyFunction_FastCall(function, args, 2);
    }
    #endif
    #if CYTHON_FAST_PYCCALL
    if (__Pyx_PyFastCFunction_Check(function)) {
        PyObject *args[2] = {arg1, arg2};
        return __Pyx_PyCFunction_FastCall(function, args, 2);
    }
    #endif
    args = PyTuple_New(2);
    if (unlikely(!args)) goto done;
    Py_INCREF(arg1);
    PyTuple_SET_ITEM(args, 0, arg1);
    Py_INCREF(arg2);
    PyTuple_SET_ITEM(args, 1, arg2);
    Py_INCREF(function);
    result = __Pyx_PyObject_Call(function, args, NULL);
    Py_DECREF(args);
    Py_DECREF(function);
done:
    return result;
}

/* PyObjectGetMethod */
static int __Pyx_PyObject_GetMethod(PyObject *obj, PyObject *name, PyObject **method) {
    PyObject *attr;
#if CYTHON_UNPACK_METHODS && CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_PYTYPE_LOOKUP
    PyTypeObject *tp = Py_TYPE(obj);
    PyObject *descr;
    descrgetfunc f = NULL;
    PyObject **dictptr, *dict;
    int meth_found = 0;
    assert (*method == NULL);
    if (unlikely(tp->tp_getattro != PyObject_GenericGetAttr)) {
        attr = __Pyx_PyObject_GetAttrStr(obj, name);
        goto try_unpack;
    }
    if (unlikely(tp->tp_dict == NULL) && unlikely(PyType_Ready(tp) < 0)) {
        return 0;
    }
    descr = _PyType_Lookup(tp, name);
    if (likely(descr != NULL)) {
        Py_INCREF(descr);
#if PY_MAJOR_VERSION >= 3
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr) || (Py_TYPE(descr) == &PyMethodDescr_Type)))
        #endif
#else
        #ifdef __Pyx_CyFunction_USED
        if (likely(PyFunction_Check(descr) || __Pyx_CyFunction_Check(descr)))
        #else
        if (likely(PyFunction_Check(descr)))
        #endif
#endif
        {
            meth_found = 1;
        } else {
            f = Py_TYPE(descr)->tp_descr_get;
            if (f != NULL && PyDescr_IsData(descr)) {
                attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
                Py_DECREF(descr);
                goto try_unpack;
            }
        }
    }
    dictptr = _PyObject_GetDictPtr(obj);
    if (dictptr != NULL && (dict = *dictptr) != NULL) {
        Py_INCREF(dict);
        attr = __Pyx_PyDict_GetItemStr(dict, name);
        if (attr != NULL) {
            Py_INCREF(attr);
            Py_DECREF(dict);
            Py_XDECREF(descr);
            goto try_unpack;
        }
        Py_DECREF(dict);
    }
    if (meth_found) {
        *method = descr;
        return 1;
    }
    if (f != NULL) {
        attr = f(descr, obj, (PyObject *)Py_TYPE(obj));
        Py_DECREF(descr);
        goto try_unpack;
    }
    if (descr != NULL) {
        *method = descr;
        return 0;
    }
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(name));
#endif
    return 0;
#else
    attr = __Pyx_PyObject_GetAttrStr(obj, name);
    goto try_unpack;
#endif
try_unpack:
#if CYTHON_UNPACK_METHODS
    if (likely(attr) && PyMethod_Check(attr) && likely(PyMethod_GET_SELF(attr) == obj)) {
        PyObject *function = PyMethod_GET_FUNCTION(attr);
        Py_INCREF(function);
        Py_DECREF(attr);
        *method = function;
        return 1;
    }
#endif
    *method = attr;
    return 0;
}

/* PyObjectCallMethod1 */
static PyObject* __Pyx__PyObject_CallMethod1(PyObject* method, PyObject* arg) {
    PyObject *result = __Pyx_PyObject_CallOneArg(method, arg);
    Py_DECREF(method);
    return result;
}
static PyObject* __Pyx_PyObject_CallMethod1(PyObject* obj, PyObject* method_name, PyObject* arg) {
    PyObject *method = NULL, *result;
    int is_method = __Pyx_PyObject_GetMethod(obj, method_name, &method);
    if (likely(is_method)) {
        result = __Pyx_PyObject_Call2Args(method, obj, arg);
        Py_DECREF(method);
        return result;
    }
    if (unlikely(!method)) return NULL;
    return __Pyx__PyObject_CallMethod1(method, arg);
}

/* pop_index */
static PyObject* __Pyx__PyObject_PopNewIndex(PyObject* L, PyObject* py_ix) {
    PyObject *r;
    if (unlikely(!py_ix)) return NULL;
    r = __Pyx__PyObject_PopIndex(L, py_ix);
    Py_DECREF(py_ix);
    return r;
}
static PyObject* __Pyx__PyObject_PopIndex(PyObject* L, PyObject* py_ix) {
    return __Pyx_PyObject_CallMethod1(L, __pyx_n_s_pop, py_ix);
}
#if CYTHON_USE_PYLIST_INTERNALS && CYTHON_ASSUME_SAFE_MACROS
static PyObject* __Pyx__PyList_PopIndex(PyObject* L, PyObject* py_ix, Py_ssize_t ix) {
    Py_ssize_t size = PyList_GET_SIZE(L);
    if (likely(size > (((PyListObject*)L)->allocated >> 1))) {
        Py_ssize_t cix = ix;
        if (cix < 0) {
            cix += size;
        }
        if (likely(__Pyx_is_valid_index(cix, size))) {
            PyObject* v = PyList_GET_ITEM(L, cix);
            __Pyx_SET_SIZE(L, Py_SIZE(L) - 1);
            size -= 1;
            memmove(&PyList_GET_ITEM(L, cix), &PyList_GET_ITEM(L, cix+1), (size_t)(size-cix)*sizeof(PyObject*));
            return v;
        }
    }
    if (py_ix == Py_None) {
        return __Pyx__PyObject_PopNewIndex(L, PyInt_FromSsize_t(ix));
    } else {
        return __Pyx__PyObject_PopIndex(L, py_ix);
    }
}
#endif

/* PyDictVersioning */
#if CYTHON_USE_DICT_VERSIONS && CYTHON_USE_TYPE_SLOTS
static CYTHON_INLINE PY_UINT64_T __Pyx_get_tp_dict_version(PyObject *obj) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    return likely(dict) ? __PYX_GET_DICT_VERSION(dict) : 0;
}
static CYTHON_INLINE PY_UINT64_T __Pyx_get_object_dict_version(PyObject *obj) {
    PyObject **dictptr = NULL;
    Py_ssize_t offset = Py_TYPE(obj)->tp_dictoffset;
    if (offset) {
#if CYTHON_COMPILING_IN_CPYTHON
        dictptr = (likely(offset > 0)) ? (PyObject **) ((char *)obj + offset) : _PyObject_GetDictPtr(obj);
#else
        dictptr = _PyObject_GetDictPtr(obj);
#endif
    }
    return (dictptr && *dictptr) ? __PYX_GET_DICT_VERSION(*dictptr) : 0;
}
static CYTHON_INLINE int __Pyx_object_dict_version_matches(PyObject* obj, PY_UINT64_T tp_dict_version, PY_UINT64_T obj_dict_version) {
    PyObject *dict = Py_TYPE(obj)->tp_dict;
    if (unlikely(!dict) || unlikely(tp_dict_version != __PYX_GET_DICT_VERSION(dict)))
        return 0;
    return obj_dict_version == __Pyx_get_object_dict_version(obj);
}
#endif

/* PyErrFetchRestore */
#if CYTHON_FAST_THREAD_STATE
static CYTHON_INLINE void __Pyx_ErrRestoreInState(PyThreadState *tstate, PyObject *type, PyObject *value, PyObject *tb) {
    PyObject *tmp_type, *tmp_value, *tmp_tb;
    tmp_type = tstate->curexc_type;
    tmp_value = tstate->curexc_value;
    tmp_tb = tstate->curexc_traceback;
    tstate->curexc_type = type;
    tstate->curexc_value = value;
    tstate->curexc_traceback = tb;
    Py_XDECREF(tmp_type);
    Py_XDECREF(tmp_value);
    Py_XDECREF(tmp_tb);
}
static CYTHON_INLINE void __Pyx_ErrFetchInState(PyThreadState *tstate, PyObject **type, PyObject **value, PyObject **tb) {
    *type = tstate->curexc_type;
    *value = tstate->curexc_value;
    *tb = tstate->curexc_traceback;
    tstate->curexc_type = 0;
    tstate->curexc_value = 0;
    tstate->curexc_traceback = 0;
}
#endif

/* WriteUnraisableException */
static void __Pyx_WriteUnraisable(const char *name, CYTHON_UNUSED int clineno,
                                  CYTHON_UNUSED int lineno, CYTHON_UNUSED const char *filename,
                                  int full_traceback, CYTHON_UNUSED int nogil) {
    PyObject *old_exc, *old_val, *old_tb;
    PyObject *ctx;
    __Pyx_PyThreadState_declare
#ifdef WITH_THREAD
    PyGILState_STATE state;
    if (nogil)
        state = PyGILState_Ensure();
#ifdef _MSC_VER
    else state = (PyGILState_STATE)-1;
#endif
#endif
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&old_exc, &old_val, &old_tb);
    if (full_traceback) {
        Py_XINCREF(old_exc);
        Py_XINCREF(old_val);
        Py_XINCREF(old_tb);
        __Pyx_ErrRestore(old_exc, old_val, old_tb);
        PyErr_PrintEx(1);
    }
    #if PY_MAJOR_VERSION < 3
    ctx = PyString_FromString(name);
    #else
    ctx = PyUnicode_FromString(name);
    #endif
    __Pyx_ErrRestore(old_exc, old_val, old_tb);
    if (!ctx) {
        PyErr_WriteUnraisable(Py_None);
    } else {
        PyErr_WriteUnraisable(ctx);
        Py_DECREF(ctx);
    }
#ifdef WITH_THREAD
    if (nogil)
        PyGILState_Release(state);
#endif
}

/* ExtTypeTest */
static CYTHON_INLINE int __Pyx_TypeTest(PyObject *obj, PyTypeObject *type) {
    if (unlikely(!type)) {
        PyErr_SetString(PyExc_SystemError, "Missing type object");
        return 0;
    }
    if (likely(__Pyx_TypeCheck(obj, type)))
        return 1;
    PyErr_Format(PyExc_TypeError, "Cannot convert %.200s to %.200s",
                 Py_TYPE(obj)->tp_name, type->tp_name);
    return 0;
}

/* BytesEquals */
static CYTHON_INLINE int __Pyx_PyBytes_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
    if (s1 == s2) {
        return (equals == Py_EQ);
    } else if (PyBytes_CheckExact(s1) & PyBytes_CheckExact(s2)) {
        const char *ps1, *ps2;
        Py_ssize_t length = PyBytes_GET_SIZE(s1);
        if (length != PyBytes_GET_SIZE(s2))
            return (equals == Py_NE);
        ps1 = PyBytes_AS_STRING(s1);
        ps2 = PyBytes_AS_STRING(s2);
        if (ps1[0] != ps2[0]) {
            return (equals == Py_NE);
        } else if (length == 1) {
            return (equals == Py_EQ);
        } else {
            int result;
#if CYTHON_USE_UNICODE_INTERNALS
            Py_hash_t hash1, hash2;
            hash1 = ((PyBytesObject*)s1)->ob_shash;
            hash2 = ((PyBytesObject*)s2)->ob_shash;
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                return (equals == Py_NE);
            }
#endif
            result = memcmp(ps1, ps2, (size_t)length);
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & PyBytes_CheckExact(s2)) {
        return (equals == Py_NE);
    } else if ((s2 == Py_None) & PyBytes_CheckExact(s1)) {
        return (equals == Py_NE);
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
#endif
}

/* UnicodeEquals */
static CYTHON_INLINE int __Pyx_PyUnicode_Equals(PyObject* s1, PyObject* s2, int equals) {
#if CYTHON_COMPILING_IN_PYPY
    return PyObject_RichCompareBool(s1, s2, equals);
#else
#if PY_MAJOR_VERSION < 3
    PyObject* owned_ref = NULL;
#endif
    int s1_is_unicode, s2_is_unicode;
    if (s1 == s2) {
        goto return_eq;
    }
    s1_is_unicode = PyUnicode_CheckExact(s1);
    s2_is_unicode = PyUnicode_CheckExact(s2);
#if PY_MAJOR_VERSION < 3
    if ((s1_is_unicode & (!s2_is_unicode)) && PyString_CheckExact(s2)) {
        owned_ref = PyUnicode_FromObject(s2);
        if (unlikely(!owned_ref))
            return -1;
        s2 = owned_ref;
        s2_is_unicode = 1;
    } else if ((s2_is_unicode & (!s1_is_unicode)) && PyString_CheckExact(s1)) {
        owned_ref = PyUnicode_FromObject(s1);
        if (unlikely(!owned_ref))
            return -1;
        s1 = owned_ref;
        s1_is_unicode = 1;
    } else if (((!s2_is_unicode) & (!s1_is_unicode))) {
        return __Pyx_PyBytes_Equals(s1, s2, equals);
    }
#endif
    if (s1_is_unicode & s2_is_unicode) {
        Py_ssize_t length;
        int kind;
        void *data1, *data2;
        if (unlikely(__Pyx_PyUnicode_READY(s1) < 0) || unlikely(__Pyx_PyUnicode_READY(s2) < 0))
            return -1;
        length = __Pyx_PyUnicode_GET_LENGTH(s1);
        if (length != __Pyx_PyUnicode_GET_LENGTH(s2)) {
            goto return_ne;
        }
#if CYTHON_USE_UNICODE_INTERNALS
        {
            Py_hash_t hash1, hash2;
        #if CYTHON_PEP393_ENABLED
            hash1 = ((PyASCIIObject*)s1)->hash;
            hash2 = ((PyASCIIObject*)s2)->hash;
        #else
            hash1 = ((PyUnicodeObject*)s1)->hash;
            hash2 = ((PyUnicodeObject*)s2)->hash;
        #endif
            if (hash1 != hash2 && hash1 != -1 && hash2 != -1) {
                goto return_ne;
            }
        }
#endif
        kind = __Pyx_PyUnicode_KIND(s1);
        if (kind != __Pyx_PyUnicode_KIND(s2)) {
            goto return_ne;
        }
        data1 = __Pyx_PyUnicode_DATA(s1);
        data2 = __Pyx_PyUnicode_DATA(s2);
        if (__Pyx_PyUnicode_READ(kind, data1, 0) != __Pyx_PyUnicode_READ(kind, data2, 0)) {
            goto return_ne;
        } else if (length == 1) {
            goto return_eq;
        } else {
            int result = memcmp(data1, data2, (size_t)(length * kind));
            #if PY_MAJOR_VERSION < 3
            Py_XDECREF(owned_ref);
            #endif
            return (equals == Py_EQ) ? (result == 0) : (result != 0);
        }
    } else if ((s1 == Py_None) & s2_is_unicode) {
        goto return_ne;
    } else if ((s2 == Py_None) & s1_is_unicode) {
        goto return_ne;
    } else {
        int result;
        PyObject* py_result = PyObject_RichCompare(s1, s2, equals);
        #if PY_MAJOR_VERSION < 3
        Py_XDECREF(owned_ref);
        #endif
        if (!py_result)
            return -1;
        result = __Pyx_PyObject_IsTrue(py_result);
        Py_DECREF(py_result);
        return result;
    }
return_eq:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_EQ);
return_ne:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(owned_ref);
    #endif
    return (equals == Py_NE);
#endif
}

/* unicode_tailmatch */
static int __Pyx_PyUnicode_TailmatchTuple(PyObject* s, PyObject* substrings,
                                          Py_ssize_t start, Py_ssize_t end, int direction) {
    Py_ssize_t i, count = PyTuple_GET_SIZE(substrings);
    for (i = 0; i < count; i++) {
        Py_ssize_t result;
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS
        result = PyUnicode_Tailmatch(s, PyTuple_GET_ITEM(substrings, i),
                                     start, end, direction);
#else
        PyObject* sub = PySequence_ITEM(substrings, i);
        if (unlikely(!sub)) return -1;
        result = PyUnicode_Tailmatch(s, sub, start, end, direction);
        Py_DECREF(sub);
#endif
        if (result) {
            return (int) result;
        }
    }
    return 0;
}
static int __Pyx_PyUnicode_Tailmatch(PyObject* s, PyObject* substr,
                                     Py_ssize_t start, Py_ssize_t end, int direction) {
    if (unlikely(PyTuple_Check(substr))) {
        return __Pyx_PyUnicode_TailmatchTuple(s, substr, start, end, direction);
    }
    return (int) PyUnicode_Tailmatch(s, substr, start, end, direction);
}

/* PyIntBinop */
#if !CYTHON_COMPILING_IN_PYPY
static PyObject* __Pyx_PyInt_AddObjC(PyObject *op1, PyObject *op2, CYTHON_UNUSED long intval, int inplace, int zerodivision_check) {
    (void)inplace;
    (void)zerodivision_check;
    #if PY_MAJOR_VERSION < 3
    if (likely(PyInt_CheckExact(op1))) {
        const long b = intval;
        long x;
        long a = PyInt_AS_LONG(op1);
            x = (long)((unsigned long)a + b);
            if (likely((x^a) >= 0 || (x^b) >= 0))
                return PyInt_FromLong(x);
            return PyLong_Type.tp_as_number->nb_add(op1, op2);
    }
    #endif
    #if CYTHON_USE_PYLONG_INTERNALS
    if (likely(PyLong_CheckExact(op1))) {
        const long b = intval;
        long a, x;
#ifdef HAVE_LONG_LONG
        const PY_LONG_LONG llb = intval;
        PY_LONG_LONG lla, llx;
#endif
        const digit* digits = ((PyLongObject*)op1)->ob_digit;
        const Py_ssize_t size = Py_SIZE(op1);
        if (likely(__Pyx_sst_abs(size) <= 1)) {
            a = likely(size) ? digits[0] : 0;
            if (size == -1) a = -a;
        } else {
            switch (size) {
                case -2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 2:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        a = (long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 2 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 3:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        a = (long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 3 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case -4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = -(PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                case 4:
                    if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                        a = (long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0]));
                        break;
#ifdef HAVE_LONG_LONG
                    } else if (8 * sizeof(PY_LONG_LONG) - 1 > 4 * PyLong_SHIFT) {
                        lla = (PY_LONG_LONG) (((((((((unsigned PY_LONG_LONG)digits[3]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[2]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[1]) << PyLong_SHIFT) | (unsigned PY_LONG_LONG)digits[0]));
                        goto long_long;
#endif
                    }
                    CYTHON_FALLTHROUGH;
                default: return PyLong_Type.tp_as_number->nb_add(op1, op2);
            }
        }
                x = a + b;
            return PyLong_FromLong(x);
#ifdef HAVE_LONG_LONG
        long_long:
                llx = lla + llb;
            return PyLong_FromLongLong(llx);
#endif
        
        
    }
    #endif
    if (PyFloat_CheckExact(op1)) {
        const long b = intval;
        double a = PyFloat_AS_DOUBLE(op1);
            double result;
            PyFPE_START_PROTECT("add", return NULL)
            result = ((double)a) + (double)b;
            PyFPE_END_PROTECT(result)
            return PyFloat_FromDouble(result);
    }
    return (inplace ? PyNumber_InPlaceAdd : PyNumber_Add)(op1, op2);
}
#endif

/* ObjectGetItem */
#if CYTHON_USE_TYPE_SLOTS
static PyObject *__Pyx_PyObject_GetIndex(PyObject *obj, PyObject* index) {
    PyObject *runerr;
    Py_ssize_t key_value;
    PySequenceMethods *m = Py_TYPE(obj)->tp_as_sequence;
    if (unlikely(!(m && m->sq_item))) {
        PyErr_Format(PyExc_TypeError, "'%.200s' object is not subscriptable", Py_TYPE(obj)->tp_name);
        return NULL;
    }
    key_value = __Pyx_PyIndex_AsSsize_t(index);
    if (likely(key_value != -1 || !(runerr = PyErr_Occurred()))) {
        return __Pyx_GetItemInt_Fast(obj, key_value, 0, 1, 1);
    }
    if (PyErr_GivenExceptionMatches(runerr, PyExc_OverflowError)) {
        PyErr_Clear();
        PyErr_Format(PyExc_IndexError, "cannot fit '%.200s' into an index-sized integer", Py_TYPE(index)->tp_name);
    }
    return NULL;
}
static PyObject *__Pyx_PyObject_GetItem(PyObject *obj, PyObject* key) {
    PyMappingMethods *m = Py_TYPE(obj)->tp_as_mapping;
    if (likely(m && m->mp_subscript)) {
        return m->mp_subscript(obj, key);
    }
    return __Pyx_PyObject_GetIndex(obj, key);
}
#endif

/* SetItemInt */
static int __Pyx_SetItemInt_Generic(PyObject *o, PyObject *j, PyObject *v) {
    int r;
    if (!j) return -1;
    r = PyObject_SetItem(o, j, v);
    Py_DECREF(j);
    return r;
}
static CYTHON_INLINE int __Pyx_SetItemInt_Fast(PyObject *o, Py_ssize_t i, PyObject *v, int is_list,
                                               CYTHON_NCP_UNUSED int wraparound, CYTHON_NCP_UNUSED int boundscheck) {
#if CYTHON_ASSUME_SAFE_MACROS && !CYTHON_AVOID_BORROWED_REFS && CYTHON_USE_TYPE_SLOTS
    if (is_list || PyList_CheckExact(o)) {
        Py_ssize_t n = (!wraparound) ? i : ((likely(i >= 0)) ? i : i + PyList_GET_SIZE(o));
        if ((!boundscheck) || likely(__Pyx_is_valid_index(n, PyList_GET_SIZE(o)))) {
            PyObject* old = PyList_GET_ITEM(o, n);
            Py_INCREF(v);
            PyList_SET_ITEM(o, n, v);
            Py_DECREF(old);
            return 1;
        }
    } else {
        PySequenceMethods *m = Py_TYPE(o)->tp_as_sequence;
        if (likely(m && m->sq_ass_item)) {
            if (wraparound && unlikely(i < 0) && likely(m->sq_length)) {
                Py_ssize_t l = m->sq_length(o);
                if (likely(l >= 0)) {
                    i += l;
                } else {
                    if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                        return -1;
                    PyErr_Clear();
                }
            }
            return m->sq_ass_item(o, i, v);
        }
    }
#else
#if CYTHON_COMPILING_IN_PYPY
    if (is_list || (PySequence_Check(o) && !PyDict_Check(o)))
#else
    if (is_list || PySequence_Check(o))
#endif
    {
        return PySequence_SetItem(o, i, v);
    }
#endif
    return __Pyx_SetItemInt_Generic(o, PyInt_FromSsize_t(i), v);
}

/* SliceObject */
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetSlice(PyObject* obj,
        Py_ssize_t cstart, Py_ssize_t cstop,
        PyObject** _py_start, PyObject** _py_stop, PyObject** _py_slice,
        int has_cstart, int has_cstop, CYTHON_UNUSED int wraparound) {
#if CYTHON_USE_TYPE_SLOTS
    PyMappingMethods* mp;
#if PY_MAJOR_VERSION < 3
    PySequenceMethods* ms = Py_TYPE(obj)->tp_as_sequence;
    if (likely(ms && ms->sq_slice)) {
        if (!has_cstart) {
            if (_py_start && (*_py_start != Py_None)) {
                cstart = __Pyx_PyIndex_AsSsize_t(*_py_start);
                if ((cstart == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstart = 0;
        }
        if (!has_cstop) {
            if (_py_stop && (*_py_stop != Py_None)) {
                cstop = __Pyx_PyIndex_AsSsize_t(*_py_stop);
                if ((cstop == (Py_ssize_t)-1) && PyErr_Occurred()) goto bad;
            } else
                cstop = PY_SSIZE_T_MAX;
        }
        if (wraparound && unlikely((cstart < 0) | (cstop < 0)) && likely(ms->sq_length)) {
            Py_ssize_t l = ms->sq_length(obj);
            if (likely(l >= 0)) {
                if (cstop < 0) {
                    cstop += l;
                    if (cstop < 0) cstop = 0;
                }
                if (cstart < 0) {
                    cstart += l;
                    if (cstart < 0) cstart = 0;
                }
            } else {
                if (!PyErr_ExceptionMatches(PyExc_OverflowError))
                    goto bad;
                PyErr_Clear();
            }
        }
        return ms->sq_slice(obj, cstart, cstop);
    }
#endif
    mp = Py_TYPE(obj)->tp_as_mapping;
    if (likely(mp && mp->mp_subscript))
#endif
    {
        PyObject* result;
        PyObject *py_slice, *py_start, *py_stop;
        if (_py_slice) {
            py_slice = *_py_slice;
        } else {
            PyObject* owned_start = NULL;
            PyObject* owned_stop = NULL;
            if (_py_start) {
                py_start = *_py_start;
            } else {
                if (has_cstart) {
                    owned_start = py_start = PyInt_FromSsize_t(cstart);
                    if (unlikely(!py_start)) goto bad;
                } else
                    py_start = Py_None;
            }
            if (_py_stop) {
                py_stop = *_py_stop;
            } else {
                if (has_cstop) {
                    owned_stop = py_stop = PyInt_FromSsize_t(cstop);
                    if (unlikely(!py_stop)) {
                        Py_XDECREF(owned_start);
                        goto bad;
                    }
                } else
                    py_stop = Py_None;
            }
            py_slice = PySlice_New(py_start, py_stop, Py_None);
            Py_XDECREF(owned_start);
            Py_XDECREF(owned_stop);
            if (unlikely(!py_slice)) goto bad;
        }
#if CYTHON_USE_TYPE_SLOTS
        result = mp->mp_subscript(obj, py_slice);
#else
        result = PyObject_GetItem(obj, py_slice);
#endif
        if (!_py_slice) {
            Py_DECREF(py_slice);
        }
        return result;
    }
    PyErr_Format(PyExc_TypeError,
        "'%.200s' object is unsliceable", Py_TYPE(obj)->tp_name);
bad:
    return NULL;
}

/* PyErrExceptionMatches */
#if CYTHON_FAST_THREAD_STATE
static int __Pyx_PyErr_ExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        if (__Pyx_PyErr_GivenExceptionMatches(exc_type, PyTuple_GET_ITEM(tuple, i))) return 1;
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_ExceptionMatchesInState(PyThreadState* tstate, PyObject* err) {
    PyObject *exc_type = tstate->curexc_type;
    if (exc_type == err) return 1;
    if (unlikely(!exc_type)) return 0;
    if (unlikely(PyTuple_Check(err)))
        return __Pyx_PyErr_ExceptionMatchesTuple(exc_type, err);
    return __Pyx_PyErr_GivenExceptionMatches(exc_type, err);
}
#endif

/* GetAttr */
static CYTHON_INLINE PyObject *__Pyx_GetAttr(PyObject *o, PyObject *n) {
#if CYTHON_USE_TYPE_SLOTS
#if PY_MAJOR_VERSION >= 3
    if (likely(PyUnicode_Check(n)))
#else
    if (likely(PyString_Check(n)))
#endif
        return __Pyx_PyObject_GetAttrStr(o, n);
#endif
    return PyObject_GetAttr(o, n);
}

/* GetAttr3 */
static PyObject *__Pyx_GetAttr3Default(PyObject *d) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (unlikely(!__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        return NULL;
    __Pyx_PyErr_Clear();
    Py_INCREF(d);
    return d;
}
static CYTHON_INLINE PyObject *__Pyx_GetAttr3(PyObject *o, PyObject *n, PyObject *d) {
    PyObject *r = __Pyx_GetAttr(o, n);
    return (likely(r)) ? r : __Pyx_GetAttr3Default(d);
}

/* GetModuleGlobalName */
#if CYTHON_USE_DICT_VERSIONS
static PyObject *__Pyx__GetModuleGlobalName(PyObject *name, PY_UINT64_T *dict_version, PyObject **dict_cached_value)
#else
static CYTHON_INLINE PyObject *__Pyx__GetModuleGlobalName(PyObject *name)
#endif
{
    PyObject *result;
#if !CYTHON_AVOID_BORROWED_REFS
#if CYTHON_COMPILING_IN_CPYTHON && PY_VERSION_HEX >= 0x030500A1
    result = _PyDict_GetItem_KnownHash(__pyx_d, name, ((PyASCIIObject *) name)->hash);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    } else if (unlikely(PyErr_Occurred())) {
        return NULL;
    }
#else
    result = PyDict_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
#endif
#else
    result = PyObject_GetItem(__pyx_d, name);
    __PYX_UPDATE_DICT_CACHE(__pyx_d, result, *dict_cached_value, *dict_version)
    if (likely(result)) {
        return __Pyx_NewRef(result);
    }
    PyErr_Clear();
#endif
    return __Pyx_GetBuiltinName(name);
}

/* Import */
static PyObject *__Pyx_Import(PyObject *name, PyObject *from_list, int level) {
    PyObject *empty_list = 0;
    PyObject *module = 0;
    PyObject *global_dict = 0;
    PyObject *empty_dict = 0;
    PyObject *list;
    #if PY_MAJOR_VERSION < 3
    PyObject *py_import;
    py_import = __Pyx_PyObject_GetAttrStr(__pyx_b, __pyx_n_s_import);
    if (!py_import)
        goto bad;
    #endif
    if (from_list)
        list = from_list;
    else {
        empty_list = PyList_New(0);
        if (!empty_list)
            goto bad;
        list = empty_list;
    }
    global_dict = PyModule_GetDict(__pyx_m);
    if (!global_dict)
        goto bad;
    empty_dict = PyDict_New();
    if (!empty_dict)
        goto bad;
    {
        #if PY_MAJOR_VERSION >= 3
        if (level == -1) {
            if ((1) && (strchr(__Pyx_MODULE_NAME, '.'))) {
                module = PyImport_ImportModuleLevelObject(
                    name, global_dict, empty_dict, list, 1);
                if (!module) {
                    if (!PyErr_ExceptionMatches(PyExc_ImportError))
                        goto bad;
                    PyErr_Clear();
                }
            }
            level = 0;
        }
        #endif
        if (!module) {
            #if PY_MAJOR_VERSION < 3
            PyObject *py_level = PyInt_FromLong(level);
            if (!py_level)
                goto bad;
            module = PyObject_CallFunctionObjArgs(py_import,
                name, global_dict, empty_dict, list, py_level, (PyObject *)NULL);
            Py_DECREF(py_level);
            #else
            module = PyImport_ImportModuleLevelObject(
                name, global_dict, empty_dict, list, level);
            #endif
        }
    }
bad:
    #if PY_MAJOR_VERSION < 3
    Py_XDECREF(py_import);
    #endif
    Py_XDECREF(empty_list);
    Py_XDECREF(empty_dict);
    return module;
}

/* ImportFrom */
static PyObject* __Pyx_ImportFrom(PyObject* module, PyObject* name) {
    PyObject* value = __Pyx_PyObject_GetAttrStr(module, name);
    if (unlikely(!value) && PyErr_ExceptionMatches(PyExc_AttributeError)) {
        PyErr_Format(PyExc_ImportError,
        #if PY_MAJOR_VERSION < 3
            "cannot import name %.230s", PyString_AS_STRING(name));
        #else
            "cannot import name %S", name);
        #endif
    }
    return value;
}

/* RaiseException */
#if PY_MAJOR_VERSION < 3
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb,
                        CYTHON_UNUSED PyObject *cause) {
    __Pyx_PyThreadState_declare
    Py_XINCREF(type);
    if (!value || value == Py_None)
        value = NULL;
    else
        Py_INCREF(value);
    if (!tb || tb == Py_None)
        tb = NULL;
    else {
        Py_INCREF(tb);
        if (!PyTraceBack_Check(tb)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: arg 3 must be a traceback or None");
            goto raise_error;
        }
    }
    if (PyType_Check(type)) {
#if CYTHON_COMPILING_IN_PYPY
        if (!value) {
            Py_INCREF(Py_None);
            value = Py_None;
        }
#endif
        PyErr_NormalizeException(&type, &value, &tb);
    } else {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto raise_error;
        }
        value = type;
        type = (PyObject*) Py_TYPE(type);
        Py_INCREF(type);
        if (!PyType_IsSubtype((PyTypeObject *)type, (PyTypeObject *)PyExc_BaseException)) {
            PyErr_SetString(PyExc_TypeError,
                "raise: exception class must be a subclass of BaseException");
            goto raise_error;
        }
    }
    __Pyx_PyThreadState_assign
    __Pyx_ErrRestore(type, value, tb);
    return;
raise_error:
    Py_XDECREF(value);
    Py_XDECREF(type);
    Py_XDECREF(tb);
    return;
}
#else
static void __Pyx_Raise(PyObject *type, PyObject *value, PyObject *tb, PyObject *cause) {
    PyObject* owned_instance = NULL;
    if (tb == Py_None) {
        tb = 0;
    } else if (tb && !PyTraceBack_Check(tb)) {
        PyErr_SetString(PyExc_TypeError,
            "raise: arg 3 must be a traceback or None");
        goto bad;
    }
    if (value == Py_None)
        value = 0;
    if (PyExceptionInstance_Check(type)) {
        if (value) {
            PyErr_SetString(PyExc_TypeError,
                "instance exception may not have a separate value");
            goto bad;
        }
        value = type;
        type = (PyObject*) Py_TYPE(value);
    } else if (PyExceptionClass_Check(type)) {
        PyObject *instance_class = NULL;
        if (value && PyExceptionInstance_Check(value)) {
            instance_class = (PyObject*) Py_TYPE(value);
            if (instance_class != type) {
                int is_subclass = PyObject_IsSubclass(instance_class, type);
                if (!is_subclass) {
                    instance_class = NULL;
                } else if (unlikely(is_subclass == -1)) {
                    goto bad;
                } else {
                    type = instance_class;
                }
            }
        }
        if (!instance_class) {
            PyObject *args;
            if (!value)
                args = PyTuple_New(0);
            else if (PyTuple_Check(value)) {
                Py_INCREF(value);
                args = value;
            } else
                args = PyTuple_Pack(1, value);
            if (!args)
                goto bad;
            owned_instance = PyObject_Call(type, args, NULL);
            Py_DECREF(args);
            if (!owned_instance)
                goto bad;
            value = owned_instance;
            if (!PyExceptionInstance_Check(value)) {
                PyErr_Format(PyExc_TypeError,
                             "calling %R should have returned an instance of "
                             "BaseException, not %R",
                             type, Py_TYPE(value));
                goto bad;
            }
        }
    } else {
        PyErr_SetString(PyExc_TypeError,
            "raise: exception class must be a subclass of BaseException");
        goto bad;
    }
    if (cause) {
        PyObject *fixed_cause;
        if (cause == Py_None) {
            fixed_cause = NULL;
        } else if (PyExceptionClass_Check(cause)) {
            fixed_cause = PyObject_CallObject(cause, NULL);
            if (fixed_cause == NULL)
                goto bad;
        } else if (PyExceptionInstance_Check(cause)) {
            fixed_cause = cause;
            Py_INCREF(fixed_cause);
        } else {
            PyErr_SetString(PyExc_TypeError,
                            "exception causes must derive from "
                            "BaseException");
            goto bad;
        }
        PyException_SetCause(value, fixed_cause);
    }
    PyErr_SetObject(type, value);
    if (tb) {
#if CYTHON_COMPILING_IN_PYPY
        PyObject *tmp_type, *tmp_value, *tmp_tb;
        PyErr_Fetch(&tmp_type, &tmp_value, &tmp_tb);
        Py_INCREF(tb);
        PyErr_Restore(tmp_type, tmp_value, tb);
        Py_XDECREF(tmp_tb);
#else
        PyThreadState *tstate = __Pyx_PyThreadState_Current;
        PyObject* tmp_tb = tstate->curexc_traceback;
        if (tb != tmp_tb) {
            Py_INCREF(tb);
            tstate->curexc_traceback = tb;
            Py_XDECREF(tmp_tb);
        }
#endif
    }
bad:
    Py_XDECREF(owned_instance);
    return;
}
#endif

/* HasAttr */
static CYTHON_INLINE int __Pyx_HasAttr(PyObject *o, PyObject *n) {
    PyObject *r;
    if (unlikely(!__Pyx_PyBaseString_Check(n))) {
        PyErr_SetString(PyExc_TypeError,
                        "hasattr(): attribute name must be string");
        return -1;
    }
    r = __Pyx_GetAttr(o, n);
    if (unlikely(!r)) {
        PyErr_Clear();
        return 0;
    } else {
        Py_DECREF(r);
        return 1;
    }
}

/* PyObject_GenericGetAttrNoDict */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject *__Pyx_RaiseGenericGetAttributeError(PyTypeObject *tp, PyObject *attr_name) {
    PyErr_Format(PyExc_AttributeError,
#if PY_MAJOR_VERSION >= 3
                 "'%.50s' object has no attribute '%U'",
                 tp->tp_name, attr_name);
#else
                 "'%.50s' object has no attribute '%.400s'",
                 tp->tp_name, PyString_AS_STRING(attr_name));
#endif
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GenericGetAttrNoDict(PyObject* obj, PyObject* attr_name) {
    PyObject *descr;
    PyTypeObject *tp = Py_TYPE(obj);
    if (unlikely(!PyString_Check(attr_name))) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    assert(!tp->tp_dictoffset);
    descr = _PyType_Lookup(tp, attr_name);
    if (unlikely(!descr)) {
        return __Pyx_RaiseGenericGetAttributeError(tp, attr_name);
    }
    Py_INCREF(descr);
    #if PY_MAJOR_VERSION < 3
    if (likely(PyType_HasFeature(Py_TYPE(descr), Py_TPFLAGS_HAVE_CLASS)))
    #endif
    {
        descrgetfunc f = Py_TYPE(descr)->tp_descr_get;
        if (unlikely(f)) {
            PyObject *res = f(descr, obj, (PyObject *)tp);
            Py_DECREF(descr);
            return res;
        }
    }
    return descr;
}
#endif

/* PyObject_GenericGetAttr */
#if CYTHON_USE_TYPE_SLOTS && CYTHON_USE_PYTYPE_LOOKUP && PY_VERSION_HEX < 0x03070000
static PyObject* __Pyx_PyObject_GenericGetAttr(PyObject* obj, PyObject* attr_name) {
    if (unlikely(Py_TYPE(obj)->tp_dictoffset)) {
        return PyObject_GenericGetAttr(obj, attr_name);
    }
    return __Pyx_PyObject_GenericGetAttrNoDict(obj, attr_name);
}
#endif

/* SetVTable */
static int __Pyx_SetVtable(PyObject *dict, void *vtable) {
#if PY_VERSION_HEX >= 0x02070000
    PyObject *ob = PyCapsule_New(vtable, 0, 0);
#else
    PyObject *ob = PyCObject_FromVoidPtr(vtable, 0);
#endif
    if (!ob)
        goto bad;
    if (PyDict_SetItem(dict, __pyx_n_s_pyx_vtable, ob) < 0)
        goto bad;
    Py_DECREF(ob);
    return 0;
bad:
    Py_XDECREF(ob);
    return -1;
}

/* PyObjectGetAttrStrNoError */
static void __Pyx_PyObject_GetAttrStr_ClearAttributeError(void) {
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    if (likely(__Pyx_PyErr_ExceptionMatches(PyExc_AttributeError)))
        __Pyx_PyErr_Clear();
}
static CYTHON_INLINE PyObject* __Pyx_PyObject_GetAttrStrNoError(PyObject* obj, PyObject* attr_name) {
    PyObject *result;
#if CYTHON_COMPILING_IN_CPYTHON && CYTHON_USE_TYPE_SLOTS && PY_VERSION_HEX >= 0x030700B1
    PyTypeObject* tp = Py_TYPE(obj);
    if (likely(tp->tp_getattro == PyObject_GenericGetAttr)) {
        return _PyObject_GenericGetAttrWithDict(obj, attr_name, NULL, 1);
    }
#endif
    result = __Pyx_PyObject_GetAttrStr(obj, attr_name);
    if (unlikely(!result)) {
        __Pyx_PyObject_GetAttrStr_ClearAttributeError();
    }
    return result;
}

/* SetupReduce */
static int __Pyx_setup_reduce_is_named(PyObject* meth, PyObject* name) {
  int ret;
  PyObject *name_attr;
  name_attr = __Pyx_PyObject_GetAttrStr(meth, __pyx_n_s_name);
  if (likely(name_attr)) {
      ret = PyObject_RichCompareBool(name_attr, name, Py_EQ);
  } else {
      ret = -1;
  }
  if (unlikely(ret < 0)) {
      PyErr_Clear();
      ret = 0;
  }
  Py_XDECREF(name_attr);
  return ret;
}
static int __Pyx_setup_reduce(PyObject* type_obj) {
    int ret = 0;
    PyObject *object_reduce = NULL;
    PyObject *object_reduce_ex = NULL;
    PyObject *reduce = NULL;
    PyObject *reduce_ex = NULL;
    PyObject *reduce_cython = NULL;
    PyObject *setstate = NULL;
    PyObject *setstate_cython = NULL;
#if CYTHON_USE_PYTYPE_LOOKUP
    if (_PyType_Lookup((PyTypeObject*)type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#else
    if (PyObject_HasAttr(type_obj, __pyx_n_s_getstate)) goto __PYX_GOOD;
#endif
#if CYTHON_USE_PYTYPE_LOOKUP
    object_reduce_ex = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#else
    object_reduce_ex = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce_ex); if (!object_reduce_ex) goto __PYX_BAD;
#endif
    reduce_ex = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce_ex); if (unlikely(!reduce_ex)) goto __PYX_BAD;
    if (reduce_ex == object_reduce_ex) {
#if CYTHON_USE_PYTYPE_LOOKUP
        object_reduce = _PyType_Lookup(&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#else
        object_reduce = __Pyx_PyObject_GetAttrStr((PyObject*)&PyBaseObject_Type, __pyx_n_s_reduce); if (!object_reduce) goto __PYX_BAD;
#endif
        reduce = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_reduce); if (unlikely(!reduce)) goto __PYX_BAD;
        if (reduce == object_reduce || __Pyx_setup_reduce_is_named(reduce, __pyx_n_s_reduce_cython)) {
            reduce_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_reduce_cython);
            if (likely(reduce_cython)) {
                ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce, reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_reduce_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
            } else if (reduce == object_reduce || PyErr_Occurred()) {
                goto __PYX_BAD;
            }
            setstate = __Pyx_PyObject_GetAttrStr(type_obj, __pyx_n_s_setstate);
            if (!setstate) PyErr_Clear();
            if (!setstate || __Pyx_setup_reduce_is_named(setstate, __pyx_n_s_setstate_cython)) {
                setstate_cython = __Pyx_PyObject_GetAttrStrNoError(type_obj, __pyx_n_s_setstate_cython);
                if (likely(setstate_cython)) {
                    ret = PyDict_SetItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate, setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                    ret = PyDict_DelItem(((PyTypeObject*)type_obj)->tp_dict, __pyx_n_s_setstate_cython); if (unlikely(ret < 0)) goto __PYX_BAD;
                } else if (!setstate || PyErr_Occurred()) {
                    goto __PYX_BAD;
                }
            }
            PyType_Modified((PyTypeObject*)type_obj);
        }
    }
    goto __PYX_GOOD;
__PYX_BAD:
    if (!PyErr_Occurred())
        PyErr_Format(PyExc_RuntimeError, "Unable to initialize pickling for %s", ((PyTypeObject*)type_obj)->tp_name);
    ret = -1;
__PYX_GOOD:
#if !CYTHON_USE_PYTYPE_LOOKUP
    Py_XDECREF(object_reduce);
    Py_XDECREF(object_reduce_ex);
#endif
    Py_XDECREF(reduce);
    Py_XDECREF(reduce_ex);
    Py_XDECREF(reduce_cython);
    Py_XDECREF(setstate);
    Py_XDECREF(setstate_cython);
    return ret;
}

/* TypeImport */
#ifndef __PYX_HAVE_RT_ImportType
#define __PYX_HAVE_RT_ImportType
static PyTypeObject *__Pyx_ImportType(PyObject *module, const char *module_name, const char *class_name,
    size_t size, enum __Pyx_ImportType_CheckSize check_size)
{
    PyObject *result = 0;
    char warning[200];
    Py_ssize_t basicsize;
#ifdef Py_LIMITED_API
    PyObject *py_basicsize;
#endif
    result = PyObject_GetAttrString(module, class_name);
    if (!result)
        goto bad;
    if (!PyType_Check(result)) {
        PyErr_Format(PyExc_TypeError,
            "%.200s.%.200s is not a type object",
            module_name, class_name);
        goto bad;
    }
#ifndef Py_LIMITED_API
    basicsize = ((PyTypeObject *)result)->tp_basicsize;
#else
    py_basicsize = PyObject_GetAttrString(result, "__basicsize__");
    if (!py_basicsize)
        goto bad;
    basicsize = PyLong_AsSsize_t(py_basicsize);
    Py_DECREF(py_basicsize);
    py_basicsize = 0;
    if (basicsize == (Py_ssize_t)-1 && PyErr_Occurred())
        goto bad;
#endif
    if ((size_t)basicsize < size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    if (check_size == __Pyx_ImportType_CheckSize_Error && (size_t)basicsize != size) {
        PyErr_Format(PyExc_ValueError,
            "%.200s.%.200s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        goto bad;
    }
    else if (check_size == __Pyx_ImportType_CheckSize_Warn && (size_t)basicsize > size) {
        PyOS_snprintf(warning, sizeof(warning),
            "%s.%s size changed, may indicate binary incompatibility. "
            "Expected %zd from C header, got %zd from PyObject",
            module_name, class_name, size, basicsize);
        if (PyErr_WarnEx(NULL, warning, 0) < 0) goto bad;
    }
    return (PyTypeObject *)result;
bad:
    Py_XDECREF(result);
    return NULL;
}
#endif

/* GetVTable */
static void* __Pyx_GetVtable(PyObject *dict) {
    void* ptr;
    PyObject *ob = PyObject_GetItem(dict, __pyx_n_s_pyx_vtable);
    if (!ob)
        goto bad;
#if PY_VERSION_HEX >= 0x02070000
    ptr = PyCapsule_GetPointer(ob, 0);
#else
    ptr = PyCObject_AsVoidPtr(ob);
#endif
    if (!ptr && !PyErr_Occurred())
        PyErr_SetString(PyExc_RuntimeError, "invalid vtable found for imported type");
    Py_DECREF(ob);
    return ptr;
bad:
    Py_XDECREF(ob);
    return NULL;
}

/* CLineInTraceback */
#ifndef CYTHON_CLINE_IN_TRACEBACK
static int __Pyx_CLineForTraceback(CYTHON_NCP_UNUSED PyThreadState *tstate, int c_line) {
    PyObject *use_cline;
    PyObject *ptype, *pvalue, *ptraceback;
#if CYTHON_COMPILING_IN_CPYTHON
    PyObject **cython_runtime_dict;
#endif
    if (unlikely(!__pyx_cython_runtime)) {
        return c_line;
    }
    __Pyx_ErrFetchInState(tstate, &ptype, &pvalue, &ptraceback);
#if CYTHON_COMPILING_IN_CPYTHON
    cython_runtime_dict = _PyObject_GetDictPtr(__pyx_cython_runtime);
    if (likely(cython_runtime_dict)) {
        __PYX_PY_DICT_LOOKUP_IF_MODIFIED(
            use_cline, *cython_runtime_dict,
            __Pyx_PyDict_GetItemStr(*cython_runtime_dict, __pyx_n_s_cline_in_traceback))
    } else
#endif
    {
      PyObject *use_cline_obj = __Pyx_PyObject_GetAttrStr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback);
      if (use_cline_obj) {
        use_cline = PyObject_Not(use_cline_obj) ? Py_False : Py_True;
        Py_DECREF(use_cline_obj);
      } else {
        PyErr_Clear();
        use_cline = NULL;
      }
    }
    if (!use_cline) {
        c_line = 0;
        PyObject_SetAttr(__pyx_cython_runtime, __pyx_n_s_cline_in_traceback, Py_False);
    }
    else if (use_cline == Py_False || (use_cline != Py_True && PyObject_Not(use_cline) != 0)) {
        c_line = 0;
    }
    __Pyx_ErrRestoreInState(tstate, ptype, pvalue, ptraceback);
    return c_line;
}
#endif

/* CodeObjectCache */
static int __pyx_bisect_code_objects(__Pyx_CodeObjectCacheEntry* entries, int count, int code_line) {
    int start = 0, mid = 0, end = count - 1;
    if (end >= 0 && code_line > entries[end].code_line) {
        return count;
    }
    while (start < end) {
        mid = start + (end - start) / 2;
        if (code_line < entries[mid].code_line) {
            end = mid;
        } else if (code_line > entries[mid].code_line) {
             start = mid + 1;
        } else {
            return mid;
        }
    }
    if (code_line <= entries[mid].code_line) {
        return mid;
    } else {
        return mid + 1;
    }
}
static PyCodeObject *__pyx_find_code_object(int code_line) {
    PyCodeObject* code_object;
    int pos;
    if (unlikely(!code_line) || unlikely(!__pyx_code_cache.entries)) {
        return NULL;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if (unlikely(pos >= __pyx_code_cache.count) || unlikely(__pyx_code_cache.entries[pos].code_line != code_line)) {
        return NULL;
    }
    code_object = __pyx_code_cache.entries[pos].code_object;
    Py_INCREF(code_object);
    return code_object;
}
static void __pyx_insert_code_object(int code_line, PyCodeObject* code_object) {
    int pos, i;
    __Pyx_CodeObjectCacheEntry* entries = __pyx_code_cache.entries;
    if (unlikely(!code_line)) {
        return;
    }
    if (unlikely(!entries)) {
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Malloc(64*sizeof(__Pyx_CodeObjectCacheEntry));
        if (likely(entries)) {
            __pyx_code_cache.entries = entries;
            __pyx_code_cache.max_count = 64;
            __pyx_code_cache.count = 1;
            entries[0].code_line = code_line;
            entries[0].code_object = code_object;
            Py_INCREF(code_object);
        }
        return;
    }
    pos = __pyx_bisect_code_objects(__pyx_code_cache.entries, __pyx_code_cache.count, code_line);
    if ((pos < __pyx_code_cache.count) && unlikely(__pyx_code_cache.entries[pos].code_line == code_line)) {
        PyCodeObject* tmp = entries[pos].code_object;
        entries[pos].code_object = code_object;
        Py_DECREF(tmp);
        return;
    }
    if (__pyx_code_cache.count == __pyx_code_cache.max_count) {
        int new_max = __pyx_code_cache.max_count + 64;
        entries = (__Pyx_CodeObjectCacheEntry*)PyMem_Realloc(
            __pyx_code_cache.entries, ((size_t)new_max) * sizeof(__Pyx_CodeObjectCacheEntry));
        if (unlikely(!entries)) {
            return;
        }
        __pyx_code_cache.entries = entries;
        __pyx_code_cache.max_count = new_max;
    }
    for (i=__pyx_code_cache.count; i>pos; i--) {
        entries[i] = entries[i-1];
    }
    entries[pos].code_line = code_line;
    entries[pos].code_object = code_object;
    __pyx_code_cache.count++;
    Py_INCREF(code_object);
}

/* AddTraceback */
#include "compile.h"
#include "frameobject.h"
#include "traceback.h"
static PyCodeObject* __Pyx_CreateCodeObjectForTraceback(
            const char *funcname, int c_line,
            int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyObject *py_srcfile = 0;
    PyObject *py_funcname = 0;
    #if PY_MAJOR_VERSION < 3
    py_srcfile = PyString_FromString(filename);
    #else
    py_srcfile = PyUnicode_FromString(filename);
    #endif
    if (!py_srcfile) goto bad;
    if (c_line) {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #else
        py_funcname = PyUnicode_FromFormat( "%s (%s:%d)", funcname, __pyx_cfilenm, c_line);
        #endif
    }
    else {
        #if PY_MAJOR_VERSION < 3
        py_funcname = PyString_FromString(funcname);
        #else
        py_funcname = PyUnicode_FromString(funcname);
        #endif
    }
    if (!py_funcname) goto bad;
    py_code = __Pyx_PyCode_New(
        0,
        0,
        0,
        0,
        0,
        __pyx_empty_bytes, /*PyObject *code,*/
        __pyx_empty_tuple, /*PyObject *consts,*/
        __pyx_empty_tuple, /*PyObject *names,*/
        __pyx_empty_tuple, /*PyObject *varnames,*/
        __pyx_empty_tuple, /*PyObject *freevars,*/
        __pyx_empty_tuple, /*PyObject *cellvars,*/
        py_srcfile,   /*PyObject *filename,*/
        py_funcname,  /*PyObject *name,*/
        py_line,
        __pyx_empty_bytes  /*PyObject *lnotab*/
    );
    Py_DECREF(py_srcfile);
    Py_DECREF(py_funcname);
    return py_code;
bad:
    Py_XDECREF(py_srcfile);
    Py_XDECREF(py_funcname);
    return NULL;
}
static void __Pyx_AddTraceback(const char *funcname, int c_line,
                               int py_line, const char *filename) {
    PyCodeObject *py_code = 0;
    PyFrameObject *py_frame = 0;
    PyThreadState *tstate = __Pyx_PyThreadState_Current;
    if (c_line) {
        c_line = __Pyx_CLineForTraceback(tstate, c_line);
    }
    py_code = __pyx_find_code_object(c_line ? -c_line : py_line);
    if (!py_code) {
        py_code = __Pyx_CreateCodeObjectForTraceback(
            funcname, c_line, py_line, filename);
        if (!py_code) goto bad;
        __pyx_insert_code_object(c_line ? -c_line : py_line, py_code);
    }
    py_frame = PyFrame_New(
        tstate,            /*PyThreadState *tstate,*/
        py_code,           /*PyCodeObject *code,*/
        __pyx_d,    /*PyObject *globals,*/
        0                  /*PyObject *locals*/
    );
    if (!py_frame) goto bad;
    __Pyx_PyFrame_SetLineNumber(py_frame, py_line);
    PyTraceBack_Here(py_frame);
bad:
    Py_XDECREF(py_code);
    Py_XDECREF(py_frame);
}

/* CIntFromPyVerify */
#define __PYX_VERIFY_RETURN_INT(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 0)
#define __PYX_VERIFY_RETURN_INT_EXC(target_type, func_type, func_value)\
    __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, 1)
#define __PYX__VERIFY_RETURN_INT(target_type, func_type, func_value, exc)\
    {\
        func_type value = func_value;\
        if (sizeof(target_type) < sizeof(func_type)) {\
            if (unlikely(value != (func_type) (target_type) value)) {\
                func_type zero = 0;\
                if (exc && unlikely(value == (func_type)-1 && PyErr_Occurred()))\
                    return (target_type) -1;\
                if (is_unsigned && unlikely(value < zero))\
                    goto raise_neg_overflow;\
                else\
                    goto raise_overflow;\
            }\
        }\
        return (target_type) value;\
    }

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_int(int value) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(int) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(int) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(int) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(int),
                                     little, !is_unsigned);
    }
}

/* CIntToPy */
static CYTHON_INLINE PyObject* __Pyx_PyInt_From_long(long value) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
    if (is_unsigned) {
        if (sizeof(long) < sizeof(long)) {
            return PyInt_FromLong((long) value);
        } else if (sizeof(long) <= sizeof(unsigned long)) {
            return PyLong_FromUnsignedLong((unsigned long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
            return PyLong_FromUnsignedLongLong((unsigned PY_LONG_LONG) value);
#endif
        }
    } else {
        if (sizeof(long) <= sizeof(long)) {
            return PyInt_FromLong((long) value);
#ifdef HAVE_LONG_LONG
        } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
            return PyLong_FromLongLong((PY_LONG_LONG) value);
#endif
        }
    }
    {
        int one = 1; int little = (int)*(unsigned char *)&one;
        unsigned char *bytes = (unsigned char *)&value;
        return _PyLong_FromByteArray(bytes, sizeof(long),
                                     little, !is_unsigned);
    }
}

/* CIntFromPy */
static CYTHON_INLINE int __Pyx_PyInt_As_int(PyObject *x) {
    const int neg_one = (int) ((int) 0 - (int) 1), const_zero = (int) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(int) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(int, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (int) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case  1: __PYX_VERIFY_RETURN_INT(int, digit, digits[0])
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 2 * PyLong_SHIFT) {
                            return (int) (((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 3 * PyLong_SHIFT) {
                            return (int) (((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) >= 4 * PyLong_SHIFT) {
                            return (int) (((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (int) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(int) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (int) 0;
                case -1: __PYX_VERIFY_RETURN_INT(int, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(int,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(int) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(int) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                            return (int) ((((((int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(int) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(int) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                            return (int) ((((((((int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(int) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) (((int)-1)*(((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(int) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(int, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(int) - 1 > 4 * PyLong_SHIFT) {
                            return (int) ((((((((((int)digits[3]) << PyLong_SHIFT) | (int)digits[2]) << PyLong_SHIFT) | (int)digits[1]) << PyLong_SHIFT) | (int)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(int) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(int) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(int, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            int val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (int) -1;
        }
    } else {
        int val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (int) -1;
        val = __Pyx_PyInt_As_int(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to int");
    return (int) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to int");
    return (int) -1;
}

/* CIntFromPy */
static CYTHON_INLINE long __Pyx_PyInt_As_long(PyObject *x) {
    const long neg_one = (long) ((long) 0 - (long) 1), const_zero = (long) 0;
    const int is_unsigned = neg_one > const_zero;
#if PY_MAJOR_VERSION < 3
    if (likely(PyInt_Check(x))) {
        if (sizeof(long) < sizeof(long)) {
            __PYX_VERIFY_RETURN_INT(long, long, PyInt_AS_LONG(x))
        } else {
            long val = PyInt_AS_LONG(x);
            if (is_unsigned && unlikely(val < 0)) {
                goto raise_neg_overflow;
            }
            return (long) val;
        }
    } else
#endif
    if (likely(PyLong_Check(x))) {
        if (is_unsigned) {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case  1: __PYX_VERIFY_RETURN_INT(long, digit, digits[0])
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 2 * PyLong_SHIFT) {
                            return (long) (((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 3 * PyLong_SHIFT) {
                            return (long) (((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) >= 4 * PyLong_SHIFT) {
                            return (long) (((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0]));
                        }
                    }
                    break;
            }
#endif
#if CYTHON_COMPILING_IN_CPYTHON
            if (unlikely(Py_SIZE(x) < 0)) {
                goto raise_neg_overflow;
            }
#else
            {
                int result = PyObject_RichCompareBool(x, Py_False, Py_LT);
                if (unlikely(result < 0))
                    return (long) -1;
                if (unlikely(result == 1))
                    goto raise_neg_overflow;
            }
#endif
            if (sizeof(long) <= sizeof(unsigned long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned long, PyLong_AsUnsignedLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(unsigned PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, unsigned PY_LONG_LONG, PyLong_AsUnsignedLongLong(x))
#endif
            }
        } else {
#if CYTHON_USE_PYLONG_INTERNALS
            const digit* digits = ((PyLongObject*)x)->ob_digit;
            switch (Py_SIZE(x)) {
                case  0: return (long) 0;
                case -1: __PYX_VERIFY_RETURN_INT(long, sdigit, (sdigit) (-(sdigit)digits[0]))
                case  1: __PYX_VERIFY_RETURN_INT(long,  digit, +digits[0])
                case -2:
                    if (8 * sizeof(long) - 1 > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 2:
                    if (8 * sizeof(long) > 1 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 2 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                            return (long) ((((((long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -3:
                    if (8 * sizeof(long) - 1 > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 3:
                    if (8 * sizeof(long) > 2 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 3 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                            return (long) ((((((((long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case -4:
                    if (8 * sizeof(long) - 1 > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, long, -(long) (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) (((long)-1)*(((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
                case 4:
                    if (8 * sizeof(long) > 3 * PyLong_SHIFT) {
                        if (8 * sizeof(unsigned long) > 4 * PyLong_SHIFT) {
                            __PYX_VERIFY_RETURN_INT(long, unsigned long, (((((((((unsigned long)digits[3]) << PyLong_SHIFT) | (unsigned long)digits[2]) << PyLong_SHIFT) | (unsigned long)digits[1]) << PyLong_SHIFT) | (unsigned long)digits[0])))
                        } else if (8 * sizeof(long) - 1 > 4 * PyLong_SHIFT) {
                            return (long) ((((((((((long)digits[3]) << PyLong_SHIFT) | (long)digits[2]) << PyLong_SHIFT) | (long)digits[1]) << PyLong_SHIFT) | (long)digits[0])));
                        }
                    }
                    break;
            }
#endif
            if (sizeof(long) <= sizeof(long)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, long, PyLong_AsLong(x))
#ifdef HAVE_LONG_LONG
            } else if (sizeof(long) <= sizeof(PY_LONG_LONG)) {
                __PYX_VERIFY_RETURN_INT_EXC(long, PY_LONG_LONG, PyLong_AsLongLong(x))
#endif
            }
        }
        {
#if CYTHON_COMPILING_IN_PYPY && !defined(_PyLong_AsByteArray)
            PyErr_SetString(PyExc_RuntimeError,
                            "_PyLong_AsByteArray() not available in PyPy, cannot convert large numbers");
#else
            long val;
            PyObject *v = __Pyx_PyNumber_IntOrLong(x);
 #if PY_MAJOR_VERSION < 3
            if (likely(v) && !PyLong_Check(v)) {
                PyObject *tmp = v;
                v = PyNumber_Long(tmp);
                Py_DECREF(tmp);
            }
 #endif
            if (likely(v)) {
                int one = 1; int is_little = (int)*(unsigned char *)&one;
                unsigned char *bytes = (unsigned char *)&val;
                int ret = _PyLong_AsByteArray((PyLongObject *)v,
                                              bytes, sizeof(val),
                                              is_little, !is_unsigned);
                Py_DECREF(v);
                if (likely(!ret))
                    return val;
            }
#endif
            return (long) -1;
        }
    } else {
        long val;
        PyObject *tmp = __Pyx_PyNumber_IntOrLong(x);
        if (!tmp) return (long) -1;
        val = __Pyx_PyInt_As_long(tmp);
        Py_DECREF(tmp);
        return val;
    }
raise_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "value too large to convert to long");
    return (long) -1;
raise_neg_overflow:
    PyErr_SetString(PyExc_OverflowError,
        "can't convert negative value to long");
    return (long) -1;
}

/* FastTypeChecks */
#if CYTHON_COMPILING_IN_CPYTHON
static int __Pyx_InBases(PyTypeObject *a, PyTypeObject *b) {
    while (a) {
        a = a->tp_base;
        if (a == b)
            return 1;
    }
    return b == &PyBaseObject_Type;
}
static CYTHON_INLINE int __Pyx_IsSubtype(PyTypeObject *a, PyTypeObject *b) {
    PyObject *mro;
    if (a == b) return 1;
    mro = a->tp_mro;
    if (likely(mro)) {
        Py_ssize_t i, n;
        n = PyTuple_GET_SIZE(mro);
        for (i = 0; i < n; i++) {
            if (PyTuple_GET_ITEM(mro, i) == (PyObject *)b)
                return 1;
        }
        return 0;
    }
    return __Pyx_InBases(a, b);
}
#if PY_MAJOR_VERSION == 2
static int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject* exc_type2) {
    PyObject *exception, *value, *tb;
    int res;
    __Pyx_PyThreadState_declare
    __Pyx_PyThreadState_assign
    __Pyx_ErrFetch(&exception, &value, &tb);
    res = exc_type1 ? PyObject_IsSubclass(err, exc_type1) : 0;
    if (unlikely(res == -1)) {
        PyErr_WriteUnraisable(err);
        res = 0;
    }
    if (!res) {
        res = PyObject_IsSubclass(err, exc_type2);
        if (unlikely(res == -1)) {
            PyErr_WriteUnraisable(err);
            res = 0;
        }
    }
    __Pyx_ErrRestore(exception, value, tb);
    return res;
}
#else
static CYTHON_INLINE int __Pyx_inner_PyErr_GivenExceptionMatches2(PyObject *err, PyObject* exc_type1, PyObject *exc_type2) {
    int res = exc_type1 ? __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type1) : 0;
    if (!res) {
        res = __Pyx_IsSubtype((PyTypeObject*)err, (PyTypeObject*)exc_type2);
    }
    return res;
}
#endif
static int __Pyx_PyErr_GivenExceptionMatchesTuple(PyObject *exc_type, PyObject *tuple) {
    Py_ssize_t i, n;
    assert(PyExceptionClass_Check(exc_type));
    n = PyTuple_GET_SIZE(tuple);
#if PY_MAJOR_VERSION >= 3
    for (i=0; i<n; i++) {
        if (exc_type == PyTuple_GET_ITEM(tuple, i)) return 1;
    }
#endif
    for (i=0; i<n; i++) {
        PyObject *t = PyTuple_GET_ITEM(tuple, i);
        #if PY_MAJOR_VERSION < 3
        if (likely(exc_type == t)) return 1;
        #endif
        if (likely(PyExceptionClass_Check(t))) {
            if (__Pyx_inner_PyErr_GivenExceptionMatches2(exc_type, NULL, t)) return 1;
        } else {
        }
    }
    return 0;
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches(PyObject *err, PyObject* exc_type) {
    if (likely(err == exc_type)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        if (likely(PyExceptionClass_Check(exc_type))) {
            return __Pyx_inner_PyErr_GivenExceptionMatches2(err, NULL, exc_type);
        } else if (likely(PyTuple_Check(exc_type))) {
            return __Pyx_PyErr_GivenExceptionMatchesTuple(err, exc_type);
        } else {
        }
    }
    return PyErr_GivenExceptionMatches(err, exc_type);
}
static CYTHON_INLINE int __Pyx_PyErr_GivenExceptionMatches2(PyObject *err, PyObject *exc_type1, PyObject *exc_type2) {
    assert(PyExceptionClass_Check(exc_type1));
    assert(PyExceptionClass_Check(exc_type2));
    if (likely(err == exc_type1 || err == exc_type2)) return 1;
    if (likely(PyExceptionClass_Check(err))) {
        return __Pyx_inner_PyErr_GivenExceptionMatches2(err, exc_type1, exc_type2);
    }
    return (PyErr_GivenExceptionMatches(err, exc_type1) || PyErr_GivenExceptionMatches(err, exc_type2));
}
#endif

/* CheckBinaryVersion */
static int __Pyx_check_binary_version(void) {
    char ctversion[4], rtversion[4];
    PyOS_snprintf(ctversion, 4, "%d.%d", PY_MAJOR_VERSION, PY_MINOR_VERSION);
    PyOS_snprintf(rtversion, 4, "%s", Py_GetVersion());
    if (ctversion[0] != rtversion[0] || ctversion[2] != rtversion[2]) {
        char message[200];
        PyOS_snprintf(message, sizeof(message),
                      "compiletime version %s of module '%.100s' "
                      "does not match runtime version %s",
                      ctversion, __Pyx_MODULE_NAME, rtversion);
        return PyErr_WarnEx(NULL, message, 1);
    }
    return 0;
}

/* InitStrings */
static int __Pyx_InitStrings(__Pyx_StringTabEntry *t) {
    while (t->p) {
        #if PY_MAJOR_VERSION < 3
        if (t->is_unicode) {
            *t->p = PyUnicode_DecodeUTF8(t->s, t->n - 1, NULL);
        } else if (t->intern) {
            *t->p = PyString_InternFromString(t->s);
        } else {
            *t->p = PyString_FromStringAndSize(t->s, t->n - 1);
        }
        #else
        if (t->is_unicode | t->is_str) {
            if (t->intern) {
                *t->p = PyUnicode_InternFromString(t->s);
            } else if (t->encoding) {
                *t->p = PyUnicode_Decode(t->s, t->n - 1, t->encoding, NULL);
            } else {
                *t->p = PyUnicode_FromStringAndSize(t->s, t->n - 1);
            }
        } else {
            *t->p = PyBytes_FromStringAndSize(t->s, t->n - 1);
        }
        #endif
        if (!*t->p)
            return -1;
        if (PyObject_Hash(*t->p) == -1)
            return -1;
        ++t;
    }
    return 0;
}

static CYTHON_INLINE PyObject* __Pyx_PyUnicode_FromString(const char* c_str) {
    return __Pyx_PyUnicode_FromStringAndSize(c_str, (Py_ssize_t)strlen(c_str));
}
static CYTHON_INLINE const char* __Pyx_PyObject_AsString(PyObject* o) {
    Py_ssize_t ignore;
    return __Pyx_PyObject_AsStringAndSize(o, &ignore);
}
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
#if !CYTHON_PEP393_ENABLED
static const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    char* defenc_c;
    PyObject* defenc = _PyUnicode_AsDefaultEncodedString(o, NULL);
    if (!defenc) return NULL;
    defenc_c = PyBytes_AS_STRING(defenc);
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    {
        char* end = defenc_c + PyBytes_GET_SIZE(defenc);
        char* c;
        for (c = defenc_c; c < end; c++) {
            if ((unsigned char) (*c) >= 128) {
                PyUnicode_AsASCIIString(o);
                return NULL;
            }
        }
    }
#endif
    *length = PyBytes_GET_SIZE(defenc);
    return defenc_c;
}
#else
static CYTHON_INLINE const char* __Pyx_PyUnicode_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
    if (unlikely(__Pyx_PyUnicode_READY(o) == -1)) return NULL;
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
    if (likely(PyUnicode_IS_ASCII(o))) {
        *length = PyUnicode_GET_LENGTH(o);
        return PyUnicode_AsUTF8(o);
    } else {
        PyUnicode_AsASCIIString(o);
        return NULL;
    }
#else
    return PyUnicode_AsUTF8AndSize(o, length);
#endif
}
#endif
#endif
static CYTHON_INLINE const char* __Pyx_PyObject_AsStringAndSize(PyObject* o, Py_ssize_t *length) {
#if __PYX_DEFAULT_STRING_ENCODING_IS_ASCII || __PYX_DEFAULT_STRING_ENCODING_IS_DEFAULT
    if (
#if PY_MAJOR_VERSION < 3 && __PYX_DEFAULT_STRING_ENCODING_IS_ASCII
            __Pyx_sys_getdefaultencoding_not_ascii &&
#endif
            PyUnicode_Check(o)) {
        return __Pyx_PyUnicode_AsStringAndSize(o, length);
    } else
#endif
#if (!CYTHON_COMPILING_IN_PYPY) || (defined(PyByteArray_AS_STRING) && defined(PyByteArray_GET_SIZE))
    if (PyByteArray_Check(o)) {
        *length = PyByteArray_GET_SIZE(o);
        return PyByteArray_AS_STRING(o);
    } else
#endif
    {
        char* result;
        int r = PyBytes_AsStringAndSize(o, &result, length);
        if (unlikely(r < 0)) {
            return NULL;
        } else {
            return result;
        }
    }
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrue(PyObject* x) {
   int is_true = x == Py_True;
   if (is_true | (x == Py_False) | (x == Py_None)) return is_true;
   else return PyObject_IsTrue(x);
}
static CYTHON_INLINE int __Pyx_PyObject_IsTrueAndDecref(PyObject* x) {
    int retval;
    if (unlikely(!x)) return -1;
    retval = __Pyx_PyObject_IsTrue(x);
    Py_DECREF(x);
    return retval;
}
static PyObject* __Pyx_PyNumber_IntOrLongWrongResultType(PyObject* result, const char* type_name) {
#if PY_MAJOR_VERSION >= 3
    if (PyLong_Check(result)) {
        if (PyErr_WarnFormat(PyExc_DeprecationWarning, 1,
                "__int__ returned non-int (type %.200s).  "
                "The ability to return an instance of a strict subclass of int "
                "is deprecated, and may be removed in a future version of Python.",
                Py_TYPE(result)->tp_name)) {
            Py_DECREF(result);
            return NULL;
        }
        return result;
    }
#endif
    PyErr_Format(PyExc_TypeError,
                 "__%.4s__ returned non-%.4s (type %.200s)",
                 type_name, type_name, Py_TYPE(result)->tp_name);
    Py_DECREF(result);
    return NULL;
}
static CYTHON_INLINE PyObject* __Pyx_PyNumber_IntOrLong(PyObject* x) {
#if CYTHON_USE_TYPE_SLOTS
  PyNumberMethods *m;
#endif
  const char *name = NULL;
  PyObject *res = NULL;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_Check(x) || PyLong_Check(x)))
#else
  if (likely(PyLong_Check(x)))
#endif
    return __Pyx_NewRef(x);
#if CYTHON_USE_TYPE_SLOTS
  m = Py_TYPE(x)->tp_as_number;
  #if PY_MAJOR_VERSION < 3
  if (m && m->nb_int) {
    name = "int";
    res = m->nb_int(x);
  }
  else if (m && m->nb_long) {
    name = "long";
    res = m->nb_long(x);
  }
  #else
  if (likely(m && m->nb_int)) {
    name = "int";
    res = m->nb_int(x);
  }
  #endif
#else
  if (!PyBytes_CheckExact(x) && !PyUnicode_CheckExact(x)) {
    res = PyNumber_Int(x);
  }
#endif
  if (likely(res)) {
#if PY_MAJOR_VERSION < 3
    if (unlikely(!PyInt_Check(res) && !PyLong_Check(res))) {
#else
    if (unlikely(!PyLong_CheckExact(res))) {
#endif
        return __Pyx_PyNumber_IntOrLongWrongResultType(res, name);
    }
  }
  else if (!PyErr_Occurred()) {
    PyErr_SetString(PyExc_TypeError,
                    "an integer is required");
  }
  return res;
}
static CYTHON_INLINE Py_ssize_t __Pyx_PyIndex_AsSsize_t(PyObject* b) {
  Py_ssize_t ival;
  PyObject *x;
#if PY_MAJOR_VERSION < 3
  if (likely(PyInt_CheckExact(b))) {
    if (sizeof(Py_ssize_t) >= sizeof(long))
        return PyInt_AS_LONG(b);
    else
        return PyInt_AsSsize_t(b);
  }
#endif
  if (likely(PyLong_CheckExact(b))) {
    #if CYTHON_USE_PYLONG_INTERNALS
    const digit* digits = ((PyLongObject*)b)->ob_digit;
    const Py_ssize_t size = Py_SIZE(b);
    if (likely(__Pyx_sst_abs(size) <= 1)) {
        ival = likely(size) ? digits[0] : 0;
        if (size == -1) ival = -ival;
        return ival;
    } else {
      switch (size) {
         case 2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -2:
           if (8 * sizeof(Py_ssize_t) > 2 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -3:
           if (8 * sizeof(Py_ssize_t) > 3 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case 4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return (Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
         case -4:
           if (8 * sizeof(Py_ssize_t) > 4 * PyLong_SHIFT) {
             return -(Py_ssize_t) (((((((((size_t)digits[3]) << PyLong_SHIFT) | (size_t)digits[2]) << PyLong_SHIFT) | (size_t)digits[1]) << PyLong_SHIFT) | (size_t)digits[0]));
           }
           break;
      }
    }
    #endif
    return PyLong_AsSsize_t(b);
  }
  x = PyNumber_Index(b);
  if (!x) return -1;
  ival = PyInt_AsSsize_t(x);
  Py_DECREF(x);
  return ival;
}
static CYTHON_INLINE PyObject * __Pyx_PyBool_FromLong(long b) {
  return b ? __Pyx_NewRef(Py_True) : __Pyx_NewRef(Py_False);
}
static CYTHON_INLINE PyObject * __Pyx_PyInt_FromSize_t(size_t ival) {
    return PyInt_FromSize_t(ival);
}


#endif /* Py_PYTHON_H */
